Class: TalonOne::AccountAdditionalCost

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/account_additional_cost.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountAdditionalCost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AccountAdditionalCost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AccountAdditionalCost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'session'
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 25

def 
  @account_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 22

def created
  @created
end

#descriptionObject

A description of this additional cost.



34
35
36
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 34

def description
  @description
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 19

def id
  @id
end

#nameObject

The internal name used in API requests.



28
29
30
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 28

def name
  @name
end

#subscribed_applications_idsObject

A list of the IDs of the applications that are subscribed to this additional cost.



37
38
39
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 37

def subscribed_applications_ids
  @subscribed_applications_ids
end

#titleObject

The human-readable name for the additional cost that will be shown in the Campaign Manager. Like ‘name`, the combination of entity and title must also be unique.



31
32
33
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 31

def title
  @title
end

#typeObject

The type of additional cost. Possible value: - ‘session`: Additional cost will be added per session. - `item`: Additional cost will be added per item. - `both`: Additional cost will be added per item and session.



40
41
42
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 40

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 351

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



109
110
111
112
113
114
115
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 109

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'NewAdditionalCost'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 89

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 323

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 338

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



344
345
346
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 344

def hash
  [id, created, , name, title, description, subscribed_applications_ids, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z]\w*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 373

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/account_additional_cost.rb', line 226

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[A-Za-z]\w*$/)
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  return false if @description.nil?
  type_validator = EnumAttributeValidator.new('String', ["session", "item", "both"])
  return false unless type_validator.valid?(@type)
  true
end