Class: TalonOne::AccountDashboardStatistic

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/account_dashboard_statistic.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountDashboardStatistic

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AccountDashboardStatistic` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AccountDashboardStatistic`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'revenue')
    if (value = attributes[:'revenue']).is_a?(Array)
      self.revenue = value
    end
  end

  if attributes.key?(:'discounts')
    if (value = attributes[:'discounts']).is_a?(Array)
      self.discounts = value
    end
  end

  if attributes.key?(:'loyalty_points')
    if (value = attributes[:'loyalty_points']).is_a?(Array)
      self.loyalty_points = value
    end
  end

  if attributes.key?(:'referrals')
    if (value = attributes[:'referrals']).is_a?(Array)
      self.referrals = value
    end
  end

  if attributes.key?(:'campaigns')
    self.campaigns = attributes[:'campaigns']
  else
    self.campaigns = nil
  end
end

Instance Attribute Details

#campaignsObject

Returns the value of attribute campaigns.



30
31
32
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 30

def campaigns
  @campaigns
end

#discountsObject

Aggregated statistic for account discount.



22
23
24
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 22

def discounts
  @discounts
end

#loyalty_pointsObject

Aggregated statistic for account loyalty points.



25
26
27
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 25

def loyalty_points
  @loyalty_points
end

#referralsObject

Aggregated statistic for account referrals.



28
29
30
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 28

def referrals
  @referrals
end

#revenueObject

Aggregated statistic for account revenue.



19
20
21
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 19

def revenue
  @revenue
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 33

def self.attribute_map
  {
    :'revenue' => :'revenue',
    :'discounts' => :'discounts',
    :'loyalty_points' => :'loyaltyPoints',
    :'referrals' => :'referrals',
    :'campaigns' => :'campaigns'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 54

def self.openapi_types
  {
    :'revenue' => :'Array<AccountDashboardStatisticRevenue>',
    :'discounts' => :'Array<AccountDashboardStatisticDiscount>',
    :'loyalty_points' => :'Array<AccountDashboardStatisticLoyaltyPoints>',
    :'referrals' => :'Array<AccountDashboardStatisticReferrals>',
    :'campaigns' => :'AccountDashboardStatisticCampaigns'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
157
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      revenue == o.revenue &&
      discounts == o.discounts &&
      loyalty_points == o.loyalty_points &&
      referrals == o.referrals &&
      campaigns == o.campaigns
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 167

def hash
  [revenue, discounts, loyalty_points, referrals, campaigns].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @campaigns.nil?
    invalid_properties.push('invalid value for "campaigns", campaigns cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
# File 'lib/talon_one_sdk/models/account_dashboard_statistic.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @campaigns.nil?
  true
end