Class: TalonOne::AchievementAdditionalProperties

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/achievement_additional_properties.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AchievementAdditionalProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementAdditionalProperties` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementAdditionalProperties`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'has_progress')
    self.has_progress = attributes[:'has_progress']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#campaign_idObject

The ID of the campaign the achievement belongs to.



19
20
21
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 19

def campaign_id
  @campaign_id
end

#created_byObject

Name of the user that created the achievement. Note: This is not available if the user has been deleted.



25
26
27
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 25

def created_by
  @created_by
end

#has_progressObject

Indicates if a customer has made progress in the achievement.



28
29
30
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 28

def has_progress
  @has_progress
end

#statusObject

The status of the achievement.



31
32
33
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 31

def status
  @status
end

#user_idObject

ID of the user that created this achievement.



22
23
24
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 22

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 56

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'user_id' => :'userId',
    :'created_by' => :'createdBy',
    :'has_progress' => :'hasProgress',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 77

def self.openapi_types
  {
    :'campaign_id' => :'Integer',
    :'user_id' => :'Integer',
    :'created_by' => :'String',
    :'has_progress' => :'Boolean',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      user_id == o.user_id &&
      created_by == o.created_by &&
      has_progress == o.has_progress &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 211

def hash
  [campaign_id, user_id, created_by, has_progress, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/achievement_additional_properties.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @campaign_id.nil?
  return false if @user_id.nil?
  status_validator = EnumAttributeValidator.new('String', ["inprogress", "expired", "not_started", "completed"])
  return false unless status_validator.valid?(@status)
  true
end