Class: TalonOne::AchievementAdditionalPropertiesV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AchievementAdditionalPropertiesV2
- Defined in:
- lib/talon_one_sdk/models/achievement_additional_properties_v2.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_by ⇒ Object
Name of the user that created the achievement.
-
#has_progress ⇒ Object
Indicates if a customer has made progress in the achievement.
-
#status ⇒ Object
The status of the achievement.
-
#user_id ⇒ Object
The ID of the user that created this achievement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AchievementAdditionalPropertiesV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AchievementAdditionalPropertiesV2
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementAdditionalPropertiesV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementAdditionalPropertiesV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'has_progress') self.has_progress = attributes[:'has_progress'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#created_by ⇒ Object
Name of the user that created the achievement. Note: This is not available if the user has been deleted.
22 23 24 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 22 def created_by @created_by end |
#has_progress ⇒ Object
Indicates if a customer has made progress in the achievement.
25 26 27 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 25 def has_progress @has_progress end |
#status ⇒ Object
The status of the achievement.
28 29 30 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 28 def status @status end |
#user_id ⇒ Object
The ID of the user that created this achievement.
19 20 21 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 19 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 53 def self.attribute_map { :'user_id' => :'userId', :'created_by' => :'createdBy', :'has_progress' => :'hasProgress', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 73 def self.openapi_types { :'user_id' => :'Integer', :'created_by' => :'String', :'has_progress' => :'Boolean', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && created_by == o.created_by && has_progress == o.has_progress && status == o.status end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 184 def hash [user_id, created_by, has_progress, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 143 |
# File 'lib/talon_one_sdk/models/achievement_additional_properties_v2.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user_id.nil? status_validator = EnumAttributeValidator.new('String', ["inprogress", "expired", "not_started", "completed"]) return false unless status_validator.valid?(@status) true end |