Class: TalonOne::AchievementProgress

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/achievement_progress.rb

Overview

The current progress of the customer in the achievement.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AchievementProgress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementProgress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementProgress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  else
    self.progress = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'completion_date')
    self.completion_date = attributes[:'completion_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end
end

Instance Attribute Details

#completion_dateObject

Timestamp at which point the customer completed the achievement.



29
30
31
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 29

def completion_date
  @completion_date
end

#end_dateObject

Timestamp at which point the achievement ends and resets for the customer.



32
33
34
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 32

def end_date
  @end_date
end

#progressObject

The current progress of the customer in the achievement.



23
24
25
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 23

def progress
  @progress
end

#start_dateObject

Timestamp at which the customer started the achievement.



26
27
28
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 26

def start_date
  @start_date
end

#statusObject

The status of the achievement.



20
21
22
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 57

def self.attribute_map
  {
    :'status' => :'status',
    :'progress' => :'progress',
    :'start_date' => :'startDate',
    :'completion_date' => :'completionDate',
    :'end_date' => :'endDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 209

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 78

def self.openapi_types
  {
    :'status' => :'String',
    :'progress' => :'Float',
    :'start_date' => :'Time',
    :'completion_date' => :'Time',
    :'end_date' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      progress == o.progress &&
      start_date == o.start_date &&
      completion_date == o.completion_date &&
      end_date == o.end_date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 202

def hash
  [status, progress, start_date, completion_date, end_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @progress.nil?
    invalid_properties.push('invalid value for "progress", progress cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/achievement_progress.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["inprogress", "completed", "expired", "not_started"])
  return false unless status_validator.valid?(@status)
  return false if @progress.nil?
  true
end