Class: TalonOne::AchievementStatusEntry

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/achievement_status_entry.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AchievementStatusEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 156

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementStatusEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementStatusEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'period_end_override')
    self.period_end_override = attributes[:'period_end_override']
  end

  if attributes.key?(:'recurrence_policy')
    self.recurrence_policy = attributes[:'recurrence_policy']
  end

  if attributes.key?(:'activation_policy')
    self.activation_policy = attributes[:'activation_policy']
  end

  if attributes.key?(:'fixed_start_date')
    self.fixed_start_date = attributes[:'fixed_start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'allow_rollback_after_completion')
    self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'current_progress')
    self.current_progress = attributes[:'current_progress']
  end
end

Instance Attribute Details

#activation_policyObject

The policy that determines how the achievement starts, ends, or resets. - ‘user_action`: The achievement ends or resets relative to when the customer started the achievement. - `fixed_schedule`: The achievement starts, ends, or resets for all customers following a fixed schedule.



45
46
47
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 45

def activation_policy
  @activation_policy
end

#allow_rollback_after_completionObject

When ‘true`, customer progress can be rolled back in completed achievements.



54
55
56
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 54

def allow_rollback_after_completion
  @allow_rollback_after_completion
end

#campaign_idObject

The ID of the campaign the achievement belongs to.



57
58
59
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 57

def campaign_id
  @campaign_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 22

def created
  @created
end

#current_progressObject

Returns the value of attribute current_progress.



62
63
64
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 62

def current_progress
  @current_progress
end

#descriptionObject

A description of the achievement.



31
32
33
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 31

def description
  @description
end

#end_dateObject

The achievement’s end date. If defined, customers cannot participate in the achievement after this date. Note: It must be an RFC3339 timestamp string.



51
52
53
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 51

def end_date
  @end_date
end

#fixed_start_dateObject

The achievement’s start date when ‘activationPolicy` is set to `fixed_schedule`. Note: It must be an RFC3339 timestamp string.



48
49
50
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 48

def fixed_start_date
  @fixed_start_date
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 19

def id
  @id
end

#nameObject

The internal name of the achievement used in API requests. Note: The name should start with a letter. This cannot be changed after the achievement has been created.



25
26
27
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 25

def name
  @name
end

#periodObject

The relative duration after which the achievement ends and resets for a particular customer profile. Note: The ‘period` does not start when the achievement is created. The period is a **positive real number** followed by one letter indicating the time unit. Examples: `30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can also round certain units down to the beginning of period and up to the end of period.: - `_D` for rounding down days only. Signifies the start of the day. Example: `30D_D` - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. Example: `23W_U` Note: You can either use the round down and round up option or set an absolute period.



37
38
39
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 37

def period
  @period
end

#period_end_overrideObject

Returns the value of attribute period_end_override.



39
40
41
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 39

def period_end_override
  @period_end_override
end

#recurrence_policyObject

The policy that determines if and how the achievement recurs. - ‘no_recurrence`: The achievement can be completed only once. - `on_expiration`: The achievement resets after it expires and becomes available again. - `on_completion`: When the customer progress status reaches `completed`, the achievement resets and becomes available again.



42
43
44
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 42

def recurrence_policy
  @recurrence_policy
end

#statusObject

The status of the achievement.



60
61
62
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 60

def status
  @status
end

#targetObject

The required number of actions or the transactional milestone to complete the achievement.



34
35
36
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 34

def target
  @target
end

#titleObject

The display name for the achievement in the Campaign Manager.



28
29
30
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 28

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



109
110
111
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 109

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 114

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 87

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'target' => :'target',
    :'period' => :'period',
    :'period_end_override' => :'periodEndOverride',
    :'recurrence_policy' => :'recurrencePolicy',
    :'activation_policy' => :'activationPolicy',
    :'fixed_start_date' => :'fixedStartDate',
    :'end_date' => :'endDate',
    :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion',
    :'campaign_id' => :'campaignId',
    :'status' => :'status',
    :'current_progress' => :'currentProgress'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 455

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



147
148
149
150
151
152
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 147

def self.openapi_all_of
  [
  :'CreateAchievement',
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 141

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 119

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'target' => :'Float',
    :'period' => :'String',
    :'period_end_override' => :'TimePoint',
    :'recurrence_policy' => :'String',
    :'activation_policy' => :'String',
    :'fixed_start_date' => :'Time',
    :'end_date' => :'Time',
    :'allow_rollback_after_completion' => :'Boolean',
    :'campaign_id' => :'Integer',
    :'status' => :'String',
    :'current_progress' => :'AchievementProgress'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 419

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      target == o.target &&
      period == o.period &&
      period_end_override == o.period_end_override &&
      recurrence_policy == o.recurrence_policy &&
      activation_policy == o.activation_policy &&
      fixed_start_date == o.fixed_start_date &&
      end_date == o.end_date &&
      allow_rollback_after_completion == o.allow_rollback_after_completion &&
      campaign_id == o.campaign_id &&
      status == o.status &&
      current_progress == o.current_progress
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


442
443
444
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 442

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



448
449
450
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 448

def hash
  [id, created, name, title, description, target, period, period_end_override, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion, campaign_id, status, current_progress].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 249

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 1000
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]\w+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 477

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/talon_one_sdk/models/achievement_status_entry.rb', line 294

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 1000
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z]\w+$/)
  return false if @title.nil?
  return false if @description.nil?
  return false if @target.nil?
  recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"])
  return false unless recurrence_policy_validator.valid?(@recurrence_policy)
  activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"])
  return false unless activation_policy_validator.valid?(@activation_policy)
  status_validator = EnumAttributeValidator.new('String', ["active", "scheduled"])
  return false unless status_validator.valid?(@status)
  true
end