Class: TalonOne::AddItemCatalogAction

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/add_item_catalog_action.rb

Overview

The specific properties of the "ADD" catalog sync action.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AddItemCatalogAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddItemCatalogAction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddItemCatalogAction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  else
    self.sku = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.key?(:'replace_if_exists')
    self.replace_if_exists = attributes[:'replace_if_exists']
  else
    self.replace_if_exists = false
  end
end

Instance Attribute Details

#attributesObject

The attributes of the item to add.



26
27
28
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 26

def attributes
  @attributes
end

#priceObject

Price of the item.



23
24
25
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 23

def price
  @price
end

#productObject

Returns the value of attribute product.



28
29
30
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 28

def product
  @product
end

#replace_if_existsObject

Indicates whether to replace the attributes of the item if the same SKU exists. Note: When set to ‘true`: - If you do not provide a new `price` value, the existing `price` value is retained. - If you do not provide a new `product` value, the `product` value is set to `null`.



31
32
33
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 31

def replace_if_exists
  @replace_if_exists
end

#skuObject

The unique SKU of the item to add.



20
21
22
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 20

def sku
  @sku
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 34

def self.attribute_map
  {
    :'sku' => :'sku',
    :'price' => :'price',
    :'attributes' => :'attributes',
    :'product' => :'product',
    :'replace_if_exists' => :'replaceIfExists'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 55

def self.openapi_types
  {
    :'sku' => :'String',
    :'price' => :'Float',
    :'attributes' => :'Object',
    :'product' => :'Product',
    :'replace_if_exists' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sku == o.sku &&
      price == o.price &&
      attributes == o.attributes &&
      product == o.product &&
      replace_if_exists == o.replace_if_exists
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 162

def hash
  [sku, price, attributes, product, replace_if_exists].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
130
# File 'lib/talon_one_sdk/models/add_item_catalog_action.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @sku.nil?
  true
end