Class: TalonOne::AddLoyaltyPointsSupport

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/add_loyalty_points_support.rb

Overview

Points to add via the support portal.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AddLoyaltyPointsSupport

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddLoyaltyPointsSupport` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddLoyaltyPointsSupport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'points')
    self.points = attributes[:'points']
  else
    self.points = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'validity_duration')
    self.validity_duration = attributes[:'validity_duration']
  end

  if attributes.key?(:'valid_until')
    self.valid_until = attributes[:'valid_until']
  end

  if attributes.key?(:'pending_duration')
    self.pending_duration = attributes[:'pending_duration']
  end

  if attributes.key?(:'pending_until')
    self.pending_until = attributes[:'pending_until']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'support_request_id')
    self.support_request_id = attributes[:'support_request_id']
  end

  if attributes.key?(:'processing_note')
    self.processing_note = attributes[:'processing_note']
  end
end

Instance Attribute Details

#application_idObject

ID of the Application that is connected to the loyalty program. It is displayed in your Talon.One deployment URL.



41
42
43
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 41

def application_id
  @application_id
end

#nameObject

Name / reason for the point addition.



23
24
25
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 23

def name
  @name
end

#pending_durationObject

The amount of time before the points are considered valid. The time format is either: - immediate or, - on_action or, - an integer followed by one letter indicating the time unit. Examples: immediate, 30s, 40m, 1h, 5D, 7W, 10M, 15Y, on_action. Available units: - s: seconds - m: minutes - h: hours - D: days - W: weeks - M: months - Y: years You can round certain units up or down: - _D for rounding down days only. Signifies the start of the day. - _U for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year.



32
33
34
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 32

def pending_duration
  @pending_duration
end

#pending_untilObject

Date and time after the points are considered valid. The value should be provided in RFC 3339 format. If passed, pendingDuration should be omitted.



35
36
37
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 35

def pending_until
  @pending_until
end

#pointsObject

Amount of loyalty points.



20
21
22
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 20

def points
  @points
end

#processing_noteObject

Note from the admin approving the support request. Stored as the processing note on the support request record. This is only used when a supportRequestId is passed.



47
48
49
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 47

def processing_note
  @processing_note
end

#subledger_idObject

ID of the subledger the points are added to. If there is no existing subledger with this ID, the subledger is created automatically.



38
39
40
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 38

def subledger_id
  @subledger_id
end

#support_request_idObject

ID of the support request to approve. When provided by an admin, the points are added on behalf of the support user who created the request.



44
45
46
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 44

def support_request_id
  @support_request_id
end

#valid_untilObject

Date and time when points should expire. The value should be provided in RFC 3339 format. If passed, validityDuration should be omitted.



29
30
31
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 29

def valid_until
  @valid_until
end

#validity_durationObject

The time format is either: - unlimited or, - an integer followed by one letter indicating the time unit. Examples: unlimited, 30s, 40m, 1h, 5D, 7W, 10M, 15Y. Available units: - s: seconds - m: minutes - h: hours - D: days - W: weeks - M: months - Y: years You can round certain units up or down: - _D for rounding down days only. Signifies the start of the day. - _U for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. If passed, validUntil should be omitted.



26
27
28
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 26

def validity_duration
  @validity_duration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 50

def self.attribute_map
  {
    :'points' => :'points',
    :'name' => :'name',
    :'validity_duration' => :'validityDuration',
    :'valid_until' => :'validUntil',
    :'pending_duration' => :'pendingDuration',
    :'pending_until' => :'pendingUntil',
    :'subledger_id' => :'subledgerId',
    :'application_id' => :'applicationId',
    :'support_request_id' => :'supportRequestId',
    :'processing_note' => :'processingNote'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



98
99
100
101
102
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 98

def self.openapi_all_of
  [
  :'AddLoyaltyPoints'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 76

def self.openapi_types
  {
    :'points' => :'Float',
    :'name' => :'String',
    :'validity_duration' => :'String',
    :'valid_until' => :'Time',
    :'pending_duration' => :'String',
    :'pending_until' => :'Time',
    :'subledger_id' => :'String',
    :'application_id' => :'Integer',
    :'support_request_id' => :'Integer',
    :'processing_note' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      points == o.points &&
      name == o.name &&
      validity_duration == o.validity_duration &&
      valid_until == o.valid_until &&
      pending_duration == o.pending_duration &&
      pending_until == o.pending_until &&
      subledger_id == o.subledger_id &&
      application_id == o.application_id &&
      support_request_id == o.support_request_id &&
      processing_note == o.processing_note
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 236

def hash
  [points, name, validity_duration, valid_until, pending_duration, pending_until, subledger_id, application_id, support_request_id, processing_note].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @points.nil?
    invalid_properties.push('invalid value for "points", points cannot be nil.')
  end

  if @points > 999999999999.99
    invalid_properties.push('invalid value for "points", must be smaller than or equal to 999999999999.99.')
  end

  if @points <= 0
    invalid_properties.push('invalid value for "points", must be greater than 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/add_loyalty_points_support.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @points.nil?
  return false if @points > 999999999999.99
  return false if @points <= 0
  true
end