Class: TalonOne::AddedDeductedPointsBalancesAction

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/added_deducted_points_balances_action.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AddedDeductedPointsBalancesAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddedDeductedPointsBalancesAction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddedDeductedPointsBalancesAction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  else
    self.operation = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end
end

Instance Attribute Details

#amountObject

The amount of added or deducted loyalty points.



19
20
21
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 19

def amount
  @amount
end

#expiry_dateObject

The expiration date for loyalty points.



31
32
33
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 31

def expiry_date
  @expiry_date
end

#operationObject

The action (addition or subtraction) made with loyalty points.



25
26
27
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 25

def operation
  @operation
end

#reasonObject

The reason for the points addition or deduction.



22
23
24
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 22

def reason
  @reason
end

#start_dateObject

The start date for loyalty points.



28
29
30
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 28

def start_date
  @start_date
end

#transaction_uuidObject

The identifier of the transaction in the loyalty ledger.



34
35
36
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 34

def transaction_uuid
  @transaction_uuid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 59

def self.attribute_map
  {
    :'amount' => :'Amount',
    :'reason' => :'Reason',
    :'operation' => :'Operation',
    :'start_date' => :'StartDate',
    :'expiry_date' => :'ExpiryDate',
    :'transaction_uuid' => :'TransactionUUID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 252

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 81

def self.openapi_types
  {
    :'amount' => :'Float',
    :'reason' => :'String',
    :'operation' => :'String',
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'transaction_uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      reason == o.reason &&
      operation == o.operation &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      transaction_uuid == o.transaction_uuid
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


239
240
241
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



245
246
247
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 245

def hash
  [amount, reason, operation, start_date, expiry_date, transaction_uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  if @operation.nil?
    invalid_properties.push('invalid value for "operation", operation cannot be nil.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/added_deducted_points_balances_action.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @reason.nil?
  return false if @operation.nil?
  operation_validator = EnumAttributeValidator.new('String', ["addition", "subtraction"])
  return false unless operation_validator.valid?(@operation)
  return false if @transaction_uuid.nil?
  true
end