Class: TalonOne::AdditionalCampaignProperties

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/additional_campaign_properties.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdditionalCampaignProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 195

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AdditionalCampaignProperties` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AdditionalCampaignProperties`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'budgets')
    if (value = attributes[:'budgets']).is_a?(Array)
      self.budgets = value
    end
  end

  if attributes.key?(:'coupon_redemption_count')
    self.coupon_redemption_count = attributes[:'coupon_redemption_count']
  end

  if attributes.key?(:'referral_redemption_count')
    self.referral_redemption_count = attributes[:'referral_redemption_count']
  end

  if attributes.key?(:'discount_count')
    self.discount_count = attributes[:'discount_count']
  end

  if attributes.key?(:'discount_effect_count')
    self.discount_effect_count = attributes[:'discount_effect_count']
  end

  if attributes.key?(:'coupon_creation_count')
    self.coupon_creation_count = attributes[:'coupon_creation_count']
  end

  if attributes.key?(:'custom_effect_count')
    self.custom_effect_count = attributes[:'custom_effect_count']
  end

  if attributes.key?(:'referral_creation_count')
    self.referral_creation_count = attributes[:'referral_creation_count']
  end

  if attributes.key?(:'add_free_item_effect_count')
    self.add_free_item_effect_count = attributes[:'add_free_item_effect_count']
  end

  if attributes.key?(:'awarded_giveaways_count')
    self.awarded_giveaways_count = attributes[:'awarded_giveaways_count']
  end

  if attributes.key?(:'created_loyalty_points_count')
    self.created_loyalty_points_count = attributes[:'created_loyalty_points_count']
  end

  if attributes.key?(:'created_loyalty_points_effect_count')
    self.created_loyalty_points_effect_count = attributes[:'created_loyalty_points_effect_count']
  end

  if attributes.key?(:'redeemed_loyalty_points_count')
    self.redeemed_loyalty_points_count = attributes[:'redeemed_loyalty_points_count']
  end

  if attributes.key?(:'redeemed_loyalty_points_effect_count')
    self.redeemed_loyalty_points_effect_count = attributes[:'redeemed_loyalty_points_effect_count']
  end

  if attributes.key?(:'call_api_effect_count')
    self.call_api_effect_count = attributes[:'call_api_effect_count']
  end

  if attributes.key?(:'reservecoupon_effect_count')
    self.reservecoupon_effect_count = attributes[:'reservecoupon_effect_count']
  end

  if attributes.key?(:'last_activity')
    self.last_activity = attributes[:'last_activity']
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'frontend_state')
    self.frontend_state = attributes[:'frontend_state']
  else
    self.frontend_state = nil
  end

  if attributes.key?(:'stores_imported')
    self.stores_imported = attributes[:'stores_imported']
  else
    self.stores_imported = nil
  end

  if attributes.key?(:'value_maps_ids')
    if (value = attributes[:'value_maps_ids']).is_a?(Array)
      self.value_maps_ids = value
    end
  end

  if attributes.key?(:'experiment_id')
    self.experiment_id = attributes[:'experiment_id']
  end
end

Instance Attribute Details

#add_free_item_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of times the [add free item effect](docs.talon.one/docs/dev/integration-api/api-effects#addfreeitem) can be triggered in this campaign.



43
44
45
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 43

def add_free_item_effect_count
  @add_free_item_effect_count
end

#awarded_giveaways_countObject

This property is deprecated. The count should be available under budgets property. Total number of giveaways awarded by rules in this campaign.



46
47
48
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 46

def awarded_giveaways_count
  @awarded_giveaways_count
end

#budgetsObject

A list of all the budgets that are defined by this campaign and their usage. Note: Budgets that are not defined do not appear in this list and their usage is not counted until they are defined.



19
20
21
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 19

def budgets
  @budgets
end

#call_api_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of webhooks triggered by rules in this campaign.



61
62
63
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 61

def call_api_effect_count
  @call_api_effect_count
end

#coupon_creation_countObject

This property is deprecated. The count should be available under budgets property. Total number of coupons created by rules in this campaign.



34
35
36
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 34

def coupon_creation_count
  @coupon_creation_count
end

#coupon_redemption_countObject

This property is deprecated. The count should be available under budgets property. Number of coupons redeemed in the campaign.



22
23
24
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 22

def coupon_redemption_count
  @coupon_redemption_count
end

#created_byObject

Name of the user who created this campaign if available.



73
74
75
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 73

def created_by
  @created_by
end

#created_loyalty_points_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty points created by rules in this campaign.



49
50
51
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 49

def created_loyalty_points_count
  @created_loyalty_points_count
end

#created_loyalty_points_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty point creation effects triggered by rules in this campaign.



52
53
54
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 52

def created_loyalty_points_effect_count
  @created_loyalty_points_effect_count
end

#custom_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of custom effects triggered by rules in this campaign.



37
38
39
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 37

def custom_effect_count
  @custom_effect_count
end

#discount_countObject

This property is deprecated. The count should be available under budgets property. Total amount of discounts redeemed in the campaign.



28
29
30
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 28

def discount_count
  @discount_count
end

#discount_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of times discounts were redeemed in this campaign.



31
32
33
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 31

def discount_effect_count
  @discount_effect_count
end

#experiment_idObject

The ID of the Experiment this Campaign is part of.



91
92
93
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 91

def experiment_id
  @experiment_id
end

#frontend_stateObject

The campaign state displayed in the Campaign Manager.



82
83
84
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 82

def frontend_state
  @frontend_state
end

#last_activityObject

Timestamp of the most recent event received by this campaign.



67
68
69
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 67

def last_activity
  @last_activity
end

#redeemed_loyalty_points_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty points redeemed by rules in this campaign.



55
56
57
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 55

def redeemed_loyalty_points_count
  @redeemed_loyalty_points_count
end

#redeemed_loyalty_points_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty point redemption effects triggered by rules in this campaign.



58
59
60
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 58

def redeemed_loyalty_points_effect_count
  @redeemed_loyalty_points_effect_count
end

#referral_creation_countObject

This property is deprecated. The count should be available under budgets property. Total number of referrals created by rules in this campaign.



40
41
42
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 40

def referral_creation_count
  @referral_creation_count
end

#referral_redemption_countObject

This property is deprecated. The count should be available under budgets property. Number of referral codes redeemed in the campaign.



25
26
27
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 25

def referral_redemption_count
  @referral_redemption_count
end

#reservecoupon_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of reserve coupon effects triggered by rules in this campaign.



64
65
66
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 64

def reservecoupon_effect_count
  @reservecoupon_effect_count
end

#stores_importedObject

Indicates whether the linked stores were imported via a CSV file.



85
86
87
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 85

def stores_imported
  @stores_imported
end

#template_idObject

The ID of the Campaign Template this Campaign was created from.



79
80
81
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 79

def template_id
  @template_id
end

#updatedObject

Timestamp of the most recent update to the campaign’s property. Updates to external entities used in this campaign are not registered by this property, such as collection or coupon updates.



70
71
72
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 70

def updated
  @updated
end

#updated_byObject

Name of the user who last updated this campaign if available.



76
77
78
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 76

def updated_by
  @updated_by
end

#value_maps_idsObject

A list of value map IDs for the campaign.



88
89
90
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 88

def value_maps_ids
  @value_maps_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



147
148
149
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 147

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



152
153
154
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 152

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 116

def self.attribute_map
  {
    :'budgets' => :'budgets',
    :'coupon_redemption_count' => :'couponRedemptionCount',
    :'referral_redemption_count' => :'referralRedemptionCount',
    :'discount_count' => :'discountCount',
    :'discount_effect_count' => :'discountEffectCount',
    :'coupon_creation_count' => :'couponCreationCount',
    :'custom_effect_count' => :'customEffectCount',
    :'referral_creation_count' => :'referralCreationCount',
    :'add_free_item_effect_count' => :'addFreeItemEffectCount',
    :'awarded_giveaways_count' => :'awardedGiveawaysCount',
    :'created_loyalty_points_count' => :'createdLoyaltyPointsCount',
    :'created_loyalty_points_effect_count' => :'createdLoyaltyPointsEffectCount',
    :'redeemed_loyalty_points_count' => :'redeemedLoyaltyPointsCount',
    :'redeemed_loyalty_points_effect_count' => :'redeemedLoyaltyPointsEffectCount',
    :'call_api_effect_count' => :'callApiEffectCount',
    :'reservecoupon_effect_count' => :'reservecouponEffectCount',
    :'last_activity' => :'lastActivity',
    :'updated' => :'updated',
    :'created_by' => :'createdBy',
    :'updated_by' => :'updatedBy',
    :'template_id' => :'templateId',
    :'frontend_state' => :'frontendState',
    :'stores_imported' => :'storesImported',
    :'value_maps_ids' => :'valueMapsIds',
    :'experiment_id' => :'experimentId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 412

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



188
189
190
191
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 188

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 157

def self.openapi_types
  {
    :'budgets' => :'Array<CampaignBudget>',
    :'coupon_redemption_count' => :'Integer',
    :'referral_redemption_count' => :'Integer',
    :'discount_count' => :'Float',
    :'discount_effect_count' => :'Integer',
    :'coupon_creation_count' => :'Integer',
    :'custom_effect_count' => :'Integer',
    :'referral_creation_count' => :'Integer',
    :'add_free_item_effect_count' => :'Integer',
    :'awarded_giveaways_count' => :'Integer',
    :'created_loyalty_points_count' => :'Float',
    :'created_loyalty_points_effect_count' => :'Integer',
    :'redeemed_loyalty_points_count' => :'Float',
    :'redeemed_loyalty_points_effect_count' => :'Integer',
    :'call_api_effect_count' => :'Integer',
    :'reservecoupon_effect_count' => :'Integer',
    :'last_activity' => :'Time',
    :'updated' => :'Time',
    :'created_by' => :'String',
    :'updated_by' => :'String',
    :'template_id' => :'Integer',
    :'frontend_state' => :'String',
    :'stores_imported' => :'Boolean',
    :'value_maps_ids' => :'Array<Integer>',
    :'experiment_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 367

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      budgets == o.budgets &&
      coupon_redemption_count == o.coupon_redemption_count &&
      referral_redemption_count == o.referral_redemption_count &&
      discount_count == o.discount_count &&
      discount_effect_count == o.discount_effect_count &&
      coupon_creation_count == o.coupon_creation_count &&
      custom_effect_count == o.custom_effect_count &&
      referral_creation_count == o.referral_creation_count &&
      add_free_item_effect_count == o.add_free_item_effect_count &&
      awarded_giveaways_count == o.awarded_giveaways_count &&
      created_loyalty_points_count == o.created_loyalty_points_count &&
      created_loyalty_points_effect_count == o.created_loyalty_points_effect_count &&
      redeemed_loyalty_points_count == o.redeemed_loyalty_points_count &&
      redeemed_loyalty_points_effect_count == o.redeemed_loyalty_points_effect_count &&
      call_api_effect_count == o.call_api_effect_count &&
      reservecoupon_effect_count == o.reservecoupon_effect_count &&
      last_activity == o.last_activity &&
      updated == o.updated &&
      created_by == o.created_by &&
      updated_by == o.updated_by &&
      template_id == o.template_id &&
      frontend_state == o.frontend_state &&
      stores_imported == o.stores_imported &&
      value_maps_ids == o.value_maps_ids &&
      experiment_id == o.experiment_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


399
400
401
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 399

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



405
406
407
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 405

def hash
  [budgets, coupon_redemption_count, referral_redemption_count, discount_count, discount_effect_count, coupon_creation_count, custom_effect_count, referral_creation_count, add_free_item_effect_count, awarded_giveaways_count, created_loyalty_points_count, created_loyalty_points_effect_count, redeemed_loyalty_points_count, redeemed_loyalty_points_effect_count, call_api_effect_count, reservecoupon_effect_count, last_activity, updated, created_by, updated_by, template_id, frontend_state, stores_imported, value_maps_ids, experiment_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 320

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @frontend_state.nil?
    invalid_properties.push('invalid value for "frontend_state", frontend_state cannot be nil.')
  end

  if @stores_imported.nil?
    invalid_properties.push('invalid value for "stores_imported", stores_imported cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 434

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



336
337
338
339
340
341
342
343
# File 'lib/talon_one_sdk/models/additional_campaign_properties.rb', line 336

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @frontend_state.nil?
  frontend_state_validator = EnumAttributeValidator.new('String', ["expired", "scheduled", "running", "disabled", "archived", "staged"])
  return false unless frontend_state_validator.valid?(@frontend_state)
  return false if @stores_imported.nil?
  true
end