Class: TalonOne::AnalyticsSKU

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/analytics_sku.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsSKU

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AnalyticsSKU` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AnalyticsSKU`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  else
    self.sku = nil
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'catalog_id')
    self.catalog_id = attributes[:'catalog_id']
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  end

  if attributes.key?(:'units_sold')
    self.units_sold = attributes[:'units_sold']
  end
end

Instance Attribute Details

#catalog_idObject

The ID of the catalog that contains the SKU.



28
29
30
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 28

def catalog_id
  @catalog_id
end

#idObject

The ID of the SKU linked to the Application.



19
20
21
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 19

def id
  @id
end

#last_updatedObject

Values in UTC for the date the SKU linked to the product was last updated.



25
26
27
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 25

def last_updated
  @last_updated
end

#product_idObject

The ID of the product that the SKU belongs to.



31
32
33
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 31

def product_id
  @product_id
end

#skuObject

The SKU linked to the Application.



22
23
24
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 22

def sku
  @sku
end

#units_soldObject

The number of times the product or SKU was purchased.



34
35
36
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 34

def units_sold
  @units_sold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'sku' => :'sku',
    :'last_updated' => :'lastUpdated',
    :'catalog_id' => :'catalogId',
    :'product_id' => :'productId',
    :'units_sold' => :'unitsSold'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 194

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 59

def self.openapi_types
  {
    :'id' => :'Integer',
    :'sku' => :'String',
    :'last_updated' => :'Time',
    :'catalog_id' => :'Integer',
    :'product_id' => :'Integer',
    :'units_sold' => :'AnalyticsDataPointWithTrend'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
177
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      sku == o.sku &&
      last_updated == o.last_updated &&
      catalog_id == o.catalog_id &&
      product_id == o.product_id &&
      units_sold == o.units_sold
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 181

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



187
188
189
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 187

def hash
  [id, sku, last_updated, catalog_id, product_id, units_sold].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/analytics_sku.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @sku.nil?
  true
end