Class: TalonOne::Application

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/application.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Application

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/talon_one_sdk/models/application.rb', line 189

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Application` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Application`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'case_sensitivity')
    self.case_sensitivity = attributes[:'case_sensitivity']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'default_discount_scope')
    self.default_discount_scope = attributes[:'default_discount_scope']
  end

  if attributes.key?(:'enable_cascading_discounts')
    self.enable_cascading_discounts = attributes[:'enable_cascading_discounts']
  end

  if attributes.key?(:'enable_flattened_cart_items')
    self.enable_flattened_cart_items = attributes[:'enable_flattened_cart_items']
  end

  if attributes.key?(:'attributes_settings')
    self.attributes_settings = attributes[:'attributes_settings']
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'enable_partial_discounts')
    self.enable_partial_discounts = attributes[:'enable_partial_discounts']
  end

  if attributes.key?(:'default_discount_additional_cost_per_item_scope')
    self.default_discount_additional_cost_per_item_scope = attributes[:'default_discount_additional_cost_per_item_scope']
  end

  if attributes.key?(:'default_evaluation_group_id')
    self.default_evaluation_group_id = attributes[:'default_evaluation_group_id']
  end

  if attributes.key?(:'default_cart_item_filter_id')
    self.default_cart_item_filter_id = attributes[:'default_cart_item_filter_id']
  end

  if attributes.key?(:'enable_campaign_state_management')
    self.enable_campaign_state_management = attributes[:'enable_campaign_state_management']
  end

  if attributes.key?(:'loyalty_programs')
    if (value = attributes[:'loyalty_programs']).is_a?(Array)
      self.loyalty_programs = value
    end
  else
    self.loyalty_programs = nil
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



28
29
30
# File 'lib/talon_one_sdk/models/application.rb', line 28

def 
  @account_id
end

#attributesObject

Arbitrary properties associated with this campaign.



46
47
48
# File 'lib/talon_one_sdk/models/application.rb', line 46

def attributes
  @attributes
end

#attributes_settingsObject

Returns the value of attribute attributes_settings.



60
61
62
# File 'lib/talon_one_sdk/models/application.rb', line 60

def attributes_settings
  @attributes_settings
end

#case_sensitivityObject

The case sensitivity behavior to check coupon codes in the campaigns of this Application.



43
44
45
# File 'lib/talon_one_sdk/models/application.rb', line 43

def case_sensitivity
  @case_sensitivity
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/application.rb', line 22

def created
  @created
end

#currencyObject

The default currency for new customer sessions.



40
41
42
# File 'lib/talon_one_sdk/models/application.rb', line 40

def currency
  @currency
end

#default_cart_item_filter_idObject

The ID of the default Cart-Item-Filter for this application.



75
76
77
# File 'lib/talon_one_sdk/models/application.rb', line 75

def default_cart_item_filter_id
  @default_cart_item_filter_id
end

#default_discount_additional_cost_per_item_scopeObject

The default scope to apply ‘setDiscountPerItem` effects on if no scope was provided with the effect.



69
70
71
# File 'lib/talon_one_sdk/models/application.rb', line 69

def default_discount_additional_cost_per_item_scope
  @default_discount_additional_cost_per_item_scope
end

#default_discount_scopeObject

The default scope to apply ‘setDiscount` effects on if no scope was provided with the effect.



52
53
54
# File 'lib/talon_one_sdk/models/application.rb', line 52

def default_discount_scope
  @default_discount_scope
end

#default_evaluation_group_idObject

The ID of the default campaign evaluation group to which new campaigns will be added unless a different group is selected when creating the campaign.



72
73
74
# File 'lib/talon_one_sdk/models/application.rb', line 72

def default_evaluation_group_id
  @default_evaluation_group_id
end

#descriptionObject

A longer description of the application.



34
35
36
# File 'lib/talon_one_sdk/models/application.rb', line 34

def description
  @description
end

#enable_campaign_state_managementObject

Indicates whether the campaign staging and revisions feature is enabled for the Application. Important: After this feature is enabled, it cannot be disabled.



78
79
80
# File 'lib/talon_one_sdk/models/application.rb', line 78

def enable_campaign_state_management
  @enable_campaign_state_management
end

#enable_cascading_discountsObject

Indicates if discounts should cascade for this Application.



55
56
57
# File 'lib/talon_one_sdk/models/application.rb', line 55

def enable_cascading_discounts
  @enable_cascading_discounts
end

#enable_flattened_cart_itemsObject

Indicates if cart items of quantity larger than one should be separated into different items of quantity one.



58
59
60
# File 'lib/talon_one_sdk/models/application.rb', line 58

def enable_flattened_cart_items
  @enable_flattened_cart_items
end

#enable_partial_discountsObject

Indicates if this Application supports partial discounts.



66
67
68
# File 'lib/talon_one_sdk/models/application.rb', line 66

def enable_partial_discounts
  @enable_partial_discounts
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/application.rb', line 19

def id
  @id
end

#limitsObject

Default limits for campaigns created in this application.



49
50
51
# File 'lib/talon_one_sdk/models/application.rb', line 49

def limits
  @limits
end

#loyalty_programsObject

An array containing all the loyalty programs to which this application is subscribed.



81
82
83
# File 'lib/talon_one_sdk/models/application.rb', line 81

def loyalty_programs
  @loyalty_programs
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/application.rb', line 25

def modified
  @modified
end

#nameObject

The name of this application.



31
32
33
# File 'lib/talon_one_sdk/models/application.rb', line 31

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox Application.



63
64
65
# File 'lib/talon_one_sdk/models/application.rb', line 63

def sandbox
  @sandbox
end

#timezoneObject

A string containing an IANA timezone descriptor.



37
38
39
# File 'lib/talon_one_sdk/models/application.rb', line 37

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



134
135
136
# File 'lib/talon_one_sdk/models/application.rb', line 134

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



139
140
141
# File 'lib/talon_one_sdk/models/application.rb', line 139

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/talon_one_sdk/models/application.rb', line 106

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'description' => :'description',
    :'timezone' => :'timezone',
    :'currency' => :'currency',
    :'case_sensitivity' => :'caseSensitivity',
    :'attributes' => :'attributes',
    :'limits' => :'limits',
    :'default_discount_scope' => :'defaultDiscountScope',
    :'enable_cascading_discounts' => :'enableCascadingDiscounts',
    :'enable_flattened_cart_items' => :'enableFlattenedCartItems',
    :'attributes_settings' => :'attributesSettings',
    :'sandbox' => :'sandbox',
    :'enable_partial_discounts' => :'enablePartialDiscounts',
    :'default_discount_additional_cost_per_item_scope' => :'defaultDiscountAdditionalCostPerItemScope',
    :'default_evaluation_group_id' => :'defaultEvaluationGroupId',
    :'default_cart_item_filter_id' => :'defaultCartItemFilterId',
    :'enable_campaign_state_management' => :'enableCampaignStateManagement',
    :'loyalty_programs' => :'loyaltyPrograms'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/talon_one_sdk/models/application.rb', line 554

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



178
179
180
181
182
183
184
185
# File 'lib/talon_one_sdk/models/application.rb', line 178

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'MutableEntity',
  :'UpdateApplication'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



172
173
174
175
# File 'lib/talon_one_sdk/models/application.rb', line 172

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/talon_one_sdk/models/application.rb', line 144

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'timezone' => :'String',
    :'currency' => :'String',
    :'case_sensitivity' => :'String',
    :'attributes' => :'Object',
    :'limits' => :'Array<LimitConfig>',
    :'default_discount_scope' => :'String',
    :'enable_cascading_discounts' => :'Boolean',
    :'enable_flattened_cart_items' => :'Boolean',
    :'attributes_settings' => :'AttributesSettings',
    :'sandbox' => :'Boolean',
    :'enable_partial_discounts' => :'Boolean',
    :'default_discount_additional_cost_per_item_scope' => :'String',
    :'default_evaluation_group_id' => :'Integer',
    :'default_cart_item_filter_id' => :'Integer',
    :'enable_campaign_state_management' => :'Boolean',
    :'loyalty_programs' => :'Array<LoyaltyProgram>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/talon_one_sdk/models/application.rb', line 512

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
       == o. &&
      name == o.name &&
      description == o.description &&
      timezone == o.timezone &&
      currency == o.currency &&
      case_sensitivity == o.case_sensitivity &&
      attributes == o.attributes &&
      limits == o.limits &&
      default_discount_scope == o.default_discount_scope &&
      enable_cascading_discounts == o.enable_cascading_discounts &&
      enable_flattened_cart_items == o.enable_flattened_cart_items &&
      attributes_settings == o.attributes_settings &&
      sandbox == o.sandbox &&
      enable_partial_discounts == o.enable_partial_discounts &&
      default_discount_additional_cost_per_item_scope == o.default_discount_additional_cost_per_item_scope &&
      default_evaluation_group_id == o.default_evaluation_group_id &&
      default_cart_item_filter_id == o.default_cart_item_filter_id &&
      enable_campaign_state_management == o.enable_campaign_state_management &&
      loyalty_programs == o.loyalty_programs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


541
542
543
# File 'lib/talon_one_sdk/models/application.rb', line 541

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



547
548
549
# File 'lib/talon_one_sdk/models/application.rb', line 547

def hash
  [id, created, modified, , name, description, timezone, currency, case_sensitivity, attributes, limits, default_discount_scope, enable_cascading_discounts, enable_flattened_cart_items, attributes_settings, sandbox, enable_partial_discounts, default_discount_additional_cost_per_item_scope, default_evaluation_group_id, default_cart_item_filter_id, enable_campaign_state_management, loyalty_programs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/talon_one_sdk/models/application.rb', line 314

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  if @timezone.to_s.length < 1
    invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length < 1
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 1.')
  end

  if @loyalty_programs.nil?
    invalid_properties.push('invalid value for "loyalty_programs", loyalty_programs cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



576
577
578
579
580
581
582
583
584
585
586
587
588
# File 'lib/talon_one_sdk/models/application.rb', line 576

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/talon_one_sdk/models/application.rb', line 366

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @timezone.nil?
  return false if @timezone.to_s.length < 1
  return false if @currency.nil?
  return false if @currency.to_s.length < 1
  case_sensitivity_validator = EnumAttributeValidator.new('String', ["sensitive", "insensitive-uppercase", "insensitive-lowercase"])
  return false unless case_sensitivity_validator.valid?(@case_sensitivity)
  default_discount_scope_validator = EnumAttributeValidator.new('String', ["sessionTotal", "cartItems", "additionalCosts"])
  return false unless default_discount_scope_validator.valid?(@default_discount_scope)
  default_discount_additional_cost_per_item_scope_validator = EnumAttributeValidator.new('String', ["price", "itemTotal", "additionalCosts"])
  return false unless default_discount_additional_cost_per_item_scope_validator.valid?(@default_discount_additional_cost_per_item_scope)
  return false if @loyalty_programs.nil?
  true
end