Class: TalonOne::ApplicationAnalyticsDataPoint

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/application_analytics_data_point.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationAnalyticsDataPoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationAnalyticsDataPoint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationAnalyticsDataPoint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  else
    self.start_time = nil
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  else
    self.end_time = nil
  end

  if attributes.key?(:'total_revenue')
    self.total_revenue = attributes[:'total_revenue']
  end

  if attributes.key?(:'sessions_count')
    self.sessions_count = attributes[:'sessions_count']
  end

  if attributes.key?(:'avg_items_per_session')
    self.avg_items_per_session = attributes[:'avg_items_per_session']
  end

  if attributes.key?(:'avg_session_value')
    self.avg_session_value = attributes[:'avg_session_value']
  end

  if attributes.key?(:'total_discounts')
    self.total_discounts = attributes[:'total_discounts']
  end

  if attributes.key?(:'coupons_count')
    self.coupons_count = attributes[:'coupons_count']
  end
end

Instance Attribute Details

#avg_items_per_sessionObject

The number of items from sessions divided by the number of sessions. The ‘influenced` value includes only sessions with at least one applied effect.



31
32
33
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 31

def avg_items_per_session
  @avg_items_per_session
end

#avg_session_valueObject

The average customer session value, calculated by dividing the revenue value by the number of sessions. The ‘influenced` value includes only sessions with at least one applied effect.



34
35
36
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 34

def avg_session_value
  @avg_session_value
end

#coupons_countObject

The number of times a coupon was successfully redeemed in influenced sessions.



40
41
42
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 40

def coupons_count
  @coupons_count
end

#end_timeObject

The end of the aggregation time frame in UTC.



22
23
24
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 22

def end_time
  @end_time
end

#sessions_countObject

The number of all closed sessions. The ‘influenced` value includes only sessions with at least one applied effect.



28
29
30
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 28

def sessions_count
  @sessions_count
end

#start_timeObject

The start of the aggregation time frame in UTC.



19
20
21
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 19

def start_time
  @start_time
end

#total_discountsObject

The total value of discounts given for cart items in influenced sessions.



37
38
39
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 37

def total_discounts
  @total_discounts
end

#total_revenueObject

The total, pre-discount value of all items purchased in a customer session.



25
26
27
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 25

def total_revenue
  @total_revenue
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 43

def self.attribute_map
  {
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'total_revenue' => :'totalRevenue',
    :'sessions_count' => :'sessionsCount',
    :'avg_items_per_session' => :'avgItemsPerSession',
    :'avg_session_value' => :'avgSessionValue',
    :'total_discounts' => :'totalDiscounts',
    :'coupons_count' => :'couponsCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 67

def self.openapi_types
  {
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'total_revenue' => :'AnalyticsDataPoint',
    :'sessions_count' => :'AnalyticsDataPoint',
    :'avg_items_per_session' => :'AnalyticsDataPoint',
    :'avg_session_value' => :'AnalyticsDataPoint',
    :'total_discounts' => :'Float',
    :'coupons_count' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      total_revenue == o.total_revenue &&
      sessions_count == o.sessions_count &&
      avg_items_per_session == o.avg_items_per_session &&
      avg_session_value == o.avg_session_value &&
      total_discounts == o.total_discounts &&
      coupons_count == o.coupons_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 207

def hash
  [start_time, end_time, total_revenue, sessions_count, avg_items_per_session, avg_session_value, total_discounts, coupons_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @start_time.nil?
    invalid_properties.push('invalid value for "start_time", start_time cannot be nil.')
  end

  if @end_time.nil?
    invalid_properties.push('invalid value for "end_time", end_time cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
# File 'lib/talon_one_sdk/models/application_analytics_data_point.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @start_time.nil?
  return false if @end_time.nil?
  true
end