Class: TalonOne::ApplicationCIFExpression

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/application_cif_expression.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationCIFExpression

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationCIFExpression` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationCIFExpression`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'cart_item_filter_id')
    self.cart_item_filter_id = attributes[:'cart_item_filter_id']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'expression')
    if (value = attributes[:'expression']).is_a?(Array)
      self.expression = value
    end
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



34
35
36
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 34

def application_id
  @application_id
end

#cart_item_filter_idObject

The ID of the Application cart item filter.



25
26
27
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 25

def cart_item_filter_id
  @cart_item_filter_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 22

def created
  @created
end

#created_byObject

The ID of the user who created the Application cart item filter.



28
29
30
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 28

def created_by
  @created_by
end

#expressionObject

Arbitrary additional JSON data associated with the Application cart item filter.



31
32
33
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 31

def expression
  @expression
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 19

def id
  @id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'cart_item_filter_id' => :'cartItemFilterId',
    :'created_by' => :'createdBy',
    :'expression' => :'expression',
    :'application_id' => :'applicationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



77
78
79
80
81
82
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 77

def self.openapi_all_of
  [
  :'Entity',
  :'NewApplicationCIFExpression'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 59

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'cart_item_filter_id' => :'Integer',
    :'created_by' => :'Integer',
    :'expression' => :'Array<Object>',
    :'application_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      cart_item_filter_id == o.cart_item_filter_id &&
      created_by == o.created_by &&
      expression == o.expression &&
      application_id == o.application_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 214

def hash
  [id, created, cart_item_filter_id, created_by, expression, application_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/application_cif_expression.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  true
end