Class: TalonOne::ApplicationCampaignStats

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/application_campaign_stats.rb

Overview

Provides statistics regarding an application’s campaigns.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationCampaignStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationCampaignStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationCampaignStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'disabled')
    self.disabled = attributes[:'disabled']
  else
    self.disabled = nil
  end

  if attributes.key?(:'staged')
    self.staged = attributes[:'staged']
  else
    self.staged = nil
  end

  if attributes.key?(:'scheduled')
    self.scheduled = attributes[:'scheduled']
  else
    self.scheduled = nil
  end

  if attributes.key?(:'running')
    self.running = attributes[:'running']
  else
    self.running = nil
  end

  if attributes.key?(:'expired')
    self.expired = attributes[:'expired']
  else
    self.expired = nil
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  else
    self.archived = nil
  end
end

Instance Attribute Details

#archivedObject

Number of archived campaigns.



35
36
37
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 35

def archived
  @archived
end

#disabledObject

Number of disabled campaigns.



20
21
22
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 20

def disabled
  @disabled
end

#expiredObject

Number of expired campaigns.



32
33
34
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 32

def expired
  @expired
end

#runningObject

Number of running campaigns.



29
30
31
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 29

def running
  @running
end

#scheduledObject

Number of scheduled campaigns.



26
27
28
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 26

def scheduled
  @scheduled
end

#stagedObject

Number of staged campaigns.



23
24
25
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 23

def staged
  @staged
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 38

def self.attribute_map
  {
    :'disabled' => :'disabled',
    :'staged' => :'staged',
    :'scheduled' => :'scheduled',
    :'running' => :'running',
    :'expired' => :'expired',
    :'archived' => :'archived'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 263

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 60

def self.openapi_types
  {
    :'disabled' => :'Integer',
    :'staged' => :'Integer',
    :'scheduled' => :'Integer',
    :'running' => :'Integer',
    :'expired' => :'Integer',
    :'archived' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      disabled == o.disabled &&
      staged == o.staged &&
      scheduled == o.scheduled &&
      running == o.running &&
      expired == o.expired &&
      archived == o.archived
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


250
251
252
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 250

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



256
257
258
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 256

def hash
  [disabled, staged, scheduled, running, expired, archived].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @disabled.nil?
    invalid_properties.push('invalid value for "disabled", disabled cannot be nil.')
  end

  if @staged.nil?
    invalid_properties.push('invalid value for "staged", staged cannot be nil.')
  end

  if @scheduled.nil?
    invalid_properties.push('invalid value for "scheduled", scheduled cannot be nil.')
  end

  if @running.nil?
    invalid_properties.push('invalid value for "running", running cannot be nil.')
  end

  if @expired.nil?
    invalid_properties.push('invalid value for "expired", expired cannot be nil.')
  end

  if @archived.nil?
    invalid_properties.push('invalid value for "archived", archived cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
172
173
# File 'lib/talon_one_sdk/models/application_campaign_stats.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @disabled.nil?
  return false if @staged.nil?
  return false if @scheduled.nil?
  return false if @running.nil?
  return false if @expired.nil?
  return false if @archived.nil?
  true
end