Class: TalonOne::ApplicationSession

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/application_session.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/talon_one_sdk/models/application_session.rb', line 156

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationSession` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationSession`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  else
    self.integration_id = nil
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'profileintegrationid')
    self.profileintegrationid = attributes[:'profileintegrationid']
  end

  if attributes.key?(:'coupon')
    self.coupon = attributes[:'coupon']
  else
    self.coupon = nil
  end

  if attributes.key?(:'referral')
    self.referral = attributes[:'referral']
  else
    self.referral = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'cart_items')
    if (value = attributes[:'cart_items']).is_a?(Array)
      self.cart_items = value
    end
  else
    self.cart_items = nil
  end

  if attributes.key?(:'discounts')
    if (value = attributes[:'discounts']).is_a?(Hash)
      self.discounts = value
    end
  else
    self.discounts = nil
  end

  if attributes.key?(:'total_discounts')
    self.total_discounts = attributes[:'total_discounts']
  else
    self.total_discounts = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



31
32
33
# File 'lib/talon_one_sdk/models/application_session.rb', line 31

def application_id
  @application_id
end

#attributesObject

Arbitrary properties associated with this item.



61
62
63
# File 'lib/talon_one_sdk/models/application_session.rb', line 61

def attributes
  @attributes
end

#cart_itemsObject

Serialized JSON representation.



49
50
51
# File 'lib/talon_one_sdk/models/application_session.rb', line 49

def cart_items
  @cart_items
end

#couponObject

Any coupon code entered.



40
41
42
# File 'lib/talon_one_sdk/models/application_session.rb', line 40

def coupon
  @coupon
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/application_session.rb', line 22

def created
  @created
end

#discountsObject

**API V1 only.** A map of labeled discount values, in the same currency as the session. If you are using the V2 endpoints, refer to the ‘totalDiscounts` property instead.



52
53
54
# File 'lib/talon_one_sdk/models/application_session.rb', line 52

def discounts
  @discounts
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/application_session.rb', line 19

def id
  @id
end

#integration_idObject

The integration ID set by your integration layer.



25
26
27
# File 'lib/talon_one_sdk/models/application_session.rb', line 25

def integration_id
  @integration_id
end

#profile_idObject

The globally unique Talon.One ID of the customer that created this entity.



34
35
36
# File 'lib/talon_one_sdk/models/application_session.rb', line 34

def profile_id
  @profile_id
end

#profileintegrationidObject

Integration ID of the customer for the session.



37
38
39
# File 'lib/talon_one_sdk/models/application_session.rb', line 37

def profileintegrationid
  @profileintegrationid
end

#referralObject

Any referral code entered.



43
44
45
# File 'lib/talon_one_sdk/models/application_session.rb', line 43

def referral
  @referral
end

#stateObject

Indicates the current state of the session. Sessions can be created as ‘open` or `closed`. The state transitions are: 1. `open` → `closed` 2. `open` → `cancelled` 3. `closed` → `cancelled` or `partially_returned` 4. `partially_returned` → `cancelled` For more information, see [Customer session states](docs.talon.one/docs/dev/concepts/entities/customer-sessions).



46
47
48
# File 'lib/talon_one_sdk/models/application_session.rb', line 46

def state
  @state
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



28
29
30
# File 'lib/talon_one_sdk/models/application_session.rb', line 28

def store_integration_id
  @store_integration_id
end

#totalObject

The total sum of the session before any discounts applied.



58
59
60
# File 'lib/talon_one_sdk/models/application_session.rb', line 58

def total
  @total
end

#total_discountsObject

The total sum of the discounts applied to this session. Note: If more than one session is returned, this value is displayed as ‘0`.



55
56
57
# File 'lib/talon_one_sdk/models/application_session.rb', line 55

def total_discounts
  @total_discounts
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



107
108
109
# File 'lib/talon_one_sdk/models/application_session.rb', line 107

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/talon_one_sdk/models/application_session.rb', line 112

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/talon_one_sdk/models/application_session.rb', line 86

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'integration_id' => :'integrationId',
    :'store_integration_id' => :'storeIntegrationId',
    :'application_id' => :'applicationId',
    :'profile_id' => :'profileId',
    :'profileintegrationid' => :'profileintegrationid',
    :'coupon' => :'coupon',
    :'referral' => :'referral',
    :'state' => :'state',
    :'cart_items' => :'cartItems',
    :'discounts' => :'discounts',
    :'total_discounts' => :'totalDiscounts',
    :'total' => :'total',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/talon_one_sdk/models/application_session.rb', line 532

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



144
145
146
147
148
149
150
151
152
# File 'lib/talon_one_sdk/models/application_session.rb', line 144

def self.openapi_all_of
  [
  :'ApplicationCustomerEntity',
  :'ApplicationEntity',
  :'Entity',
  :'IntegrationEntity',
  :'IntegrationStoreEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
# File 'lib/talon_one_sdk/models/application_session.rb', line 138

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/application_session.rb', line 117

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'integration_id' => :'String',
    :'store_integration_id' => :'String',
    :'application_id' => :'Integer',
    :'profile_id' => :'Integer',
    :'profileintegrationid' => :'String',
    :'coupon' => :'String',
    :'referral' => :'String',
    :'state' => :'String',
    :'cart_items' => :'Array<CartItem>',
    :'discounts' => :'Hash<String, Float>',
    :'total_discounts' => :'Float',
    :'total' => :'Float',
    :'attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/talon_one_sdk/models/application_session.rb', line 497

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      integration_id == o.integration_id &&
      store_integration_id == o.store_integration_id &&
      application_id == o.application_id &&
      profile_id == o.profile_id &&
      profileintegrationid == o.profileintegrationid &&
      coupon == o.coupon &&
      referral == o.referral &&
      state == o.state &&
      cart_items == o.cart_items &&
      discounts == o.discounts &&
      total_discounts == o.total_discounts &&
      total == o.total &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


519
520
521
# File 'lib/talon_one_sdk/models/application_session.rb', line 519

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



525
526
527
# File 'lib/talon_one_sdk/models/application_session.rb', line 525

def hash
  [id, created, integration_id, store_integration_id, application_id, profile_id, profileintegrationid, coupon, referral, state, cart_items, discounts, total_discounts, total, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/talon_one_sdk/models/application_session.rb', line 259

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if !@profileintegrationid.nil? && @profileintegrationid.to_s.length > 1000
    invalid_properties.push('invalid value for "profileintegrationid", the character length must be smaller than or equal to 1000.')
  end

  if @coupon.nil?
    invalid_properties.push('invalid value for "coupon", coupon cannot be nil.')
  end

  if @referral.nil?
    invalid_properties.push('invalid value for "referral", referral cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @cart_items.nil?
    invalid_properties.push('invalid value for "cart_items", cart_items cannot be nil.')
  end

  if @discounts.nil?
    invalid_properties.push('invalid value for "discounts", discounts cannot be nil.')
  end

  if @total_discounts.nil?
    invalid_properties.push('invalid value for "total_discounts", total_discounts cannot be nil.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/talon_one_sdk/models/application_session.rb', line 554

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/talon_one_sdk/models/application_session.rb', line 327

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if @application_id.nil?
  return false if !@profileintegrationid.nil? && @profileintegrationid.to_s.length > 1000
  return false if @coupon.nil?
  return false if @referral.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["open", "closed", "partially_returned", "cancelled"])
  return false unless state_validator.valid?(@state)
  return false if @cart_items.nil?
  return false if @discounts.nil?
  return false if @total_discounts.nil?
  return false if @total.nil?
  true
end