Class: TalonOne::Attribute

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/attribute.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Attribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/talon_one_sdk/models/attribute.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Attribute` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Attribute`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  else
    self.entity = nil
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'suggestions')
    if (value = attributes[:'suggestions']).is_a?(Array)
      self.suggestions = value
    end
  else
    self.suggestions = nil
  end

  if attributes.key?(:'has_allowed_list')
    self.has_allowed_list = attributes[:'has_allowed_list']
  else
    self.has_allowed_list = false
  end

  if attributes.key?(:'restricted_by_suggestions')
    self.restricted_by_suggestions = attributes[:'restricted_by_suggestions']
  else
    self.restricted_by_suggestions = false
  end

  if attributes.key?(:'editable')
    self.editable = attributes[:'editable']
  else
    self.editable = nil
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'subscribed_catalogs_ids')
    if (value = attributes[:'subscribed_catalogs_ids']).is_a?(Array)
      self.subscribed_catalogs_ids = value
    end
  end

  if attributes.key?(:'allowed_subscriptions')
    if (value = attributes[:'allowed_subscriptions']).is_a?(Array)
      self.allowed_subscriptions = value
    end
  end

  if attributes.key?(:'event_type_id')
    self.event_type_id = attributes[:'event_type_id']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/attribute.rb', line 25

def 
  @account_id
end

#allowed_subscriptionsObject

A list of allowed subscription types for this attribute. Note: This only applies to attributes associated with the ‘CartItem` entity.



63
64
65
# File 'lib/talon_one_sdk/models/attribute.rb', line 63

def allowed_subscriptions
  @allowed_subscriptions
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/attribute.rb', line 22

def created
  @created
end

#descriptionObject

A description of this attribute.



42
43
44
# File 'lib/talon_one_sdk/models/attribute.rb', line 42

def description
  @description
end

#editableObject

Whether or not this attribute can be edited.



54
55
56
# File 'lib/talon_one_sdk/models/attribute.rb', line 54

def editable
  @editable
end

#entityObject

The name of the entity that can have this attribute. When creating or updating the entities of a given type, you can include an ‘attributes` object with keys corresponding to the `name` of the custom attributes for that type.



28
29
30
# File 'lib/talon_one_sdk/models/attribute.rb', line 28

def entity
  @entity
end

#event_typeObject

Returns the value of attribute event_type.



30
31
32
# File 'lib/talon_one_sdk/models/attribute.rb', line 30

def event_type
  @event_type
end

#event_type_idObject

Returns the value of attribute event_type_id.



65
66
67
# File 'lib/talon_one_sdk/models/attribute.rb', line 65

def event_type_id
  @event_type_id
end

#has_allowed_listObject

Whether or not this attribute has an allowed list of values associated with it.



48
49
50
# File 'lib/talon_one_sdk/models/attribute.rb', line 48

def has_allowed_list
  @has_allowed_list
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/attribute.rb', line 19

def id
  @id
end

#nameObject

The attribute name that will be used in API requests and Talang. E.g. if ‘name == "region"` then you would set the region attribute by including an `attributes.region` property in your request payload.



33
34
35
# File 'lib/talon_one_sdk/models/attribute.rb', line 33

def name
  @name
end

#restricted_by_suggestionsObject

Whether or not this attribute’s value is restricted by suggestions (‘suggestions` property) or by an allowed list of value (`hasAllowedList` property).



51
52
53
# File 'lib/talon_one_sdk/models/attribute.rb', line 51

def restricted_by_suggestions
  @restricted_by_suggestions
end

#subscribed_applications_idsObject

A list of the IDs of the applications where this attribute is available.



57
58
59
# File 'lib/talon_one_sdk/models/attribute.rb', line 57

def subscribed_applications_ids
  @subscribed_applications_ids
end

#subscribed_catalogs_idsObject

A list of the IDs of the catalogs where this attribute is available.



60
61
62
# File 'lib/talon_one_sdk/models/attribute.rb', line 60

def subscribed_catalogs_ids
  @subscribed_catalogs_ids
end

#suggestionsObject

A list of suggestions for the attribute.



45
46
47
# File 'lib/talon_one_sdk/models/attribute.rb', line 45

def suggestions
  @suggestions
end

#titleObject

The human-readable name for the attribute that will be shown in the Campaign Manager. Like ‘name`, the combination of entity and title must also be unique.



36
37
38
# File 'lib/talon_one_sdk/models/attribute.rb', line 36

def title
  @title
end

#typeObject

The data type of the attribute, a ‘time` attribute must be sent as a string that conforms to the [RFC3339](www.ietf.org/rfc/rfc3339.txt) timestamp format.



39
40
41
# File 'lib/talon_one_sdk/models/attribute.rb', line 39

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



113
114
115
# File 'lib/talon_one_sdk/models/attribute.rb', line 113

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/talon_one_sdk/models/attribute.rb', line 118

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/talon_one_sdk/models/attribute.rb', line 90

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'entity' => :'entity',
    :'event_type' => :'eventType',
    :'name' => :'name',
    :'title' => :'title',
    :'type' => :'type',
    :'description' => :'description',
    :'suggestions' => :'suggestions',
    :'has_allowed_list' => :'hasAllowedList',
    :'restricted_by_suggestions' => :'restrictedBySuggestions',
    :'editable' => :'editable',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'subscribed_catalogs_ids' => :'subscribedCatalogsIds',
    :'allowed_subscriptions' => :'allowedSubscriptions',
    :'event_type_id' => :'eventTypeId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/talon_one_sdk/models/attribute.rb', line 521

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



152
153
154
155
156
157
158
# File 'lib/talon_one_sdk/models/attribute.rb', line 152

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'NewAttribute'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



146
147
148
149
# File 'lib/talon_one_sdk/models/attribute.rb', line 146

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/talon_one_sdk/models/attribute.rb', line 123

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'account_id' => :'Integer',
    :'entity' => :'String',
    :'event_type' => :'String',
    :'name' => :'String',
    :'title' => :'String',
    :'type' => :'String',
    :'description' => :'String',
    :'suggestions' => :'Array<String>',
    :'has_allowed_list' => :'Boolean',
    :'restricted_by_suggestions' => :'Boolean',
    :'editable' => :'Boolean',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'subscribed_catalogs_ids' => :'Array<Integer>',
    :'allowed_subscriptions' => :'Array<String>',
    :'event_type_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/talon_one_sdk/models/attribute.rb', line 484

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      entity == o.entity &&
      event_type == o.event_type &&
      name == o.name &&
      title == o.title &&
      type == o.type &&
      description == o.description &&
      suggestions == o.suggestions &&
      has_allowed_list == o.has_allowed_list &&
      restricted_by_suggestions == o.restricted_by_suggestions &&
      editable == o.editable &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      subscribed_catalogs_ids == o.subscribed_catalogs_ids &&
      allowed_subscriptions == o.allowed_subscriptions &&
      event_type_id == o.event_type_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


508
509
510
# File 'lib/talon_one_sdk/models/attribute.rb', line 508

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



514
515
516
# File 'lib/talon_one_sdk/models/attribute.rb', line 514

def hash
  [id, created, , entity, event_type, name, title, type, description, suggestions, has_allowed_list, restricted_by_suggestions, editable, subscribed_applications_ids, subscribed_catalogs_ids, allowed_subscriptions, event_type_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/talon_one_sdk/models/attribute.rb', line 279

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @entity.nil?
    invalid_properties.push('invalid value for "entity", entity cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z]\w*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @suggestions.nil?
    invalid_properties.push('invalid value for "suggestions", suggestions cannot be nil.')
  end

  if @suggestions.length > 50
    invalid_properties.push('invalid value for "suggestions", number of items must be less than or equal to 50.')
  end

  if @editable.nil?
    invalid_properties.push('invalid value for "editable", editable cannot be nil.')
  end

  if !@allowed_subscriptions.nil? && @allowed_subscriptions.length > 2
    invalid_properties.push('invalid value for "allowed_subscriptions", number of items must be less than or equal to 2.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/talon_one_sdk/models/attribute.rb', line 543

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/talon_one_sdk/models/attribute.rb', line 345

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @entity.nil?
  entity_validator = EnumAttributeValidator.new('String', ["Application", "Campaign", "CustomerProfile", "CustomerSession", "CartItem", "Coupon", "Event", "Giveaway", "LoyaltyCard", "Referral", "Store"])
  return false unless entity_validator.valid?(@entity)
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[A-Za-z]\w*$/)
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["string", "number", "boolean", "time", "(list string)", "(list number)", "(list time)", "location", "(list location)"])
  return false unless type_validator.valid?(@type)
  return false if @description.nil?
  return false if @suggestions.nil?
  return false if @suggestions.length > 50
  return false if @editable.nil?
  return false if !@allowed_subscriptions.nil? && @allowed_subscriptions.length > 2
  true
end