Class: TalonOne::Audience
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Audience
- Defined in:
- lib/talon_one_sdk/models/audience.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#created ⇒ Object
The time this entity was created.
-
#created_in3rd_party ⇒ Object
Determines if this audience is a 3rd party audience or not.
-
#description ⇒ Object
A description of the audience.
-
#id ⇒ Object
The internal ID of this entity.
-
#integration ⇒ Object
The Talon.One-supported [3rd-party platform](docs.talon.one/docs/dev/technology-partners/overview) that this audience was created in.
-
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
-
#last_update ⇒ Object
The last time that the audience memberships changed.
-
#name ⇒ Object
The human-friendly display name for this audience.
-
#sandbox ⇒ Object
Indicates if this is a live or sandbox Application.
-
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Audience
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Audience
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/talon_one_sdk/models/audience.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Audience` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Audience`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'subscribed_applications_ids') if (value = attributes[:'subscribed_applications_ids']).is_a?(Array) self.subscribed_applications_ids = value end end if attributes.key?(:'integration') self.integration = attributes[:'integration'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'created_in3rd_party') self.created_in3rd_party = attributes[:'created_in3rd_party'] end if attributes.key?(:'last_update') self.last_update = attributes[:'last_update'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/audience.rb', line 19 def account_id @account_id end |
#created ⇒ Object
The time this entity was created.
25 26 27 |
# File 'lib/talon_one_sdk/models/audience.rb', line 25 def created @created end |
#created_in3rd_party ⇒ Object
Determines if this audience is a 3rd party audience or not.
46 47 48 |
# File 'lib/talon_one_sdk/models/audience.rb', line 46 def created_in3rd_party @created_in3rd_party end |
#description ⇒ Object
A description of the audience.
34 35 36 |
# File 'lib/talon_one_sdk/models/audience.rb', line 34 def description @description end |
#id ⇒ Object
The internal ID of this entity.
22 23 24 |
# File 'lib/talon_one_sdk/models/audience.rb', line 22 def id @id end |
#integration ⇒ Object
The Talon.One-supported [3rd-party platform](docs.talon.one/docs/dev/technology-partners/overview) that this audience was created in. For example, ‘mParticle`, `Segment`, `Shopify`, `Braze`, or `Iterable`. Note: If you do not integrate with any of these platforms, do not use this property.
40 41 42 |
# File 'lib/talon_one_sdk/models/audience.rb', line 40 def integration @integration end |
#integration_id ⇒ Object
The ID of this audience in the third-party integration. Note: To create an audience that doesn’t come from a 3rd party platform, do not use this property.
43 44 45 |
# File 'lib/talon_one_sdk/models/audience.rb', line 43 def integration_id @integration_id end |
#last_update ⇒ Object
The last time that the audience memberships changed.
49 50 51 |
# File 'lib/talon_one_sdk/models/audience.rb', line 49 def last_update @last_update end |
#name ⇒ Object
The human-friendly display name for this audience.
28 29 30 |
# File 'lib/talon_one_sdk/models/audience.rb', line 28 def name @name end |
#sandbox ⇒ Object
Indicates if this is a live or sandbox Application.
31 32 33 |
# File 'lib/talon_one_sdk/models/audience.rb', line 31 def sandbox @sandbox end |
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
37 38 39 |
# File 'lib/talon_one_sdk/models/audience.rb', line 37 def subscribed_applications_ids @subscribed_applications_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/talon_one_sdk/models/audience.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/talon_one_sdk/models/audience.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/talon_one_sdk/models/audience.rb', line 52 def self.attribute_map { :'account_id' => :'accountId', :'id' => :'id', :'created' => :'created', :'name' => :'name', :'sandbox' => :'sandbox', :'description' => :'description', :'subscribed_applications_ids' => :'subscribedApplicationsIds', :'integration' => :'integration', :'integration_id' => :'integrationId', :'created_in3rd_party' => :'createdIn3rdParty', :'last_update' => :'lastUpdate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/talon_one_sdk/models/audience.rb', line 336 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
102 103 104 105 106 107 108 |
# File 'lib/talon_one_sdk/models/audience.rb', line 102 def self.openapi_all_of [ :'AccountEntity', :'Entity', :'NewAudience' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/talon_one_sdk/models/audience.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/talon_one_sdk/models/audience.rb', line 79 def self.openapi_types { :'account_id' => :'Integer', :'id' => :'Integer', :'created' => :'Time', :'name' => :'String', :'sandbox' => :'Boolean', :'description' => :'String', :'subscribed_applications_ids' => :'Array<Integer>', :'integration' => :'String', :'integration_id' => :'String', :'created_in3rd_party' => :'Boolean', :'last_update' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/talon_one_sdk/models/audience.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && id == o.id && created == o.created && name == o.name && sandbox == o.sandbox && description == o.description && subscribed_applications_ids == o.subscribed_applications_ids && integration == o.integration && integration_id == o.integration_id && created_in3rd_party == o.created_in3rd_party && last_update == o.last_update end |
#eql?(o) ⇒ Boolean
323 324 325 |
# File 'lib/talon_one_sdk/models/audience.rb', line 323 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
329 330 331 |
# File 'lib/talon_one_sdk/models/audience.rb', line 329 def hash [account_id, id, created, name, sandbox, description, subscribed_applications_ids, integration, integration_id, created_in3rd_party, last_update].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/talon_one_sdk/models/audience.rb', line 183 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@integration_id.nil? && @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if !@integration_id.nil? && @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/talon_one_sdk/models/audience.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/talon_one_sdk/models/audience.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @id.nil? return false if @created.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if !@integration_id.nil? && @integration_id.to_s.length > 1000 return false if !@integration_id.nil? && @integration_id.to_s.length < 1 true end |