Class: TalonOne::AudienceCustomer

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/audience_customer.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AudienceCustomer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AudienceCustomer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AudienceCustomer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  else
    self.integration_id = nil
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'closed_sessions')
    self.closed_sessions = attributes[:'closed_sessions']
  else
    self.closed_sessions = nil
  end

  if attributes.key?(:'total_sales')
    self.total_sales = attributes[:'total_sales']
  else
    self.total_sales = nil
  end

  if attributes.key?(:'loyalty_memberships')
    if (value = attributes[:'loyalty_memberships']).is_a?(Array)
      self.loyalty_memberships = value
    end
  end

  if attributes.key?(:'audience_memberships')
    if (value = attributes[:'audience_memberships']).is_a?(Array)
      self.audience_memberships = value
    end
  end

  if attributes.key?(:'last_activity')
    self.last_activity = attributes[:'last_activity']
  else
    self.last_activity = nil
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'connected_applications_ids')
    if (value = attributes[:'connected_applications_ids']).is_a?(Array)
      self.connected_applications_ids = value
    end
  end

  if attributes.key?(:'connected_audiences')
    if (value = attributes[:'connected_audiences']).is_a?(Array)
      self.connected_audiences = value
    end
  end
end

Instance Attribute Details

#account_idObject

The ID of the Talon.One account that owns this profile.



31
32
33
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 31

def 
  @account_id
end

#attributesObject

Arbitrary properties associated with this item.



28
29
30
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 28

def attributes
  @attributes
end

#audience_membershipsObject

The audiences the customer belongs to.



43
44
45
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 43

def audience_memberships
  @audience_memberships
end

#closed_sessionsObject

The total number of closed sessions. Does not include closed sessions that have been cancelled or reopened. See the [docs](docs.talon.one/docs/dev/concepts/entities/customer-sessions#customer-session-states).



34
35
36
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 34

def closed_sessions
  @closed_sessions
end

#connected_applications_idsObject

A list of the IDs of the Applications that are connected to this customer profile.



52
53
54
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 52

def connected_applications_ids
  @connected_applications_ids
end

#connected_audiencesObject

A list of the IDs of the audiences that are connected to this customer profile.



55
56
57
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 55

def connected_audiences
  @connected_audiences
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 22

def created
  @created
end

#idObject

The internal ID of the customer profile.



19
20
21
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 19

def id
  @id
end

#integration_idObject

The integration ID set by your integration layer.



25
26
27
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 25

def integration_id
  @integration_id
end

#last_activityObject

Timestamp of the most recent event received from this customer. This field is updated on calls that trigger the Rule Engine and that are not [dry requests](docs.talon.one/docs/dev/integration-api/dry-requests/#overlay). For example, [reserving a coupon](docs.talon.one/integration-api#tag/Coupons/operation/createCouponReservation) for a customer doesn’t impact this field.



46
47
48
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 46

def last_activity
  @last_activity
end

#loyalty_membershipsObject

**DEPRECATED. Always returns ‘null`.** A list of loyalty programs joined by the customer.



40
41
42
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 40

def loyalty_memberships
  @loyalty_memberships
end

#sandboxObject

An indicator of whether the customer is part of a sandbox or live Application. See the [docs](docs.talon.one/docs/product/applications/overview#application-environments).



49
50
51
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 49

def sandbox
  @sandbox
end

#total_salesObject

The total amount of money spent by the customer before discounts are applied. The total sales amount excludes the following: - Cancelled or reopened sessions. - Returned items.



37
38
39
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 37

def total_sales
  @total_sales
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 58

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'integration_id' => :'integrationId',
    :'attributes' => :'attributes',
    :'account_id' => :'accountId',
    :'closed_sessions' => :'closedSessions',
    :'total_sales' => :'totalSales',
    :'loyalty_memberships' => :'loyaltyMemberships',
    :'audience_memberships' => :'audienceMemberships',
    :'last_activity' => :'lastActivity',
    :'sandbox' => :'sandbox',
    :'connected_applications_ids' => :'connectedApplicationsIds',
    :'connected_audiences' => :'connectedAudiences'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 375

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



112
113
114
115
116
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 112

def self.openapi_all_of
  [
  :'CustomerProfile'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 87

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'integration_id' => :'String',
    :'attributes' => :'Hash<String, Object>',
    :'account_id' => :'Integer',
    :'closed_sessions' => :'Integer',
    :'total_sales' => :'Float',
    :'loyalty_memberships' => :'Array<LoyaltyMembership>',
    :'audience_memberships' => :'Array<AudienceMembership>',
    :'last_activity' => :'Time',
    :'sandbox' => :'Boolean',
    :'connected_applications_ids' => :'Array<Integer>',
    :'connected_audiences' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 342

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      integration_id == o.integration_id &&
      attributes == o.attributes &&
       == o. &&
      closed_sessions == o.closed_sessions &&
      total_sales == o.total_sales &&
      loyalty_memberships == o.loyalty_memberships &&
      audience_memberships == o.audience_memberships &&
      last_activity == o.last_activity &&
      sandbox == o.sandbox &&
      connected_applications_ids == o.connected_applications_ids &&
      connected_audiences == o.connected_audiences
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


362
363
364
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 362

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



368
369
370
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 368

def hash
  [id, created, integration_id, attributes, , closed_sessions, total_sales, loyalty_memberships, audience_memberships, last_activity, sandbox, connected_applications_ids, connected_audiences].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @closed_sessions.nil?
    invalid_properties.push('invalid value for "closed_sessions", closed_sessions cannot be nil.')
  end

  if @total_sales.nil?
    invalid_properties.push('invalid value for "total_sales", total_sales cannot be nil.')
  end

  if @last_activity.nil?
    invalid_properties.push('invalid value for "last_activity", last_activity cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/talon_one_sdk/models/audience_customer.rb', line 253

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length > 1000
  return false if @account_id.nil?
  return false if @closed_sessions.nil?
  return false if @total_sales.nil?
  return false if @last_activity.nil?
  true
end