Class: TalonOne::AwardDiscountBundleItemByAttribute

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb

Overview

Identifies a bundle slot by ranking items by a per-item attribute expression and picking the highest- or lowest-ranked one.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AwardDiscountBundleItemByAttribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AwardDiscountBundleItemByAttribute` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AwardDiscountBundleItemByAttribute`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'attribute')
    self.attribute = attributes[:'attribute']
  else
    self.attribute = nil
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end
end

Instance Attribute Details

#attributeObject

A per-item attribute expression used to rank bundle items.



23
24
25
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 23

def attribute
  @attribute
end

#directionObject

Ranking direction. highest picks the item with the largest attribute value, lowest the smallest.



26
27
28
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 26

def direction
  @direction
end

#typeObject

A bundle-item selector of type byAttribute.



20
21
22
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 51

def self.attribute_map
  {
    :'type' => :'type',
    :'attribute' => :'attribute',
    :'direction' => :'direction'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 70

def self.openapi_types
  {
    :'type' => :'String',
    :'attribute' => :'String',
    :'direction' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      attribute == o.attribute &&
      direction == o.direction
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 201

def hash
  [type, attribute, direction].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @attribute.nil?
    invalid_properties.push('invalid value for "attribute", attribute cannot be nil.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/talon_one_sdk/models/award_discount_bundle_item_by_attribute.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["byAttribute"])
  return false unless type_validator.valid?(@type)
  return false if @attribute.nil?
  return false if @direction.nil?
  direction_validator = EnumAttributeValidator.new('String', ["highest", "lowest"])
  return false unless direction_validator.valid?(@direction)
  true
end