Class: TalonOne::AwardGiveawayBlock

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/award_giveaway_block.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AwardGiveawayBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AwardGiveawayBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AwardGiveawayBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'giveaway_pool')
    self.giveaway_pool = attributes[:'giveaway_pool']
  else
    self.giveaway_pool = nil
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  else
    self.profile = nil
  end

  if attributes.key?(:'on_failure')
    if (value = attributes[:'on_failure']).is_a?(Array)
      self.on_failure = value
    end
  end

  if attributes.key?(:'on_error')
    if (value = attributes[:'on_error']).is_a?(Hash)
      self.on_error = value
    end
  end
end

Instance Attribute Details

#giveaway_poolObject

Returns the value of attribute giveaway_pool.



27
28
29
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 27

def giveaway_pool
  @giveaway_pool
end

#idObject

Unique identifier for this block.



19
20
21
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 19

def id
  @id
end

#on_errorObject

Named error handlers evaluated when a specific error occurs.



36
37
38
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 36

def on_error
  @on_error
end

#on_failureObject

Blocks evaluated when this block fails or returns false.



33
34
35
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 33

def on_failure
  @on_failure
end

#profileObject

The customer profile to award the giveaway to. Current targets the customer in the current session; Advocate targets the person who invited their friend via referral program.



30
31
32
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 30

def profile
  @profile
end

#tagsObject

Semantic labels attached to this block.



25
26
27
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 25

def tags
  @tags
end

#typeObject

Identifies the block variant and determines which additional properties are present in it.



22
23
24
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 22

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'tags' => :'tags',
    :'giveaway_pool' => :'giveawayPool',
    :'profile' => :'profile',
    :'on_failure' => :'onFailure',
    :'on_error' => :'onError'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



103
104
105
106
107
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 103

def self.openapi_all_of
  [
  :'BaseBlock'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 84

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'tags' => :'Array<String>',
    :'giveaway_pool' => :'AwardGiveawayBlock1GiveawayPool',
    :'profile' => :'String',
    :'on_failure' => :'Array<Object>',
    :'on_error' => :'Hash<String, Array<Object>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      tags == o.tags &&
      giveaway_pool == o.giveaway_pool &&
      profile == o.profile &&
      on_failure == o.on_failure &&
      on_error == o.on_error
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 267

def hash
  [id, type, tags, giveaway_pool, profile, on_failure, on_error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @giveaway_pool.nil?
    invalid_properties.push('invalid value for "giveaway_pool", giveaway_pool cannot be nil.')
  end

  if @profile.nil?
    invalid_properties.push('invalid value for "profile", profile cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/award_giveaway_block.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  return false if @giveaway_pool.nil?
  return false if @profile.nil?
  profile_validator = EnumAttributeValidator.new('String', ["Current", "Advocate"])
  return false unless profile_validator.valid?(@profile)
  true
end