Class: TalonOne::AwardGiveawayEffectProps

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/award_giveaway_effect_props.rb

Overview

The properties specific to the "awardGiveaway" effect. This effect contains information on the giveaway item, and which profile it was awarded to.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AwardGiveawayEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AwardGiveawayEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AwardGiveawayEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pool_id')
    self.pool_id = attributes[:'pool_id']
  else
    self.pool_id = nil
  end

  if attributes.key?(:'pool_name')
    self.pool_name = attributes[:'pool_name']
  else
    self.pool_name = nil
  end

  if attributes.key?(:'recipient_integration_id')
    self.recipient_integration_id = attributes[:'recipient_integration_id']
  else
    self.recipient_integration_id = nil
  end

  if attributes.key?(:'giveaway_id')
    self.giveaway_id = attributes[:'giveaway_id']
  else
    self.giveaway_id = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end
end

Instance Attribute Details

#codeObject

The giveaway code that was awarded.



32
33
34
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 32

def code
  @code
end

#giveaway_idObject

The internal ID for the giveaway that was awarded.



29
30
31
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 29

def giveaway_id
  @giveaway_id
end

#pool_idObject

The ID of the giveaways pool the code was taken from.



20
21
22
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 20

def pool_id
  @pool_id
end

#pool_nameObject

The name of the giveaways pool the code was taken from.



23
24
25
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 23

def pool_name
  @pool_name
end

#recipient_integration_idObject

The integration ID of the profile that was awarded the giveaway.



26
27
28
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 26

def recipient_integration_id
  @recipient_integration_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 35

def self.attribute_map
  {
    :'pool_id' => :'poolId',
    :'pool_name' => :'poolName',
    :'recipient_integration_id' => :'recipientIntegrationId',
    :'giveaway_id' => :'giveawayId',
    :'code' => :'code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 56

def self.openapi_types
  {
    :'pool_id' => :'Integer',
    :'pool_name' => :'String',
    :'recipient_integration_id' => :'String',
    :'giveaway_id' => :'Integer',
    :'code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pool_id == o.pool_id &&
      pool_name == o.pool_name &&
      recipient_integration_id == o.recipient_integration_id &&
      giveaway_id == o.giveaway_id &&
      code == o.code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 238

def hash
  [pool_id, pool_name, recipient_integration_id, giveaway_id, code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pool_id.nil?
    invalid_properties.push('invalid value for "pool_id", pool_id cannot be nil.')
  end

  if @pool_name.nil?
    invalid_properties.push('invalid value for "pool_name", pool_name cannot be nil.')
  end

  if @recipient_integration_id.nil?
    invalid_properties.push('invalid value for "recipient_integration_id", recipient_integration_id cannot be nil.')
  end

  if @recipient_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @giveaway_id.nil?
    invalid_properties.push('invalid value for "giveaway_id", giveaway_id cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
161
162
# File 'lib/talon_one_sdk/models/award_giveaway_effect_props.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pool_id.nil?
  return false if @pool_name.nil?
  return false if @recipient_integration_id.nil?
  return false if @recipient_integration_id.to_s.length > 1000
  return false if @giveaway_id.nil?
  return false if @code.nil?
  true
end