Class: TalonOne::AwardItemBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AwardItemBlock
- Defined in:
- lib/talon_one_sdk/models/award_item_block.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier for this block.
-
#name ⇒ Object
The display name of the item to award.
-
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
-
#on_failure ⇒ Object
Blocks evaluated when this block fails or returns false.
-
#partial ⇒ Object
When set to
true, applies a partial item reward if the remaining budget is insufficient to award the full reward. -
#quantity ⇒ Object
The number of items to award.
-
#sku ⇒ Object
The stock keeping unit of the item to award.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AwardItemBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AwardItemBlock
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AwardItemBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AwardItemBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'sku') self.sku = attributes[:'sku'] else self.sku = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'partial') self.partial = attributes[:'partial'] end if attributes.key?(:'on_failure') if (value = attributes[:'on_failure']).is_a?(Array) self.on_failure = value end end if attributes.key?(:'on_error') if (value = attributes[:'on_error']).is_a?(Hash) self.on_error = value end end end |
Instance Attribute Details
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 19 def id @id end |
#name ⇒ Object
The display name of the item to award.
31 32 33 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 31 def name @name end |
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
43 44 45 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 43 def on_error @on_error end |
#on_failure ⇒ Object
Blocks evaluated when this block fails or returns false.
40 41 42 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 40 def on_failure @on_failure end |
#partial ⇒ Object
When set to true, applies a partial item reward if the remaining budget is insufficient to award the full reward.
37 38 39 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 37 def partial @partial end |
#quantity ⇒ Object
The number of items to award. Supports template placeholders (e.g. "/ 2}") for dynamic quantities.
34 35 36 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 34 def quantity @quantity end |
#sku ⇒ Object
The stock keeping unit of the item to award.
28 29 30 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 28 def sku @sku end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 25 def @tags end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 46 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'sku' => :'sku', :'name' => :'name', :'quantity' => :'quantity', :'partial' => :'partial', :'on_failure' => :'onFailure', :'on_error' => :'onError' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 288 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 92 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 71 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'sku' => :'String', :'name' => :'String', :'quantity' => :'String', :'partial' => :'Boolean', :'on_failure' => :'Array<Object>', :'on_error' => :'Hash<String, Array<Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && sku == o.sku && name == o.name && quantity == o.quantity && partial == o.partial && on_failure == o.on_failure && on_error == o.on_error end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 281 def hash [id, type, , sku, name, quantity, partial, on_failure, on_error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @sku.nil? invalid_properties.push('invalid value for "sku", sku cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/award_item_block.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @sku.nil? return false if @name.nil? return false if @quantity.nil? true end |