Class: TalonOne::BaseLoyaltyProgram
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::BaseLoyaltyProgram
- Defined in:
- lib/talon_one_sdk/models/base_loyalty_program.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allow_subledger ⇒ Object
Indicates if this program supports subledgers inside the program.
-
#card_code_settings ⇒ Object
Returns the value of attribute card_code_settings.
-
#default_pending ⇒ Object
The default duration of the pending time after which points should be valid.
-
#default_validity ⇒ Object
The default duration after which new loyalty points should expire.
-
#description ⇒ Object
Description of our Loyalty Program.
-
#program_join_policy ⇒ Object
The policy that defines when the customer joins the loyalty program.
-
#return_policy ⇒ Object
The policy that defines the rollback of points in case of a partially returned, cancelled, or reopened [customer session](docs.talon.one/docs/dev/concepts/entities/customer-sessions).
-
#sandbox ⇒ Object
Indicates if this program is a live or sandbox program.
-
#subscribed_applications ⇒ Object
A list containing the IDs of all applications that are subscribed to this Loyalty Program.
-
#tier_cycle_start_date ⇒ Object
Timestamp at which the tier cycle starts for all customers in the loyalty program.
-
#tiers_downgrade_policy ⇒ Object
The policy that defines how customer tiers are downgraded in the loyalty program after tier reevaluation.
-
#tiers_expiration_policy ⇒ Object
The policy that defines how tier expiration, used to reevaluate the customer’s current tier, is determined.
-
#tiers_expire_in ⇒ Object
The amount of time after which the tier expires and is reevaluated.
-
#title ⇒ Object
The display title for the Loyalty Program.
-
#users_per_card_limit ⇒ Object
The max amount of user profiles with whom a card can be shared.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BaseLoyaltyProgram
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BaseLoyaltyProgram
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BaseLoyaltyProgram` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BaseLoyaltyProgram`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'subscribed_applications') if (value = attributes[:'subscribed_applications']).is_a?(Array) self.subscribed_applications = value end end if attributes.key?(:'default_validity') self.default_validity = attributes[:'default_validity'] end if attributes.key?(:'default_pending') self.default_pending = attributes[:'default_pending'] end if attributes.key?(:'allow_subledger') self.allow_subledger = attributes[:'allow_subledger'] end if attributes.key?(:'users_per_card_limit') self.users_per_card_limit = attributes[:'users_per_card_limit'] end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] end if attributes.key?(:'program_join_policy') self.program_join_policy = attributes[:'program_join_policy'] end if attributes.key?(:'tiers_expiration_policy') self.tiers_expiration_policy = attributes[:'tiers_expiration_policy'] end if attributes.key?(:'tier_cycle_start_date') self.tier_cycle_start_date = attributes[:'tier_cycle_start_date'] end if attributes.key?(:'tiers_expire_in') self.tiers_expire_in = attributes[:'tiers_expire_in'] end if attributes.key?(:'tiers_downgrade_policy') self.tiers_downgrade_policy = attributes[:'tiers_downgrade_policy'] end if attributes.key?(:'card_code_settings') self.card_code_settings = attributes[:'card_code_settings'] end if attributes.key?(:'return_policy') self.return_policy = attributes[:'return_policy'] end end |
Instance Attribute Details
#allow_subledger ⇒ Object
Indicates if this program supports subledgers inside the program.
34 35 36 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 34 def allow_subledger @allow_subledger end |
#card_code_settings ⇒ Object
Returns the value of attribute card_code_settings.
57 58 59 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 57 def card_code_settings @card_code_settings end |
#default_pending ⇒ Object
The default duration of the pending time after which points should be valid. Accepted values: ‘immediate’, ‘on_action’ or a specific time. The time format is a number followed by one letter indicating the time unit, like ‘30s’, ‘40m’, ‘1h’, ‘5D’, ‘7W’, or 10M’. These rounding suffixes are also supported: - ‘_D’ for rounding down. Can be used as a suffix after ‘D’, and signifies the start of the day. - ‘_U’ for rounding up. Can be used as a suffix after ‘D’, ‘W’, and ‘M’, and signifies the end of the day, week, and month.
31 32 33 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 31 def default_pending @default_pending end |
#default_validity ⇒ Object
The default duration after which new loyalty points should expire. Can be ‘unlimited’ or a specific time. The time format is a number followed by one letter indicating the time unit, like ‘30s’, ‘40m’, ‘1h’, ‘5D’, ‘7W’, or 10M’. These rounding suffixes are also supported: - ‘_D’ for rounding down. Can be used as a suffix after ‘D’, and signifies the start of the day. - ‘_U’ for rounding up. Can be used as a suffix after ‘D’, ‘W’, and ‘M’, and signifies the end of the day, week, and month.
28 29 30 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 28 def default_validity @default_validity end |
#description ⇒ Object
Description of our Loyalty Program.
22 23 24 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 22 def description @description end |
#program_join_policy ⇒ Object
The policy that defines when the customer joins the loyalty program. - ‘not_join`: The customer does not join the loyalty program but can still earn and spend loyalty points. Note: The customer does not have a program join date. - `points_activated`: The customer joins the loyalty program only when their earned loyalty points become active for the first time. - `points_earned`: The customer joins the loyalty program when they earn loyalty points for the first time.
43 44 45 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 43 def program_join_policy @program_join_policy end |
#return_policy ⇒ Object
The policy that defines the rollback of points in case of a partially returned, cancelled, or reopened [customer session](docs.talon.one/docs/dev/concepts/entities/customer-sessions). - ‘only_pending`: Only pending points can be rolled back. - `within_balance`: Available active points can be rolled back if there aren’t enough pending points. The active balance of the customer cannot be negative. - ‘unlimited`: Allows negative balance without any limit.
60 61 62 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 60 def return_policy @return_policy end |
#sandbox ⇒ Object
Indicates if this program is a live or sandbox program. Programs of a given type can only be connected to Applications of the same type.
40 41 42 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 40 def sandbox @sandbox end |
#subscribed_applications ⇒ Object
A list containing the IDs of all applications that are subscribed to this Loyalty Program.
25 26 27 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 25 def subscribed_applications @subscribed_applications end |
#tier_cycle_start_date ⇒ Object
Timestamp at which the tier cycle starts for all customers in the loyalty program. Note: This is only required when the tier expiration policy is set to ‘absolute_expiration`.
49 50 51 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 49 def tier_cycle_start_date @tier_cycle_start_date end |
#tiers_downgrade_policy ⇒ Object
The policy that defines how customer tiers are downgraded in the loyalty program after tier reevaluation. - ‘one_down`: If the customer doesn’t have enough points to stay in the current tier, they are downgraded by one tier. - ‘balance_based`: The customer’s tier is reevaluated based on the amount of active points they have at the moment.
55 56 57 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 55 def tiers_downgrade_policy @tiers_downgrade_policy end |
#tiers_expiration_policy ⇒ Object
The policy that defines how tier expiration, used to reevaluate the customer’s current tier, is determined. - ‘tier_start_date`: The tier expiration is relative to when the customer joined the current tier. - `program_join_date`: The tier expiration is relative to when the customer joined the loyalty program. - `customer_attribute`: The tier expiration is determined by a custom customer attribute. - `absolute_expiration`: The tier is reevaluated at the start of each tier cycle. For this policy, it is required to provide a `tierCycleStartDate`.
46 47 48 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 46 def tiers_expiration_policy @tiers_expiration_policy end |
#tiers_expire_in ⇒ Object
The amount of time after which the tier expires and is reevaluated. The time format is an integer followed by one letter indicating the time unit. Examples: ‘30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can round certain units up or down: - `_D` for rounding down days only. Signifies the start of the day. - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year.
52 53 54 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 52 def tiers_expire_in @tiers_expire_in end |
#title ⇒ Object
The display title for the Loyalty Program.
19 20 21 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 19 def title @title end |
#users_per_card_limit ⇒ Object
The max amount of user profiles with whom a card can be shared. This can be set to 0 for no limit. This property is only used when ‘cardBased` is `true`.
37 38 39 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 37 def users_per_card_limit @users_per_card_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
106 107 108 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 106 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
111 112 113 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 111 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 85 def self.attribute_map { :'title' => :'title', :'description' => :'description', :'subscribed_applications' => :'subscribedApplications', :'default_validity' => :'defaultValidity', :'default_pending' => :'defaultPending', :'allow_subledger' => :'allowSubledger', :'users_per_card_limit' => :'usersPerCardLimit', :'sandbox' => :'sandbox', :'program_join_policy' => :'programJoinPolicy', :'tiers_expiration_policy' => :'tiersExpirationPolicy', :'tier_cycle_start_date' => :'tierCycleStartDate', :'tiers_expire_in' => :'tiersExpireIn', :'tiers_downgrade_policy' => :'tiersDowngradePolicy', :'card_code_settings' => :'cardCodeSettings', :'return_policy' => :'returnPolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 340 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 137 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 116 def self.openapi_types { :'title' => :'String', :'description' => :'String', :'subscribed_applications' => :'Array<Integer>', :'default_validity' => :'String', :'default_pending' => :'String', :'allow_subledger' => :'Boolean', :'users_per_card_limit' => :'Integer', :'sandbox' => :'Boolean', :'program_join_policy' => :'String', :'tiers_expiration_policy' => :'String', :'tier_cycle_start_date' => :'Time', :'tiers_expire_in' => :'String', :'tiers_downgrade_policy' => :'String', :'card_code_settings' => :'CodeGeneratorSettings', :'return_policy' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && description == o.description && subscribed_applications == o.subscribed_applications && default_validity == o.default_validity && default_pending == o.default_pending && allow_subledger == o.allow_subledger && users_per_card_limit == o.users_per_card_limit && sandbox == o.sandbox && program_join_policy == o.program_join_policy && tiers_expiration_policy == o.tiers_expiration_policy && tier_cycle_start_date == o.tier_cycle_start_date && tiers_expire_in == o.tiers_expire_in && tiers_downgrade_policy == o.tiers_downgrade_policy && card_code_settings == o.card_code_settings && return_policy == o.return_policy end |
#eql?(o) ⇒ Boolean
327 328 329 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 327 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 333 def hash [title, description, subscribed_applications, default_validity, default_pending, allow_subledger, users_per_card_limit, sandbox, program_join_policy, tiers_expiration_policy, tier_cycle_start_date, tiers_expire_in, tiers_downgrade_policy, card_code_settings, return_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
223 224 225 226 227 228 229 230 231 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 223 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@users_per_card_limit.nil? && @users_per_card_limit < 0 invalid_properties.push('invalid value for "users_per_card_limit", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 362 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/talon_one_sdk/models/base_loyalty_program.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@users_per_card_limit.nil? && @users_per_card_limit < 0 program_join_policy_validator = EnumAttributeValidator.new('String', ["not_join", "points_activated", "points_earned"]) return false unless program_join_policy_validator.valid?(@program_join_policy) tiers_expiration_policy_validator = EnumAttributeValidator.new('String', ["tier_start_date", "program_join_date", "customer_attribute", "absolute_expiration"]) return false unless tiers_expiration_policy_validator.valid?(@tiers_expiration_policy) tiers_downgrade_policy_validator = EnumAttributeValidator.new('String', ["one_down", "balance_based"]) return false unless tiers_downgrade_policy_validator.valid?(@tiers_downgrade_policy) return_policy_validator = EnumAttributeValidator.new('String', ["only_pending", "within_balance", "unlimited"]) return false unless return_policy_validator.valid?(@return_policy) true end |