Class: TalonOne::BaseNotification
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::BaseNotification
- Defined in:
- lib/talon_one_sdk/models/base_notification.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Indicates whether the notification is activated.
-
#id ⇒ Object
Unique ID for this entity.
-
#policy ⇒ Object
Returns the value of attribute policy.
-
#type ⇒ Object
The notification type.
-
#webhook ⇒ Object
Returns the value of attribute webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BaseNotification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BaseNotification
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BaseNotification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BaseNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'policy') self.policy = attributes[:'policy'] else self.policy = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = true end if attributes.key?(:'webhook') self.webhook = attributes[:'webhook'] else self.webhook = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#enabled ⇒ Object
Indicates whether the notification is activated.
21 22 23 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 21 def enabled @enabled end |
#id ⇒ Object
Unique ID for this entity.
26 27 28 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 26 def id @id end |
#policy ⇒ Object
Returns the value of attribute policy.
18 19 20 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 18 def policy @policy end |
#type ⇒ Object
The notification type.
29 30 31 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 29 def type @type end |
#webhook ⇒ Object
Returns the value of attribute webhook.
23 24 25 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 23 def webhook @webhook end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 54 def self.attribute_map { :'policy' => :'policy', :'enabled' => :'enabled', :'webhook' => :'webhook', :'id' => :'id', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 258 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 92 def self.openapi_all_of [ :'BaseNotificationEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 75 def self.openapi_types { :'policy' => :'BaseNotificationPolicy', :'enabled' => :'Boolean', :'webhook' => :'BaseNotificationWebhook', :'id' => :'Integer', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && policy == o.policy && enabled == o.enabled && webhook == o.webhook && id == o.id && type == o.type end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 251 def hash [policy, enabled, webhook, id, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @policy.nil? invalid_properties.push('invalid value for "policy", policy cannot be nil.') end if @webhook.nil? invalid_properties.push('invalid value for "webhook", webhook cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id < 1 invalid_properties.push('invalid value for "id", must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/talon_one_sdk/models/base_notification.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @policy.nil? return false if @webhook.nil? return false if @id.nil? return false if @id < 1 return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["campaign", "loyalty_added_deducted_points", "card_added_deducted_points", "loyalty_added_deducted_points_balances", "loyalty_card_added_deducted_points_balances", "coupon", "expiring_coupons", "expiring_points", "card_expiring_points", "pending_to_active_points", "strikethrough_pricing", "tier_downgrade", "tier_upgrade", "tier_will_downgrade"]) return false unless type_validator.valid?(@type) true end |