Class: TalonOne::BaseNotificationWebhook

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/base_notification_webhook.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BaseNotificationWebhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BaseNotificationWebhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BaseNotificationWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  else
    self.headers = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = true
  end
end

Instance Attribute Details

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 22

def created
  @created
end

#enabledObject

Indicates whether the notification is activated.



34
35
36
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 34

def enabled
  @enabled
end

#headersObject

List of API HTTP headers for the given webhook-based notification.



31
32
33
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 31

def headers
  @headers
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 19

def id
  @id
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 25

def modified
  @modified
end

#urlObject

API URL for the given webhook-based notification.



28
29
30
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 28

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'url' => :'url',
    :'headers' => :'headers',
    :'enabled' => :'enabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



77
78
79
80
81
82
83
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 77

def self.openapi_all_of
  [
  :'Entity',
  :'MutableEntity',
  :'NewNotificationWebhook'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 59

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'url' => :'String',
    :'headers' => :'Array<String>',
    :'enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
      url == o.url &&
      headers == o.headers &&
      enabled == o.enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 251

def hash
  [id, created, modified, url, headers, enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @headers.nil?
    invalid_properties.push('invalid value for "headers", headers cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
# File 'lib/talon_one_sdk/models/base_notification_webhook.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @url.nil?
  return false if @headers.nil?
  true
end