Class: TalonOne::BestPriorPriceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/best_prior_price_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BestPriorPriceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BestPriorPriceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BestPriorPriceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'skus')
    if (value = attributes[:'skus']).is_a?(Array)
      self.skus = value
    end
  else
    self.skus = nil
  end

  if attributes.key?(:'timeframe_end_date')
    self.timeframe_end_date = attributes[:'timeframe_end_date']
  else
    self.timeframe_end_date = nil
  end

  if attributes.key?(:'timeframe')
    self.timeframe = attributes[:'timeframe']
  else
    self.timeframe = nil
  end

  if attributes.key?(:'timeframe_end_date_type')
    self.timeframe_end_date_type = attributes[:'timeframe_end_date_type']
  else
    self.timeframe_end_date_type = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end
end

Instance Attribute Details

#skusObject

List of product SKUs to check when determining the best prior price.



19
20
21
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 19

def skus
  @skus
end

#targetObject

Returns the value of attribute target.



30
31
32
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 30

def target
  @target
end

#timeframeObject

The number of days prior to the timeframeEndDate. Only prices within this look back period are considered for the best prior price evaluation.



25
26
27
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 25

def timeframe
  @timeframe
end

#timeframe_end_dateObject

The end date and time that defines the latest time for retrieving historical SKU prices.



22
23
24
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 22

def timeframe_end_date
  @timeframe_end_date
end

#timeframe_end_date_typeObject

Sets the timeframe for retrieving historical pricing data. Can be one of the following values: - ‘strict`: The timeframe ends at the `timeframeEndDate` value. - `price`: The timeframe ends at the start of current price value and takes the prices prior to the start of the current price value into account. - `sale`: The timeframe ends at the start of current `contextId` and takes the prices prior to the start of the `contextId` into account.



28
29
30
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 28

def timeframe_end_date_type
  @timeframe_end_date_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 55

def self.attribute_map
  {
    :'skus' => :'skus',
    :'timeframe_end_date' => :'timeframeEndDate',
    :'timeframe' => :'timeframe',
    :'timeframe_end_date_type' => :'timeframeEndDateType',
    :'target' => :'target'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 252

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 76

def self.openapi_types
  {
    :'skus' => :'Array<String>',
    :'timeframe_end_date' => :'Time',
    :'timeframe' => :'String',
    :'timeframe_end_date_type' => :'String',
    :'target' => :'BestPriorTarget'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      skus == o.skus &&
      timeframe_end_date == o.timeframe_end_date &&
      timeframe == o.timeframe &&
      timeframe_end_date_type == o.timeframe_end_date_type &&
      target == o.target
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


239
240
241
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



245
246
247
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 245

def hash
  [skus, timeframe_end_date, timeframe, timeframe_end_date_type, target].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @skus.nil?
    invalid_properties.push('invalid value for "skus", skus cannot be nil.')
  end

  if @skus.length < 1
    invalid_properties.push('invalid value for "skus", number of items must be greater than or equal to 1.')
  end

  if @timeframe_end_date.nil?
    invalid_properties.push('invalid value for "timeframe_end_date", timeframe_end_date cannot be nil.')
  end

  if @timeframe.nil?
    invalid_properties.push('invalid value for "timeframe", timeframe cannot be nil.')
  end

  if @timeframe_end_date_type.nil?
    invalid_properties.push('invalid value for "timeframe_end_date_type", timeframe_end_date_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/best_prior_price_request.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @skus.nil?
  return false if @skus.length < 1
  return false if @timeframe_end_date.nil?
  return false if @timeframe.nil?
  return false if @timeframe_end_date_type.nil?
  timeframe_end_date_type_validator = EnumAttributeValidator.new('String', ["strict", "price", "sale"])
  return false unless timeframe_end_date_type_validator.valid?(@timeframe_end_date_type)
  true
end