Class: TalonOne::Binding

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/binding.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Binding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/talon_one_sdk/models/binding.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Binding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Binding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'expression')
    if (value = attributes[:'expression']).is_a?(Array)
      self.expression = value
    end
  else
    self.expression = nil
  end

  if attributes.key?(:'value_type')
    self.value_type = attributes[:'value_type']
  end

  if attributes.key?(:'min_value')
    self.min_value = attributes[:'min_value']
  end

  if attributes.key?(:'max_value')
    self.max_value = attributes[:'max_value']
  end

  if attributes.key?(:'attribute_id')
    self.attribute_id = attributes[:'attribute_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end
end

Instance Attribute Details

#attribute_idObject

Id of the attribute attached to the placeholder.



37
38
39
# File 'lib/talon_one_sdk/models/binding.rb', line 37

def attribute_id
  @attribute_id
end

#descriptionObject

Describes the placeholder field and value in the template. This description can be used when creating campaigns from this template.



40
41
42
# File 'lib/talon_one_sdk/models/binding.rb', line 40

def description
  @description
end

#expressionObject

A Talang expression that will be evaluated and its result attached to the name of the binding.



25
26
27
# File 'lib/talon_one_sdk/models/binding.rb', line 25

def expression
  @expression
end

#max_valueObject

The maximum value allowed for this placeholder.



34
35
36
# File 'lib/talon_one_sdk/models/binding.rb', line 34

def max_value
  @max_value
end

#min_valueObject

The minimum value allowed for this placeholder.



31
32
33
# File 'lib/talon_one_sdk/models/binding.rb', line 31

def min_value
  @min_value
end

#nameObject

A descriptive name for the value to be bound.



19
20
21
# File 'lib/talon_one_sdk/models/binding.rb', line 19

def name
  @name
end

#typeObject

The kind of binding. Possible values are: - ‘bundle` - `cartItemFilter` - `subledgerBalance` - `templateParameter`



22
23
24
# File 'lib/talon_one_sdk/models/binding.rb', line 22

def type
  @type
end

#value_typeObject

Can be one of the following: - ‘string` - `number` - `boolean`



28
29
30
# File 'lib/talon_one_sdk/models/binding.rb', line 28

def value_type
  @value_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/binding.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/binding.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/binding.rb', line 43

def self.attribute_map
  {
    :'name' => :'name',
    :'type' => :'type',
    :'expression' => :'expression',
    :'value_type' => :'valueType',
    :'min_value' => :'minValue',
    :'max_value' => :'maxValue',
    :'attribute_id' => :'attributeId',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/talon_one_sdk/models/binding.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/binding.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/binding.rb', line 67

def self.openapi_types
  {
    :'name' => :'String',
    :'type' => :'String',
    :'expression' => :'Array<Object>',
    :'value_type' => :'String',
    :'min_value' => :'Float',
    :'max_value' => :'Float',
    :'attribute_id' => :'Integer',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/talon_one_sdk/models/binding.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      type == o.type &&
      expression == o.expression &&
      value_type == o.value_type &&
      min_value == o.min_value &&
      max_value == o.max_value &&
      attribute_id == o.attribute_id &&
      description == o.description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/talon_one_sdk/models/binding.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/talon_one_sdk/models/binding.rb', line 209

def hash
  [name, type, expression, value_type, min_value, max_value, attribute_id, description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/talon_one_sdk/models/binding.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @expression.nil?
    invalid_properties.push('invalid value for "expression", expression cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/talon_one_sdk/models/binding.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
# File 'lib/talon_one_sdk/models/binding.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @expression.nil?
  true
end