Class: TalonOne::Blueprint

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/blueprint.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Blueprint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/talon_one_sdk/models/blueprint.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Blueprint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Blueprint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  else
    self.rules = nil
  end

  if attributes.key?(:'cart_item_filters')
    if (value = attributes[:'cart_item_filters']).is_a?(Array)
      self.cart_item_filters = value
    end
  else
    self.cart_item_filters = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this blueprint.



22
23
24
# File 'lib/talon_one_sdk/models/blueprint.rb', line 22

def 
  @account_id
end

#application_idObject

The ID of the Application that owns this blueprint.



25
26
27
# File 'lib/talon_one_sdk/models/blueprint.rb', line 25

def application_id
  @application_id
end

#cart_item_filtersObject

Array of cart item filter templates in this blueprint. Cart item filters only contain name (no description, as description is at the blueprint level).



43
44
45
# File 'lib/talon_one_sdk/models/blueprint.rb', line 43

def cart_item_filters
  @cart_item_filters
end

#categoryObject

Category used to group blueprints.



34
35
36
# File 'lib/talon_one_sdk/models/blueprint.rb', line 34

def category
  @category
end

#createdObject

Timestamp when the blueprint was created.



46
47
48
# File 'lib/talon_one_sdk/models/blueprint.rb', line 46

def created
  @created
end

#created_byObject

ID of the user who created the blueprint.



49
50
51
# File 'lib/talon_one_sdk/models/blueprint.rb', line 49

def created_by
  @created_by
end

#descriptionObject

A longer, more detailed description of the blueprint.



31
32
33
# File 'lib/talon_one_sdk/models/blueprint.rb', line 31

def description
  @description
end

#idObject

The internal ID of this blueprint.



19
20
21
# File 'lib/talon_one_sdk/models/blueprint.rb', line 19

def id
  @id
end

#modifiedObject

Timestamp when the blueprint was last updated.



52
53
54
# File 'lib/talon_one_sdk/models/blueprint.rb', line 52

def modified
  @modified
end

#modified_byObject

ID of the user who last updated the blueprint.



55
56
57
# File 'lib/talon_one_sdk/models/blueprint.rb', line 55

def modified_by
  @modified_by
end

#rulesObject

Array of rule templates in this blueprint. Rules only contain title (no description, as description is at the blueprint level).



40
41
42
# File 'lib/talon_one_sdk/models/blueprint.rb', line 40

def rules
  @rules
end

#sourceObject

Indicates whether the blueprint is custom or shipped by Talon.One.



37
38
39
# File 'lib/talon_one_sdk/models/blueprint.rb', line 37

def source
  @source
end

#titleObject

A short description of the blueprint.



28
29
30
# File 'lib/talon_one_sdk/models/blueprint.rb', line 28

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/talon_one_sdk/models/blueprint.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/talon_one_sdk/models/blueprint.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/talon_one_sdk/models/blueprint.rb', line 80

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'application_id' => :'applicationId',
    :'title' => :'title',
    :'description' => :'description',
    :'category' => :'category',
    :'source' => :'source',
    :'rules' => :'rules',
    :'cart_item_filters' => :'cartItemFilters',
    :'created' => :'created',
    :'created_by' => :'createdBy',
    :'modified' => :'modified',
    :'modified_by' => :'modifiedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/talon_one_sdk/models/blueprint.rb', line 430

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/talon_one_sdk/models/blueprint.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/talon_one_sdk/models/blueprint.rb', line 109

def self.openapi_types
  {
    :'id' => :'Integer',
    :'account_id' => :'Integer',
    :'application_id' => :'Integer',
    :'title' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'source' => :'String',
    :'rules' => :'Array<CatalogRule>',
    :'cart_item_filters' => :'Array<CartItemFilterTemplate>',
    :'created' => :'Time',
    :'created_by' => :'Integer',
    :'modified' => :'Time',
    :'modified_by' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/talon_one_sdk/models/blueprint.rb', line 397

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      application_id == o.application_id &&
      title == o.title &&
      description == o.description &&
      category == o.category &&
      source == o.source &&
      rules == o.rules &&
      cart_item_filters == o.cart_item_filters &&
      created == o.created &&
      created_by == o.created_by &&
      modified == o.modified &&
      modified_by == o.modified_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


417
418
419
# File 'lib/talon_one_sdk/models/blueprint.rb', line 417

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



423
424
425
# File 'lib/talon_one_sdk/models/blueprint.rb', line 423

def hash
  [id, , application_id, title, description, category, source, rules, cart_item_filters, created, created_by, modified, modified_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/talon_one_sdk/models/blueprint.rb', line 228

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @rules.nil?
    invalid_properties.push('invalid value for "rules", rules cannot be nil.')
  end

  if @cart_item_filters.nil?
    invalid_properties.push('invalid value for "cart_item_filters", cart_item_filters cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/talon_one_sdk/models/blueprint.rb', line 452

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/talon_one_sdk/models/blueprint.rb', line 276

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @account_id.nil?
  return false if @application_id.nil?
  return false if @title.nil?
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["promotions", "pricing", "loyalty", "custom"])
  return false unless category_validator.valid?(@category)
  return false if @source.nil?
  source_validator = EnumAttributeValidator.new('String', ["custom", "default"])
  return false unless source_validator.valid?(@source)
  return false if @rules.nil?
  return false if @cart_item_filters.nil?
  return false if @created.nil?
  return false if @created_by.nil?
  true
end