Class: TalonOne::Bundle

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/bundle.rb

Overview

A named bundle definition consisting of selector sources with matching constraints. Replaces bundle bindings in V1 rulesets.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Bundle

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/talon_one_sdk/models/bundle.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Bundle` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Bundle`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'sources')
    if (value = attributes[:'sources']).is_a?(Array)
      self.sources = value
    end
  else
    self.sources = nil
  end

  if attributes.key?(:'counts')
    if (value = attributes[:'counts']).is_a?(Array)
      self.counts = value
    end
  else
    self.counts = nil
  end

  if attributes.key?(:'matchers')
    if (value = attributes[:'matchers']).is_a?(Array)
      self.matchers = value
    end
  end
end

Instance Attribute Details

#countsObject

The number of items to retrieve from each corresponding source in sources.



32
33
34
# File 'lib/talon_one_sdk/models/bundle.rb', line 32

def counts
  @counts
end

#idObject

An identifier derived from the bundle content.



20
21
22
# File 'lib/talon_one_sdk/models/bundle.rb', line 20

def id
  @id
end

#matchersObject

Attribute names that the bundled items must share.



35
36
37
# File 'lib/talon_one_sdk/models/bundle.rb', line 35

def matchers
  @matchers
end

#nameObject

The name of the bundle.



23
24
25
# File 'lib/talon_one_sdk/models/bundle.rb', line 23

def name
  @name
end

#sourcesObject

The selector sources of bundle items. Each source is expressed as a {{$selectorName}} reference.



29
30
31
# File 'lib/talon_one_sdk/models/bundle.rb', line 29

def sources
  @sources
end

#typeObject

A binding of type bundle.



26
27
28
# File 'lib/talon_one_sdk/models/bundle.rb', line 26

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/talon_one_sdk/models/bundle.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/talon_one_sdk/models/bundle.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/bundle.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'type' => :'type',
    :'sources' => :'sources',
    :'counts' => :'counts',
    :'matchers' => :'matchers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/talon_one_sdk/models/bundle.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/talon_one_sdk/models/bundle.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
# File 'lib/talon_one_sdk/models/bundle.rb', line 82

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'sources' => :'Array<String>',
    :'counts' => :'Array<Integer>',
    :'matchers' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
# File 'lib/talon_one_sdk/models/bundle.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      type == o.type &&
      sources == o.sources &&
      counts == o.counts &&
      matchers == o.matchers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/talon_one_sdk/models/bundle.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/talon_one_sdk/models/bundle.rb', line 269

def hash
  [id, name, type, sources, counts, matchers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/bundle.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @sources.nil?
    invalid_properties.push('invalid value for "sources", sources cannot be nil.')
  end

  if @counts.nil?
    invalid_properties.push('invalid value for "counts", counts cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/talon_one_sdk/models/bundle.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/talon_one_sdk/models/bundle.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["bundle"])
  return false unless type_validator.valid?(@type)
  return false if @sources.nil?
  return false if @counts.nil?
  true
end