Class: TalonOne::CampaignSet

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/campaign_set.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignSet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignSet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignSet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'set')
    self.set = attributes[:'set']
  else
    self.set = nil
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



19
20
21
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 19

def application_id
  @application_id
end

#idObject

The internal ID of this entity.



22
23
24
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 22

def id
  @id
end

#setObject

Returns the value of attribute set.



27
28
29
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 27

def set
  @set
end

#updated_byObject

Name of the user who last updated this campaign set, if available.



30
31
32
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 30

def updated_by
  @updated_by
end

#versionObject

Version of the campaign set.



25
26
27
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 25

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 33

def self.attribute_map
  {
    :'application_id' => :'applicationId',
    :'id' => :'id',
    :'version' => :'version',
    :'set' => :'set',
    :'updated_by' => :'updatedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



71
72
73
74
75
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 71

def self.openapi_all_of
  [
  :'ApplicationEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 54

def self.openapi_types
  {
    :'application_id' => :'Integer',
    :'id' => :'Integer',
    :'version' => :'Integer',
    :'set' => :'CampaignSetBranchNode',
    :'updated_by' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      application_id == o.application_id &&
      id == o.id &&
      version == o.version &&
      set == o.set &&
      updated_by == o.updated_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 226

def hash
  [application_id, id, version, set, updated_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @version < 1
    invalid_properties.push('invalid value for "version", must be greater than or equal to 1.')
  end

  if @set.nil?
    invalid_properties.push('invalid value for "set", set cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/campaign_set.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @application_id.nil?
  return false if @id.nil?
  return false if @version.nil?
  return false if @version < 1
  return false if @set.nil?
  true
end