Class: TalonOne::CampaignStateChangedNotificationItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignStateChangedNotificationItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignStateChangedNotificationItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignStateChangedNotificationItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'campaign')
    self.campaign = attributes[:'campaign']
  else
    self.campaign = nil
  end

  if attributes.key?(:'old_state')
    self.old_state = attributes[:'old_state']
  else
    self.old_state = nil
  end

  if attributes.key?(:'new_state')
    self.new_state = attributes[:'new_state']
  else
    self.new_state = nil
  end

  if attributes.key?(:'ruleset')
    self.ruleset = attributes[:'ruleset']
  end

  if attributes.key?(:'placeholders')
    if (value = attributes[:'placeholders']).is_a?(Array)
      self.placeholders = value
    end
  end
end

Instance Attribute Details

#campaignObject

The campaign whose state changed.



22
23
24
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 22

def campaign
  @campaign
end

#eventObject

The type of the event. Can be one of the following: [‘campaign_state_changed’, ‘campaign_ruleset_changed’, ‘campaign_edited’, ‘campaign_created’, ‘campaign_deleted’]



19
20
21
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 19

def event
  @event
end

#new_stateObject

The campaign’s new state. Can be one of the following: [‘running’, ‘disabled’, ‘scheduled’, ‘expired’, ‘archived’]



28
29
30
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 28

def new_state
  @new_state
end

#old_stateObject

The campaign’s old state. Can be one of the following: [‘running’, ‘disabled’, ‘scheduled’, ‘expired’, ‘archived’]



25
26
27
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 25

def old_state
  @old_state
end

#placeholdersObject

The current details of the [placeholders](docs.talon.one/docs/product/campaigns/templates/create-templates#use-placeholders) in the campaign.



34
35
36
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 34

def placeholders
  @placeholders
end

#rulesetObject

The current ruleset.



31
32
33
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 31

def ruleset
  @ruleset
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 37

def self.attribute_map
  {
    :'event' => :'Event',
    :'campaign' => :'campaign',
    :'old_state' => :'oldState',
    :'new_state' => :'newState',
    :'ruleset' => :'ruleset',
    :'placeholders' => :'placeholders'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



77
78
79
80
81
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 77

def self.openapi_all_of
  [
  :'CampaignNotificationItemBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 59

def self.openapi_types
  {
    :'event' => :'String',
    :'campaign' => :'Campaign',
    :'old_state' => :'String',
    :'new_state' => :'String',
    :'ruleset' => :'Ruleset',
    :'placeholders' => :'Array<PlaceholderDetails>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      campaign == o.campaign &&
      old_state == o.old_state &&
      new_state == o.new_state &&
      ruleset == o.ruleset &&
      placeholders == o.placeholders
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 230

def hash
  [event, campaign, old_state, new_state, ruleset, placeholders].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @campaign.nil?
    invalid_properties.push('invalid value for "campaign", campaign cannot be nil.')
  end

  if @old_state.nil?
    invalid_properties.push('invalid value for "old_state", old_state cannot be nil.')
  end

  if @new_state.nil?
    invalid_properties.push('invalid value for "new_state", new_state cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
# File 'lib/talon_one_sdk/models/campaign_state_changed_notification_item.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event.nil?
  return false if @campaign.nil?
  return false if @old_state.nil?
  return false if @new_state.nil?
  true
end