Class: TalonOne::CardAddedDeductedPointsBalancesNotification

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CardAddedDeductedPointsBalancesNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CardAddedDeductedPointsBalancesNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CardAddedDeductedPointsBalancesNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  else
    self.card_identifier = nil
  end

  if attributes.key?(:'employee_name')
    self.employee_name = attributes[:'employee_name']
  else
    self.employee_name = nil
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'notification_type')
    self.notification_type = attributes[:'notification_type']
  else
    self.notification_type = nil
  end

  if attributes.key?(:'profile_integration_ids')
    if (value = attributes[:'profile_integration_ids']).is_a?(Array)
      self.profile_integration_ids = value
    end
  else
    self.profile_integration_ids = nil
  end

  if attributes.key?(:'session_integration_id')
    self.session_integration_id = attributes[:'session_integration_id']
  else
    self.session_integration_id = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'type_of_change')
    self.type_of_change = attributes[:'type_of_change']
  else
    self.type_of_change = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'users_per_card_limit')
    self.users_per_card_limit = attributes[:'users_per_card_limit']
  else
    self.users_per_card_limit = nil
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  else
    self.actions = nil
  end

  if attributes.key?(:'current_points')
    self.current_points = attributes[:'current_points']
  else
    self.current_points = nil
  end
end

Instance Attribute Details

#actionsObject

The list of actions that have been triggered in the loyalty program.



49
50
51
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 49

def actions
  @actions
end

#card_identifierObject

Loyalty card identification number.



19
20
21
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 19

def card_identifier
  @card_identifier
end

#current_pointsObject

The current points balance.



52
53
54
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 52

def current_points
  @current_points
end

#employee_nameObject

The name of the employee who added or deducted points.



22
23
24
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 22

def employee_name
  @employee_name
end

#loyalty_program_idObject

The ID of the loyalty program.



25
26
27
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 25

def loyalty_program_id
  @loyalty_program_id
end

#notification_typeObject

The type of notification.



28
29
30
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 28

def notification_type
  @notification_type
end

#profile_integration_idsObject

The integration ID of the customer profile to whom points were added or deducted.



31
32
33
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 31

def profile_integration_ids
  @profile_integration_ids
end

#session_integration_idObject

The integration ID of the session through which the points were earned or lost.



34
35
36
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 34

def session_integration_id
  @session_integration_id
end

#subledger_idObject

The ID of the subledger within the loyalty program where these points were added or deducted.



37
38
39
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 37

def subledger_id
  @subledger_id
end

#type_of_changeObject

The notification source, that is, it indicates whether the points were added or deducted via one of the following routes: - [The Campaign Manager](/docs/product/getting-started) - [Management API](/management-api#tag/Loyalty) - [Rule Engine](/docs/product/applications/evaluation-order-for-rules-and-filters)



40
41
42
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 40

def type_of_change
  @type_of_change
end

#user_idObject

The ID of the employee who added or deducted points.



43
44
45
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 43

def user_id
  @user_id
end

#users_per_card_limitObject

The max amount of user profiles with whom a card can be shared. This can be set to ‘0` for no limit.



46
47
48
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 46

def users_per_card_limit
  @users_per_card_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 77

def self.attribute_map
  {
    :'card_identifier' => :'CardIdentifier',
    :'employee_name' => :'EmployeeName',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'notification_type' => :'NotificationType',
    :'profile_integration_ids' => :'ProfileIntegrationIDs',
    :'session_integration_id' => :'SessionIntegrationID',
    :'subledger_id' => :'SubledgerID',
    :'type_of_change' => :'TypeOfChange',
    :'user_id' => :'UserID',
    :'users_per_card_limit' => :'UsersPerCardLimit',
    :'actions' => :'Actions',
    :'current_points' => :'CurrentPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 472

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 105

def self.openapi_types
  {
    :'card_identifier' => :'String',
    :'employee_name' => :'String',
    :'loyalty_program_id' => :'Integer',
    :'notification_type' => :'String',
    :'profile_integration_ids' => :'Array<String>',
    :'session_integration_id' => :'String',
    :'subledger_id' => :'String',
    :'type_of_change' => :'String',
    :'user_id' => :'Integer',
    :'users_per_card_limit' => :'Integer',
    :'actions' => :'Array<AddedDeductedPointsBalancesAction>',
    :'current_points' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 440

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      card_identifier == o.card_identifier &&
      employee_name == o.employee_name &&
      loyalty_program_id == o.loyalty_program_id &&
      notification_type == o.notification_type &&
      profile_integration_ids == o.profile_integration_ids &&
      session_integration_id == o.session_integration_id &&
      subledger_id == o.subledger_id &&
      type_of_change == o.type_of_change &&
      user_id == o.user_id &&
      users_per_card_limit == o.users_per_card_limit &&
      actions == o.actions &&
      current_points == o.current_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


459
460
461
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 459

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



465
466
467
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 465

def hash
  [card_identifier, employee_name, loyalty_program_id, notification_type, profile_integration_ids, session_integration_id, subledger_id, type_of_change, user_id, users_per_card_limit, actions, current_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @card_identifier.nil?
    invalid_properties.push('invalid value for "card_identifier", card_identifier cannot be nil.')
  end

  if @employee_name.nil?
    invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @notification_type.nil?
    invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.')
  end

  if @profile_integration_ids.nil?
    invalid_properties.push('invalid value for "profile_integration_ids", profile_integration_ids cannot be nil.')
  end

  if @session_integration_id.nil?
    invalid_properties.push('invalid value for "session_integration_id", session_integration_id cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @type_of_change.nil?
    invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @users_per_card_limit.nil?
    invalid_properties.push('invalid value for "users_per_card_limit", users_per_card_limit cannot be nil.')
  end

  if @actions.nil?
    invalid_properties.push('invalid value for "actions", actions cannot be nil.')
  end

  if @actions.length < 1
    invalid_properties.push('invalid value for "actions", number of items must be greater than or equal to 1.')
  end

  if @current_points.nil?
    invalid_properties.push('invalid value for "current_points", current_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 494

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/talon_one_sdk/models/card_added_deducted_points_balances_notification.rb', line 287

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @card_identifier.nil?
  return false if @employee_name.nil?
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @notification_type.nil?
  notification_type_validator = EnumAttributeValidator.new('String', ["LoyaltyCardAddedDeductedPointsBalances"])
  return false unless notification_type_validator.valid?(@notification_type)
  return false if @profile_integration_ids.nil?
  return false if @session_integration_id.nil?
  return false if @subledger_id.nil?
  return false if @type_of_change.nil?
  type_of_change_validator = EnumAttributeValidator.new('String', ["campaign_manager", "rule_engine", "management_api"])
  return false unless type_of_change_validator.valid?(@type_of_change)
  return false if @user_id.nil?
  return false if @users_per_card_limit.nil?
  return false if @actions.nil?
  return false if @actions.length < 1
  return false if @current_points.nil?
  true
end