Class: TalonOne::CardLedgerTransactionLogEntry

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb

Overview

Log entry for a given loyalty card transaction.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CardLedgerTransactionLogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CardLedgerTransactionLogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CardLedgerTransactionLogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  else
    self.card_identifier = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  end

  if attributes.key?(:'customer_session_id')
    self.customer_session_id = attributes[:'customer_session_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  else
    self.start_date = nil
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end
end

Instance Attribute Details

#amountObject

Amount of loyalty points added or deducted in the transaction.



56
57
58
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 56

def amount
  @amount
end

#application_idObject

The ID of the Application that owns this entity.



32
33
34
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 32

def application_id
  @application_id
end

#card_identifierObject

The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.



29
30
31
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 29

def card_identifier
  @card_identifier
end

#createdObject

Date and time the loyalty card transaction occurred.



23
24
25
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 23

def created
  @created
end

#customer_session_idObject

ID of the customer session where the transaction occurred.



38
39
40
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 38

def customer_session_id
  @customer_session_id
end

#expiry_dateObject

Date when points expire. Possible values are: - ‘unlimited`: Points have no expiration date. - `timestamp value`: Points become active from the given date.



50
51
52
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 50

def expiry_date
  @expiry_date
end

#idObject

ID of the loyalty ledger entry.



59
60
61
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 59

def id
  @id
end

#nameObject

Name or reason of the loyalty ledger transaction.



44
45
46
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 44

def name
  @name
end

#program_idObject

ID of the loyalty program.



26
27
28
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 26

def program_id
  @program_id
end

#session_idObject

The internal ID of the session.



35
36
37
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 35

def session_id
  @session_id
end

#start_dateObject

When points become active. Possible values: - ‘immediate`: Points are immediately active. - a timestamp value: Points become active at a given date and time.



47
48
49
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 47

def start_date
  @start_date
end

#subledger_idObject

ID of the subledger.



53
54
55
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 53

def subledger_id
  @subledger_id
end

#transaction_uuidObject

Unique identifier of the transaction in the UUID format.



20
21
22
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 20

def transaction_uuid
  @transaction_uuid
end

#typeObject

Type of transaction. Possible values: - ‘addition`: Signifies added points. - `subtraction`: Signifies deducted points.



41
42
43
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 41

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



104
105
106
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 104

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 109

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 84

def self.attribute_map
  {
    :'transaction_uuid' => :'transactionUUID',
    :'created' => :'created',
    :'program_id' => :'programId',
    :'card_identifier' => :'cardIdentifier',
    :'application_id' => :'applicationId',
    :'session_id' => :'sessionId',
    :'customer_session_id' => :'customerSessionId',
    :'type' => :'type',
    :'name' => :'name',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'subledger_id' => :'subledgerId',
    :'amount' => :'amount',
    :'id' => :'id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 532

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 134

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 114

def self.openapi_types
  {
    :'transaction_uuid' => :'String',
    :'created' => :'Time',
    :'program_id' => :'Integer',
    :'card_identifier' => :'String',
    :'application_id' => :'Integer',
    :'session_id' => :'Integer',
    :'customer_session_id' => :'String',
    :'type' => :'String',
    :'name' => :'String',
    :'start_date' => :'String',
    :'expiry_date' => :'String',
    :'subledger_id' => :'String',
    :'amount' => :'Float',
    :'id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 498

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_uuid == o.transaction_uuid &&
      created == o.created &&
      program_id == o.program_id &&
      card_identifier == o.card_identifier &&
      application_id == o.application_id &&
      session_id == o.session_id &&
      customer_session_id == o.customer_session_id &&
      type == o.type &&
      name == o.name &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      subledger_id == o.subledger_id &&
      amount == o.amount &&
      id == o.id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


519
520
521
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 519

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



525
526
527
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 525

def hash
  [transaction_uuid, created, program_id, card_identifier, application_id, session_id, customer_session_id, type, name, start_date, expiry_date, subledger_id, amount, id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 236

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @card_identifier.nil?
    invalid_properties.push('invalid value for "card_identifier", card_identifier cannot be nil.')
  end

  if @card_identifier.to_s.length > 108
    invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.')
  end

  if @card_identifier.to_s.length < 4
    invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  if @card_identifier !~ pattern
    invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.")
  end

  if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
    invalid_properties.push('invalid value for "customer_session_id", the character length must be smaller than or equal to 255.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length > 255
    invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 255.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @start_date.to_s.length > 64
    invalid_properties.push('invalid value for "start_date", the character length must be smaller than or equal to 64.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @subledger_id.to_s.length > 64
    invalid_properties.push('invalid value for "subledger_id", the character length must be smaller than or equal to 64.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 554

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/talon_one_sdk/models/card_ledger_transaction_log_entry.rb', line 321

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @transaction_uuid.nil?
  return false if @created.nil?
  return false if @program_id.nil?
  return false if @card_identifier.nil?
  return false if @card_identifier.to_s.length > 108
  return false if @card_identifier.to_s.length < 4
  return false if @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  return false if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["addition", "subtraction"])
  return false unless type_validator.valid?(@type)
  return false if @type.to_s.length > 255
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @start_date.nil?
  return false if @start_date.to_s.length > 64
  return false if @expiry_date.nil?
  return false if @subledger_id.nil?
  return false if @subledger_id.to_s.length > 64
  return false if @amount.nil?
  return false if @id.nil?
  true
end