Class: TalonOne::CatalogSyncRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CatalogSyncRequest
- Defined in:
- lib/talon_one_sdk/models/catalog_sync_request.rb
Instance Attribute Summary collapse
-
#actions ⇒ Object
Returns the value of attribute actions.
-
#version ⇒ Object
The version number of the catalog to apply the actions on.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CatalogSyncRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CatalogSyncRequest
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CatalogSyncRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CatalogSyncRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'actions') if (value = attributes[:'actions']).is_a?(Array) self.actions = value end else self.actions = nil end if attributes.key?(:'version') self.version = attributes[:'version'] end end |
Instance Attribute Details
#actions ⇒ Object
Returns the value of attribute actions.
18 19 20 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 18 def actions @actions end |
#version ⇒ Object
The version number of the catalog to apply the actions on.
21 22 23 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 21 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 24 def self.attribute_map { :'actions' => :'actions', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 175 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 42 def self.openapi_types { :'actions' => :'Array<Object>', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && actions == o.actions && version == o.version end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 168 def hash [actions, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @actions.nil? invalid_properties.push('invalid value for "actions", actions cannot be nil.') end if @actions.length > 1000 invalid_properties.push('invalid value for "actions", number of items must be less than or equal to 1000.') end if @actions.length < 1 invalid_properties.push('invalid value for "actions", number of items must be greater than or equal to 1.') end if !@version.nil? && @version < 1 invalid_properties.push('invalid value for "version", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 116 117 |
# File 'lib/talon_one_sdk/models/catalog_sync_request.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @actions.nil? return false if @actions.length > 1000 return false if @actions.length < 1 return false if !@version.nil? && @version < 1 true end |