Class: TalonOne::CatalogsStrikethroughNotificationPolicy

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CatalogsStrikethroughNotificationPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CatalogsStrikethroughNotificationPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CatalogsStrikethroughNotificationPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'ahead_of_days_trigger')
    self.ahead_of_days_trigger = attributes[:'ahead_of_days_trigger']
  end

  if attributes.key?(:'batch_size')
    self.batch_size = attributes[:'batch_size']
  else
    self.batch_size = 1000
  end
end

Instance Attribute Details

#ahead_of_days_triggerObject

The number of days in advance that strikethrough pricing updates should be sent.



22
23
24
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 22

def ahead_of_days_trigger
  @ahead_of_days_trigger
end

#batch_sizeObject

The required size of each batch of data.



25
26
27
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 25

def batch_size
  @batch_size
end

#nameObject

Notification name.



19
20
21
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 19

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 28

def self.attribute_map
  {
    :'name' => :'name',
    :'ahead_of_days_trigger' => :'aheadOfDaysTrigger',
    :'batch_size' => :'batchSize'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 47

def self.openapi_types
  {
    :'name' => :'String',
    :'ahead_of_days_trigger' => :'Integer',
    :'batch_size' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      ahead_of_days_trigger == o.ahead_of_days_trigger &&
      batch_size == o.batch_size
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 179

def hash
  [name, ahead_of_days_trigger, batch_size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@ahead_of_days_trigger.nil? && @ahead_of_days_trigger > 30
    invalid_properties.push('invalid value for "ahead_of_days_trigger", must be smaller than or equal to 30.')
  end

  if !@ahead_of_days_trigger.nil? && @ahead_of_days_trigger < 1
    invalid_properties.push('invalid value for "ahead_of_days_trigger", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
125
126
127
# File 'lib/talon_one_sdk/models/catalogs_strikethrough_notification_policy.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@ahead_of_days_trigger.nil? && @ahead_of_days_trigger > 30
  return false if !@ahead_of_days_trigger.nil? && @ahead_of_days_trigger < 1
  true
end