Class: TalonOne::Change

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/change.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Change

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/talon_one_sdk/models/change.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Change` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Change`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  else
    self.entity = nil
  end

  if attributes.key?(:'old')
    self.old = attributes[:'old']
  end

  if attributes.key?(:'new')
    self.new = attributes[:'new']
  end

  if attributes.key?(:'management_key_id')
    self.management_key_id = attributes[:'management_key_id']
  end
end

Instance Attribute Details

#application_idObject

ID of application associated with change.



28
29
30
# File 'lib/talon_one_sdk/models/change.rb', line 28

def application_id
  @application_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/change.rb', line 22

def created
  @created
end

#entityObject

API endpoint on which the change was initiated.



31
32
33
# File 'lib/talon_one_sdk/models/change.rb', line 31

def entity
  @entity
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/change.rb', line 19

def id
  @id
end

#management_key_idObject

ID of management key used to perform changes.



40
41
42
# File 'lib/talon_one_sdk/models/change.rb', line 40

def management_key_id
  @management_key_id
end

#newObject

Resource after the change occurred.



37
38
39
# File 'lib/talon_one_sdk/models/change.rb', line 37

def new
  @new
end

#oldObject

Resource before the change occurred.



34
35
36
# File 'lib/talon_one_sdk/models/change.rb', line 34

def old
  @old
end

#user_idObject

The ID of the user associated with this entity.



25
26
27
# File 'lib/talon_one_sdk/models/change.rb', line 25

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/change.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/change.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/change.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'user_id' => :'userId',
    :'application_id' => :'applicationId',
    :'entity' => :'entity',
    :'old' => :'old',
    :'new' => :'new',
    :'management_key_id' => :'managementKeyId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/talon_one_sdk/models/change.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



87
88
89
90
91
92
# File 'lib/talon_one_sdk/models/change.rb', line 87

def self.openapi_all_of
  [
  :'Entity',
  :'UserEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/change.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/change.rb', line 67

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'user_id' => :'Integer',
    :'application_id' => :'Integer',
    :'entity' => :'String',
    :'old' => :'Object',
    :'new' => :'Object',
    :'management_key_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/change.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      user_id == o.user_id &&
      application_id == o.application_id &&
      entity == o.entity &&
      old == o.old &&
      new == o.new &&
      management_key_id == o.management_key_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/talon_one_sdk/models/change.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/talon_one_sdk/models/change.rb', line 249

def hash
  [id, created, user_id, application_id, entity, old, new, management_key_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/talon_one_sdk/models/change.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @entity.nil?
    invalid_properties.push('invalid value for "entity", entity cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/change.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
# File 'lib/talon_one_sdk/models/change.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @user_id.nil?
  return false if @entity.nil?
  true
end