Class: TalonOne::CheckAttributeBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CheckAttributeBlock
- Defined in:
- lib/talon_one_sdk/models/check_attribute_block.rb
Direct Known Subclasses
PromotionCheckAttributeBlock, StrikethroughCheckAttributeBlock
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attribute ⇒ Object
The attribute path identifier (e.g. "$Session.Total").
-
#count ⇒ Object
Returns the value of attribute count.
-
#id ⇒ Object
Unique identifier for this block.
-
#max ⇒ Object
Returns the value of attribute max.
-
#min ⇒ Object
Returns the value of attribute min.
-
#operator ⇒ Object
The comparison operator applied to the attribute.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
-
#value ⇒ Object
Returns the value of attribute value.
-
#values ⇒ Object
Returns the value of attribute values.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckAttributeBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckAttributeBlock
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CheckAttributeBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CheckAttributeBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'attribute') self.attribute = attributes[:'attribute'] else self.attribute = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'min') self.min = attributes[:'min'] end if attributes.key?(:'max') self.max = attributes[:'max'] end if attributes.key?(:'values') self.values = attributes[:'values'] end if attributes.key?(:'count') self.count = attributes[:'count'] end end |
Instance Attribute Details
#attribute ⇒ Object
The attribute path identifier (e.g. "$Session.Total").
31 32 33 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 31 def attribute @attribute end |
#count ⇒ Object
Returns the value of attribute count.
41 42 43 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 41 def count @count end |
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 19 def id @id end |
#max ⇒ Object
Returns the value of attribute max.
37 38 39 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 37 def max @max end |
#min ⇒ Object
Returns the value of attribute min.
35 36 37 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 35 def min @min end |
#operator ⇒ Object
The comparison operator applied to the attribute.
28 29 30 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 28 def operator @operator end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 25 def @tags end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 22 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
33 34 35 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 33 def value @value end |
#values ⇒ Object
Returns the value of attribute values.
39 40 41 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 39 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 66 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'operator' => :'operator', :'attribute' => :'attribute', :'value' => :'value', :'min' => :'min', :'max' => :'max', :'values' => :'values', :'count' => :'count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 119 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3
126 127 128 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 126 def self.openapi_discriminator_name :'operator' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 113 114 115 116 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 108 def self.openapi_nullable Set.new([ :'value', :'min', :'max', :'values', :'count' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 92 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'operator' => :'String', :'attribute' => :'String', :'value' => :'Object', :'min' => :'Object', :'max' => :'Object', :'values' => :'Object', :'count' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && operator == o.operator && attribute == o.attribute && value == o.value && min == o.min && max == o.max && values == o.values && count == o.count end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 299 def hash [id, type, , operator, attribute, value, min, max, values, count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 199 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end if @attribute.nil? invalid_properties.push('invalid value for "attribute", attribute cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/talon_one_sdk/models/check_attribute_block.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["equals", "not(equals)", "lessThan", "lessThanOrEqual", "greaterThan", "greaterThanOrEqual", "between", "contains", "not(contains)", "matchesRegexp", "startsWith", "endsWith", "oneOf", "not(oneOf)", "inCollection", "not(inCollection)", "empty", "not(empty)", "exists", "not(exists)", "isTrue", "isFalse", "containsAtLeast", "containsExactly", "containsOneOf", "containsNoneOf", "containsAllOf"]) return false unless operator_validator.valid?(@operator) return false if @attribute.nil? true end |