Class: TalonOne::CheckLoyaltyBalanceBlock

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/check_loyalty_balance_block.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CheckLoyaltyBalanceBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CheckLoyaltyBalanceBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CheckLoyaltyBalanceBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'operator')
    self.operator = attributes[:'operator']
  else
    self.operator = nil
  end

  if attributes.key?(:'program')
    self.program = attributes[:'program']
  else
    self.program = nil
  end

  if attributes.key?(:'subledger')
    self.subledger = attributes[:'subledger']
  else
    self.subledger = nil
  end

  if attributes.key?(:'balance')
    self.balance = attributes[:'balance']
  else
    self.balance = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'on_failure')
    if (value = attributes[:'on_failure']).is_a?(Array)
      self.on_failure = value
    end
  end
end

Instance Attribute Details

#balanceObject

The type of balance to check: - current is the sum of currently active points - pending is the sum of pending points. - negative is the sum of negative points. - tentativeCurrent is the tentative points balance within the current open customer session.



36
37
38
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 36

def balance
  @balance
end

#idObject

Unique identifier for this block.



19
20
21
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 19

def id
  @id
end

#on_failureObject

Promotion blocks evaluated when this block fails or returns false.



42
43
44
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 42

def on_failure
  @on_failure
end

#operatorObject

An indicator of how the block compares the balance to the value.



28
29
30
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 28

def operator
  @operator
end

#programObject

Returns the value of attribute program.



30
31
32
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 30

def program
  @program
end

#subledgerObject

The name of the subledger to check the balance of. Can be empty if this block checks the loyalty program's main ledger balance instead of a subledger.



33
34
35
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 33

def subledger
  @subledger
end

#tagsObject

Semantic labels attached to this block.



25
26
27
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 25

def tags
  @tags
end

#typeObject

Identifies the block variant and determines which additional properties are present in it.



22
23
24
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 22

def type
  @type
end

#valueObject

The numeric value to compare the balance against.



39
40
41
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 39

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'tags' => :'tags',
    :'operator' => :'operator',
    :'program' => :'program',
    :'subledger' => :'subledger',
    :'balance' => :'balance',
    :'value' => :'value',
    :'on_failure' => :'onFailure'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 345

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



113
114
115
116
117
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 113

def self.openapi_all_of
  [
  :'BaseBlock'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 92

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'tags' => :'Array<String>',
    :'operator' => :'String',
    :'program' => :'CheckLoyaltyBalanceBlock1Program',
    :'subledger' => :'String',
    :'balance' => :'String',
    :'value' => :'Float',
    :'on_failure' => :'Array<PromotionBlock>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      tags == o.tags &&
      operator == o.operator &&
      program == o.program &&
      subledger == o.subledger &&
      balance == o.balance &&
      value == o.value &&
      on_failure == o.on_failure
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


332
333
334
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 332

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



338
339
340
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 338

def hash
  [id, type, tags, operator, program, subledger, balance, value, on_failure].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @operator.nil?
    invalid_properties.push('invalid value for "operator", operator cannot be nil.')
  end

  if @program.nil?
    invalid_properties.push('invalid value for "program", program cannot be nil.')
  end

  if @subledger.nil?
    invalid_properties.push('invalid value for "subledger", subledger cannot be nil.')
  end

  if @balance.nil?
    invalid_properties.push('invalid value for "balance", balance cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 367

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/check_loyalty_balance_block.rb', line 228

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  return false if @operator.nil?
  operator_validator = EnumAttributeValidator.new('String', ["equals", "not(equals)", "lessThan", "lessThanOrEqual", "greaterThan", "greaterThanOrEqual"])
  return false unless operator_validator.valid?(@operator)
  return false if @program.nil?
  return false if @subledger.nil?
  return false if @balance.nil?
  balance_validator = EnumAttributeValidator.new('String', ["current", "pending", "negative", "tentativeCurrent"])
  return false unless balance_validator.valid?(@balance)
  return false if @value.nil?
  true
end