Class: TalonOne::CodeGeneratorSettings

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/code_generator_settings.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CodeGeneratorSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CodeGeneratorSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CodeGeneratorSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'valid_characters')
    if (value = attributes[:'valid_characters']).is_a?(Array)
      self.valid_characters = value
    end
  else
    self.valid_characters = nil
  end

  if attributes.key?(:'coupon_pattern')
    self.coupon_pattern = attributes[:'coupon_pattern']
  else
    self.coupon_pattern = nil
  end
end

Instance Attribute Details

#coupon_patternObject

The pattern used to generate codes, such as coupon codes, referral codes, and loyalty cards. The character ‘#` is a placeholder and is replaced by a random character from the `validCharacters` set.



22
23
24
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 22

def coupon_pattern
  @coupon_pattern
end

#valid_charactersObject

List of characters used to generate the random parts of a code.



19
20
21
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 19

def valid_characters
  @valid_characters
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 25

def self.attribute_map
  {
    :'valid_characters' => :'validCharacters',
    :'coupon_pattern' => :'couponPattern'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 185

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 43

def self.openapi_types
  {
    :'valid_characters' => :'Array<String>',
    :'coupon_pattern' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      valid_characters == o.valid_characters &&
      coupon_pattern == o.coupon_pattern
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 172

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



178
179
180
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 178

def hash
  [valid_characters, coupon_pattern].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 89

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @valid_characters.nil?
    invalid_properties.push('invalid value for "valid_characters", valid_characters cannot be nil.')
  end

  if @coupon_pattern.nil?
    invalid_properties.push('invalid value for "coupon_pattern", coupon_pattern cannot be nil.')
  end

  if @coupon_pattern.to_s.length > 100
    invalid_properties.push('invalid value for "coupon_pattern", the character length must be smaller than or equal to 100.')
  end

  if @coupon_pattern.to_s.length < 3
    invalid_properties.push('invalid value for "coupon_pattern", the character length must be greater than or equal to 3.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@#-]+$/)
  if @coupon_pattern !~ pattern
    invalid_properties.push("invalid value for \"coupon_pattern\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



118
119
120
121
122
123
124
125
126
# File 'lib/talon_one_sdk/models/code_generator_settings.rb', line 118

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @valid_characters.nil?
  return false if @coupon_pattern.nil?
  return false if @coupon_pattern.to_s.length > 100
  return false if @coupon_pattern.to_s.length < 3
  return false if @coupon_pattern !~ Regexp.new(/^[A-Za-z0-9._%+@#-]+$/)
  true
end