Class: TalonOne::CreateApplicationAPIKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CreateApplicationAPIKey
- Defined in:
- lib/talon_one_sdk/models/create_application_api_key.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expires ⇒ Object
The date the API key expires.
-
#platform ⇒ Object
The third-party platform the API key is valid for.
-
#time_offset ⇒ Object
A time offset in nanoseconds associated with the API key.
-
#title ⇒ Object
Title of the API key.
-
#type ⇒ Object
The API key type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApplicationAPIKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateApplicationAPIKey
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CreateApplicationAPIKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CreateApplicationAPIKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'expires') self.expires = attributes[:'expires'] else self.expires = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'time_offset') self.time_offset = attributes[:'time_offset'] end end |
Instance Attribute Details
#expires ⇒ Object
The date the API key expires.
22 23 24 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 22 def expires @expires end |
#platform ⇒ Object
The third-party platform the API key is valid for. Use ‘none` for a generic API key to be used from your own integration layer.
25 26 27 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 25 def platform @platform end |
#time_offset ⇒ Object
A time offset in nanoseconds associated with the API key. When making a request using the API key, rule evaluation is based on a date that is calculated by adding the offset to the current date.
31 32 33 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 31 def time_offset @time_offset end |
#title ⇒ Object
Title of the API key.
19 20 21 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 19 def title @title end |
#type ⇒ Object
The API key type. Can be empty or ‘staging`. Staging API keys can only be used for dry requests with the [Update customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) endpoint, [Update customer profile](docs.talon.one/integration-api#tag/Customer-profiles/operation/updateCustomerProfileV2) endpoint, and [Track event](docs.talon.one/integration-api#tag/Events/operation/trackEventV2) endpoint. When using the _Update customer profile_ endpoint with a staging API key, the query parameter `runRuleEngine` must be `true`.
28 29 30 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 28 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 56 def self.attribute_map { :'title' => :'title', :'expires' => :'expires', :'platform' => :'platform', :'type' => :'type', :'time_offset' => :'timeOffset' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 230 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 77 def self.openapi_types { :'title' => :'String', :'expires' => :'Time', :'platform' => :'String', :'type' => :'String', :'time_offset' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
205 206 207 208 209 210 211 212 213 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 205 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && expires == o.expires && platform == o.platform && type == o.type && time_offset == o.time_offset end |
#eql?(o) ⇒ Boolean
217 218 219 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 217 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 223 def hash [title, expires, platform, type, time_offset].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 136 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @expires.nil? invalid_properties.push('invalid value for "expires", expires cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/talon_one_sdk/models/create_application_api_key.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? return false if @expires.nil? platform_validator = EnumAttributeValidator.new('String', ["none", "segment", "braze", "mparticle", "shopify", "iterable", "customer_engagement", "customer_data", "salesforce", "emarsys"]) return false unless platform_validator.valid?(@platform) type_validator = EnumAttributeValidator.new('String', ["staging"]) return false unless type_validator.valid?(@type) true end |