Class: TalonOne::CreateCouponData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/create_coupon_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCouponData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CreateCouponData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CreateCouponData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  end

  if attributes.key?(:'total_result_size')
    self.total_result_size = attributes[:'total_result_size']
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'type_of_change')
    self.type_of_change = attributes[:'type_of_change']
  else
    self.type_of_change = nil
  end

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  else
    self.operation = nil
  end

  if attributes.key?(:'employee_name')
    self.employee_name = attributes[:'employee_name']
  else
    self.employee_name = nil
  end

  if attributes.key?(:'notification_type')
    self.notification_type = attributes[:'notification_type']
  else
    self.notification_type = nil
  end
end

Instance Attribute Details

#batch_idObject

The ID of the batch to which the coupon belongs. Note: The Batch ID is generated when coupons are created.



24
25
26
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 24

def batch_id
  @batch_id
end

#dataObject

The array of coupons codes. If 1000 or fewer coupons are requested, all coupon data is sent. If 1001 or more coupons are requested, only ‘BatchID` is sent.



19
20
21
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 19

def data
  @data
end

#employee_nameObject

Returns the value of attribute employee_name.



33
34
35
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 33

def employee_name
  @employee_name
end

#notification_typeObject

The type of the not



36
37
38
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 36

def notification_type
  @notification_type
end

#operationObject

Returns the value of attribute operation.



30
31
32
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 30

def operation
  @operation
end

#total_result_sizeObject

Returns the value of attribute total_result_size.



21
22
23
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 21

def total_result_size
  @total_result_size
end

#type_of_changeObject

Returns the value of attribute type_of_change.



27
28
29
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 27

def type_of_change
  @type_of_change
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 61

def self.attribute_map
  {
    :'data' => :'data',
    :'total_result_size' => :'totalResultSize',
    :'batch_id' => :'BatchID',
    :'type_of_change' => :'TypeOfChange',
    :'operation' => :'Operation',
    :'employee_name' => :'EmployeeName',
    :'notification_type' => :'NotificationType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 263

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 84

def self.openapi_types
  {
    :'data' => :'Array<ExtendedCoupon>',
    :'total_result_size' => :'Integer',
    :'batch_id' => :'String',
    :'type_of_change' => :'String',
    :'operation' => :'String',
    :'employee_name' => :'String',
    :'notification_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
245
246
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data == o.data &&
      total_result_size == o.total_result_size &&
      batch_id == o.batch_id &&
      type_of_change == o.type_of_change &&
      operation == o.operation &&
      employee_name == o.employee_name &&
      notification_type == o.notification_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


250
251
252
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 250

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



256
257
258
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 256

def hash
  [data, total_result_size, batch_id, type_of_change, operation, employee_name, notification_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type_of_change.nil?
    invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.')
  end

  if @operation.nil?
    invalid_properties.push('invalid value for "operation", operation cannot be nil.')
  end

  if @employee_name.nil?
    invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.')
  end

  if @notification_type.nil?
    invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
# File 'lib/talon_one_sdk/models/create_coupon_data.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type_of_change.nil?
  return false if @operation.nil?
  return false if @employee_name.nil?
  return false if @notification_type.nil?
  notification_type_validator = EnumAttributeValidator.new('String', ["CouponCreated"])
  return false unless notification_type_validator.valid?(@notification_type)
  true
end