Class: TalonOne::CreateManagementKey

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/create_management_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateManagementKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CreateManagementKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CreateManagementKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'endpoints')
    if (value = attributes[:'endpoints']).is_a?(Array)
      self.endpoints = value
    end
  else
    self.endpoints = nil
  end

  if attributes.key?(:'allowed_application_ids')
    if (value = attributes[:'allowed_application_ids']).is_a?(Array)
      self.allowed_application_ids = value
    end
  end
end

Instance Attribute Details

#allowed_application_idsObject

A list of Application IDs that you can access with the management key. An empty or missing list means the management key can be used for all Applications in the account.



28
29
30
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 28

def allowed_application_ids
  @allowed_application_ids
end

#endpointsObject

The list of endpoints that can be accessed with the key



25
26
27
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 25

def endpoints
  @endpoints
end

#expiry_dateObject

The date the management key expires.



22
23
24
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 22

def expiry_date
  @expiry_date
end

#nameObject

Name for management key.



19
20
21
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 19

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'expiry_date' => :'expiryDate',
    :'endpoints' => :'endpoints',
    :'allowed_application_ids' => :'allowedApplicationIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 195

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 51

def self.openapi_types
  {
    :'name' => :'String',
    :'expiry_date' => :'Time',
    :'endpoints' => :'Array<Endpoint>',
    :'allowed_application_ids' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      expiry_date == o.expiry_date &&
      endpoints == o.endpoints &&
      allowed_application_ids == o.allowed_application_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 182

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



188
189
190
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 188

def hash
  [name, expiry_date, endpoints, allowed_application_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @endpoints.nil?
    invalid_properties.push('invalid value for "endpoints", endpoints cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/create_management_key.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @expiry_date.nil?
  return false if @endpoints.nil?
  true
end