Class: TalonOne::CreateTemplateCampaign
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CreateTemplateCampaign
- Defined in:
- lib/talon_one_sdk/models/create_template_campaign.rb
Instance Attribute Summary collapse
-
#campaign_attributes_overrides ⇒ Object
Custom Campaign Attributes.
-
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/account-settings/managing-campaign-groups) this campaign belongs to.
-
#description ⇒ Object
A detailed description of the campaign.
-
#evaluation_group_id ⇒ Object
The ID of the campaign evaluation group the campaign belongs to.
-
#limit_overrides ⇒ Object
Limits for this Campaign.
-
#linked_store_ids ⇒ Object
A list of store IDs that are linked to the campaign.
-
#name ⇒ Object
A user-facing name for this campaign.
-
#tags ⇒ Object
A list of tags for the campaign.
-
#template_id ⇒ Object
The ID of the Campaign Template which will be used in order to create the Campaign.
-
#template_param_values ⇒ Object
Actual values to replace the template placeholder values in the Ruleset bindings.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTemplateCampaign
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateTemplateCampaign
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CreateTemplateCampaign` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CreateTemplateCampaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] else self.template_id = nil end if attributes.key?(:'campaign_attributes_overrides') self.campaign_attributes_overrides = attributes[:'campaign_attributes_overrides'] end if attributes.key?(:'template_param_values') if (value = attributes[:'template_param_values']).is_a?(Array) self.template_param_values = value end end if attributes.key?(:'limit_overrides') if (value = attributes[:'limit_overrides']).is_a?(Array) self.limit_overrides = value end end if attributes.key?(:'campaign_groups') if (value = attributes[:'campaign_groups']).is_a?(Array) self.campaign_groups = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'evaluation_group_id') self.evaluation_group_id = attributes[:'evaluation_group_id'] end if attributes.key?(:'linked_store_ids') if (value = attributes[:'linked_store_ids']).is_a?(Array) self.linked_store_ids = value end end end |
Instance Attribute Details
#campaign_attributes_overrides ⇒ Object
Custom Campaign Attributes. If the Campaign Template defines the same values, they will be overridden.
28 29 30 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 28 def campaign_attributes_overrides @campaign_attributes_overrides end |
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/account-settings/managing-campaign-groups) this campaign belongs to.
37 38 39 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 37 def campaign_groups @campaign_groups end |
#description ⇒ Object
A detailed description of the campaign.
22 23 24 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 22 def description @description end |
#evaluation_group_id ⇒ Object
The ID of the campaign evaluation group the campaign belongs to.
43 44 45 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 43 def evaluation_group_id @evaluation_group_id end |
#limit_overrides ⇒ Object
Limits for this Campaign. If the Campaign Template or Application define default values for the same limits, they will be overridden.
34 35 36 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 34 def limit_overrides @limit_overrides end |
#linked_store_ids ⇒ Object
A list of store IDs that are linked to the campaign. Note: Campaigns with linked store IDs will only be evaluated when there is a [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) that references a linked store.
46 47 48 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 46 def linked_store_ids @linked_store_ids end |
#name ⇒ Object
A user-facing name for this campaign.
19 20 21 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 19 def name @name end |
#tags ⇒ Object
A list of tags for the campaign. If the campaign template has tags, they will be overridden by this list.
40 41 42 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 40 def @tags end |
#template_id ⇒ Object
The ID of the Campaign Template which will be used in order to create the Campaign.
25 26 27 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 25 def template_id @template_id end |
#template_param_values ⇒ Object
Actual values to replace the template placeholder values in the Ruleset bindings. Values for all Template Parameters must be provided.
31 32 33 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 31 def template_param_values @template_param_values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 49 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'template_id' => :'templateId', :'campaign_attributes_overrides' => :'campaignAttributesOverrides', :'template_param_values' => :'templateParamValues', :'limit_overrides' => :'limitOverrides', :'campaign_groups' => :'campaignGroups', :'tags' => :'tags', :'evaluation_group_id' => :'evaluationGroupId', :'linked_store_ids' => :'linkedStoreIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 272 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 75 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'template_id' => :'Integer', :'campaign_attributes_overrides' => :'Object', :'template_param_values' => :'Array<Binding>', :'limit_overrides' => :'Array<LimitConfig>', :'campaign_groups' => :'Array<Integer>', :'tags' => :'Array<String>', :'evaluation_group_id' => :'Integer', :'linked_store_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && template_id == o.template_id && campaign_attributes_overrides == o.campaign_attributes_overrides && template_param_values == o.template_param_values && limit_overrides == o.limit_overrides && campaign_groups == o.campaign_groups && == o. && evaluation_group_id == o.evaluation_group_id && linked_store_ids == o.linked_store_ids end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 265 def hash [name, description, template_id, campaign_attributes_overrides, template_param_values, limit_overrides, campaign_groups, , evaluation_group_id, linked_store_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @template_id.nil? invalid_properties.push('invalid value for "template_id", template_id cannot be nil.') end if !@tags.nil? && @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 294 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 |
# File 'lib/talon_one_sdk/models/create_template_campaign.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @template_id.nil? return false if !@tags.nil? && @tags.length > 50 true end |