Class: TalonOne::CustomEffect

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/custom_effect.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomEffect

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomEffect` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomEffect`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  else
    self.application_ids = nil
  end

  if attributes.key?(:'is_per_item')
    self.is_per_item = attributes[:'is_per_item']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  else
    self.payload = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Array)
      self.params = value
    end
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 25

def 
  @account_id
end

#application_idsObject

The IDs of the Applications that are related to this entity.



31
32
33
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 31

def application_ids
  @application_ids
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 22

def created
  @created
end

#created_byObject

ID of the user who created this effect.



58
59
60
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 58

def created_by
  @created_by
end

#descriptionObject

The description of this effect.



46
47
48
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 46

def description
  @description
end

#enabledObject

Determines if this effect is active.



49
50
51
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 49

def enabled
  @enabled
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 19

def id
  @id
end

#is_per_itemObject

Indicates if this effect is per item or not.



34
35
36
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 34

def is_per_item
  @is_per_item
end

#modifiedObject

The time this entity was last modified.



28
29
30
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 28

def modified
  @modified
end

#modified_byObject

ID of the user who last updated this effect if available.



55
56
57
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 55

def modified_by
  @modified_by
end

#nameObject

The name of this effect.



37
38
39
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 37

def name
  @name
end

#paramsObject

Array of template argument definitions.



52
53
54
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 52

def params
  @params
end

#payloadObject

The JSON payload of this effect.



43
44
45
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 43

def payload
  @payload
end

#titleObject

The title of this effect.



40
41
42
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 40

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'modified' => :'modified',
    :'application_ids' => :'applicationIds',
    :'is_per_item' => :'isPerItem',
    :'name' => :'name',
    :'title' => :'title',
    :'payload' => :'payload',
    :'description' => :'description',
    :'enabled' => :'enabled',
    :'params' => :'params',
    :'modified_by' => :'modifiedBy',
    :'created_by' => :'createdBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 455

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



117
118
119
120
121
122
123
124
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 117

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'MutableEntity',
  :'NewCustomEffect'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 91

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'account_id' => :'Integer',
    :'modified' => :'Time',
    :'application_ids' => :'Array<Integer>',
    :'is_per_item' => :'Boolean',
    :'name' => :'String',
    :'title' => :'String',
    :'payload' => :'String',
    :'description' => :'String',
    :'enabled' => :'Boolean',
    :'params' => :'Array<TemplateArgDef>',
    :'modified_by' => :'Integer',
    :'created_by' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 421

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      modified == o.modified &&
      application_ids == o.application_ids &&
      is_per_item == o.is_per_item &&
      name == o.name &&
      title == o.title &&
      payload == o.payload &&
      description == o.description &&
      enabled == o.enabled &&
      params == o.params &&
      modified_by == o.modified_by &&
      created_by == o.created_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


442
443
444
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 442

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



448
449
450
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 448

def hash
  [id, created, , modified, application_ids, is_per_item, name, title, payload, description, enabled, params, modified_by, created_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 225

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @application_ids.length < 1
    invalid_properties.push('invalid value for "application_ids", number of items must be greater than or equal to 1.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z](\w|\s)*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @payload.nil?
    invalid_properties.push('invalid value for "payload", payload cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 477

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/talon_one_sdk/models/custom_effect.rb', line 287

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @modified.nil?
  return false if @application_ids.nil?
  return false if @application_ids.length < 1
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[A-Za-z](\w|\s)*$/)
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  return false if @payload.nil?
  return false if @enabled.nil?
  return false if @created_by.nil?
  true
end