Class: TalonOne::CustomerAchievement

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/customer_achievement.rb

Overview

A customer's progress in an achievement, together with the achievement definition.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerAchievement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerAchievement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerAchievement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'recurrence_policy')
    self.recurrence_policy = attributes[:'recurrence_policy']
  else
    self.recurrence_policy = nil
  end

  if attributes.key?(:'activation_policy')
    self.activation_policy = attributes[:'activation_policy']
  else
    self.activation_policy = nil
  end

  if attributes.key?(:'fixed_start_date')
    self.fixed_start_date = attributes[:'fixed_start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'allow_rollback_after_completion')
    self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion']
  else
    self.allow_rollback_after_completion = nil
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'campaign_ids')
    if (value = attributes[:'campaign_ids']).is_a?(Array)
      self.campaign_ids = value
    end
  else
    self.campaign_ids = nil
  end

  if attributes.key?(:'referenced_by_campaigns')
    if (value = attributes[:'referenced_by_campaigns']).is_a?(Array)
      self.referenced_by_campaigns = value
    end
  else
    self.referenced_by_campaigns = nil
  end

  if attributes.key?(:'current_progress')
    self.current_progress = attributes[:'current_progress']
  end
end

Instance Attribute Details

#activation_policyObject

The policy that determines how the achievement starts, ends, or resets. - user_action: The achievement ends or resets relative to when the customer started the achievement. - fixed_schedule: The achievement starts, ends, or resets for all customers following a fixed schedule.



38
39
40
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 38

def activation_policy
  @activation_policy
end

#allow_rollback_after_completionObject

When true, customer progress can be rolled back in completed achievements.



47
48
49
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 47

def allow_rollback_after_completion
  @allow_rollback_after_completion
end

#campaign_idObject

This property is deprecated. Use campaignIds (Integration API) or referencedByCampaigns (Management API) instead. The first campaign ID in campaignIds. Only returned when campaignIds is not empty.



50
51
52
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 50

def campaign_id
  @campaign_id
end

#campaign_idsObject

The IDs of the campaigns that reference this achievement, in ascending order.



53
54
55
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 53

def campaign_ids
  @campaign_ids
end

#current_progressObject

Returns the value of attribute current_progress.



58
59
60
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 58

def current_progress
  @current_progress
end

#descriptionObject

The description of the achievement in the Campaign Manager.



29
30
31
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 29

def description
  @description
end

#end_dateObject

The achievement's end date. If defined, customers cannot participate in the achievement after this date. Note: It is an RFC3339 timestamp string.



44
45
46
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 44

def end_date
  @end_date
end

#fixed_start_dateObject

The achievement's start date when activationPolicy is equal to fixed_schedule. Note: It is an RFC3339 timestamp string.



41
42
43
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 41

def fixed_start_date
  @fixed_start_date
end

#idObject

The internal ID of the achievement.



20
21
22
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 20

def id
  @id
end

#nameObject

The internal name of the achievement used in API requests.



23
24
25
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 23

def name
  @name
end

#recurrence_policyObject

The policy that determines if and how the achievement recurs. - no_recurrence: The achievement can be completed only once. - on_expiration: The achievement resets after it expires and becomes available again. - on_completion: When the customer progress status reaches completed, the achievement resets and becomes available again.



35
36
37
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 35

def recurrence_policy
  @recurrence_policy
end

#referenced_by_campaignsObject

The campaigns that reference this achievement. They are sorted in ascending order by their id.



56
57
58
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 56

def referenced_by_campaigns
  @referenced_by_campaigns
end

#targetObject

The required number of actions or the transactional milestone to complete the achievement.



32
33
34
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 32

def target
  @target
end

#titleObject

The display name of the achievement in the Campaign Manager.



26
27
28
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 26

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



103
104
105
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 83

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'target' => :'target',
    :'recurrence_policy' => :'recurrencePolicy',
    :'activation_policy' => :'activationPolicy',
    :'fixed_start_date' => :'fixedStartDate',
    :'end_date' => :'endDate',
    :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion',
    :'campaign_id' => :'campaignId',
    :'campaign_ids' => :'campaignIds',
    :'referenced_by_campaigns' => :'referencedByCampaigns',
    :'current_progress' => :'currentProgress'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 469

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 113

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'target' => :'Float',
    :'recurrence_policy' => :'String',
    :'activation_policy' => :'String',
    :'fixed_start_date' => :'Time',
    :'end_date' => :'Time',
    :'allow_rollback_after_completion' => :'Boolean',
    :'campaign_id' => :'Integer',
    :'campaign_ids' => :'Array<Integer>',
    :'referenced_by_campaigns' => :'Array<CampaignReference>',
    :'current_progress' => :'AchievementProgress'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 435

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      target == o.target &&
      recurrence_policy == o.recurrence_policy &&
      activation_policy == o.activation_policy &&
      fixed_start_date == o.fixed_start_date &&
      end_date == o.end_date &&
      allow_rollback_after_completion == o.allow_rollback_after_completion &&
      campaign_id == o.campaign_id &&
      campaign_ids == o.campaign_ids &&
      referenced_by_campaigns == o.referenced_by_campaigns &&
      current_progress == o.current_progress
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


456
457
458
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 456

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



462
463
464
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 462

def hash
  [id, name, title, description, target, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion, campaign_id, campaign_ids, referenced_by_campaigns, current_progress].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 237

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 1000
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]\w+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @recurrence_policy.nil?
    invalid_properties.push('invalid value for "recurrence_policy", recurrence_policy cannot be nil.')
  end

  if @activation_policy.nil?
    invalid_properties.push('invalid value for "activation_policy", activation_policy cannot be nil.')
  end

  if @allow_rollback_after_completion.nil?
    invalid_properties.push('invalid value for "allow_rollback_after_completion", allow_rollback_after_completion cannot be nil.')
  end

  if @campaign_ids.nil?
    invalid_properties.push('invalid value for "campaign_ids", campaign_ids cannot be nil.')
  end

  if @referenced_by_campaigns.nil?
    invalid_properties.push('invalid value for "referenced_by_campaigns", referenced_by_campaigns cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 491

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/talon_one_sdk/models/customer_achievement.rb', line 298

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 1000
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z]\w+$/)
  return false if @title.nil?
  return false if @description.nil?
  return false if @target.nil?
  return false if @recurrence_policy.nil?
  recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"])
  return false unless recurrence_policy_validator.valid?(@recurrence_policy)
  return false if @activation_policy.nil?
  activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"])
  return false unless activation_policy_validator.valid?(@activation_policy)
  return false if @allow_rollback_after_completion.nil?
  return false if @campaign_ids.nil?
  return false if @referenced_by_campaigns.nil?
  true
end