Class: TalonOne::CustomerActivityReport

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/customer_activity_report.rb

Overview

A summary report of customer activity for a given time range.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerActivityReport

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerActivityReport` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerActivityReport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  else
    self.integration_id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  else
    self.customer_id = nil
  end

  if attributes.key?(:'last_activity')
    self.last_activity = attributes[:'last_activity']
  end

  if attributes.key?(:'coupon_redemptions')
    self.coupon_redemptions = attributes[:'coupon_redemptions']
  else
    self.coupon_redemptions = nil
  end

  if attributes.key?(:'coupon_use_attempts')
    self.coupon_use_attempts = attributes[:'coupon_use_attempts']
  else
    self.coupon_use_attempts = nil
  end

  if attributes.key?(:'coupon_failed_attempts')
    self.coupon_failed_attempts = attributes[:'coupon_failed_attempts']
  else
    self.coupon_failed_attempts = nil
  end

  if attributes.key?(:'accrued_discounts')
    self.accrued_discounts = attributes[:'accrued_discounts']
  else
    self.accrued_discounts = nil
  end

  if attributes.key?(:'accrued_revenue')
    self.accrued_revenue = attributes[:'accrued_revenue']
  else
    self.accrued_revenue = nil
  end

  if attributes.key?(:'total_orders')
    self.total_orders = attributes[:'total_orders']
  else
    self.total_orders = nil
  end

  if attributes.key?(:'total_orders_no_coupon')
    self.total_orders_no_coupon = attributes[:'total_orders_no_coupon']
  else
    self.total_orders_no_coupon = nil
  end

  if attributes.key?(:'campaign_name')
    self.campaign_name = attributes[:'campaign_name']
  else
    self.campaign_name = nil
  end
end

Instance Attribute Details

#accrued_discountsObject

Number of accrued discounts in all customer campaigns.



44
45
46
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 44

def accrued_discounts
  @accrued_discounts
end

#accrued_revenueObject

Amount of accrued revenue in all customer campaigns.



47
48
49
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 47

def accrued_revenue
  @accrued_revenue
end

#campaign_nameObject

The name of the campaign this customer belongs to.



56
57
58
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 56

def campaign_name
  @campaign_name
end

#coupon_failed_attemptsObject

Number of failed coupon use attempts in all customer campaigns.



41
42
43
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 41

def coupon_failed_attempts
  @coupon_failed_attempts
end

#coupon_redemptionsObject

Number of coupon redemptions in all customer campaigns.



35
36
37
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 35

def coupon_redemptions
  @coupon_redemptions
end

#coupon_use_attemptsObject

Number of coupon use attempts in all customer campaigns.



38
39
40
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 38

def coupon_use_attempts
  @coupon_use_attempts
end

#createdObject

The time this entity was created.



23
24
25
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 23

def created
  @created
end

#customer_idObject

The internal Talon.One ID of the customer.



29
30
31
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 29

def customer_id
  @customer_id
end

#integration_idObject

The integration ID set by your integration layer.



20
21
22
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 20

def integration_id
  @integration_id
end

#last_activityObject

The last activity of the customer.



32
33
34
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 32

def last_activity
  @last_activity
end

#nameObject

The name for this customer profile.



26
27
28
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 26

def name
  @name
end

#total_ordersObject

Number of orders in all customer campaigns.



50
51
52
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 50

def total_orders
  @total_orders
end

#total_orders_no_couponObject

Number of orders without coupon used in all customer campaigns.



53
54
55
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 53

def total_orders_no_coupon
  @total_orders_no_coupon
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 59

def self.attribute_map
  {
    :'integration_id' => :'integrationId',
    :'created' => :'created',
    :'name' => :'name',
    :'customer_id' => :'customerId',
    :'last_activity' => :'lastActivity',
    :'coupon_redemptions' => :'couponRedemptions',
    :'coupon_use_attempts' => :'couponUseAttempts',
    :'coupon_failed_attempts' => :'couponFailedAttempts',
    :'accrued_discounts' => :'accruedDiscounts',
    :'accrued_revenue' => :'accruedRevenue',
    :'total_orders' => :'totalOrders',
    :'total_orders_no_coupon' => :'totalOrdersNoCoupon',
    :'campaign_name' => :'campaignName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 451

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



113
114
115
116
117
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 113

def self.openapi_all_of
  [
  :'IntegrationEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 88

def self.openapi_types
  {
    :'integration_id' => :'String',
    :'created' => :'Time',
    :'name' => :'String',
    :'customer_id' => :'Integer',
    :'last_activity' => :'Time',
    :'coupon_redemptions' => :'Integer',
    :'coupon_use_attempts' => :'Integer',
    :'coupon_failed_attempts' => :'Integer',
    :'accrued_discounts' => :'Float',
    :'accrued_revenue' => :'Float',
    :'total_orders' => :'Integer',
    :'total_orders_no_coupon' => :'Integer',
    :'campaign_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 418

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      integration_id == o.integration_id &&
      created == o.created &&
      name == o.name &&
      customer_id == o.customer_id &&
      last_activity == o.last_activity &&
      coupon_redemptions == o.coupon_redemptions &&
      coupon_use_attempts == o.coupon_use_attempts &&
      coupon_failed_attempts == o.coupon_failed_attempts &&
      accrued_discounts == o.accrued_discounts &&
      accrued_revenue == o.accrued_revenue &&
      total_orders == o.total_orders &&
      total_orders_no_coupon == o.total_orders_no_coupon &&
      campaign_name == o.campaign_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


438
439
440
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 438

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



444
445
446
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 444

def hash
  [integration_id, created, name, customer_id, last_activity, coupon_redemptions, coupon_use_attempts, coupon_failed_attempts, accrued_discounts, accrued_revenue, total_orders, total_orders_no_coupon, campaign_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 214

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @coupon_redemptions.nil?
    invalid_properties.push('invalid value for "coupon_redemptions", coupon_redemptions cannot be nil.')
  end

  if @coupon_use_attempts.nil?
    invalid_properties.push('invalid value for "coupon_use_attempts", coupon_use_attempts cannot be nil.')
  end

  if @coupon_failed_attempts.nil?
    invalid_properties.push('invalid value for "coupon_failed_attempts", coupon_failed_attempts cannot be nil.')
  end

  if @accrued_discounts.nil?
    invalid_properties.push('invalid value for "accrued_discounts", accrued_discounts cannot be nil.')
  end

  if @accrued_revenue.nil?
    invalid_properties.push('invalid value for "accrued_revenue", accrued_revenue cannot be nil.')
  end

  if @total_orders.nil?
    invalid_properties.push('invalid value for "total_orders", total_orders cannot be nil.')
  end

  if @total_orders_no_coupon.nil?
    invalid_properties.push('invalid value for "total_orders_no_coupon", total_orders_no_coupon cannot be nil.')
  end

  if @campaign_name.nil?
    invalid_properties.push('invalid value for "campaign_name", campaign_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 473

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/customer_activity_report.rb', line 274

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length > 1000
  return false if @created.nil?
  return false if @name.nil?
  return false if @customer_id.nil?
  return false if @coupon_redemptions.nil?
  return false if @coupon_use_attempts.nil?
  return false if @coupon_failed_attempts.nil?
  return false if @accrued_discounts.nil?
  return false if @accrued_revenue.nil?
  return false if @total_orders.nil?
  return false if @total_orders_no_coupon.nil?
  return false if @campaign_name.nil?
  true
end