Class: TalonOne::CustomerInventory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CustomerInventory
- Defined in:
- lib/talon_one_sdk/models/customer_inventory.rb
Instance Attribute Summary collapse
-
#achievements ⇒ Object
Returns the value of attribute achievements.
-
#coupons ⇒ Object
The coupons reserved by this profile.
-
#giveaways ⇒ Object
Returns the value of attribute giveaways.
-
#loyalty ⇒ Object
Returns the value of attribute loyalty.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#referrals ⇒ Object
Returns the value of attribute referrals.
-
#rewards ⇒ Object
The customer rewards that are
unlockedand not yetused.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerInventory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerInventory
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerInventory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerInventory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile') self.profile = attributes[:'profile'] end if attributes.key?(:'loyalty') self.loyalty = attributes[:'loyalty'] end if attributes.key?(:'referrals') if (value = attributes[:'referrals']).is_a?(Array) self.referrals = value end end if attributes.key?(:'coupons') if (value = attributes[:'coupons']).is_a?(Array) self.coupons = value end end if attributes.key?(:'giveaways') if (value = attributes[:'giveaways']).is_a?(Array) self.giveaways = value end end if attributes.key?(:'achievements') if (value = attributes[:'achievements']).is_a?(Array) self.achievements = value end end if attributes.key?(:'rewards') if (value = attributes[:'rewards']).is_a?(Array) self.rewards = value end end end |
Instance Attribute Details
#achievements ⇒ Object
Returns the value of attribute achievements.
29 30 31 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 29 def achievements @achievements end |
#coupons ⇒ Object
The coupons reserved by this profile. This array includes hard and soft reservations.
25 26 27 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 25 def coupons @coupons end |
#giveaways ⇒ Object
Returns the value of attribute giveaways.
27 28 29 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 27 def giveaways @giveaways end |
#loyalty ⇒ Object
Returns the value of attribute loyalty.
20 21 22 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 20 def loyalty @loyalty end |
#profile ⇒ Object
Returns the value of attribute profile.
18 19 20 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 18 def profile @profile end |
#referrals ⇒ Object
Returns the value of attribute referrals.
22 23 24 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 22 def referrals @referrals end |
#rewards ⇒ Object
The customer rewards that are unlocked and not yet used.
32 33 34 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 32 def rewards @rewards end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 35 def self.attribute_map { :'profile' => :'profile', :'loyalty' => :'loyalty', :'referrals' => :'referrals', :'coupons' => :'coupons', :'giveaways' => :'giveaways', :'achievements' => :'achievements', :'rewards' => :'rewards' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 175 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 58 def self.openapi_types { :'profile' => :'CustomerProfile', :'loyalty' => :'Loyalty', :'referrals' => :'Array<InventoryReferral>', :'coupons' => :'Array<InventoryCoupon>', :'giveaways' => :'Array<Giveaway>', :'achievements' => :'Array<AchievementProgressWithDefinition>', :'rewards' => :'Array<Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && profile == o.profile && loyalty == o.loyalty && referrals == o.referrals && coupons == o.coupons && giveaways == o.giveaways && achievements == o.achievements && rewards == o.rewards end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 168 def hash [profile, loyalty, referrals, coupons, giveaways, achievements, rewards].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 |
# File 'lib/talon_one_sdk/models/customer_inventory.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |