Class: TalonOne::CustomerProfileIntegrationRequestV2

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerProfileIntegrationRequestV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerProfileIntegrationRequestV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerProfileIntegrationRequestV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'evaluable_campaign_ids')
    if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array)
      self.evaluable_campaign_ids = value
    end
  end

  if attributes.key?(:'response_content')
    if (value = attributes[:'response_content']).is_a?(Array)
      self.response_content = value
    end
  end

  if attributes.key?(:'audiences_changes')
    self.audiences_changes = attributes[:'audiences_changes']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary properties associated with this item.



19
20
21
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 19

def attributes
  @attributes
end

#audiences_changesObject

Audiences memberships changes for this profile.



28
29
30
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 28

def audiences_changes
  @audiences_changes
end

#evaluable_campaign_idsObject

When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.



22
23
24
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 22

def evaluable_campaign_ids
  @evaluable_campaign_ids
end

#response_contentObject

Extends the response with the chosen data entities. Use this property to get as much data back as needed from one request instead of sending extra requests to other endpoints.



25
26
27
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 25

def response_content
  @response_content
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 53

def self.attribute_map
  {
    :'attributes' => :'attributes',
    :'evaluable_campaign_ids' => :'evaluableCampaignIds',
    :'response_content' => :'responseContent',
    :'audiences_changes' => :'audiencesChanges'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 89

def self.openapi_all_of
  [
  :'EvaluableCampaignIds',
  :'NewCustomerProfile',
  :'ResponseContentObject'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 73

def self.openapi_types
  {
    :'attributes' => :'Hash<String, Object>',
    :'evaluable_campaign_ids' => :'Array<Integer>',
    :'response_content' => :'Array<String>',
    :'audiences_changes' => :'ProfileAudiencesChanges'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attributes == o.attributes &&
      evaluable_campaign_ids == o.evaluable_campaign_ids &&
      response_content == o.response_content &&
      audiences_changes == o.audiences_changes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 170

def hash
  [attributes, evaluable_campaign_ids, response_content, audiences_changes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
# File 'lib/talon_one_sdk/models/customer_profile_integration_request_v2.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end