Class: TalonOne::CustomerSessionV2

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/customer_session_v2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerSessionV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 195

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerSessionV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerSessionV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  else
    self.integration_id = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'evaluable_campaign_ids')
    if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array)
      self.evaluable_campaign_ids = value
    end
  end

  if attributes.key?(:'coupon_codes')
    if (value = attributes[:'coupon_codes']).is_a?(Array)
      self.coupon_codes = value
    end
  end

  if attributes.key?(:'referral_code')
    self.referral_code = attributes[:'referral_code']
  end

  if attributes.key?(:'loyalty_cards')
    if (value = attributes[:'loyalty_cards']).is_a?(Array)
      self.loyalty_cards = value
    end
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'open'
  end

  if attributes.key?(:'cart_items')
    if (value = attributes[:'cart_items']).is_a?(Array)
      self.cart_items = value
    end
  end

  if attributes.key?(:'experiment_variant_allocations')
    if (value = attributes[:'experiment_variant_allocations']).is_a?(Array)
      self.experiment_variant_allocations = value
    end
  end

  if attributes.key?(:'additional_costs')
    if (value = attributes[:'additional_costs']).is_a?(Hash)
      self.additional_costs = value
    end
  end

  if attributes.key?(:'identifiers')
    if (value = attributes[:'identifiers']).is_a?(Array)
      self.identifiers = value
    end
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'first_session')
    self.first_session = attributes[:'first_session']
  else
    self.first_session = nil
  end

  if attributes.key?(:'update_count')
    self.update_count = attributes[:'update_count']
  else
    self.update_count = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'cart_item_total')
    self.cart_item_total = attributes[:'cart_item_total']
  else
    self.cart_item_total = nil
  end

  if attributes.key?(:'additional_cost_total')
    self.additional_cost_total = attributes[:'additional_cost_total']
  else
    self.additional_cost_total = nil
  end

  if attributes.key?(:'cart_item_additional_cost_total')
    self.cart_item_additional_cost_total = attributes[:'cart_item_additional_cost_total']
  else
    self.cart_item_additional_cost_total = nil
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  else
    self.updated = nil
  end
end

Instance Attribute Details

#additional_cost_totalObject

The total value of additional costs, before any discounts are applied.



79
80
81
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 79

def additional_cost_total
  @additional_cost_total
end

#additional_costsObject

Use this property to set a value for the additional costs of this session, such as a shipping cost. They must be created in the Campaign Manager before you set them with this property. See [Managing additional costs](docs.talon.one/docs/product/account/dev-tools/managing-additional-costs).



58
59
60
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 58

def additional_costs
  @additional_costs
end

#application_idObject

The ID of the Application that owns this entity.



28
29
30
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 28

def application_id
  @application_id
end

#attributesObject

Use this property to set a value for the attributes of your choice. Attributes represent any information to attach to your session, like the shipping city. You can use [built-in attributes](docs.talon.one/docs/dev/concepts/attributes#built-in-attributes) or [custom ones](docs.talon.one/docs/dev/concepts/attributes#custom-attributes). Custom attributes must be created in the Campaign Manager before you set them with this property.



64
65
66
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 64

def attributes
  @attributes
end

#cart_item_additional_cost_totalObject

The total value of additional costs applied to individual items, before any discounts are applied.



82
83
84
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 82

def cart_item_additional_cost_total
  @cart_item_additional_cost_total
end

#cart_item_totalObject

The total value of cart items, before any discounts are applied.



76
77
78
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 76

def cart_item_total
  @cart_item_total
end

#cart_itemsObject

The items to add to this session. **Do not exceed 1000 items** and ensure the sum of all cart item’s ‘quantity` **does not exceed 10.000** per request.



52
53
54
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 52

def cart_items
  @cart_items
end

#coupon_codesObject

Any coupon codes entered. **Important - for requests only**: - If you [create a coupon budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign, ensure the session contains a coupon code by the time you close it. - In requests where ‘dry=false`, providing an empty array discards any previous coupons. To avoid this, omit the parameter entirely.



40
41
42
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 40

def coupon_codes
  @coupon_codes
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 22

def created
  @created
end

#evaluable_campaign_idsObject

When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.



37
38
39
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 37

def evaluable_campaign_ids
  @evaluable_campaign_ids
end

#experiment_variant_allocationsObject

The experiment variant allocations to add to this session.



55
56
57
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 55

def experiment_variant_allocations
  @experiment_variant_allocations
end

#first_sessionObject

Indicates whether this is the first session for the customer’s profile. It’s always ‘true` for anonymous sessions.



67
68
69
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 67

def first_session
  @first_session
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 19

def id
  @id
end

#identifiersObject

Session custom identifiers that you can set limits on or use inside your rules. For example, you can use IP addresses as identifiers to potentially identify devices and limit discounts abuse in case of customers creating multiple accounts. See the [tutorial](docs.talon.one/docs/dev/tutorials/using-identifiers). Important: Ensure the session contains an identifier by the time you close it if: - You [create a unique identifier budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign. - Your campaign has [coupons](docs.talon.one/docs/product/campaigns/coupons/coupon-page-overview). - We recommend passing an anonymized (hashed) version of the identifier value.



61
62
63
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 61

def identifiers
  @identifiers
end

#integration_idObject

The integration ID set by your integration layer.



25
26
27
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 25

def integration_id
  @integration_id
end

#loyalty_cardsObject

Identifier of a loyalty card.



46
47
48
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 46

def loyalty_cards
  @loyalty_cards
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.



31
32
33
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 31

def profile_id
  @profile_id
end

#referral_codeObject

Any referral code entered. **Important - for requests only**: - If you [create a referral budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign, ensure the session contains a referral code by the time you close it. - In requests where ‘dry=false`, providing an empty value discards the previous referral code. To avoid this, omit the parameter entirely.



43
44
45
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 43

def referral_code
  @referral_code
end

#stateObject

Indicates the current state of the session. Sessions can be created as ‘open` or `closed`. The state transitions are: 1. `open` → `closed` 2. `open` → `cancelled` 3. Either: - `closed` → `cancelled` (only via [Update customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2)) or - `closed` → `partially_returned` (only via [Return cart items](docs.talon.one/integration-api#tag/Customer-sessions/operation/returnCartItems)) - `closed` → `open` (only via [Reopen customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/reopenCustomerSession)) 4. `partially_returned` → `cancelled` For more information, see [Customer session states](docs.talon.one/docs/dev/concepts/entities/customer-sessions).



49
50
51
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 49

def state
  @state
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



34
35
36
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 34

def store_integration_id
  @store_integration_id
end

#totalObject

The total value of cart items and additional costs in the session, before any discounts are applied.



73
74
75
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 73

def total
  @total
end

#update_countObject

The number of times the session was updated. When the session is created, this value is initialized to ‘1`.



70
71
72
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 70

def update_count
  @update_count
end

#updatedObject

Timestamp of the most recent event received on this session.



85
86
87
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 85

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



139
140
141
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 139

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



144
145
146
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 144

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 110

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'integration_id' => :'integrationId',
    :'application_id' => :'applicationId',
    :'profile_id' => :'profileId',
    :'store_integration_id' => :'storeIntegrationId',
    :'evaluable_campaign_ids' => :'evaluableCampaignIds',
    :'coupon_codes' => :'couponCodes',
    :'referral_code' => :'referralCode',
    :'loyalty_cards' => :'loyaltyCards',
    :'state' => :'state',
    :'cart_items' => :'cartItems',
    :'experiment_variant_allocations' => :'experimentVariantAllocations',
    :'additional_costs' => :'additionalCosts',
    :'identifiers' => :'identifiers',
    :'attributes' => :'attributes',
    :'first_session' => :'firstSession',
    :'update_count' => :'updateCount',
    :'total' => :'total',
    :'cart_item_total' => :'cartItemTotal',
    :'additional_cost_total' => :'additionalCostTotal',
    :'cart_item_additional_cost_total' => :'cartItemAdditionalCostTotal',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 673

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 184

def self.openapi_all_of
  [
  :'ApplicationEntity',
  :'Entity',
  :'IntegrationEntity',
  :'NewCustomerSessionV2'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



178
179
180
181
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 178

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 149

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'integration_id' => :'String',
    :'application_id' => :'Integer',
    :'profile_id' => :'String',
    :'store_integration_id' => :'String',
    :'evaluable_campaign_ids' => :'Array<Integer>',
    :'coupon_codes' => :'Array<String>',
    :'referral_code' => :'String',
    :'loyalty_cards' => :'Array<String>',
    :'state' => :'String',
    :'cart_items' => :'Array<CartItem>',
    :'experiment_variant_allocations' => :'Array<ExperimentVariantAllocation>',
    :'additional_costs' => :'Hash<String, AdditionalCost>',
    :'identifiers' => :'Array<String>',
    :'attributes' => :'Hash<String, Object>',
    :'first_session' => :'Boolean',
    :'update_count' => :'Integer',
    :'total' => :'Float',
    :'cart_item_total' => :'Float',
    :'additional_cost_total' => :'Float',
    :'cart_item_additional_cost_total' => :'Float',
    :'updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 630

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      integration_id == o.integration_id &&
      application_id == o.application_id &&
      profile_id == o.profile_id &&
      store_integration_id == o.store_integration_id &&
      evaluable_campaign_ids == o.evaluable_campaign_ids &&
      coupon_codes == o.coupon_codes &&
      referral_code == o.referral_code &&
      loyalty_cards == o.loyalty_cards &&
      state == o.state &&
      cart_items == o.cart_items &&
      experiment_variant_allocations == o.experiment_variant_allocations &&
      additional_costs == o.additional_costs &&
      identifiers == o.identifiers &&
      attributes == o.attributes &&
      first_session == o.first_session &&
      update_count == o.update_count &&
      total == o.total &&
      cart_item_total == o.cart_item_total &&
      additional_cost_total == o.additional_cost_total &&
      cart_item_additional_cost_total == o.cart_item_additional_cost_total &&
      updated == o.updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


660
661
662
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 660

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



666
667
668
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 666

def hash
  [id, created, integration_id, application_id, profile_id, store_integration_id, evaluable_campaign_ids, coupon_codes, referral_code, loyalty_cards, state, cart_items, experiment_variant_allocations, additional_costs, identifiers, attributes, first_session, update_count, total, cart_item_total, additional_cost_total, cart_item_additional_cost_total, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 344

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.')
  end

  if !@referral_code.nil? && @referral_code.to_s.length > 100
    invalid_properties.push('invalid value for "referral_code", the character length must be smaller than or equal to 100.')
  end

  if !@loyalty_cards.nil? && @loyalty_cards.length > 1
    invalid_properties.push('invalid value for "loyalty_cards", number of items must be less than or equal to 1.')
  end

  if !@identifiers.nil? && @identifiers.length > 5
    invalid_properties.push('invalid value for "identifiers", number of items must be less than or equal to 5.')
  end

  if @first_session.nil?
    invalid_properties.push('invalid value for "first_session", first_session cannot be nil.')
  end

  if @update_count.nil?
    invalid_properties.push('invalid value for "update_count", update_count cannot be nil.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @cart_item_total.nil?
    invalid_properties.push('invalid value for "cart_item_total", cart_item_total cannot be nil.')
  end

  if @additional_cost_total.nil?
    invalid_properties.push('invalid value for "additional_cost_total", additional_cost_total cannot be nil.')
  end

  if @cart_item_additional_cost_total.nil?
    invalid_properties.push('invalid value for "cart_item_additional_cost_total", cart_item_additional_cost_total cannot be nil.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



695
696
697
698
699
700
701
702
703
704
705
706
707
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 695

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/talon_one_sdk/models/customer_session_v2.rb', line 420

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length > 1000
  return false if @application_id.nil?
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if !@referral_code.nil? && @referral_code.to_s.length > 100
  return false if !@loyalty_cards.nil? && @loyalty_cards.length > 1
  state_validator = EnumAttributeValidator.new('String', ["open", "closed", "partially_returned", "cancelled"])
  return false unless state_validator.valid?(@state)
  return false if !@identifiers.nil? && @identifiers.length > 5
  return false if @first_session.nil?
  return false if @update_count.nil?
  return false if @total.nil?
  return false if @cart_item_total.nil?
  return false if @additional_cost_total.nil?
  return false if @cart_item_additional_cost_total.nil?
  return false if @updated.nil?
  true
end