Class: TalonOne::DeductLoyaltyPointsEffectProps

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb

Overview

The properties specific to the "deductLoyaltyPoints" effect. This gets triggered whenever a validated rule contained a condition to only trigger when the given number of loyalty points could be deduced. These points are automatically stored and managed inside Talon.One.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeductLoyaltyPointsEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::DeductLoyaltyPointsEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::DeductLoyaltyPointsEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rule_title')
    self.rule_title = attributes[:'rule_title']
  else
    self.rule_title = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'sub_ledger_id')
    self.sub_ledger_id = attributes[:'sub_ledger_id']
  else
    self.sub_ledger_id = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  end
end

Instance Attribute Details

#card_identifierObject

The card on which these points were added.



38
39
40
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 38

def card_identifier
  @card_identifier
end

#nameObject

The name property gets one of the following two values. It can be the loyalty program name or it can represent a reason for the respective deduction of loyalty points. The latter is an optional value defined in a deduction rule.



35
36
37
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 35

def name
  @name
end

#program_idObject

The ID of the loyalty program where these points were added.



23
24
25
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 23

def program_id
  @program_id
end

#rule_titleObject

The title of the rule that contained triggered this points deduction.



20
21
22
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 20

def rule_title
  @rule_title
end

#sub_ledger_idObject

The ID of the subledger within the loyalty program where these points were added.



26
27
28
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 26

def sub_ledger_id
  @sub_ledger_id
end

#transaction_uuidObject

The identifier of this deduction in the loyalty ledger.



32
33
34
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 32

def transaction_uuid
  @transaction_uuid
end

#valueObject

The amount of points that were deducted.



29
30
31
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 29

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 41

def self.attribute_map
  {
    :'rule_title' => :'ruleTitle',
    :'program_id' => :'programId',
    :'sub_ledger_id' => :'subLedgerId',
    :'value' => :'value',
    :'transaction_uuid' => :'transactionUUID',
    :'name' => :'name',
    :'card_identifier' => :'cardIdentifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 312

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 64

def self.openapi_types
  {
    :'rule_title' => :'String',
    :'program_id' => :'Integer',
    :'sub_ledger_id' => :'String',
    :'value' => :'Float',
    :'transaction_uuid' => :'String',
    :'name' => :'String',
    :'card_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rule_title == o.rule_title &&
      program_id == o.program_id &&
      sub_ledger_id == o.sub_ledger_id &&
      value == o.value &&
      transaction_uuid == o.transaction_uuid &&
      name == o.name &&
      card_identifier == o.card_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 299

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



305
306
307
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 305

def hash
  [rule_title, program_id, sub_ledger_id, value, transaction_uuid, name, card_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @rule_title.nil?
    invalid_properties.push('invalid value for "rule_title", rule_title cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @sub_ledger_id.nil?
    invalid_properties.push('invalid value for "sub_ledger_id", sub_ledger_id cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length > 108
    invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length < 4
    invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  if !@card_identifier.nil? && @card_identifier !~ pattern
    invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/talon_one_sdk/models/deduct_loyalty_points_effect_props.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @rule_title.nil?
  return false if @program_id.nil?
  return false if @sub_ledger_id.nil?
  return false if @value.nil?
  return false if @transaction_uuid.nil?
  return false if @name.nil?
  return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108
  return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4
  return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  true
end