Module: TalonOne::EffectAllOfProps
- Defined in:
- lib/talon_one_sdk/models/effect_all_of_props.rb
Class Method Summary collapse
-
.build(data) ⇒ Object
Builds the object.
-
.openapi_one_of ⇒ Object
List of class defined in oneOf (OpenAPI v3).
Class Method Details
.build(data) ⇒ Object
Builds the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/talon_one_sdk/models/effect_all_of_props.rb', line 64 def build(data) # Go through the list of oneOf items and attempt to identify the appropriate one. # Note: # - We do not attempt to check whether exactly one item matches. # - No advanced validation of types in some cases (e.g. "x: { type: string }" will happily match { x: 123 }) # due to the way the deserialization is made in the base_object template (it just casts without verifying). # - TODO: scalar values are de facto behaving as if they were nullable. # - TODO: logging when debugging is set. openapi_one_of.each do |klass| begin next if klass == :AnyType # "nullable: true" return find_and_cast_into_type(klass, data) rescue # rescue all errors so we keep iterating even if the current item lookup raises end end openapi_one_of.include?(:AnyType) ? data : nil end |
.openapi_one_of ⇒ Object
List of class defined in oneOf (OpenAPI v3)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/talon_one_sdk/models/effect_all_of_props.rb', line 20 def openapi_one_of [ :'AcceptCouponEffectProps', :'AcceptReferralEffectProps', :'AddFreeItemEffectProps', :'AddLoyaltyPointsEffectProps', :'AddToAudienceEffectProps', :'AwardGiveawayEffectProps', :'ChangeLoyaltyTierLevelEffectProps', :'CouponCreatedEffectProps', :'CustomEffectProps', :'DeductLoyaltyPointsEffectProps', :'ErrorEffectProps', :'ExtendLoyaltyPointsExpiryDateEffectProps', :'IncreaseAchievementProgressEffectProps', :'RedeemReferralEffectProps', :'ReferralCreatedEffectProps', :'RejectCouponEffectProps', :'RejectReferralEffectProps', :'RemoveFromAudienceEffectProps', :'ReserveCouponEffectProps', :'RollbackAddedLoyaltyPointsEffectProps', :'RollbackCouponEffectProps', :'RollbackDeductedLoyaltyPointsEffectProps', :'RollbackDiscountEffectProps', :'RollbackIncreasedAchievementProgressEffectProps', :'RollbackReferralEffectProps', :'SetDiscountEffectProps', :'SetDiscountPerAdditionalCostEffectProps', :'SetDiscountPerAdditionalCostPerItemEffectProps', :'SetDiscountPerItemEffectProps', :'SetLoyaltyPointsExpiryDateEffectProps', :'ShowBundleMetadataEffectProps', :'ShowNotificationEffectProps', :'StartAchievementProgressEffectProps', :'TriggerWebhookEffectProps', :'UpdateAttributeEffectProps', :'WillAwardGiveawayEffectProps' ] end |