Class: TalonOne::EvaluableCampaignIds
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::EvaluableCampaignIds
- Defined in:
- lib/talon_one_sdk/models/evaluable_campaign_ids.rb
Instance Attribute Summary collapse
-
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EvaluableCampaignIds
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EvaluableCampaignIds
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EvaluableCampaignIds` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EvaluableCampaignIds`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'evaluable_campaign_ids') if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array) self.evaluable_campaign_ids = value end end end |
Instance Attribute Details
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.
19 20 21 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 19 def evaluable_campaign_ids @evaluable_campaign_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 22 def self.attribute_map { :'evaluable_campaign_ids' => :'evaluableCampaignIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 112 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
46 47 48 49 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 46 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 39 def self.openapi_types { :'evaluable_campaign_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 91 def ==(o) return true if self.equal?(o) self.class == o.class && evaluable_campaign_ids == o.evaluable_campaign_ids end |
#eql?(o) ⇒ Boolean
99 100 101 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 99 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 105 def hash [evaluable_campaign_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 76 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 134 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
84 85 86 87 |
# File 'lib/talon_one_sdk/models/evaluable_campaign_ids.rb', line 84 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |