Class: TalonOne::EventV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::EventV2
- Defined in:
- lib/talon_one_sdk/models/event_v2.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event.
-
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#store_integration_id ⇒ Object
The integration ID of the store.
-
#type ⇒ Object
A string representing the event name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventV2
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EventV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EventV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'store_integration_id') self.store_integration_id = attributes[:'store_integration_id'] end if attributes.key?(:'evaluable_campaign_ids') if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array) self.evaluable_campaign_ids = value end end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).
31 32 33 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 31 def attributes @attributes end |
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.
25 26 27 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 25 def evaluable_campaign_ids @evaluable_campaign_ids end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
19 20 21 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 19 def profile_id @profile_id end |
#store_integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store.
22 23 24 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 22 def store_integration_id @store_integration_id end |
#type ⇒ Object
A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.
28 29 30 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 28 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 34 def self.attribute_map { :'profile_id' => :'profileId', :'store_integration_id' => :'storeIntegrationId', :'evaluable_campaign_ids' => :'evaluableCampaignIds', :'type' => :'type', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 216 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 72 def self.openapi_all_of [ :'EvaluableCampaignIds', :'EventAttributesEntity', :'IntegrationProfileEntity', :'IntegrationStoreEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 55 def self.openapi_types { :'profile_id' => :'String', :'store_integration_id' => :'String', :'evaluable_campaign_ids' => :'Array<Integer>', :'type' => :'String', :'attributes' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && profile_id == o.profile_id && store_integration_id == o.store_integration_id && evaluable_campaign_ids == o.evaluable_campaign_ids && type == o.type && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 209 def hash [profile_id, store_integration_id, evaluable_campaign_ids, type, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length < 1 invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 154 155 |
# File 'lib/talon_one_sdk/models/event_v2.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 return false if @type.nil? return false if @type.to_s.length < 1 true end |