Class: TalonOne::EventV3

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/event_v3.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EventV3

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/talon_one_sdk/models/event_v3.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EventV3` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EventV3`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connected_session_id')
    self.connected_session_id = attributes[:'connected_session_id']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  else
    self.attributes = nil
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'referral_code')
    self.referral_code = attributes[:'referral_code']
  end

  if attributes.key?(:'effects')
    if (value = attributes[:'effects']).is_a?(Array)
      self.effects = value
    end
  else
    self.effects = nil
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



28
29
30
# File 'lib/talon_one_sdk/models/event_v3.rb', line 28

def application_id
  @application_id
end

#attributesObject

Arbitrary additional JSON data associated with the event.



40
41
42
# File 'lib/talon_one_sdk/models/event_v3.rb', line 40

def attributes
  @attributes
end

#connected_session_idObject

The ID of the session to reference. The session must be in closed state. Otherwise, the API call will fail.



19
20
21
# File 'lib/talon_one_sdk/models/event_v3.rb', line 19

def connected_session_id
  @connected_session_id
end

#createdObject

The time this entity was created.



25
26
27
# File 'lib/talon_one_sdk/models/event_v3.rb', line 25

def created
  @created
end

#effectsObject

An array of effects generated by the rules of the enabled campaigns of the Application. You decide how to apply them in your system. See the list of API effects.



49
50
51
# File 'lib/talon_one_sdk/models/event_v3.rb', line 49

def effects
  @effects
end

#idObject

The internal ID of this entity.



22
23
24
# File 'lib/talon_one_sdk/models/event_v3.rb', line 22

def id
  @id
end

#integration_idObject

The unique ID of the event. Only one event with this ID can be registered.



43
44
45
# File 'lib/talon_one_sdk/models/event_v3.rb', line 43

def integration_id
  @integration_id
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known profileId, we recommend you use a guest profileId.



31
32
33
# File 'lib/talon_one_sdk/models/event_v3.rb', line 31

def profile_id
  @profile_id
end

#referral_codeObject

The referral code submitted with the event. The endpoint does not validate the code, and submitting a code does not redeem it. Use the "Referral code is valid" condition in the Rule Builder to validate and redeem the code, or "Referral code is valid (without redemption)" to validate without redeeming.



46
47
48
# File 'lib/talon_one_sdk/models/event_v3.rb', line 46

def referral_code
  @referral_code
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



34
35
36
# File 'lib/talon_one_sdk/models/event_v3.rb', line 34

def store_integration_id
  @store_integration_id
end

#typeObject

The name of the event. Must be a custom event, not a built-in event.



37
38
39
# File 'lib/talon_one_sdk/models/event_v3.rb', line 37

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/event_v3.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/event_v3.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/event_v3.rb', line 52

def self.attribute_map
  {
    :'connected_session_id' => :'connectedSessionId',
    :'id' => :'id',
    :'created' => :'created',
    :'application_id' => :'applicationId',
    :'profile_id' => :'profileId',
    :'store_integration_id' => :'storeIntegrationId',
    :'type' => :'type',
    :'attributes' => :'attributes',
    :'integration_id' => :'integrationId',
    :'referral_code' => :'referralCode',
    :'effects' => :'effects'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/talon_one_sdk/models/event_v3.rb', line 420

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
107
108
109
110
111
# File 'lib/talon_one_sdk/models/event_v3.rb', line 102

def self.openapi_all_of
  [
  :'ApplicationEntity',
  :'Entity',
  :'EventV3Connections',
  :'EventV3Entity',
  :'EventV3ReferralEntity',
  :'IntegrationEvent'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/event_v3.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/event_v3.rb', line 79

def self.openapi_types
  {
    :'connected_session_id' => :'String',
    :'id' => :'Integer',
    :'created' => :'Time',
    :'application_id' => :'Integer',
    :'profile_id' => :'String',
    :'store_integration_id' => :'String',
    :'type' => :'String',
    :'attributes' => :'Object',
    :'integration_id' => :'String',
    :'referral_code' => :'String',
    :'effects' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/talon_one_sdk/models/event_v3.rb', line 389

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connected_session_id == o.connected_session_id &&
      id == o.id &&
      created == o.created &&
      application_id == o.application_id &&
      profile_id == o.profile_id &&
      store_integration_id == o.store_integration_id &&
      type == o.type &&
      attributes == o.attributes &&
      integration_id == o.integration_id &&
      referral_code == o.referral_code &&
      effects == o.effects
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


407
408
409
# File 'lib/talon_one_sdk/models/event_v3.rb', line 407

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



413
414
415
# File 'lib/talon_one_sdk/models/event_v3.rb', line 413

def hash
  [connected_session_id, id, created, application_id, profile_id, store_integration_id, type, attributes, integration_id, referral_code, effects].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/event_v3.rb', line 190

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
    invalid_properties.push('invalid value for "connected_session_id", the character length must be greater than or equal to 1.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length < 1
    invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.')
  end

  if @attributes.nil?
    invalid_properties.push('invalid value for "attributes", attributes cannot be nil.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.')
  end

  if !@referral_code.nil? && @referral_code.to_s.length > 100
    invalid_properties.push('invalid value for "referral_code", the character length must be smaller than or equal to 100.')
  end

  if @effects.nil?
    invalid_properties.push('invalid value for "effects", effects cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/talon_one_sdk/models/event_v3.rb', line 442

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/talon_one_sdk/models/event_v3.rb', line 246

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if @type.nil?
  return false if @type.to_s.length < 1
  return false if @attributes.nil?
  return false if !@integration_id.nil? && @integration_id.to_s.length < 1
  return false if !@referral_code.nil? && @referral_code.to_s.length > 100
  return false if @effects.nil?
  true
end