Class: TalonOne::ExperimentSegmentInsights

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/experiment_segment_insights.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExperimentSegmentInsights

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentSegmentInsights` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentSegmentInsights`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  else
    self.metrics = nil
  end

  if attributes.key?(:'total_segments_tested')
    self.total_segments_tested = attributes[:'total_segments_tested']
  else
    self.total_segments_tested = nil
  end

  if attributes.key?(:'dimensions_tested')
    self.dimensions_tested = attributes[:'dimensions_tested']
  else
    self.dimensions_tested = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end
end

Instance Attribute Details

#dimensions_testedObject

Number of segmentation dimensions that had sufficient data variance to test. Dimensions where all sessions fall into a single bucket are excluded.



25
26
27
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 25

def dimensions_tested
  @dimensions_tested
end

#metricsObject

Segment insights grouped by metric. This array always contains exactly three metric objects. Each metric includes a segments array, which is empty if no significant results were found. The metrics array itself is empty if the ‘reason` property is populated.



19
20
21
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 19

def metrics
  @metrics
end

#reasonObject

Empty string when segment insights are available. Contains a reason code when insights could not be computed (e.g., "insufficient_data" when the experiment has fewer than 100 sessions per variant).



28
29
30
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 28

def reason
  @reason
end

#total_segments_testedObject

Total number of segment-metric combinations that were tested for statistical significance.



22
23
24
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 22

def total_segments_tested
  @total_segments_tested
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 31

def self.attribute_map
  {
    :'metrics' => :'metrics',
    :'total_segments_tested' => :'totalSegmentsTested',
    :'dimensions_tested' => :'dimensionsTested',
    :'reason' => :'reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 51

def self.openapi_types
  {
    :'metrics' => :'Array<ExperimentSegmentInsightMetric>',
    :'total_segments_tested' => :'Integer',
    :'dimensions_tested' => :'Integer',
    :'reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      metrics == o.metrics &&
      total_segments_tested == o.total_segments_tested &&
      dimensions_tested == o.dimensions_tested &&
      reason == o.reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 203

def hash
  [metrics, total_segments_tested, dimensions_tested, reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metrics.nil?
    invalid_properties.push('invalid value for "metrics", metrics cannot be nil.')
  end

  if @total_segments_tested.nil?
    invalid_properties.push('invalid value for "total_segments_tested", total_segments_tested cannot be nil.')
  end

  if @dimensions_tested.nil?
    invalid_properties.push('invalid value for "dimensions_tested", dimensions_tested cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
# File 'lib/talon_one_sdk/models/experiment_segment_insights.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metrics.nil?
  return false if @total_segments_tested.nil?
  return false if @dimensions_tested.nil?
  return false if @reason.nil?
  true
end