Class: TalonOne::ExperimentVariant

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/experiment_variant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExperimentVariant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentVariant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentVariant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'experiment_id')
    self.experiment_id = attributes[:'experiment_id']
  end

  if attributes.key?(:'ruleset')
    self.ruleset = attributes[:'ruleset']
  end

  if attributes.key?(:'weight')
    self.weight = attributes[:'weight']
  end

  if attributes.key?(:'is_primary')
    self.is_primary = attributes[:'is_primary']
  else
    self.is_primary = nil
  end
end

Instance Attribute Details

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 22

def created
  @created
end

#experiment_idObject

Returns the value of attribute experiment_id.



26
27
28
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 26

def experiment_id
  @experiment_id
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 19

def id
  @id
end

#is_primaryObject

Returns the value of attribute is_primary.



32
33
34
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 32

def is_primary
  @is_primary
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 24

def name
  @name
end

#rulesetObject

Returns the value of attribute ruleset.



28
29
30
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 28

def ruleset
  @ruleset
end

#weightObject

Returns the value of attribute weight.



30
31
32
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 30

def weight
  @weight
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'experiment_id' => :'experimentId',
    :'ruleset' => :'ruleset',
    :'weight' => :'weight',
    :'is_primary' => :'isPrimary'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



77
78
79
80
81
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 77

def self.openapi_all_of
  [
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 58

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'name' => :'String',
    :'experiment_id' => :'Integer',
    :'ruleset' => :'Ruleset',
    :'weight' => :'Integer',
    :'is_primary' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      experiment_id == o.experiment_id &&
      ruleset == o.ruleset &&
      weight == o.weight &&
      is_primary == o.is_primary
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 233

def hash
  [id, created, name, experiment_id, ruleset, weight, is_primary].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_primary.nil?
    invalid_properties.push('invalid value for "is_primary", is_primary cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
# File 'lib/talon_one_sdk/models/experiment_variant.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @is_primary.nil?
  true
end