Class: TalonOne::ExperimentVerdict

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/experiment_verdict.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExperimentVerdict

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentVerdict` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentVerdict`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'winner_variant_name')
    self.winner_variant_name = attributes[:'winner_variant_name']
  else
    self.winner_variant_name = nil
  end

  if attributes.key?(:'verdict_summary')
    self.verdict_summary = attributes[:'verdict_summary']
  else
    self.verdict_summary = nil
  end

  if attributes.key?(:'key_findings')
    if (value = attributes[:'key_findings']).is_a?(Array)
      self.key_findings = value
    end
  else
    self.key_findings = nil
  end

  if attributes.key?(:'ai_confidence_level')
    self.ai_confidence_level = attributes[:'ai_confidence_level']
  else
    self.ai_confidence_level = nil
  end

  if attributes.key?(:'recommendation')
    self.recommendation = attributes[:'recommendation']
  else
    self.recommendation = nil
  end
end

Instance Attribute Details

#ai_confidence_levelObject

Your confidence in this overall verdict, from 0 to 100.



28
29
30
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 28

def ai_confidence_level
  @ai_confidence_level
end

#key_findingsObject

A bullet point stating the most important finding, including the metric, the percentage change, and the confidence.



25
26
27
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 25

def key_findings
  @key_findings
end

#recommendationObject

A short, actionable recommendation based on the findings. If inconclusive, suggest running the test longer. If there is a clear winner, recommend promoting it.



31
32
33
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 31

def recommendation
  @recommendation
end

#verdict_summaryObject

A one-sentence summary of the outcome, including the key metric and confidence level that led to the decision.



22
23
24
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 22

def verdict_summary
  @verdict_summary
end

#winner_variant_nameObject

The name of the winning variant. If no variant shows a statistically significant advantage on key business metrics, return ‘Inconclusive’.



19
20
21
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 19

def winner_variant_name
  @winner_variant_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 34

def self.attribute_map
  {
    :'winner_variant_name' => :'winnerVariantName',
    :'verdict_summary' => :'verdictSummary',
    :'key_findings' => :'keyFindings',
    :'ai_confidence_level' => :'aiConfidenceLevel',
    :'recommendation' => :'recommendation'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 55

def self.openapi_types
  {
    :'winner_variant_name' => :'String',
    :'verdict_summary' => :'String',
    :'key_findings' => :'Array<String>',
    :'ai_confidence_level' => :'String',
    :'recommendation' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      winner_variant_name == o.winner_variant_name &&
      verdict_summary == o.verdict_summary &&
      key_findings == o.key_findings &&
      ai_confidence_level == o.ai_confidence_level &&
      recommendation == o.recommendation
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 230

def hash
  [winner_variant_name, verdict_summary, key_findings, ai_confidence_level, recommendation].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @winner_variant_name.nil?
    invalid_properties.push('invalid value for "winner_variant_name", winner_variant_name cannot be nil.')
  end

  if @verdict_summary.nil?
    invalid_properties.push('invalid value for "verdict_summary", verdict_summary cannot be nil.')
  end

  if @key_findings.nil?
    invalid_properties.push('invalid value for "key_findings", key_findings cannot be nil.')
  end

  if @ai_confidence_level.nil?
    invalid_properties.push('invalid value for "ai_confidence_level", ai_confidence_level cannot be nil.')
  end

  if @recommendation.nil?
    invalid_properties.push('invalid value for "recommendation", recommendation cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
158
# File 'lib/talon_one_sdk/models/experiment_verdict.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @winner_variant_name.nil?
  return false if @verdict_summary.nil?
  return false if @key_findings.nil?
  return false if @ai_confidence_level.nil?
  return false if @recommendation.nil?
  true
end