Class: TalonOne::ExpiringCardPointsData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/expiring_card_points_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpiringCardPointsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExpiringCardPointsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExpiringCardPointsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'amount_of_expiring_points')
    self.amount_of_expiring_points = attributes[:'amount_of_expiring_points']
  else
    self.amount_of_expiring_points = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  else
    self.card_identifier = nil
  end

  if attributes.key?(:'users_per_card_limit')
    self.users_per_card_limit = attributes[:'users_per_card_limit']
  else
    self.users_per_card_limit = nil
  end

  if attributes.key?(:'profiles')
    if (value = attributes[:'profiles']).is_a?(Array)
      self.profiles = value
    end
  else
    self.profiles = nil
  end
end

Instance Attribute Details

#amount_of_expiring_pointsObject

The amount of loyalty points that will be expired soon.



25
26
27
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 25

def amount_of_expiring_points
  @amount_of_expiring_points
end

#card_identifierObject

The identifier of the loyalty card, ‘which must match the regular expression `^[A-Za-z0-9._%+@-]+$`.



31
32
33
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 31

def card_identifier
  @card_identifier
end

#expiry_dateObject

The expiration date of loyalty points.



19
20
21
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 19

def expiry_date
  @expiry_date
end

#loyalty_program_idObject

The ID of the loyalty program.



22
23
24
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 22

def loyalty_program_id
  @loyalty_program_id
end

#profilesObject

The integration IDs of the customer profiles linked to the card.



37
38
39
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 37

def profiles
  @profiles
end

#subledger_idObject

The ID of the subledger within the loyalty program where these points were added.



28
29
30
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 28

def subledger_id
  @subledger_id
end

#users_per_card_limitObject

The maximum number of customer profiles with which a card can be shared. This can be set to ‘0` for no limit.



34
35
36
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 34

def users_per_card_limit
  @users_per_card_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 40

def self.attribute_map
  {
    :'expiry_date' => :'ExpiryDate',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'amount_of_expiring_points' => :'AmountOfExpiringPoints',
    :'subledger_id' => :'SubledgerID',
    :'card_identifier' => :'CardIdentifier',
    :'users_per_card_limit' => :'UsersPerCardLimit',
    :'profiles' => :'Profiles'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 309

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 63

def self.openapi_types
  {
    :'expiry_date' => :'Date',
    :'loyalty_program_id' => :'Integer',
    :'amount_of_expiring_points' => :'Float',
    :'subledger_id' => :'String',
    :'card_identifier' => :'String',
    :'users_per_card_limit' => :'Integer',
    :'profiles' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expiry_date == o.expiry_date &&
      loyalty_program_id == o.loyalty_program_id &&
      amount_of_expiring_points == o.amount_of_expiring_points &&
      subledger_id == o.subledger_id &&
      card_identifier == o.card_identifier &&
      users_per_card_limit == o.users_per_card_limit &&
      profiles == o.profiles
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 302

def hash
  [expiry_date, loyalty_program_id, amount_of_expiring_points, subledger_id, card_identifier, users_per_card_limit, profiles].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @amount_of_expiring_points.nil?
    invalid_properties.push('invalid value for "amount_of_expiring_points", amount_of_expiring_points cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @card_identifier.nil?
    invalid_properties.push('invalid value for "card_identifier", card_identifier cannot be nil.')
  end

  if @users_per_card_limit.nil?
    invalid_properties.push('invalid value for "users_per_card_limit", users_per_card_limit cannot be nil.')
  end

  if @users_per_card_limit < 0
    invalid_properties.push('invalid value for "users_per_card_limit", must be greater than or equal to 0.')
  end

  if @profiles.nil?
    invalid_properties.push('invalid value for "profiles", profiles cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/talon_one_sdk/models/expiring_card_points_data.rb', line 188

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expiry_date.nil?
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @amount_of_expiring_points.nil?
  return false if @subledger_id.nil?
  return false if @card_identifier.nil?
  return false if @users_per_card_limit.nil?
  return false if @users_per_card_limit < 0
  return false if @profiles.nil?
  true
end