Class: TalonOne::ExpiringCouponsData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/expiring_coupons_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpiringCouponsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExpiringCouponsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExpiringCouponsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'coupon_value')
    self.coupon_value = attributes[:'coupon_value']
  else
    self.coupon_value = nil
  end

  if attributes.key?(:'created_date')
    self.created_date = attributes[:'created_date']
  end

  if attributes.key?(:'valid_from')
    self.valid_from = attributes[:'valid_from']
  end

  if attributes.key?(:'valid_until')
    self.valid_until = attributes[:'valid_until']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  else
    self.usage_limit = nil
  end

  if attributes.key?(:'usage_counter')
    self.usage_counter = attributes[:'usage_counter']
  else
    self.usage_counter = nil
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  else
    self.attributes = nil
  end
end

Instance Attribute Details

#attributesObject

Custom attributes associated with this coupon.



46
47
48
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 46

def attributes
  @attributes
end

#batch_idObject

The ID of the batch the coupon belongs to.



43
44
45
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 43

def batch_id
  @batch_id
end

#campaign_idObject

The ID of the campaign to which the coupon belongs.



31
32
33
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 31

def campaign_id
  @campaign_id
end

#coupon_valueObject

The coupon code.



19
20
21
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 19

def coupon_value
  @coupon_value
end

#created_dateObject

Timestamp at which point the coupon was created.



22
23
24
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 22

def created_date
  @created_date
end

#customer_profile_idObject

The Integration ID of the customer that is allowed to redeem this coupon.



34
35
36
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 34

def customer_profile_id
  @customer_profile_id
end

#usage_counterObject

The number of times the coupon has been successfully redeemed.



40
41
42
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 40

def usage_counter
  @usage_counter
end

#usage_limitObject

The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.



37
38
39
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 37

def usage_limit
  @usage_limit
end

#valid_fromObject

Timestamp at which point the coupon becomes valid.



25
26
27
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 25

def valid_from
  @valid_from
end

#valid_untilObject

Timestamp at which point the coupon expires. Coupon never expires if this is omitted, zero, or negative.



28
29
30
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 28

def valid_until
  @valid_until
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 49

def self.attribute_map
  {
    :'coupon_value' => :'CouponValue',
    :'created_date' => :'CreatedDate',
    :'valid_from' => :'ValidFrom',
    :'valid_until' => :'ValidUntil',
    :'campaign_id' => :'CampaignId',
    :'customer_profile_id' => :'CustomerProfileId',
    :'usage_limit' => :'UsageLimit',
    :'usage_counter' => :'UsageCounter',
    :'batch_id' => :'BatchId',
    :'attributes' => :'Attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 334

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 75

def self.openapi_types
  {
    :'coupon_value' => :'String',
    :'created_date' => :'Time',
    :'valid_from' => :'Time',
    :'valid_until' => :'Time',
    :'campaign_id' => :'Integer',
    :'customer_profile_id' => :'String',
    :'usage_limit' => :'Integer',
    :'usage_counter' => :'Integer',
    :'batch_id' => :'String',
    :'attributes' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      coupon_value == o.coupon_value &&
      created_date == o.created_date &&
      valid_from == o.valid_from &&
      valid_until == o.valid_until &&
      campaign_id == o.campaign_id &&
      customer_profile_id == o.customer_profile_id &&
      usage_limit == o.usage_limit &&
      usage_counter == o.usage_counter &&
      batch_id == o.batch_id &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 327

def hash
  [coupon_value, created_date, valid_from, valid_until, campaign_id, customer_profile_id, usage_limit, usage_counter, batch_id, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @coupon_value.nil?
    invalid_properties.push('invalid value for "coupon_value", coupon_value cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @campaign_id < 1
    invalid_properties.push('invalid value for "campaign_id", must be greater than or equal to 1.')
  end

  if @usage_limit.nil?
    invalid_properties.push('invalid value for "usage_limit", usage_limit cannot be nil.')
  end

  if @usage_limit > 999999
    invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.')
  end

  if @usage_limit < 0
    invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.')
  end

  if @usage_counter.nil?
    invalid_properties.push('invalid value for "usage_counter", usage_counter cannot be nil.')
  end

  if @attributes.nil?
    invalid_properties.push('invalid value for "attributes", attributes cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/talon_one_sdk/models/expiring_coupons_data.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @coupon_value.nil?
  return false if @campaign_id.nil?
  return false if @campaign_id < 1
  return false if @usage_limit.nil?
  return false if @usage_limit > 999999
  return false if @usage_limit < 0
  return false if @usage_counter.nil?
  return false if @attributes.nil?
  true
end