Class: TalonOne::ExpiringPointsData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/expiring_points_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpiringPointsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExpiringPointsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExpiringPointsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  else
    self.customer_profile_id = nil
  end

  if attributes.key?(:'amount_of_expiring_points')
    self.amount_of_expiring_points = attributes[:'amount_of_expiring_points']
  else
    self.amount_of_expiring_points = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end
end

Instance Attribute Details

#amount_of_expiring_pointsObject

The amount of loyalty points that will be expired soon.



28
29
30
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 28

def amount_of_expiring_points
  @amount_of_expiring_points
end

#customer_profile_idObject

The integration ID of the customer profile that has expiring points.



25
26
27
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 25

def customer_profile_id
  @customer_profile_id
end

#expiry_dateObject

The expiration date of loyalty points.



19
20
21
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 19

def expiry_date
  @expiry_date
end

#loyalty_program_idObject

The ID of the loyalty program.



22
23
24
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 22

def loyalty_program_id
  @loyalty_program_id
end

#subledger_idObject

The ID of the subledger within the loyalty program where these points were added.



31
32
33
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 31

def subledger_id
  @subledger_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 34

def self.attribute_map
  {
    :'expiry_date' => :'ExpiryDate',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'customer_profile_id' => :'CustomerProfileID',
    :'amount_of_expiring_points' => :'AmountOfExpiringPoints',
    :'subledger_id' => :'SubledgerID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 55

def self.openapi_types
  {
    :'expiry_date' => :'Date',
    :'loyalty_program_id' => :'Integer',
    :'customer_profile_id' => :'String',
    :'amount_of_expiring_points' => :'Float',
    :'subledger_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expiry_date == o.expiry_date &&
      loyalty_program_id == o.loyalty_program_id &&
      customer_profile_id == o.customer_profile_id &&
      amount_of_expiring_points == o.amount_of_expiring_points &&
      subledger_id == o.subledger_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 237

def hash
  [expiry_date, loyalty_program_id, customer_profile_id, amount_of_expiring_points, subledger_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @customer_profile_id.nil?
    invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.')
  end

  if @amount_of_expiring_points.nil?
    invalid_properties.push('invalid value for "amount_of_expiring_points", amount_of_expiring_points cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/expiring_points_data.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expiry_date.nil?
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @customer_profile_id.nil?
  return false if @amount_of_expiring_points.nil?
  return false if @subledger_id.nil?
  true
end