Class: TalonOne::GenerateCouponFailureDetailedSummary

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateCouponFailureDetailedSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::GenerateCouponFailureDetailedSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::GenerateCouponFailureDetailedSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  else
    self.session_id = nil
  end

  if attributes.key?(:'event_id')
    self.event_id = attributes[:'event_id']
  else
    self.event_id = nil
  end

  if attributes.key?(:'coupon')
    self.coupon = attributes[:'coupon']
  else
    self.coupon = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application. It is displayed in your Talon.One deployment URL.



19
20
21
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 19

def application_id
  @application_id
end

#couponObject

The coupon code that could not be redeemed.



28
29
30
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 28

def coupon
  @coupon
end

#event_idObject

The ID of the event for which the coupon redemption failed.



25
26
27
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 25

def event_id
  @event_id
end

#languageObject

The language of the summary.



31
32
33
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 31

def language
  @language
end

#session_idObject

ID of the customer session where the coupon redemption failed.



22
23
24
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 22

def session_id
  @session_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 34

def self.attribute_map
  {
    :'application_id' => :'applicationID',
    :'session_id' => :'sessionID',
    :'event_id' => :'eventID',
    :'coupon' => :'coupon',
    :'language' => :'language'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 55

def self.openapi_types
  {
    :'application_id' => :'Float',
    :'session_id' => :'String',
    :'event_id' => :'Integer',
    :'coupon' => :'String',
    :'language' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      application_id == o.application_id &&
      session_id == o.session_id &&
      event_id == o.event_id &&
      coupon == o.coupon &&
      language == o.language
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 220

def hash
  [application_id, session_id, event_id, coupon, language].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @session_id.nil?
    invalid_properties.push('invalid value for "session_id", session_id cannot be nil.')
  end

  if @session_id.to_s.length > 255
    invalid_properties.push('invalid value for "session_id", the character length must be smaller than or equal to 255.')
  end

  if @event_id.nil?
    invalid_properties.push('invalid value for "event_id", event_id cannot be nil.')
  end

  if @coupon.nil?
    invalid_properties.push('invalid value for "coupon", coupon cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
154
# File 'lib/talon_one_sdk/models/generate_coupon_failure_detailed_summary.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @application_id.nil?
  return false if @session_id.nil?
  return false if @session_id.to_s.length > 255
  return false if @event_id.nil?
  return false if @coupon.nil?
  true
end