Class: TalonOne::GenerateLoyaltyCard

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/generate_loyalty_card.rb

Overview

The parameters necessary to generate a loyalty card.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateLoyaltyCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::GenerateLoyaltyCard` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::GenerateLoyaltyCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'active'
  end

  if attributes.key?(:'customer_profile_ids')
    if (value = attributes[:'customer_profile_ids']).is_a?(Array)
      self.customer_profile_ids = value
    end
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  end
end

Instance Attribute Details

#card_identifierObject

The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.



26
27
28
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 26

def card_identifier
  @card_identifier
end

#customer_profile_idsObject

Integration IDs of the customer profiles linked to the card.



23
24
25
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 23

def customer_profile_ids
  @customer_profile_ids
end

#statusObject

Status of the loyalty card.



20
21
22
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 51

def self.attribute_map
  {
    :'status' => :'status',
    :'customer_profile_ids' => :'customerProfileIds',
    :'card_identifier' => :'cardIdentifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 70

def self.openapi_types
  {
    :'status' => :'String',
    :'customer_profile_ids' => :'Array<String>',
    :'card_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      customer_profile_ids == o.customer_profile_ids &&
      card_identifier == o.card_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 201

def hash
  [status, customer_profile_ids, card_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@card_identifier.nil? && @card_identifier.to_s.length > 108
    invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length < 4
    invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  if !@card_identifier.nil? && @card_identifier !~ pattern
    invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/generate_loyalty_card.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["active", "inactive"])
  return false unless status_validator.valid?(@status)
  return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108
  return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4
  return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  true
end