Class: TalonOne::Giveaway

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/giveaway.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Giveaway

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/giveaway.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Giveaway` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Giveaway`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'pool_id')
    self.pool_id = attributes[:'pool_id']
  else
    self.pool_id = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'used')
    self.used = attributes[:'used']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'profile_integration_id')
    self.profile_integration_id = attributes[:'profile_integration_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary properties associated with this giveaway.



37
38
39
# File 'lib/talon_one_sdk/models/giveaway.rb', line 37

def attributes
  @attributes
end

#codeObject

The code value of this giveaway.



25
26
27
# File 'lib/talon_one_sdk/models/giveaway.rb', line 25

def code
  @code
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/giveaway.rb', line 22

def created
  @created
end

#end_dateObject

Timestamp at which point the giveaway becomes invalid.



34
35
36
# File 'lib/talon_one_sdk/models/giveaway.rb', line 34

def end_date
  @end_date
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/giveaway.rb', line 19

def id
  @id
end

#import_idObject

The ID of the Import which created this giveaway.



43
44
45
# File 'lib/talon_one_sdk/models/giveaway.rb', line 43

def import_id
  @import_id
end

#pool_idObject

The ID of the pool to return giveaway codes from.



28
29
30
# File 'lib/talon_one_sdk/models/giveaway.rb', line 28

def pool_id
  @pool_id
end

#profile_idObject

The internal ID of the customer profile that was awarded the giveaway, if the giveaway was awarded and an internal ID exists.



49
50
51
# File 'lib/talon_one_sdk/models/giveaway.rb', line 49

def profile_id
  @profile_id
end

#profile_integration_idObject

The third-party integration ID of the customer profile that was awarded the giveaway, if the giveaway was awarded.



46
47
48
# File 'lib/talon_one_sdk/models/giveaway.rb', line 46

def profile_integration_id
  @profile_integration_id
end

#start_dateObject

Timestamp at which point the giveaway becomes valid.



31
32
33
# File 'lib/talon_one_sdk/models/giveaway.rb', line 31

def start_date
  @start_date
end

#usedObject

Indicates whether this giveaway code was given before.



40
41
42
# File 'lib/talon_one_sdk/models/giveaway.rb', line 40

def used
  @used
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/giveaway.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/giveaway.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/giveaway.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'code' => :'code',
    :'pool_id' => :'poolId',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'attributes' => :'attributes',
    :'used' => :'used',
    :'import_id' => :'importId',
    :'profile_integration_id' => :'profileIntegrationId',
    :'profile_id' => :'profileId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/talon_one_sdk/models/giveaway.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
# File 'lib/talon_one_sdk/models/giveaway.rb', line 102

def self.openapi_all_of
  [
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/giveaway.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/giveaway.rb', line 79

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'code' => :'String',
    :'pool_id' => :'Integer',
    :'start_date' => :'Time',
    :'end_date' => :'Time',
    :'attributes' => :'Object',
    :'used' => :'Boolean',
    :'import_id' => :'Integer',
    :'profile_integration_id' => :'String',
    :'profile_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/talon_one_sdk/models/giveaway.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      code == o.code &&
      pool_id == o.pool_id &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      attributes == o.attributes &&
      used == o.used &&
      import_id == o.import_id &&
      profile_integration_id == o.profile_integration_id &&
      profile_id == o.profile_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/talon_one_sdk/models/giveaway.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/talon_one_sdk/models/giveaway.rb', line 278

def hash
  [id, created, code, pool_id, start_date, end_date, attributes, used, import_id, profile_integration_id, profile_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/talon_one_sdk/models/giveaway.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @pool_id.nil?
    invalid_properties.push('invalid value for "pool_id", pool_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/talon_one_sdk/models/giveaway.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/giveaway.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @code.nil?
  return false if @pool_id.nil?
  true
end