Class: TalonOne::GiveawayPoolNotificationData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/giveaway_pool_notification_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GiveawayPoolNotificationData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::GiveawayPoolNotificationData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::GiveawayPoolNotificationData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'pool_id')
    self.pool_id = attributes[:'pool_id']
  else
    self.pool_id = nil
  end

  if attributes.key?(:'pool_name')
    self.pool_name = attributes[:'pool_name']
  else
    self.pool_name = nil
  end

  if attributes.key?(:'pool_description')
    self.pool_description = attributes[:'pool_description']
  else
    self.pool_description = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'total_codes')
    self.total_codes = attributes[:'total_codes']
  else
    self.total_codes = nil
  end

  if attributes.key?(:'used_codes')
    self.used_codes = attributes[:'used_codes']
  else
    self.used_codes = nil
  end

  if attributes.key?(:'remaining_codes')
    self.remaining_codes = attributes[:'remaining_codes']
  else
    self.remaining_codes = nil
  end

  if attributes.key?(:'threshold_percent')
    self.threshold_percent = attributes[:'threshold_percent']
  else
    self.threshold_percent = nil
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns the giveaway pool.



31
32
33
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 31

def 
  @account_id
end

#application_idObject

The ID of the Application connected to the giveaway pool.



34
35
36
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 34

def application_id
  @application_id
end

#eventObject

The event type of the notification.



19
20
21
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 19

def event
  @event
end

#pool_descriptionObject

The description of the giveaway pool.



28
29
30
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 28

def pool_description
  @pool_description
end

#pool_idObject

The ID of the giveaway pool.



22
23
24
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 22

def pool_id
  @pool_id
end

#pool_nameObject

The name of the giveaway pool.



25
26
27
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 25

def pool_name
  @pool_name
end

#remaining_codesObject

The number of codes remaining in the giveaway pool.



43
44
45
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 43

def remaining_codes
  @remaining_codes
end

#threshold_percentObject

The percentage threshold for the notification. The notification is triggered when the number of codes drops below this threshold.



46
47
48
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 46

def threshold_percent
  @threshold_percent
end

#total_codesObject

The total number of codes in the giveaway pool.



37
38
39
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 37

def total_codes
  @total_codes
end

#used_codesObject

The number of codes that have been used.



40
41
42
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 40

def used_codes
  @used_codes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 49

def self.attribute_map
  {
    :'event' => :'Event',
    :'pool_id' => :'PoolId',
    :'pool_name' => :'PoolName',
    :'pool_description' => :'PoolDescription',
    :'account_id' => :'AccountId',
    :'application_id' => :'ApplicationId',
    :'total_codes' => :'TotalCodes',
    :'used_codes' => :'UsedCodes',
    :'remaining_codes' => :'RemainingCodes',
    :'threshold_percent' => :'ThresholdPercent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 397

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 75

def self.openapi_types
  {
    :'event' => :'String',
    :'pool_id' => :'Integer',
    :'pool_name' => :'String',
    :'pool_description' => :'String',
    :'account_id' => :'Integer',
    :'application_id' => :'Integer',
    :'total_codes' => :'Integer',
    :'used_codes' => :'Integer',
    :'remaining_codes' => :'Integer',
    :'threshold_percent' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 367

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      pool_id == o.pool_id &&
      pool_name == o.pool_name &&
      pool_description == o.pool_description &&
       == o. &&
      application_id == o.application_id &&
      total_codes == o.total_codes &&
      used_codes == o.used_codes &&
      remaining_codes == o.remaining_codes &&
      threshold_percent == o.threshold_percent
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


384
385
386
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 384

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



390
391
392
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 390

def hash
  [event, pool_id, pool_name, pool_description, , application_id, total_codes, used_codes, remaining_codes, threshold_percent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @pool_id.nil?
    invalid_properties.push('invalid value for "pool_id", pool_id cannot be nil.')
  end

  if @pool_id < 1
    invalid_properties.push('invalid value for "pool_id", must be greater than or equal to 1.')
  end

  if @pool_name.nil?
    invalid_properties.push('invalid value for "pool_name", pool_name cannot be nil.')
  end

  if @pool_description.nil?
    invalid_properties.push('invalid value for "pool_description", pool_description cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @account_id < 1
    invalid_properties.push('invalid value for "account_id", must be greater than or equal to 1.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @application_id < 1
    invalid_properties.push('invalid value for "application_id", must be greater than or equal to 1.')
  end

  if @total_codes.nil?
    invalid_properties.push('invalid value for "total_codes", total_codes cannot be nil.')
  end

  if @used_codes.nil?
    invalid_properties.push('invalid value for "used_codes", used_codes cannot be nil.')
  end

  if @remaining_codes.nil?
    invalid_properties.push('invalid value for "remaining_codes", remaining_codes cannot be nil.')
  end

  if @threshold_percent.nil?
    invalid_properties.push('invalid value for "threshold_percent", threshold_percent cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 419

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/giveaway_pool_notification_data.rb', line 235

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event.nil?
  return false if @pool_id.nil?
  return false if @pool_id < 1
  return false if @pool_name.nil?
  return false if @pool_description.nil?
  return false if @account_id.nil?
  return false if @account_id < 1
  return false if @application_id.nil?
  return false if @application_id < 1
  return false if @total_codes.nil?
  return false if @used_codes.nil?
  return false if @remaining_codes.nil?
  return false if @threshold_percent.nil?
  true
end