Class: TalonOne::GiveawaysPool

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/giveaways_pool.rb

Overview

Giveaways pools is an entity for managing multiple similar giveaways.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GiveawaysPool

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::GiveawaysPool` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::GiveawaysPool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  else
    self.sandbox = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



26
27
28
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 26

def 
  @account_id
end

#createdObject

The time this entity was created.



23
24
25
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 23

def created
  @created
end

#created_byObject

ID of the user who created this giveaways pool.



44
45
46
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 44

def created_by
  @created_by
end

#descriptionObject

The description of this giveaways pool.



32
33
34
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 32

def description
  @description
end

#idObject

The internal ID of this entity.



20
21
22
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 20

def id
  @id
end

#modifiedObject

Timestamp of the most recent update to the giveaways pool.



41
42
43
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 41

def modified
  @modified
end

#modified_byObject

ID of the user who last updated this giveaways pool if available.



47
48
49
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 47

def modified_by
  @modified_by
end

#nameObject

The name of this giveaways pool.



29
30
31
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 29

def name
  @name
end

#sandboxObject

Indicates if this program is a live or sandbox program. Programs of a given type can only be connected to Applications of the same type.



38
39
40
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 38

def sandbox
  @sandbox
end

#subscribed_applications_idsObject

A list of the IDs of the applications that this giveaways pool is enabled for.



35
36
37
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 35

def subscribed_applications_ids
  @subscribed_applications_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 50

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'description' => :'description',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'sandbox' => :'sandbox',
    :'modified' => :'modified',
    :'created_by' => :'createdBy',
    :'modified_by' => :'modifiedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



98
99
100
101
102
103
104
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 98

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'NewGiveawaysPool'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 76

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'sandbox' => :'Boolean',
    :'modified' => :'Time',
    :'created_by' => :'Integer',
    :'modified_by' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      name == o.name &&
      description == o.description &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      sandbox == o.sandbox &&
      modified == o.modified &&
      created_by == o.created_by &&
      modified_by == o.modified_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 307

def hash
  [id, created, , name, description, subscribed_applications_ids, sandbox, modified, created_by, modified_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/giveaways_pool.rb', line 211

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @sandbox.nil?
  return false if @created_by.nil?
  true
end