Class: TalonOne::HiddenConditionsEffects

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/hidden_conditions_effects.rb

Overview

Contains information about hidden conditions and effects in the Application.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ HiddenConditionsEffects

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::HiddenConditionsEffects` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::HiddenConditionsEffects`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'built_in_effects')
    if (value = attributes[:'built_in_effects']).is_a?(Array)
      self.built_in_effects = value
    end
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'custom_effects')
    if (value = attributes[:'custom_effects']).is_a?(Array)
      self.custom_effects = value
    end
  end

  if attributes.key?(:'webhooks')
    if (value = attributes[:'webhooks']).is_a?(Array)
      self.webhooks = value
    end
  end
end

Instance Attribute Details

#built_in_effectsObject

List of hidden built-in effects.



20
21
22
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 20

def built_in_effects
  @built_in_effects
end

#conditionsObject

List of hidden conditions.



23
24
25
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 23

def conditions
  @conditions
end

#custom_effectsObject

List of the IDs of hidden custom effects.



26
27
28
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 26

def custom_effects
  @custom_effects
end

#webhooksObject

List of the IDs of hidden webhooks.



29
30
31
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 29

def webhooks
  @webhooks
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 32

def self.attribute_map
  {
    :'built_in_effects' => :'builtInEffects',
    :'conditions' => :'conditions',
    :'custom_effects' => :'customEffects',
    :'webhooks' => :'webhooks'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 149

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 52

def self.openapi_types
  {
    :'built_in_effects' => :'Array<String>',
    :'conditions' => :'Array<String>',
    :'custom_effects' => :'Array<Integer>',
    :'webhooks' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



125
126
127
128
129
130
131
132
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 125

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      built_in_effects == o.built_in_effects &&
      conditions == o.conditions &&
      custom_effects == o.custom_effects &&
      webhooks == o.webhooks
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


136
137
138
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 136

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



142
143
144
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 142

def hash
  [built_in_effects, conditions, custom_effects, webhooks].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



118
119
120
121
# File 'lib/talon_one_sdk/models/hidden_conditions_effects.rb', line 118

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end