Class: TalonOne::IncreaseAchievementProgressEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IncreaseAchievementProgressEffectProps
- Defined in:
- lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb
Overview
The properties specific to the "increaseAchievementProgress" effect. This gets triggered whenever a validated rule contained an "increase customer progress" effect.
Instance Attribute Summary collapse
-
#achievement_id ⇒ Object
The internal ID of the achievement.
-
#achievement_name ⇒ Object
The name of the achievement.
-
#delta ⇒ Object
The value by which the customer’s current progress in the achievement is increased.
-
#is_just_completed ⇒ Object
Indicates if the customer has completed the achievement in the current session.
-
#progress_tracker_id ⇒ Object
The internal ID of the achievement progress tracker.
-
#target ⇒ Object
The target value to complete the achievement.
-
#value ⇒ Object
The current progress of the customer in the achievement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IncreaseAchievementProgressEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IncreaseAchievementProgressEffectProps
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IncreaseAchievementProgressEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IncreaseAchievementProgressEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'achievement_id') self.achievement_id = attributes[:'achievement_id'] else self.achievement_id = nil end if attributes.key?(:'achievement_name') self.achievement_name = attributes[:'achievement_name'] else self.achievement_name = nil end if attributes.key?(:'progress_tracker_id') self.progress_tracker_id = attributes[:'progress_tracker_id'] end if attributes.key?(:'delta') self.delta = attributes[:'delta'] else self.delta = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end if attributes.key?(:'is_just_completed') self.is_just_completed = attributes[:'is_just_completed'] else self.is_just_completed = nil end end |
Instance Attribute Details
#achievement_id ⇒ Object
The internal ID of the achievement.
20 21 22 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 20 def achievement_id @achievement_id end |
#achievement_name ⇒ Object
The name of the achievement.
23 24 25 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 23 def achievement_name @achievement_name end |
#delta ⇒ Object
The value by which the customer’s current progress in the achievement is increased.
29 30 31 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 29 def delta @delta end |
#is_just_completed ⇒ Object
Indicates if the customer has completed the achievement in the current session.
38 39 40 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 38 def is_just_completed @is_just_completed end |
#progress_tracker_id ⇒ Object
The internal ID of the achievement progress tracker.
26 27 28 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 26 def progress_tracker_id @progress_tracker_id end |
#target ⇒ Object
The target value to complete the achievement.
35 36 37 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 35 def target @target end |
#value ⇒ Object
The current progress of the customer in the achievement.
32 33 34 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 32 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 41 def self.attribute_map { :'achievement_id' => :'achievementId', :'achievement_name' => :'achievementName', :'progress_tracker_id' => :'progressTrackerId', :'delta' => :'delta', :'value' => :'value', :'target' => :'target', :'is_just_completed' => :'isJustCompleted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 273 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 64 def self.openapi_types { :'achievement_id' => :'Integer', :'achievement_name' => :'String', :'progress_tracker_id' => :'Integer', :'delta' => :'Float', :'value' => :'Float', :'target' => :'Float', :'is_just_completed' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && achievement_id == o.achievement_id && achievement_name == o.achievement_name && progress_tracker_id == o.progress_tracker_id && delta == o.delta && value == o.value && target == o.target && is_just_completed == o.is_just_completed end |
#eql?(o) ⇒ Boolean
260 261 262 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 260 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 266 def hash [achievement_id, achievement_name, progress_tracker_id, delta, value, target, is_just_completed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @achievement_id.nil? invalid_properties.push('invalid value for "achievement_id", achievement_id cannot be nil.') end if @achievement_name.nil? invalid_properties.push('invalid value for "achievement_name", achievement_name cannot be nil.') end if @delta.nil? invalid_properties.push('invalid value for "delta", delta cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end if @is_just_completed.nil? invalid_properties.push('invalid value for "is_just_completed", is_just_completed cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/talon_one_sdk/models/increase_achievement_progress_effect_props.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @achievement_id.nil? return false if @achievement_name.nil? return false if @delta.nil? return false if @value.nil? return false if @target.nil? return false if @is_just_completed.nil? true end |