Class: TalonOne::IntegrationCustomerProfileAudienceRequestItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationCustomerProfileAudienceRequestItem
- Defined in:
- lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Defines the action to perform: - ‘add`: Adds the customer profile to the audience.
-
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
-
#profile_integration_id ⇒ Object
The ID of this customer profile in the third-party integration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationCustomerProfileAudienceRequestItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationCustomerProfileAudienceRequestItem
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationCustomerProfileAudienceRequestItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationCustomerProfileAudienceRequestItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'profile_integration_id') self.profile_integration_id = attributes[:'profile_integration_id'] else self.profile_integration_id = nil end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end end |
Instance Attribute Details
#action ⇒ Object
Defines the action to perform: - ‘add`: Adds the customer profile to the audience. Note: If the customer profile does not exist, it will be created. The profile will not be visible in any Application until a session or profile update is received for that profile. - `delete`: Removes the customer profile from the audience.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 19 def action @action end |
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 25 def integration_id @integration_id end |
#profile_integration_id ⇒ Object
The ID of this customer profile in the third-party integration.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 22 def profile_integration_id @profile_integration_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 50 def self.attribute_map { :'action' => :'action', :'profile_integration_id' => :'profileIntegrationId', :'integration_id' => :'integrationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 69 def self.openapi_types { :'action' => :'String', :'profile_integration_id' => :'String', :'integration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && profile_integration_id == o.profile_integration_id && integration_id == o.integration_id end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 207 def hash [action, profile_integration_id, integration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @profile_integration_id.nil? invalid_properties.push('invalid value for "profile_integration_id", profile_integration_id cannot be nil.') end if @profile_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "profile_integration_id", the character length must be smaller than or equal to 1000.') end if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/talon_one_sdk/models/integration_customer_profile_audience_request_item.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["add", "delete"]) return false unless action_validator.valid?(@action) return false if @profile_integration_id.nil? return false if @profile_integration_id.to_s.length > 1000 return false if @integration_id.nil? true end |