Class: TalonOne::IntegrationEventV2Request

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_event_v2_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationEventV2Request

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationEventV2Request` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationEventV2Request`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'evaluable_campaign_ids')
    if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array)
      self.evaluable_campaign_ids = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'response_content')
    if (value = attributes[:'response_content']).is_a?(Array)
      self.response_content = value
    end
  end

  if attributes.key?(:'loyalty_cards')
    if (value = attributes[:'loyalty_cards']).is_a?(Array)
      self.loyalty_cards = value
    end
  end
end

Instance Attribute Details

#attributesObject

Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).



31
32
33
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 31

def attributes
  @attributes
end

#evaluable_campaign_idsObject

When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.



25
26
27
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 25

def evaluable_campaign_ids
  @evaluable_campaign_ids
end

#loyalty_cardsObject

Identifiers of the loyalty cards used during this event.



37
38
39
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 37

def loyalty_cards
  @loyalty_cards
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.



19
20
21
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 19

def profile_id
  @profile_id
end

#response_contentObject

Extends the response with the chosen data entities. Use this property to get as much data back as needed from one request instead of sending extra requests to other endpoints.



34
35
36
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 34

def response_content
  @response_content
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



22
23
24
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 22

def store_integration_id
  @store_integration_id
end

#typeObject

A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.



28
29
30
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 28

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 62

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'store_integration_id' => :'storeIntegrationId',
    :'evaluable_campaign_ids' => :'evaluableCampaignIds',
    :'type' => :'type',
    :'attributes' => :'attributes',
    :'response_content' => :'responseContent',
    :'loyalty_cards' => :'loyaltyCards'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



104
105
106
107
108
109
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 104

def self.openapi_all_of
  [
  :'EventV2',
  :'ResponseContentObject'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 85

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'store_integration_id' => :'String',
    :'evaluable_campaign_ids' => :'Array<Integer>',
    :'type' => :'String',
    :'attributes' => :'Object',
    :'response_content' => :'Array<String>',
    :'loyalty_cards' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



252
253
254
255
256
257
258
259
260
261
262
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 252

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      store_integration_id == o.store_integration_id &&
      evaluable_campaign_ids == o.evaluable_campaign_ids &&
      type == o.type &&
      attributes == o.attributes &&
      response_content == o.response_content &&
      loyalty_cards == o.loyalty_cards
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 272

def hash
  [profile_id, store_integration_id, evaluable_campaign_ids, type, attributes, response_content, loyalty_cards].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length < 1
    invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.')
  end

  if !@loyalty_cards.nil? && @loyalty_cards.length > 1
    invalid_properties.push('invalid value for "loyalty_cards", number of items must be less than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
# File 'lib/talon_one_sdk/models/integration_event_v2_request.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if @type.nil?
  return false if @type.to_s.length < 1
  return false if !@loyalty_cards.nil? && @loyalty_cards.length > 1
  true
end