Class: TalonOne::IntegrationEventV3Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationEventV3Response
- Defined in:
- lib/talon_one_sdk/models/integration_event_v3_response.rb
Instance Attribute Summary collapse
-
#achievements ⇒ Object
The achievements progress of the customer.
-
#advanced_event ⇒ Object
The advanced event that was processed.
-
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
-
#campaign_eligibility ⇒ Object
A list of campaigns and their evaluation status for the current customer session.
-
#created_coupons ⇒ Object
The coupons that were created during the event processing.
-
#created_referrals ⇒ Object
The referrals that were created during the event processing.
-
#customer_profile ⇒ Object
The customer profile associated with the event.
-
#effects ⇒ Object
The effects generated by the rules in your running campaigns.
-
#loyalty ⇒ Object
The loyalty program status of the customer.
-
#referral ⇒ Object
The referral that was processed.
-
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
-
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationEventV3Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationEventV3Response
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationEventV3Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationEventV3Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_profile') self.customer_profile = attributes[:'customer_profile'] end if attributes.key?(:'loyalty') self.loyalty = attributes[:'loyalty'] end if attributes.key?(:'triggered_campaigns') if (value = attributes[:'triggered_campaigns']).is_a?(Array) self.triggered_campaigns = value end end if attributes.key?(:'campaign_eligibility') if (value = attributes[:'campaign_eligibility']).is_a?(Array) self.campaign_eligibility = value end end if attributes.key?(:'effects') if (value = attributes[:'effects']).is_a?(Array) self.effects = value end else self.effects = nil end if attributes.key?(:'rule_failure_reasons') if (value = attributes[:'rule_failure_reasons']).is_a?(Array) self.rule_failure_reasons = value end end if attributes.key?(:'created_coupons') if (value = attributes[:'created_coupons']).is_a?(Array) self.created_coupons = value end else self.created_coupons = nil end if attributes.key?(:'created_referrals') if (value = attributes[:'created_referrals']).is_a?(Array) self.created_referrals = value end else self.created_referrals = nil end if attributes.key?(:'awarded_giveaways') if (value = attributes[:'awarded_giveaways']).is_a?(Array) self.awarded_giveaways = value end end if attributes.key?(:'achievements') if (value = attributes[:'achievements']).is_a?(Array) self.achievements = value end end if attributes.key?(:'advanced_event') self.advanced_event = attributes[:'advanced_event'] end if attributes.key?(:'referral') self.referral = attributes[:'referral'] end end |
Instance Attribute Details
#achievements ⇒ Object
The achievements progress of the customer.
46 47 48 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 46 def achievements @achievements end |
#advanced_event ⇒ Object
The advanced event that was processed.
49 50 51 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 49 def advanced_event @advanced_event end |
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
43 44 45 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 43 def awarded_giveaways @awarded_giveaways end |
#campaign_eligibility ⇒ Object
A list of campaigns and their evaluation status for the current customer session. Note: - This response can only be included if the dry parameter in the query is set to true. - Do not include triggeredCampaigns or ruleFailureReasons in responseContent to avoid duplicate results.
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 28 def campaign_eligibility @campaign_eligibility end |
#created_coupons ⇒ Object
The coupons that were created during the event processing.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 37 def created_coupons @created_coupons end |
#created_referrals ⇒ Object
The referrals that were created during the event processing.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 40 def created_referrals @created_referrals end |
#customer_profile ⇒ Object
The customer profile associated with the event.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 19 def customer_profile @customer_profile end |
#effects ⇒ Object
The effects generated by the rules in your running campaigns. See API effects.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 31 def effects @effects end |
#loyalty ⇒ Object
The loyalty program status of the customer.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 22 def loyalty @loyalty end |
#referral ⇒ Object
The referral that was processed.
52 53 54 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 52 def referral @referral end |
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
34 35 36 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 34 def rule_failure_reasons @rule_failure_reasons end |
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 25 def triggered_campaigns @triggered_campaigns end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 55 def self.attribute_map { :'customer_profile' => :'customerProfile', :'loyalty' => :'loyalty', :'triggered_campaigns' => :'triggeredCampaigns', :'campaign_eligibility' => :'campaignEligibility', :'effects' => :'effects', :'rule_failure_reasons' => :'ruleFailureReasons', :'created_coupons' => :'createdCoupons', :'created_referrals' => :'createdReferrals', :'awarded_giveaways' => :'awardedGiveaways', :'achievements' => :'achievements', :'advanced_event' => :'advancedEvent', :'referral' => :'referral' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 107 def self.openapi_all_of [ :'IntegrationResponse' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 83 def self.openapi_types { :'customer_profile' => :'CustomerProfile', :'loyalty' => :'Loyalty', :'triggered_campaigns' => :'Array<Campaign>', :'campaign_eligibility' => :'Array<CampaignEligibility>', :'effects' => :'Array<Effect>', :'rule_failure_reasons' => :'Array<RuleFailureReason>', :'created_coupons' => :'Array<Coupon>', :'created_referrals' => :'Array<Referral>', :'awarded_giveaways' => :'Array<Giveaway>', :'achievements' => :'Array<CustomerAchievement>', :'advanced_event' => :'EventV3', :'referral' => :'InventoryReferral' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && customer_profile == o.customer_profile && loyalty == o.loyalty && triggered_campaigns == o.triggered_campaigns && campaign_eligibility == o.campaign_eligibility && effects == o.effects && rule_failure_reasons == o.rule_failure_reasons && created_coupons == o.created_coupons && created_referrals == o.created_referrals && awarded_giveaways == o.awarded_giveaways && achievements == o.achievements && advanced_event == o.advanced_event && referral == o.referral end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 287 def hash [customer_profile, loyalty, triggered_campaigns, campaign_eligibility, effects, rule_failure_reasons, created_coupons, created_referrals, awarded_giveaways, achievements, advanced_event, referral].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @effects.nil? invalid_properties.push('invalid value for "effects", effects cannot be nil.') end if @created_coupons.nil? invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.') end if @created_referrals.nil? invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
222 223 224 225 226 227 228 |
# File 'lib/talon_one_sdk/models/integration_event_v3_response.rb', line 222 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @effects.nil? return false if @created_coupons.nil? return false if @created_referrals.nil? true end |