Class: TalonOne::IntegrationHubEventPayloadCouponBasedNotifications
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationHubEventPayloadCouponBasedNotifications
- Defined in:
- lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#batch_id ⇒ Object
Returns the value of attribute batch_id.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#created ⇒ Object
Returns the value of attribute created.
-
#discount_counter ⇒ Object
Returns the value of attribute discount_counter.
-
#discount_limit ⇒ Object
Returns the value of attribute discount_limit.
-
#discount_remainder ⇒ Object
Returns the value of attribute discount_remainder.
-
#employee_name ⇒ Object
Returns the value of attribute employee_name.
-
#event_id ⇒ Object
The ID of the integration hub event.
-
#expiry_date ⇒ Object
Returns the value of attribute expiry_date.
-
#id ⇒ Object
Returns the value of attribute id.
-
#import_id ⇒ Object
Returns the value of attribute import_id.
-
#limits ⇒ Object
Returns the value of attribute limits.
-
#published_at ⇒ Object
Timestamp when the event was published.
-
#recipient_integration_id ⇒ Object
Returns the value of attribute recipient_integration_id.
-
#referral_id ⇒ Object
Returns the value of attribute referral_id.
-
#reservation_limit ⇒ Object
Returns the value of attribute reservation_limit.
-
#source_of_event ⇒ Object
Returns the value of attribute source_of_event.
-
#start_date ⇒ Object
Returns the value of attribute start_date.
-
#usage_counter ⇒ Object
Returns the value of attribute usage_counter.
-
#usage_limit ⇒ Object
Returns the value of attribute usage_limit.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadCouponBasedNotifications
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadCouponBasedNotifications
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 138 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventPayloadCouponBasedNotifications` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventPayloadCouponBasedNotifications`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] else self.usage_limit = nil end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'usage_counter') self.usage_counter = attributes[:'usage_counter'] else self.usage_counter = nil end if attributes.key?(:'discount_counter') self.discount_counter = attributes[:'discount_counter'] end if attributes.key?(:'discount_remainder') self.discount_remainder = attributes[:'discount_remainder'] end if attributes.key?(:'referral_id') self.referral_id = attributes[:'referral_id'] end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] end if attributes.key?(:'import_id') self.import_id = attributes[:'import_id'] end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] else self.published_at = nil end if attributes.key?(:'source_of_event') self.source_of_event = attributes[:'source_of_event'] else self.source_of_event = nil end if attributes.key?(:'employee_name') self.employee_name = attributes[:'employee_name'] else self.employee_name = nil end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
53 54 55 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 53 def attributes @attributes end |
#batch_id ⇒ Object
Returns the value of attribute batch_id.
51 52 53 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 51 def batch_id @batch_id end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 25 def campaign_id @campaign_id end |
#created ⇒ Object
Returns the value of attribute created.
23 24 25 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 23 def created @created end |
#discount_counter ⇒ Object
Returns the value of attribute discount_counter.
41 42 43 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 41 def discount_counter @discount_counter end |
#discount_limit ⇒ Object
Returns the value of attribute discount_limit.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 31 def discount_limit @discount_limit end |
#discount_remainder ⇒ Object
Returns the value of attribute discount_remainder.
43 44 45 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 43 def discount_remainder @discount_remainder end |
#employee_name ⇒ Object
Returns the value of attribute employee_name.
62 63 64 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 62 def employee_name @employee_name end |
#event_id ⇒ Object
The ID of the integration hub event. Return this value in the delivery-status callback to mark the event delivered or failed.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 19 def event_id @event_id end |
#expiry_date ⇒ Object
Returns the value of attribute expiry_date.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 37 def expiry_date @expiry_date end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 21 def id @id end |
#import_id ⇒ Object
Returns the value of attribute import_id.
49 50 51 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 49 def import_id @import_id end |
#limits ⇒ Object
Returns the value of attribute limits.
55 56 57 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 55 def limits @limits end |
#published_at ⇒ Object
Timestamp when the event was published.
58 59 60 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 58 def published_at @published_at end |
#recipient_integration_id ⇒ Object
Returns the value of attribute recipient_integration_id.
47 48 49 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 47 def recipient_integration_id @recipient_integration_id end |
#referral_id ⇒ Object
Returns the value of attribute referral_id.
45 46 47 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 45 def referral_id @referral_id end |
#reservation_limit ⇒ Object
Returns the value of attribute reservation_limit.
33 34 35 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 33 def reservation_limit @reservation_limit end |
#source_of_event ⇒ Object
Returns the value of attribute source_of_event.
60 61 62 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 60 def source_of_event @source_of_event end |
#start_date ⇒ Object
Returns the value of attribute start_date.
35 36 37 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 35 def start_date @start_date end |
#usage_counter ⇒ Object
Returns the value of attribute usage_counter.
39 40 41 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 39 def usage_counter @usage_counter end |
#usage_limit ⇒ Object
Returns the value of attribute usage_limit.
29 30 31 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 29 def usage_limit @usage_limit end |
#value ⇒ Object
Returns the value of attribute value.
27 28 29 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 27 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 65 def self.attribute_map { :'event_id' => :'EventId', :'id' => :'Id', :'created' => :'Created', :'campaign_id' => :'CampaignId', :'value' => :'Value', :'usage_limit' => :'UsageLimit', :'discount_limit' => :'DiscountLimit', :'reservation_limit' => :'ReservationLimit', :'start_date' => :'StartDate', :'expiry_date' => :'ExpiryDate', :'usage_counter' => :'UsageCounter', :'discount_counter' => :'DiscountCounter', :'discount_remainder' => :'DiscountRemainder', :'referral_id' => :'ReferralId', :'recipient_integration_id' => :'RecipientIntegrationId', :'import_id' => :'ImportId', :'batch_id' => :'BatchId', :'attributes' => :'Attributes', :'limits' => :'Limits', :'published_at' => :'PublishedAt', :'source_of_event' => :'SourceOfEvent', :'employee_name' => :'EmployeeName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 472 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
131 132 133 134 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 131 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 103 def self.openapi_types { :'event_id' => :'Integer', :'id' => :'Integer', :'created' => :'Time', :'campaign_id' => :'Integer', :'value' => :'String', :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'usage_counter' => :'Integer', :'discount_counter' => :'Float', :'discount_remainder' => :'Float', :'referral_id' => :'Integer', :'recipient_integration_id' => :'String', :'import_id' => :'Integer', :'batch_id' => :'String', :'attributes' => :'Object', :'limits' => :'Array<IntegrationHubEventPayloadCouponBasedNotificationsLimits>', :'published_at' => :'Time', :'source_of_event' => :'String', :'employee_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 430 def ==(o) return true if self.equal?(o) self.class == o.class && event_id == o.event_id && id == o.id && created == o.created && campaign_id == o.campaign_id && value == o.value && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && usage_counter == o.usage_counter && discount_counter == o.discount_counter && discount_remainder == o.discount_remainder && referral_id == o.referral_id && recipient_integration_id == o.recipient_integration_id && import_id == o.import_id && batch_id == o.batch_id && attributes == o.attributes && limits == o.limits && published_at == o.published_at && source_of_event == o.source_of_event && employee_name == o.employee_name end |
#eql?(o) ⇒ Boolean
459 460 461 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 459 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
465 466 467 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 465 def hash [event_id, id, created, campaign_id, value, usage_limit, discount_limit, reservation_limit, start_date, expiry_date, usage_counter, discount_counter, discount_remainder, referral_id, recipient_integration_id, import_id, batch_id, attributes, limits, published_at, source_of_event, employee_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 265 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @usage_limit.nil? invalid_properties.push('invalid value for "usage_limit", usage_limit cannot be nil.') end if @usage_counter.nil? invalid_properties.push('invalid value for "usage_counter", usage_counter cannot be nil.') end if @published_at.nil? invalid_properties.push('invalid value for "published_at", published_at cannot be nil.') end if @source_of_event.nil? invalid_properties.push('invalid value for "source_of_event", source_of_event cannot be nil.') end if @employee_name.nil? invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 494 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_coupon_based_notifications.rb', line 313 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @event_id.nil? return false if @id.nil? return false if @created.nil? return false if @campaign_id.nil? return false if @value.nil? return false if @usage_limit.nil? return false if @usage_counter.nil? return false if @published_at.nil? return false if @source_of_event.nil? return false if @employee_name.nil? true end |