Class: TalonOne::IntegrationHubFlowConfigResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationHubFlowConfigResponse
- Defined in:
- lib/talon_one_sdk/models/integration_hub_flow_config_response.rb
Instance Attribute Summary collapse
-
#max_events_per_message ⇒ Object
Maximum number of events to send in a single message to IntegrationHub.
-
#max_retries ⇒ Object
Maximum number of retries for a IntegrationHub event before it is ignored.
-
#worker_count ⇒ Object
Number of IntegrationHub workers to run in parallel for this flow (maximum 500).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationHubFlowConfigResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationHubFlowConfigResponse
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubFlowConfigResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubFlowConfigResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'worker_count') self.worker_count = attributes[:'worker_count'] end if attributes.key?(:'max_events_per_message') self. = attributes[:'max_events_per_message'] end if attributes.key?(:'max_retries') self.max_retries = attributes[:'max_retries'] end end |
Instance Attribute Details
#max_events_per_message ⇒ Object
Maximum number of events to send in a single message to IntegrationHub.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 22 def @max_events_per_message end |
#max_retries ⇒ Object
Maximum number of retries for a IntegrationHub event before it is ignored.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 25 def max_retries @max_retries end |
#worker_count ⇒ Object
Number of IntegrationHub workers to run in parallel for this flow (maximum 500).
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 19 def worker_count @worker_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 28 def self.attribute_map { :'worker_count' => :'WorkerCount', :'max_events_per_message' => :'MaxEventsPerMessage', :'max_retries' => :'MaxRetries' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 196 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 47 def self.openapi_types { :'worker_count' => :'Integer', :'max_events_per_message' => :'Integer', :'max_retries' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && worker_count == o.worker_count && == o. && max_retries == o.max_retries end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 189 def hash [worker_count, , max_retries].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@worker_count.nil? && @worker_count > 500 invalid_properties.push('invalid value for "worker_count", must be smaller than or equal to 500.') end if !@worker_count.nil? && @worker_count < 1 invalid_properties.push('invalid value for "worker_count", must be greater than or equal to 1.') end if !@max_events_per_message.nil? && @max_events_per_message < 1 invalid_properties.push('invalid value for "max_events_per_message", must be greater than or equal to 1.') end if !@max_retries.nil? && @max_retries < 0 invalid_properties.push('invalid value for "max_retries", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config_response.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@worker_count.nil? && @worker_count > 500 return false if !@worker_count.nil? && @worker_count < 1 return false if !@max_events_per_message.nil? && @max_events_per_message < 1 return false if !@max_retries.nil? && @max_retries < 0 true end |