Class: TalonOne::IntegrationHubFlowResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationHubFlowResponse
- Defined in:
- lib/talon_one_sdk/models/integration_hub_flow_response.rb
Instance Attribute Summary collapse
-
#application_id ⇒ Object
ID of the application the flow is registered for.
-
#config ⇒ Object
Returns the value of attribute config.
-
#created_at ⇒ Object
Timestamp when the flow was created.
-
#disabled_until ⇒ Object
Timestamp until which the flow is disabled.
-
#event_type ⇒ Object
The event type we want to register a flow for.
-
#id ⇒ Object
ID of the integration hub flow.
-
#instance_name ⇒ Object
Name of the integration instance.
-
#integration_name ⇒ Object
Name of the integration.
-
#loyalty_program_id ⇒ Object
ID of the loyalty program the flow is registered for.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationHubFlowResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationHubFlowResponse
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubFlowResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubFlowResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'integration_name') self.integration_name = attributes[:'integration_name'] end if attributes.key?(:'instance_name') self.instance_name = attributes[:'instance_name'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'disabled_until') self.disabled_until = attributes[:'disabled_until'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] else self.event_type = nil end if attributes.key?(:'config') self.config = attributes[:'config'] else self.config = nil end end |
Instance Attribute Details
#application_id ⇒ Object
ID of the application the flow is registered for.
34 35 36 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 34 def application_id @application_id end |
#config ⇒ Object
Returns the value of attribute config.
42 43 44 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 42 def config @config end |
#created_at ⇒ Object
Timestamp when the flow was created.
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 28 def created_at @created_at end |
#disabled_until ⇒ Object
Timestamp until which the flow is disabled. Null when the flow is active.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 31 def disabled_until @disabled_until end |
#event_type ⇒ Object
The event type we want to register a flow for.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 40 def event_type @event_type end |
#id ⇒ Object
ID of the integration hub flow.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 19 def id @id end |
#instance_name ⇒ Object
Name of the integration instance.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 25 def instance_name @instance_name end |
#integration_name ⇒ Object
Name of the integration.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 22 def integration_name @integration_name end |
#loyalty_program_id ⇒ Object
ID of the loyalty program the flow is registered for.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 37 def loyalty_program_id @loyalty_program_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 45 def self.attribute_map { :'id' => :'id', :'integration_name' => :'integrationName', :'instance_name' => :'instanceName', :'created_at' => :'createdAt', :'disabled_until' => :'disabledUntil', :'application_id' => :'applicationId', :'loyalty_program_id' => :'loyaltyProgramId', :'event_type' => :'eventType', :'config' => :'config' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 258 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 85 def self.openapi_nullable Set.new([ :'disabled_until', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 70 def self.openapi_types { :'id' => :'Integer', :'integration_name' => :'String', :'instance_name' => :'String', :'created_at' => :'Time', :'disabled_until' => :'Time', :'application_id' => :'Integer', :'loyalty_program_id' => :'Integer', :'event_type' => :'String', :'config' => :'IntegrationHubFlowConfigResponse' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && integration_name == o.integration_name && instance_name == o.instance_name && created_at == o.created_at && disabled_until == o.disabled_until && application_id == o.application_id && loyalty_program_id == o.loyalty_program_id && event_type == o.event_type && config == o.config end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 251 def hash [id, integration_name, instance_name, created_at, disabled_until, application_id, loyalty_program_id, event_type, config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created_at.nil? return false if @event_type.nil? return false if @config.nil? true end |