Class: TalonOne::IntegrationState

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_state.rb

Overview

Contains all state that might interest application integration plugins. This is the response type returned by all of the Integration API operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationState

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/integration_state.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationState` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationState`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'session')
    self.session = attributes[:'session']
  else
    self.session = nil
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  else
    self.profile = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.key?(:'coupon')
    self.coupon = attributes[:'coupon']
  end
end

Instance Attribute Details

#couponObject

Returns the value of attribute coupon.



27
28
29
# File 'lib/talon_one_sdk/models/integration_state.rb', line 27

def coupon
  @coupon
end

#eventObject

Returns the value of attribute event.



23
24
25
# File 'lib/talon_one_sdk/models/integration_state.rb', line 23

def event
  @event
end

#loyaltyObject

Returns the value of attribute loyalty.



25
26
27
# File 'lib/talon_one_sdk/models/integration_state.rb', line 25

def loyalty
  @loyalty
end

#profileObject

Returns the value of attribute profile.



21
22
23
# File 'lib/talon_one_sdk/models/integration_state.rb', line 21

def profile
  @profile
end

#sessionObject

Returns the value of attribute session.



19
20
21
# File 'lib/talon_one_sdk/models/integration_state.rb', line 19

def session
  @session
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/integration_state.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/integration_state.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/integration_state.rb', line 30

def self.attribute_map
  {
    :'session' => :'session',
    :'profile' => :'profile',
    :'event' => :'event',
    :'loyalty' => :'loyalty',
    :'coupon' => :'coupon'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one_sdk/models/integration_state.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/talon_one_sdk/models/integration_state.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/talon_one_sdk/models/integration_state.rb', line 51

def self.openapi_types
  {
    :'session' => :'CustomerSession',
    :'profile' => :'CustomerProfile',
    :'event' => :'Event',
    :'loyalty' => :'Loyalty',
    :'coupon' => :'Coupon'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/integration_state.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      session == o.session &&
      profile == o.profile &&
      event == o.event &&
      loyalty == o.loyalty &&
      coupon == o.coupon
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/talon_one_sdk/models/integration_state.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/talon_one_sdk/models/integration_state.rb', line 190

def hash
  [session, profile, event, loyalty, coupon].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/talon_one_sdk/models/integration_state.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @session.nil?
    invalid_properties.push('invalid value for "session", session cannot be nil.')
  end

  if @profile.nil?
    invalid_properties.push('invalid value for "profile", profile cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/talon_one_sdk/models/integration_state.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
138
# File 'lib/talon_one_sdk/models/integration_state.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @session.nil?
  return false if @profile.nil?
  return false if @event.nil?
  true
end