Class: TalonOne::InventoryReferral

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/inventory_referral.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InventoryReferral

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::InventoryReferral` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::InventoryReferral`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'advocate_profile_integration_id')
    self.advocate_profile_integration_id = attributes[:'advocate_profile_integration_id']
  else
    self.advocate_profile_integration_id = nil
  end

  if attributes.key?(:'friend_profile_integration_id')
    self.friend_profile_integration_id = attributes[:'friend_profile_integration_id']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'usage_counter')
    self.usage_counter = attributes[:'usage_counter']
  else
    self.usage_counter = nil
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'referred_customers')
    if (value = attributes[:'referred_customers']).is_a?(Array)
      self.referred_customers = value
    end
  else
    self.referred_customers = nil
  end
end

Instance Attribute Details

#advocate_profile_integration_idObject

The Integration ID of the Advocate’s Profile.



37
38
39
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 37

def advocate_profile_integration_id
  @advocate_profile_integration_id
end

#attributesObject

Arbitrary properties associated with this item.



43
44
45
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 43

def attributes
  @attributes
end

#batch_idObject

The ID of the batch the referrals belong to.



55
56
57
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 55

def batch_id
  @batch_id
end

#campaign_idObject

ID of the campaign from which the referral received the referral code.



34
35
36
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 34

def campaign_id
  @campaign_id
end

#codeObject

The referral code.



49
50
51
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 49

def code
  @code
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 22

def created
  @created
end

#expiry_dateObject

Expiration date of the referral code. Referral never expires if this is omitted.



28
29
30
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 28

def expiry_date
  @expiry_date
end

#friend_profile_integration_idObject

An optional Integration ID of the Friend’s Profile.



40
41
42
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 40

def friend_profile_integration_id
  @friend_profile_integration_id
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 19

def id
  @id
end

#import_idObject

The ID of the Import which created this referral.



46
47
48
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 46

def import_id
  @import_id
end

#referred_customersObject

An array of referred customers.



58
59
60
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 58

def referred_customers
  @referred_customers
end

#start_dateObject

Timestamp at which point the referral code becomes valid.



25
26
27
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 25

def start_date
  @start_date
end

#usage_counterObject

The number of times this referral code has been successfully used.



52
53
54
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 52

def usage_counter
  @usage_counter
end

#usage_limitObject

The number of times a referral code can be used. ‘0` means no limit but any campaign usage limits will still apply.



31
32
33
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 31

def usage_limit
  @usage_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'usage_limit' => :'usageLimit',
    :'campaign_id' => :'campaignId',
    :'advocate_profile_integration_id' => :'advocateProfileIntegrationId',
    :'friend_profile_integration_id' => :'friendProfileIntegrationId',
    :'attributes' => :'attributes',
    :'import_id' => :'importId',
    :'code' => :'code',
    :'usage_counter' => :'usageCounter',
    :'batch_id' => :'batchId',
    :'referred_customers' => :'referredCustomers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 414

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



117
118
119
120
121
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 117

def self.openapi_all_of
  [
  :'Referral'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 91

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'usage_limit' => :'Integer',
    :'campaign_id' => :'Integer',
    :'advocate_profile_integration_id' => :'String',
    :'friend_profile_integration_id' => :'String',
    :'attributes' => :'Object',
    :'import_id' => :'Integer',
    :'code' => :'String',
    :'usage_counter' => :'Integer',
    :'batch_id' => :'String',
    :'referred_customers' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 380

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      usage_limit == o.usage_limit &&
      campaign_id == o.campaign_id &&
      advocate_profile_integration_id == o.advocate_profile_integration_id &&
      friend_profile_integration_id == o.friend_profile_integration_id &&
      attributes == o.attributes &&
      import_id == o.import_id &&
      code == o.code &&
      usage_counter == o.usage_counter &&
      batch_id == o.batch_id &&
      referred_customers == o.referred_customers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


401
402
403
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 401

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



407
408
409
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 407

def hash
  [id, created, start_date, expiry_date, usage_limit, campaign_id, advocate_profile_integration_id, friend_profile_integration_id, attributes, import_id, code, usage_counter, batch_id, referred_customers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 214

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if !@usage_limit.nil? && @usage_limit > 999999
    invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.')
  end

  if !@usage_limit.nil? && @usage_limit < 0
    invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @advocate_profile_integration_id.nil?
    invalid_properties.push('invalid value for "advocate_profile_integration_id", advocate_profile_integration_id cannot be nil.')
  end

  if @advocate_profile_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "advocate_profile_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @code.to_s.length < 4
    invalid_properties.push('invalid value for "code", the character length must be greater than or equal to 4.')
  end

  if @usage_counter.nil?
    invalid_properties.push('invalid value for "usage_counter", usage_counter cannot be nil.')
  end

  if @referred_customers.nil?
    invalid_properties.push('invalid value for "referred_customers", referred_customers cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/talon_one_sdk/models/inventory_referral.rb', line 266

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if !@usage_limit.nil? && @usage_limit > 999999
  return false if !@usage_limit.nil? && @usage_limit < 0
  return false if @campaign_id.nil?
  return false if @advocate_profile_integration_id.nil?
  return false if @advocate_profile_integration_id.to_s.length > 1000
  return false if @code.nil?
  return false if @code.to_s.length < 4
  return false if @usage_counter.nil?
  return false if @referred_customers.nil?
  true
end