Class: TalonOne::LedgerInfo

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/ledger_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LedgerInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LedgerInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LedgerInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_balance')
    self.current_balance = attributes[:'current_balance']
  else
    self.current_balance = nil
  end

  if attributes.key?(:'pending_balance')
    self.pending_balance = attributes[:'pending_balance']
  else
    self.pending_balance = nil
  end

  if attributes.key?(:'negative_balance')
    self.negative_balance = attributes[:'negative_balance']
  end

  if attributes.key?(:'expired_balance')
    self.expired_balance = attributes[:'expired_balance']
  else
    self.expired_balance = nil
  end

  if attributes.key?(:'spent_balance')
    self.spent_balance = attributes[:'spent_balance']
  else
    self.spent_balance = nil
  end

  if attributes.key?(:'tentative_current_balance')
    self.tentative_current_balance = attributes[:'tentative_current_balance']
  else
    self.tentative_current_balance = nil
  end

  if attributes.key?(:'tentative_pending_balance')
    self.tentative_pending_balance = attributes[:'tentative_pending_balance']
  end

  if attributes.key?(:'tentative_negative_balance')
    self.tentative_negative_balance = attributes[:'tentative_negative_balance']
  end

  if attributes.key?(:'current_tier')
    self.current_tier = attributes[:'current_tier']
  end

  if attributes.key?(:'points_to_next_tier')
    self.points_to_next_tier = attributes[:'points_to_next_tier']
  end

  if attributes.key?(:'next_tier_name')
    self.next_tier_name = attributes[:'next_tier_name']
  end
end

Instance Attribute Details

#current_balanceObject

Sum of currently active points.



19
20
21
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 19

def current_balance
  @current_balance
end

#current_tierObject

Tier for which the ledger is eligible.



43
44
45
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 43

def current_tier
  @current_tier
end

#expired_balanceObject

DEPRECATED Value is shown as 0.



28
29
30
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 28

def expired_balance
  @expired_balance
end

#negative_balanceObject

Sum of negative points. This implies that ‘currentBalance` is `0`.



25
26
27
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 25

def negative_balance
  @negative_balance
end

#next_tier_nameObject

The name of the next higher tier level in the loyalty program. Note: - Returns ‘null` if the customer has reached the highest available tier. - Returns the lowest level tier name if the customer is not currently assigned to any tier.



49
50
51
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 49

def next_tier_name
  @next_tier_name
end

#pending_balanceObject

Sum of pending points.



22
23
24
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 22

def pending_balance
  @pending_balance
end

#points_to_next_tierObject

Points required to move up a tier.



46
47
48
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 46

def points_to_next_tier
  @points_to_next_tier
end

#spent_balanceObject

DEPRECATED Value is shown as 0.



31
32
33
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 31

def spent_balance
  @spent_balance
end

#tentative_current_balanceObject

The tentative points balance, reflecting the ‘currentBalance` and all point additions and deductions within the current open customer session. When the session is closed, the effects are applied and the `currentBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.



34
35
36
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 34

def tentative_current_balance
  @tentative_current_balance
end

#tentative_negative_balanceObject

The tentative negative balance after all additions and deductions from the current customer session are applied to ‘negativeBalance`. When the session is closed, the tentative effects are applied and `negativeBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.



40
41
42
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 40

def tentative_negative_balance
  @tentative_negative_balance
end

#tentative_pending_balanceObject

The tentative points balance, reflecting the ‘pendingBalance` and all point additions with a future activation date within the current open customer session. When the session is closed, the effects are applied and the `pendingBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.



37
38
39
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 37

def tentative_pending_balance
  @tentative_pending_balance
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 52

def self.attribute_map
  {
    :'current_balance' => :'currentBalance',
    :'pending_balance' => :'pendingBalance',
    :'negative_balance' => :'negativeBalance',
    :'expired_balance' => :'expiredBalance',
    :'spent_balance' => :'spentBalance',
    :'tentative_current_balance' => :'tentativeCurrentBalance',
    :'tentative_pending_balance' => :'tentativePendingBalance',
    :'tentative_negative_balance' => :'tentativeNegativeBalance',
    :'current_tier' => :'currentTier',
    :'points_to_next_tier' => :'pointsToNextTier',
    :'next_tier_name' => :'nextTierName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 302

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 102

def self.openapi_all_of
  [
  :'LoyaltyProgramBalance'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 79

def self.openapi_types
  {
    :'current_balance' => :'Float',
    :'pending_balance' => :'Float',
    :'negative_balance' => :'Float',
    :'expired_balance' => :'Float',
    :'spent_balance' => :'Float',
    :'tentative_current_balance' => :'Float',
    :'tentative_pending_balance' => :'Float',
    :'tentative_negative_balance' => :'Float',
    :'current_tier' => :'Tier',
    :'points_to_next_tier' => :'Float',
    :'next_tier_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 271

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_balance == o.current_balance &&
      pending_balance == o.pending_balance &&
      negative_balance == o.negative_balance &&
      expired_balance == o.expired_balance &&
      spent_balance == o.spent_balance &&
      tentative_current_balance == o.tentative_current_balance &&
      tentative_pending_balance == o.tentative_pending_balance &&
      tentative_negative_balance == o.tentative_negative_balance &&
      current_tier == o.current_tier &&
      points_to_next_tier == o.points_to_next_tier &&
      next_tier_name == o.next_tier_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


289
290
291
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 289

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



295
296
297
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 295

def hash
  [current_balance, pending_balance, negative_balance, expired_balance, spent_balance, tentative_current_balance, tentative_pending_balance, tentative_negative_balance, current_tier, points_to_next_tier, next_tier_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_balance.nil?
    invalid_properties.push('invalid value for "current_balance", current_balance cannot be nil.')
  end

  if @pending_balance.nil?
    invalid_properties.push('invalid value for "pending_balance", pending_balance cannot be nil.')
  end

  if @expired_balance.nil?
    invalid_properties.push('invalid value for "expired_balance", expired_balance cannot be nil.')
  end

  if @spent_balance.nil?
    invalid_properties.push('invalid value for "spent_balance", spent_balance cannot be nil.')
  end

  if @tentative_current_balance.nil?
    invalid_properties.push('invalid value for "tentative_current_balance", tentative_current_balance cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
# File 'lib/talon_one_sdk/models/ledger_info.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_balance.nil?
  return false if @pending_balance.nil?
  return false if @expired_balance.nil?
  return false if @spent_balance.nil?
  return false if @tentative_current_balance.nil?
  true
end