Class: TalonOne::LedgerPointsEntryIntegrationAPI

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb

Overview

Loyalty profile points with start and expiry dates.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LedgerPointsEntryIntegrationAPI

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LedgerPointsEntryIntegrationAPI` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LedgerPointsEntryIntegrationAPI`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'customer_session_id')
    self.customer_session_id = attributes[:'customer_session_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  else
    self.start_date = nil
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'validity_duration')
    self.validity_duration = attributes[:'validity_duration']
  end
end

Instance Attribute Details

#amountObject

Amount of loyalty points added in the transaction.



47
48
49
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 47

def amount
  @amount
end

#createdObject

Date and time the loyalty points were added.



26
27
28
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 26

def created
  @created
end

#customer_session_idObject

ID of the customer session where points were added.



32
33
34
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 32

def customer_session_id
  @customer_session_id
end

#expiry_dateObject

Date when points expire. Possible values are: - ‘unlimited`: Points have no expiration date. - `timestamp value`: Points expire on the given date and time.



41
42
43
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 41

def expiry_date
  @expiry_date
end

#idObject

ID of the transaction that adds loyalty points.



20
21
22
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 20

def id
  @id
end

#nameObject

Name or reason of the transaction that adds loyalty points.



35
36
37
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 35

def name
  @name
end

#program_idObject

ID of the loyalty program.



29
30
31
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 29

def program_id
  @program_id
end

#start_dateObject

When points become active. Possible values: - ‘immediate`: Points are active immediately. - `timestamp value`: Points become active at a given date and time.



38
39
40
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 38

def start_date
  @start_date
end

#subledger_idObject

ID of the subledger.



44
45
46
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 44

def subledger_id
  @subledger_id
end

#transaction_uuidObject

Unique identifier of the transaction in the UUID format.



23
24
25
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 23

def transaction_uuid
  @transaction_uuid
end

#validity_durationObject

The duration for which the points remain active, relative to the activation date. Note: This only applies to points for which ‘awaitsActivation` is `true` and `expiryDate` is not set.



50
51
52
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 50

def validity_duration
  @validity_duration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'transaction_uuid' => :'transactionUUID',
    :'created' => :'created',
    :'program_id' => :'programId',
    :'customer_session_id' => :'customerSessionId',
    :'name' => :'name',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'subledger_id' => :'subledgerId',
    :'amount' => :'amount',
    :'validity_duration' => :'validityDuration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 410

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 80

def self.openapi_types
  {
    :'id' => :'Integer',
    :'transaction_uuid' => :'String',
    :'created' => :'Time',
    :'program_id' => :'Integer',
    :'customer_session_id' => :'String',
    :'name' => :'String',
    :'start_date' => :'String',
    :'expiry_date' => :'String',
    :'subledger_id' => :'String',
    :'amount' => :'Float',
    :'validity_duration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 379

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      transaction_uuid == o.transaction_uuid &&
      created == o.created &&
      program_id == o.program_id &&
      customer_session_id == o.customer_session_id &&
      name == o.name &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      subledger_id == o.subledger_id &&
      amount == o.amount &&
      validity_duration == o.validity_duration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


397
398
399
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 397

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



403
404
405
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 403

def hash
  [id, transaction_uuid, created, program_id, customer_session_id, name, start_date, expiry_date, subledger_id, amount, validity_duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
    invalid_properties.push('invalid value for "customer_session_id", the character length must be smaller than or equal to 255.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @start_date.to_s.length > 64
    invalid_properties.push('invalid value for "start_date", the character length must be smaller than or equal to 64.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @subledger_id.to_s.length > 64
    invalid_properties.push('invalid value for "subledger_id", the character length must be smaller than or equal to 64.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 432

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/talon_one_sdk/models/ledger_points_entry_integration_api.rb', line 243

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @transaction_uuid.nil?
  return false if @created.nil?
  return false if @program_id.nil?
  return false if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @start_date.nil?
  return false if @start_date.to_s.length > 64
  return false if @expiry_date.nil?
  return false if @subledger_id.nil?
  return false if @subledger_id.to_s.length > 64
  return false if @amount.nil?
  true
end