Class: TalonOne::LibraryAttribute

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/library_attribute.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LibraryAttribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LibraryAttribute` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LibraryAttribute`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  else
    self.entity = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'presets')
    if (value = attributes[:'presets']).is_a?(Array)
      self.presets = value
    end
  else
    self.presets = nil
  end

  if attributes.key?(:'suggestions')
    if (value = attributes[:'suggestions']).is_a?(Array)
      self.suggestions = value
    end
  else
    self.suggestions = nil
  end
end

Instance Attribute Details

#descriptionObject

A description of the attribute.



31
32
33
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 31

def description
  @description
end

#entityObject

The name of the entity that can have this attribute. When creating or updating the entities of a given type, you can include an ‘attributes` object with keys corresponding to the `name` of the custom attributes for that type.



19
20
21
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 19

def entity
  @entity
end

#nameObject

The attribute name that will be used in API requests and Talang. E.g. if ‘name == "region"` then you would set the region attribute by including an `attributes.region` property in your request payload.



22
23
24
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 22

def name
  @name
end

#presetsObject

The presets that indicate to which industry the attribute applies to.



34
35
36
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 34

def presets
  @presets
end

#suggestionsObject

Short suggestions that are used to group attributes.



37
38
39
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 37

def suggestions
  @suggestions
end

#titleObject

The human-readable name for the attribute that will be shown in the Campaign Manager. Like ‘name`, the combination of entity and title must also be unique.



25
26
27
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 25

def title
  @title
end

#typeObject

The data type of the attribute, a ‘time` attribute must be sent as a string that conforms to the [RFC3339](www.ietf.org/rfc/rfc3339.txt) timestamp format.



28
29
30
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 28

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 62

def self.attribute_map
  {
    :'entity' => :'entity',
    :'name' => :'name',
    :'title' => :'title',
    :'type' => :'type',
    :'description' => :'description',
    :'presets' => :'presets',
    :'suggestions' => :'suggestions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 319

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 85

def self.openapi_types
  {
    :'entity' => :'String',
    :'name' => :'String',
    :'title' => :'String',
    :'type' => :'String',
    :'description' => :'String',
    :'presets' => :'Array<String>',
    :'suggestions' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      entity == o.entity &&
      name == o.name &&
      title == o.title &&
      type == o.type &&
      description == o.description &&
      presets == o.presets &&
      suggestions == o.suggestions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 306

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



312
313
314
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 312

def hash
  [entity, name, title, type, description, presets, suggestions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @entity.nil?
    invalid_properties.push('invalid value for "entity", entity cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @presets.nil?
    invalid_properties.push('invalid value for "presets", presets cannot be nil.')
  end

  if @suggestions.nil?
    invalid_properties.push('invalid value for "suggestions", suggestions cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 341

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/talon_one_sdk/models/library_attribute.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @entity.nil?
  entity_validator = EnumAttributeValidator.new('String', ["Application", "Campaign", "CustomerProfile", "CustomerSession", "CartItem", "Coupon", "Event"])
  return false unless entity_validator.valid?(@entity)
  return false if @name.nil?
  return false if @title.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["string", "number", "boolean", "time"])
  return false unless type_validator.valid?(@type)
  return false if @description.nil?
  return false if @presets.nil?
  return false if @suggestions.nil?
  true
end