Class: TalonOne::LoyaltyBalancesWithTiers
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LoyaltyBalancesWithTiers
- Defined in:
- lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb
Overview
List of loyalty balances for a ledger and its subledgers.
Instance Attribute Summary collapse
-
#balance ⇒ Object
Returns the value of attribute balance.
-
#subledger_balances ⇒ Object
Map of the loyalty balances of the subledgers of a ledger.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoyaltyBalancesWithTiers
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LoyaltyBalancesWithTiers
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyBalancesWithTiers` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyBalancesWithTiers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'balance') self.balance = attributes[:'balance'] end if attributes.key?(:'subledger_balances') if (value = attributes[:'subledger_balances']).is_a?(Hash) self.subledger_balances = value end end end |
Instance Attribute Details
#balance ⇒ Object
Returns the value of attribute balance.
19 20 21 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 19 def balance @balance end |
#subledger_balances ⇒ Object
Map of the loyalty balances of the subledgers of a ledger.
22 23 24 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 22 def subledger_balances @subledger_balances end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 25 def self.attribute_map { :'balance' => :'balance', :'subledger_balances' => :'subledgerBalances' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 122 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 43 def self.openapi_types { :'balance' => :'LoyaltyBalanceWithTier', :'subledger_balances' => :'Hash<String, LoyaltyBalanceWithTier>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 100 def ==(o) return true if self.equal?(o) self.class == o.class && balance == o.balance && subledger_balances == o.subledger_balances end |
#eql?(o) ⇒ Boolean
109 110 111 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 109 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 115 def hash [balance, subledger_balances].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 144 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
93 94 95 96 |
# File 'lib/talon_one_sdk/models/loyalty_balances_with_tiers.rb', line 93 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |