Class: TalonOne::LoyaltyCardBatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LoyaltyCardBatch
- Defined in:
- lib/talon_one_sdk/models/loyalty_card_batch.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#batch_id ⇒ Object
ID of the loyalty card batch.
-
#card_code_settings ⇒ Object
Returns the value of attribute card_code_settings.
-
#number_of_cards ⇒ Object
Number of loyalty cards in the batch.
-
#status ⇒ Object
Status of the loyalty cards in the batch.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoyaltyCardBatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LoyaltyCardBatch
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyCardBatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyCardBatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number_of_cards') self.number_of_cards = attributes[:'number_of_cards'] else self.number_of_cards = nil end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'active' end if attributes.key?(:'card_code_settings') self.card_code_settings = attributes[:'card_code_settings'] end end |
Instance Attribute Details
#batch_id ⇒ Object
ID of the loyalty card batch.
22 23 24 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 22 def batch_id @batch_id end |
#card_code_settings ⇒ Object
Returns the value of attribute card_code_settings.
27 28 29 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 27 def card_code_settings @card_code_settings end |
#number_of_cards ⇒ Object
Number of loyalty cards in the batch.
19 20 21 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 19 def number_of_cards @number_of_cards end |
#status ⇒ Object
Status of the loyalty cards in the batch.
25 26 27 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 25 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 52 def self.attribute_map { :'number_of_cards' => :'numberOfCards', :'batch_id' => :'batchId', :'status' => :'status', :'card_code_settings' => :'cardCodeSettings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 72 def self.openapi_types { :'number_of_cards' => :'Integer', :'batch_id' => :'String', :'status' => :'String', :'card_code_settings' => :'CodeGeneratorSettings' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && number_of_cards == o.number_of_cards && batch_id == o.batch_id && status == o.status && card_code_settings == o.card_code_settings end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 224 def hash [number_of_cards, batch_id, status, card_code_settings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @number_of_cards.nil? invalid_properties.push('invalid value for "number_of_cards", number_of_cards cannot be nil.') end if !@batch_id.nil? && @batch_id.to_s.length > 20 invalid_properties.push('invalid value for "batch_id", the character length must be smaller than or equal to 20.') end if !@batch_id.nil? && @batch_id.to_s.length < 4 invalid_properties.push('invalid value for "batch_id", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9_-]*$/) if !@batch_id.nil? && @batch_id !~ pattern invalid_properties.push("invalid value for \"batch_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/talon_one_sdk/models/loyalty_card_batch.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @number_of_cards.nil? return false if !@batch_id.nil? && @batch_id.to_s.length > 20 return false if !@batch_id.nil? && @batch_id.to_s.length < 4 return false if !@batch_id.nil? && @batch_id !~ Regexp.new(/^[A-Za-z0-9_-]*$/) status_validator = EnumAttributeValidator.new('String', ["active", "inactive"]) return false unless status_validator.valid?(@status) true end |