Class: TalonOne::LoyaltyDashboardData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_dashboard_data.rb

Overview

Datapoint for the graphs and cards on a loyalty program dashboard.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltyDashboardData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyDashboardData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyDashboardData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'total_active_points')
    self.total_active_points = attributes[:'total_active_points']
  else
    self.total_active_points = nil
  end

  if attributes.key?(:'total_pending_points')
    self.total_pending_points = attributes[:'total_pending_points']
  else
    self.total_pending_points = nil
  end

  if attributes.key?(:'total_spent_points')
    self.total_spent_points = attributes[:'total_spent_points']
  else
    self.total_spent_points = nil
  end

  if attributes.key?(:'total_expired_points')
    self.total_expired_points = attributes[:'total_expired_points']
  else
    self.total_expired_points = nil
  end

  if attributes.key?(:'total_negative_points')
    self.total_negative_points = attributes[:'total_negative_points']
  else
    self.total_negative_points = nil
  end

  if attributes.key?(:'total_members')
    self.total_members = attributes[:'total_members']
  else
    self.total_members = nil
  end

  if attributes.key?(:'new_members')
    self.new_members = attributes[:'new_members']
  else
    self.new_members = nil
  end

  if attributes.key?(:'spent_points')
    self.spent_points = attributes[:'spent_points']
  else
    self.spent_points = nil
  end

  if attributes.key?(:'earned_points')
    self.earned_points = attributes[:'earned_points']
  else
    self.earned_points = nil
  end
end

Instance Attribute Details

#dateObject

Date at which data point was collected.



20
21
22
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 20

def date
  @date
end

#earned_pointsObject

Points that were earned on this day.



47
48
49
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 47

def earned_points
  @earned_points
end

#new_membersObject

Number of members who joined on this day.



41
42
43
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 41

def new_members
  @new_members
end

#spent_pointsObject

Points spent on this day.



44
45
46
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 44

def spent_points
  @spent_points
end

#total_active_pointsObject

Total of active points for this loyalty program.



23
24
25
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 23

def total_active_points
  @total_active_points
end

#total_expired_pointsObject

Total of expired points for this loyalty program.



32
33
34
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 32

def total_expired_points
  @total_expired_points
end

#total_membersObject

Number of loyalty program members.



38
39
40
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 38

def total_members
  @total_members
end

#total_negative_pointsObject

Total of negative points for this loyalty program.



35
36
37
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 35

def total_negative_points
  @total_negative_points
end

#total_pending_pointsObject

Total of pending points for this loyalty program.



26
27
28
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 26

def total_pending_points
  @total_pending_points
end

#total_spent_pointsObject

Total of spent points for this loyalty program.



29
30
31
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 29

def total_spent_points
  @total_spent_points
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 50

def self.attribute_map
  {
    :'date' => :'date',
    :'total_active_points' => :'totalActivePoints',
    :'total_pending_points' => :'totalPendingPoints',
    :'total_spent_points' => :'totalSpentPoints',
    :'total_expired_points' => :'totalExpiredPoints',
    :'total_negative_points' => :'totalNegativePoints',
    :'total_members' => :'totalMembers',
    :'new_members' => :'newMembers',
    :'spent_points' => :'spentPoints',
    :'earned_points' => :'earnedPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 371

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 76

def self.openapi_types
  {
    :'date' => :'Time',
    :'total_active_points' => :'Float',
    :'total_pending_points' => :'Float',
    :'total_spent_points' => :'Float',
    :'total_expired_points' => :'Float',
    :'total_negative_points' => :'Float',
    :'total_members' => :'Float',
    :'new_members' => :'Float',
    :'spent_points' => :'LoyaltyDashboardPointsBreakdown',
    :'earned_points' => :'LoyaltyDashboardPointsBreakdown'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 341

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      total_active_points == o.total_active_points &&
      total_pending_points == o.total_pending_points &&
      total_spent_points == o.total_spent_points &&
      total_expired_points == o.total_expired_points &&
      total_negative_points == o.total_negative_points &&
      total_members == o.total_members &&
      new_members == o.new_members &&
      spent_points == o.spent_points &&
      earned_points == o.earned_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 358

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



364
365
366
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 364

def hash
  [date, total_active_points, total_pending_points, total_spent_points, total_expired_points, total_negative_points, total_members, new_members, spent_points, earned_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @total_active_points.nil?
    invalid_properties.push('invalid value for "total_active_points", total_active_points cannot be nil.')
  end

  if @total_pending_points.nil?
    invalid_properties.push('invalid value for "total_pending_points", total_pending_points cannot be nil.')
  end

  if @total_spent_points.nil?
    invalid_properties.push('invalid value for "total_spent_points", total_spent_points cannot be nil.')
  end

  if @total_expired_points.nil?
    invalid_properties.push('invalid value for "total_expired_points", total_expired_points cannot be nil.')
  end

  if @total_negative_points.nil?
    invalid_properties.push('invalid value for "total_negative_points", total_negative_points cannot be nil.')
  end

  if @total_members.nil?
    invalid_properties.push('invalid value for "total_members", total_members cannot be nil.')
  end

  if @new_members.nil?
    invalid_properties.push('invalid value for "new_members", new_members cannot be nil.')
  end

  if @spent_points.nil?
    invalid_properties.push('invalid value for "spent_points", spent_points cannot be nil.')
  end

  if @earned_points.nil?
    invalid_properties.push('invalid value for "earned_points", earned_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/talon_one_sdk/models/loyalty_dashboard_data.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @date.nil?
  return false if @total_active_points.nil?
  return false if @total_pending_points.nil?
  return false if @total_spent_points.nil?
  return false if @total_expired_points.nil?
  return false if @total_negative_points.nil?
  return false if @total_members.nil?
  return false if @new_members.nil?
  return false if @spent_points.nil?
  return false if @earned_points.nil?
  true
end