Class: TalonOne::LoyaltyProgram

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_program.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltyProgram

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 207

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyProgram` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyProgram`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribed_applications')
    if (value = attributes[:'subscribed_applications']).is_a?(Array)
      self.subscribed_applications = value
    end
  end

  if attributes.key?(:'default_validity')
    self.default_validity = attributes[:'default_validity']
  end

  if attributes.key?(:'default_pending')
    self.default_pending = attributes[:'default_pending']
  end

  if attributes.key?(:'allow_subledger')
    self.allow_subledger = attributes[:'allow_subledger']
  end

  if attributes.key?(:'users_per_card_limit')
    self.users_per_card_limit = attributes[:'users_per_card_limit']
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'program_join_policy')
    self.program_join_policy = attributes[:'program_join_policy']
  end

  if attributes.key?(:'tiers_expiration_policy')
    self.tiers_expiration_policy = attributes[:'tiers_expiration_policy']
  end

  if attributes.key?(:'tier_cycle_start_date')
    self.tier_cycle_start_date = attributes[:'tier_cycle_start_date']
  end

  if attributes.key?(:'tiers_expire_in')
    self.tiers_expire_in = attributes[:'tiers_expire_in']
  end

  if attributes.key?(:'tiers_downgrade_policy')
    self.tiers_downgrade_policy = attributes[:'tiers_downgrade_policy']
  end

  if attributes.key?(:'card_code_settings')
    self.card_code_settings = attributes[:'card_code_settings']
  end

  if attributes.key?(:'return_policy')
    self.return_policy = attributes[:'return_policy']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'tiers')
    if (value = attributes[:'tiers']).is_a?(Array)
      self.tiers = value
    end
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end

  if attributes.key?(:'card_based')
    self.card_based = attributes[:'card_based']
  else
    self.card_based = false
  end

  if attributes.key?(:'can_update_tiers')
    self.can_update_tiers = attributes[:'can_update_tiers']
  else
    self.can_update_tiers = false
  end

  if attributes.key?(:'can_update_tier_expiration_policy')
    self.can_update_tier_expiration_policy = attributes[:'can_update_tier_expiration_policy']
  end

  if attributes.key?(:'can_upgrade_to_advanced_tiers')
    self.can_upgrade_to_advanced_tiers = attributes[:'can_upgrade_to_advanced_tiers']
  else
    self.can_upgrade_to_advanced_tiers = false
  end

  if attributes.key?(:'can_update_subledgers')
    self.can_update_subledgers = attributes[:'can_update_subledgers']
  else
    self.can_update_subledgers = false
  end
end

Instance Attribute Details

#account_idObject

The ID of the Talon.One account that owns this program.



69
70
71
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 69

def 
  @account_id
end

#allow_subledgerObject

Indicates if this program supports subledgers inside the program.



40
41
42
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 40

def allow_subledger
  @allow_subledger
end

#can_update_subledgersObject

‘True` if the `allowSubledger` property can be updated in the loyalty program.



93
94
95
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 93

def can_update_subledgers
  @can_update_subledgers
end

#can_update_tier_expiration_policyObject

‘True` if the tier expiration policy can be updated.



87
88
89
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 87

def can_update_tier_expiration_policy
  @can_update_tier_expiration_policy
end

#can_update_tiersObject

‘True` if the tier definitions can be updated.



84
85
86
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 84

def can_update_tiers
  @can_update_tiers
end

#can_upgrade_to_advanced_tiersObject

‘True` if the program can be upgraded to use the `tiersExpireIn` and `tiersDowngradePolicy` properties.



90
91
92
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 90

def can_upgrade_to_advanced_tiers
  @can_upgrade_to_advanced_tiers
end

#card_basedObject

Defines the type of loyalty program: - ‘true`: the program is a card-based. - `false`: the program is profile-based.



81
82
83
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 81

def card_based
  @card_based
end

#card_code_settingsObject

Returns the value of attribute card_code_settings.



63
64
65
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 63

def card_code_settings
  @card_code_settings
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 22

def created
  @created
end

#default_pendingObject

The default duration of the pending time after which points should be valid. Accepted values: ‘immediate’, ‘on_action’ or a specific time. The time format is a number followed by one letter indicating the time unit, like ‘30s’, ‘40m’, ‘1h’, ‘5D’, ‘7W’, or 10M’. These rounding suffixes are also supported: - ‘_D’ for rounding down. Can be used as a suffix after ‘D’, and signifies the start of the day. - ‘_U’ for rounding up. Can be used as a suffix after ‘D’, ‘W’, and ‘M’, and signifies the end of the day, week, and month.



37
38
39
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 37

def default_pending
  @default_pending
end

#default_validityObject

The default duration after which new loyalty points should expire. Can be ‘unlimited’ or a specific time. The time format is a number followed by one letter indicating the time unit, like ‘30s’, ‘40m’, ‘1h’, ‘5D’, ‘7W’, or 10M’. These rounding suffixes are also supported: - ‘_D’ for rounding down. Can be used as a suffix after ‘D’, and signifies the start of the day. - ‘_U’ for rounding up. Can be used as a suffix after ‘D’, ‘W’, and ‘M’, and signifies the end of the day, week, and month.



34
35
36
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 34

def default_validity
  @default_validity
end

#descriptionObject

Description of our Loyalty Program.



28
29
30
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 28

def description
  @description
end

#idObject

The ID of loyalty program.



19
20
21
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 19

def id
  @id
end

#nameObject

The internal name for the Loyalty Program. This is an immutable value.



72
73
74
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 72

def name
  @name
end

#program_join_policyObject

The policy that defines when the customer joins the loyalty program. - ‘not_join`: The customer does not join the loyalty program but can still earn and spend loyalty points. Note: The customer does not have a program join date. - `points_activated`: The customer joins the loyalty program only when their earned loyalty points become active for the first time. - `points_earned`: The customer joins the loyalty program when they earn loyalty points for the first time.



49
50
51
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 49

def program_join_policy
  @program_join_policy
end

#return_policyObject

The policy that defines the rollback of points in case of a partially returned, cancelled, or reopened [customer session](docs.talon.one/docs/dev/concepts/entities/customer-sessions). - ‘only_pending`: Only pending points can be rolled back. - `within_balance`: Available active points can be rolled back if there aren’t enough pending points. The active balance of the customer cannot be negative. - ‘unlimited`: Allows negative balance without any limit.



66
67
68
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 66

def return_policy
  @return_policy
end

#sandboxObject

Indicates if this program is a live or sandbox program. Programs of a given type can only be connected to Applications of the same type.



46
47
48
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 46

def sandbox
  @sandbox
end

#subscribed_applicationsObject

A list containing the IDs of all applications that are subscribed to this Loyalty Program.



31
32
33
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 31

def subscribed_applications
  @subscribed_applications
end

#tier_cycle_start_dateObject

Timestamp at which the tier cycle starts for all customers in the loyalty program. Note: This is only required when the tier expiration policy is set to ‘absolute_expiration`.



55
56
57
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 55

def tier_cycle_start_date
  @tier_cycle_start_date
end

#tiersObject

The tiers in this loyalty program.



75
76
77
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 75

def tiers
  @tiers
end

#tiers_downgrade_policyObject

The policy that defines how customer tiers are downgraded in the loyalty program after tier reevaluation. - ‘one_down`: If the customer doesn’t have enough points to stay in the current tier, they are downgraded by one tier. - ‘balance_based`: The customer’s tier is reevaluated based on the amount of active points they have at the moment.



61
62
63
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 61

def tiers_downgrade_policy
  @tiers_downgrade_policy
end

#tiers_expiration_policyObject

The policy that defines how tier expiration, used to reevaluate the customer’s current tier, is determined. - ‘tier_start_date`: The tier expiration is relative to when the customer joined the current tier. - `program_join_date`: The tier expiration is relative to when the customer joined the loyalty program. - `customer_attribute`: The tier expiration is determined by a custom customer attribute. - `absolute_expiration`: The tier is reevaluated at the start of each tier cycle. For this policy, it is required to provide a `tierCycleStartDate`.



52
53
54
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 52

def tiers_expiration_policy
  @tiers_expiration_policy
end

#tiers_expire_inObject

The amount of time after which the tier expires and is reevaluated. The time format is an integer followed by one letter indicating the time unit. Examples: ‘30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can round certain units up or down: - `_D` for rounding down days only. Signifies the start of the day. - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year.



58
59
60
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 58

def tiers_expire_in
  @tiers_expire_in
end

#timezoneObject

A string containing an IANA timezone descriptor.



78
79
80
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 78

def timezone
  @timezone
end

#titleObject

The display title for the Loyalty Program.



25
26
27
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 25

def title
  @title
end

#users_per_card_limitObject

The max amount of user profiles with whom a card can be shared. This can be set to 0 for no limit. This property is only used when ‘cardBased` is `true`.



43
44
45
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 43

def users_per_card_limit
  @users_per_card_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



150
151
152
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 150

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



155
156
157
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 155

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 118

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'title' => :'title',
    :'description' => :'description',
    :'subscribed_applications' => :'subscribedApplications',
    :'default_validity' => :'defaultValidity',
    :'default_pending' => :'defaultPending',
    :'allow_subledger' => :'allowSubledger',
    :'users_per_card_limit' => :'usersPerCardLimit',
    :'sandbox' => :'sandbox',
    :'program_join_policy' => :'programJoinPolicy',
    :'tiers_expiration_policy' => :'tiersExpirationPolicy',
    :'tier_cycle_start_date' => :'tierCycleStartDate',
    :'tiers_expire_in' => :'tiersExpireIn',
    :'tiers_downgrade_policy' => :'tiersDowngradePolicy',
    :'card_code_settings' => :'cardCodeSettings',
    :'return_policy' => :'returnPolicy',
    :'account_id' => :'accountID',
    :'name' => :'name',
    :'tiers' => :'tiers',
    :'timezone' => :'timezone',
    :'card_based' => :'cardBased',
    :'can_update_tiers' => :'canUpdateTiers',
    :'can_update_tier_expiration_policy' => :'canUpdateTierExpirationPolicy',
    :'can_upgrade_to_advanced_tiers' => :'canUpgradeToAdvancedTiers',
    :'can_update_subledgers' => :'canUpdateSubledgers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 577

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 198

def self.openapi_all_of
  [
  :'BaseLoyaltyProgram',
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



192
193
194
195
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 192

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 160

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'title' => :'String',
    :'description' => :'String',
    :'subscribed_applications' => :'Array<Integer>',
    :'default_validity' => :'String',
    :'default_pending' => :'String',
    :'allow_subledger' => :'Boolean',
    :'users_per_card_limit' => :'Integer',
    :'sandbox' => :'Boolean',
    :'program_join_policy' => :'String',
    :'tiers_expiration_policy' => :'String',
    :'tier_cycle_start_date' => :'Time',
    :'tiers_expire_in' => :'String',
    :'tiers_downgrade_policy' => :'String',
    :'card_code_settings' => :'CodeGeneratorSettings',
    :'return_policy' => :'String',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'tiers' => :'Array<LoyaltyTier>',
    :'timezone' => :'String',
    :'card_based' => :'Boolean',
    :'can_update_tiers' => :'Boolean',
    :'can_update_tier_expiration_policy' => :'Boolean',
    :'can_upgrade_to_advanced_tiers' => :'Boolean',
    :'can_update_subledgers' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 531

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      title == o.title &&
      description == o.description &&
      subscribed_applications == o.subscribed_applications &&
      default_validity == o.default_validity &&
      default_pending == o.default_pending &&
      allow_subledger == o.allow_subledger &&
      users_per_card_limit == o.users_per_card_limit &&
      sandbox == o.sandbox &&
      program_join_policy == o.program_join_policy &&
      tiers_expiration_policy == o.tiers_expiration_policy &&
      tier_cycle_start_date == o.tier_cycle_start_date &&
      tiers_expire_in == o.tiers_expire_in &&
      tiers_downgrade_policy == o.tiers_downgrade_policy &&
      card_code_settings == o.card_code_settings &&
      return_policy == o.return_policy &&
       == o. &&
      name == o.name &&
      tiers == o.tiers &&
      timezone == o.timezone &&
      card_based == o.card_based &&
      can_update_tiers == o.can_update_tiers &&
      can_update_tier_expiration_policy == o.can_update_tier_expiration_policy &&
      can_upgrade_to_advanced_tiers == o.can_upgrade_to_advanced_tiers &&
      can_update_subledgers == o.can_update_subledgers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


564
565
566
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 564

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



570
571
572
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 570

def hash
  [id, created, title, description, subscribed_applications, default_validity, default_pending, allow_subledger, users_per_card_limit, sandbox, program_join_policy, tiers_expiration_policy, tier_cycle_start_date, tiers_expire_in, tiers_downgrade_policy, card_code_settings, return_policy, , name, tiers, timezone, card_based, can_update_tiers, can_update_tier_expiration_policy, can_upgrade_to_advanced_tiers, can_update_subledgers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 350

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if !@users_per_card_limit.nil? && @users_per_card_limit < 0
    invalid_properties.push('invalid value for "users_per_card_limit", must be greater than or equal to 0.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  if @timezone.to_s.length < 1
    invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.')
  end

  if @card_based.nil?
    invalid_properties.push('invalid value for "card_based", card_based cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 599

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/talon_one_sdk/models/loyalty_program.rb', line 390

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if !@users_per_card_limit.nil? && @users_per_card_limit < 0
  program_join_policy_validator = EnumAttributeValidator.new('String', ["not_join", "points_activated", "points_earned"])
  return false unless program_join_policy_validator.valid?(@program_join_policy)
  tiers_expiration_policy_validator = EnumAttributeValidator.new('String', ["tier_start_date", "program_join_date", "customer_attribute", "absolute_expiration"])
  return false unless tiers_expiration_policy_validator.valid?(@tiers_expiration_policy)
  tiers_downgrade_policy_validator = EnumAttributeValidator.new('String', ["one_down", "balance_based"])
  return false unless tiers_downgrade_policy_validator.valid?(@tiers_downgrade_policy)
  return_policy_validator = EnumAttributeValidator.new('String', ["only_pending", "within_balance", "unlimited"])
  return false unless return_policy_validator.valid?(@return_policy)
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @timezone.nil?
  return false if @timezone.to_s.length < 1
  return false if @card_based.nil?
  true
end