Class: TalonOne::LoyaltyProgramLedgers

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_program_ledgers.rb

Overview

Customer-specific information about loyalty points.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltyProgramLedgers

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyProgramLedgers` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyProgramLedgers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'join_date')
    self.join_date = attributes[:'join_date']
  end

  if attributes.key?(:'ledger')
    self.ledger = attributes[:'ledger']
  else
    self.ledger = nil
  end

  if attributes.key?(:'sub_ledgers')
    if (value = attributes[:'sub_ledgers']).is_a?(Hash)
      self.sub_ledgers = value
    end
  end
end

Instance Attribute Details

#idObject

The internal ID of loyalty program.



20
21
22
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 20

def id
  @id
end

#join_dateObject

The date on which the customer joined the loyalty program in RFC3339. Note: This is in the loyalty program’s time zone.



29
30
31
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 29

def join_date
  @join_date
end

#ledgerObject

Information about the main ledger in the loyalty program.



32
33
34
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 32

def ledger
  @ledger
end

#nameObject

Internal name of loyalty program.



26
27
28
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 26

def name
  @name
end

#sub_ledgersObject

A map containing information about each loyalty subledger.



35
36
37
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 35

def sub_ledgers
  @sub_ledgers
end

#titleObject

Visible name of loyalty program.



23
24
25
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 23

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'name' => :'name',
    :'join_date' => :'joinDate',
    :'ledger' => :'ledger',
    :'sub_ledgers' => :'subLedgers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 60

def self.openapi_types
  {
    :'id' => :'Integer',
    :'title' => :'String',
    :'name' => :'String',
    :'join_date' => :'Time',
    :'ledger' => :'LedgerInfo',
    :'sub_ledgers' => :'Hash<String, LedgerInfo>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      name == o.name &&
      join_date == o.join_date &&
      ledger == o.ledger &&
      sub_ledgers == o.sub_ledgers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 224

def hash
  [id, title, name, join_date, ledger, sub_ledgers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @ledger.nil?
    invalid_properties.push('invalid value for "ledger", ledger cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/loyalty_program_ledgers.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @title.nil?
  return false if @name.nil?
  return false if @ledger.nil?
  true
end