Class: TalonOne::LoyaltyProgramTransaction

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_program_transaction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltyProgramTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 175

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyProgramTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyProgramTransaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  else
    self.start_date = nil
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'customer_session_id')
    self.customer_session_id = attributes[:'customer_session_id']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_email')
    self.user_email = attributes[:'user_email']
  end

  if attributes.key?(:'ruleset_id')
    self.ruleset_id = attributes[:'ruleset_id']
  end

  if attributes.key?(:'rule_name')
    self.rule_name = attributes[:'rule_name']
  end

  if attributes.key?(:'flags')
    self.flags = attributes[:'flags']
  end

  if attributes.key?(:'validity_duration')
    self.validity_duration = attributes[:'validity_duration']
  end
end

Instance Attribute Details

#amountObject

Amount of loyalty points added or deducted in the transaction.



37
38
39
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 37

def amount
  @amount
end

#campaign_idObject

ID of the campaign.



28
29
30
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 28

def campaign_id
  @campaign_id
end

#card_identifierObject

The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.



52
53
54
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 52

def card_identifier
  @card_identifier
end

#createdObject

Date and time the loyalty transaction occurred.



31
32
33
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 31

def created
  @created
end

#customer_profile_idObject

Customer profile integration ID used in the loyalty program.



49
50
51
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 49

def customer_profile_id
  @customer_profile_id
end

#customer_session_idObject

ID of the customer session where the transaction occurred.



58
59
60
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 58

def customer_session_id
  @customer_session_id
end

#expiry_dateObject

When points expire. Possible values: - ‘unlimited`: Points have no expiration date. - a timestamp value: Points expire at a given date and time.



46
47
48
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 46

def expiry_date
  @expiry_date
end

#flagsObject

The flags of the transaction, when applicable. The ‘createsNegativeBalance` flag indicates whether the transaction results in a negative balance.



76
77
78
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 76

def flags
  @flags
end

#idObject

ID of the loyalty ledger transaction.



19
20
21
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 19

def id
  @id
end

#import_idObject

ID of the import where the transaction occurred.



61
62
63
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 61

def import_id
  @import_id
end

#nameObject

Name or reason for the loyalty ledger transaction.



40
41
42
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 40

def name
  @name
end

#program_idObject

ID of the loyalty program.



25
26
27
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 25

def program_id
  @program_id
end

#rule_nameObject

Name of the rule that triggered the effect. Applies only for transactions that resulted from a customer session.



73
74
75
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 73

def rule_name
  @rule_name
end

#ruleset_idObject

ID of the ruleset containing the rule that triggered the effect. Applies only for transactions that resulted from a customer session.



70
71
72
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 70

def ruleset_id
  @ruleset_id
end

#start_dateObject

When points become active. Possible values: - ‘immediate`: Points are immediately active. - `on_action`: Points become active based on the customer’s action. - a timestamp value: Points become active at a given date and time.



43
44
45
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 43

def start_date
  @start_date
end

#subledger_idObject

ID of the subledger.



55
56
57
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 55

def subledger_id
  @subledger_id
end

#transaction_uuidObject

Unique identifier of the transaction in the UUID format.



22
23
24
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 22

def transaction_uuid
  @transaction_uuid
end

#typeObject

Type of transaction. Possible values: - ‘addition`: Signifies added points. - `subtraction`: Signifies deducted points.



34
35
36
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 34

def type
  @type
end

#user_emailObject

The email of the Campaign Manager account that manually added or deducted points. Applies only to manual transactions.



67
68
69
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 67

def user_email
  @user_email
end

#user_idObject

ID of the user who manually added or deducted points. Applies only to manual transactions.



64
65
66
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 64

def user_id
  @user_id
end

#validity_durationObject

The duration for which the points remain active, relative to the activation date. Note: This only applies to points for which ‘awaitsActivation` is `true` and `expiryDate` is not set.



79
80
81
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 79

def validity_duration
  @validity_duration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



131
132
133
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 131

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



136
137
138
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 136

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 104

def self.attribute_map
  {
    :'id' => :'id',
    :'transaction_uuid' => :'transactionUUID',
    :'program_id' => :'programId',
    :'campaign_id' => :'campaignId',
    :'created' => :'created',
    :'type' => :'type',
    :'amount' => :'amount',
    :'name' => :'name',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'customer_profile_id' => :'customerProfileId',
    :'card_identifier' => :'cardIdentifier',
    :'subledger_id' => :'subledgerId',
    :'customer_session_id' => :'customerSessionId',
    :'import_id' => :'importId',
    :'user_id' => :'userId',
    :'user_email' => :'userEmail',
    :'ruleset_id' => :'rulesetId',
    :'rule_name' => :'ruleName',
    :'flags' => :'flags',
    :'validity_duration' => :'validityDuration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 613

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



168
169
170
171
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 168

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 141

def self.openapi_types
  {
    :'id' => :'Integer',
    :'transaction_uuid' => :'String',
    :'program_id' => :'Integer',
    :'campaign_id' => :'Integer',
    :'created' => :'Time',
    :'type' => :'String',
    :'amount' => :'Float',
    :'name' => :'String',
    :'start_date' => :'String',
    :'expiry_date' => :'String',
    :'customer_profile_id' => :'String',
    :'card_identifier' => :'String',
    :'subledger_id' => :'String',
    :'customer_session_id' => :'String',
    :'import_id' => :'Integer',
    :'user_id' => :'Integer',
    :'user_email' => :'String',
    :'ruleset_id' => :'Integer',
    :'rule_name' => :'String',
    :'flags' => :'LoyaltyLedgerEntryFlags',
    :'validity_duration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 572

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      transaction_uuid == o.transaction_uuid &&
      program_id == o.program_id &&
      campaign_id == o.campaign_id &&
      created == o.created &&
      type == o.type &&
      amount == o.amount &&
      name == o.name &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      customer_profile_id == o.customer_profile_id &&
      card_identifier == o.card_identifier &&
      subledger_id == o.subledger_id &&
      customer_session_id == o.customer_session_id &&
      import_id == o.import_id &&
      user_id == o.user_id &&
      user_email == o.user_email &&
      ruleset_id == o.ruleset_id &&
      rule_name == o.rule_name &&
      flags == o.flags &&
      validity_duration == o.validity_duration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


600
601
602
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 600

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



606
607
608
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 606

def hash
  [id, transaction_uuid, program_id, campaign_id, created, type, amount, name, start_date, expiry_date, customer_profile_id, card_identifier, subledger_id, customer_session_id, import_id, user_id, user_email, ruleset_id, rule_name, flags, validity_duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 296

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length > 255
    invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 255.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @start_date.to_s.length > 64
    invalid_properties.push('invalid value for "start_date", the character length must be smaller than or equal to 64.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if !@customer_profile_id.nil? && @customer_profile_id.to_s.length > 255
    invalid_properties.push('invalid value for "customer_profile_id", the character length must be smaller than or equal to 255.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length > 108
    invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length < 4
    invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  if !@card_identifier.nil? && @card_identifier !~ pattern
    invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.")
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @subledger_id.to_s.length > 64
    invalid_properties.push('invalid value for "subledger_id", the character length must be smaller than or equal to 64.')
  end

  if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
    invalid_properties.push('invalid value for "customer_session_id", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 635

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/talon_one_sdk/models/loyalty_program_transaction.rb', line 381

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @transaction_uuid.nil?
  return false if @program_id.nil?
  return false if @created.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["addition", "subtraction"])
  return false unless type_validator.valid?(@type)
  return false if @type.to_s.length > 255
  return false if @amount.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @start_date.nil?
  return false if @start_date.to_s.length > 64
  return false if @expiry_date.nil?
  return false if !@customer_profile_id.nil? && @customer_profile_id.to_s.length > 255
  return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108
  return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4
  return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  return false if @subledger_id.nil?
  return false if @subledger_id.to_s.length > 64
  return false if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
  true
end