Class: TalonOne::LoyaltySubLedger

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_sub_ledger.rb

Overview

Ledger of Balance in Loyalty Program for a Customer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltySubLedger

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltySubLedger` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltySubLedger`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'total_active_points')
    self.total_active_points = attributes[:'total_active_points']
  else
    self.total_active_points = nil
  end

  if attributes.key?(:'total_pending_points')
    self.total_pending_points = attributes[:'total_pending_points']
  else
    self.total_pending_points = nil
  end

  if attributes.key?(:'total_spent_points')
    self.total_spent_points = attributes[:'total_spent_points']
  else
    self.total_spent_points = nil
  end

  if attributes.key?(:'total_expired_points')
    self.total_expired_points = attributes[:'total_expired_points']
  else
    self.total_expired_points = nil
  end

  if attributes.key?(:'total_negative_points')
    self.total_negative_points = attributes[:'total_negative_points']
  else
    self.total_negative_points = nil
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'expiring_points')
    if (value = attributes[:'expiring_points']).is_a?(Array)
      self.expiring_points = value
    end
  end

  if attributes.key?(:'active_points')
    if (value = attributes[:'active_points']).is_a?(Array)
      self.active_points = value
    end
  end

  if attributes.key?(:'pending_points')
    if (value = attributes[:'pending_points']).is_a?(Array)
      self.pending_points = value
    end
  end

  if attributes.key?(:'expired_points')
    if (value = attributes[:'expired_points']).is_a?(Array)
      self.expired_points = value
    end
  end

  if attributes.key?(:'current_tier')
    self.current_tier = attributes[:'current_tier']
  end
end

Instance Attribute Details

#active_pointsObject

List of all currently active points.



44
45
46
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 44

def active_points
  @active_points
end

#current_tierObject

Tier for which the ledger is eligible.



53
54
55
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 53

def current_tier
  @current_tier
end

#expired_pointsObject

List of expired points.



50
51
52
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 50

def expired_points
  @expired_points
end

#expiring_pointsObject

List of all points that will expire.



41
42
43
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 41

def expiring_points
  @expiring_points
end

#pending_pointsObject

List of all points pending activation.



47
48
49
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 47

def pending_points
  @pending_points
end

#totalObject

DEPRECATED Use ‘totalActivePoints` property instead. Total amount of currently active and available points in the customer’s balance.



20
21
22
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 20

def total
  @total
end

#total_active_pointsObject

Total amount of currently active and available points in the customer’s balance.



23
24
25
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 23

def total_active_points
  @total_active_points
end

#total_expired_pointsObject

Total amount of points, that expired without ever being spent.



32
33
34
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 32

def total_expired_points
  @total_expired_points
end

#total_negative_pointsObject

Total amount of negative points. This implies that ‘totalActivePoints` is `0`.



35
36
37
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 35

def total_negative_points
  @total_negative_points
end

#total_pending_pointsObject

Total amount of pending points, which are not active yet but will become active in the future.



26
27
28
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 26

def total_pending_points
  @total_pending_points
end

#total_spent_pointsObject

Total amount of points already spent by this customer.



29
30
31
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 29

def total_spent_points
  @total_spent_points
end

#transactionsObject

List of all events that have happened such as additions, subtractions and expiries.



38
39
40
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 38

def transactions
  @transactions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 56

def self.attribute_map
  {
    :'total' => :'total',
    :'total_active_points' => :'totalActivePoints',
    :'total_pending_points' => :'totalPendingPoints',
    :'total_spent_points' => :'totalSpentPoints',
    :'total_expired_points' => :'totalExpiredPoints',
    :'total_negative_points' => :'totalNegativePoints',
    :'transactions' => :'transactions',
    :'expiring_points' => :'expiringPoints',
    :'active_points' => :'activePoints',
    :'pending_points' => :'pendingPoints',
    :'expired_points' => :'expiredPoints',
    :'current_tier' => :'currentTier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 333

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 84

def self.openapi_types
  {
    :'total' => :'Float',
    :'total_active_points' => :'Float',
    :'total_pending_points' => :'Float',
    :'total_spent_points' => :'Float',
    :'total_expired_points' => :'Float',
    :'total_negative_points' => :'Float',
    :'transactions' => :'Array<LoyaltyLedgerEntry>',
    :'expiring_points' => :'Array<LoyaltyLedgerEntry>',
    :'active_points' => :'Array<LoyaltyLedgerEntry>',
    :'pending_points' => :'Array<LoyaltyLedgerEntry>',
    :'expired_points' => :'Array<LoyaltyLedgerEntry>',
    :'current_tier' => :'Tier'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total == o.total &&
      total_active_points == o.total_active_points &&
      total_pending_points == o.total_pending_points &&
      total_spent_points == o.total_spent_points &&
      total_expired_points == o.total_expired_points &&
      total_negative_points == o.total_negative_points &&
      transactions == o.transactions &&
      expiring_points == o.expiring_points &&
      active_points == o.active_points &&
      pending_points == o.pending_points &&
      expired_points == o.expired_points &&
      current_tier == o.current_tier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



326
327
328
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 326

def hash
  [total, total_active_points, total_pending_points, total_spent_points, total_expired_points, total_negative_points, transactions, expiring_points, active_points, pending_points, expired_points, current_tier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @total_active_points.nil?
    invalid_properties.push('invalid value for "total_active_points", total_active_points cannot be nil.')
  end

  if @total_pending_points.nil?
    invalid_properties.push('invalid value for "total_pending_points", total_pending_points cannot be nil.')
  end

  if @total_spent_points.nil?
    invalid_properties.push('invalid value for "total_spent_points", total_spent_points cannot be nil.')
  end

  if @total_expired_points.nil?
    invalid_properties.push('invalid value for "total_expired_points", total_expired_points cannot be nil.')
  end

  if @total_negative_points.nil?
    invalid_properties.push('invalid value for "total_negative_points", total_negative_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
# File 'lib/talon_one_sdk/models/loyalty_sub_ledger.rb', line 228

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total.nil?
  return false if @total_active_points.nil?
  return false if @total_pending_points.nil?
  return false if @total_spent_points.nil?
  return false if @total_expired_points.nil?
  return false if @total_negative_points.nil?
  true
end