Class: TalonOne::LoyaltyTier

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/loyalty_tier.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoyaltyTier

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyTier` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyTier`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'program_name')
    self.program_name = attributes[:'program_name']
  end

  if attributes.key?(:'program_title')
    self.program_title = attributes[:'program_title']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'min_points')
    self.min_points = attributes[:'min_points']
  else
    self.min_points = nil
  end
end

Instance Attribute Details

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 22

def created
  @created
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 19

def id
  @id
end

#min_pointsObject

The minimum amount of points required to enter the tier.



37
38
39
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 37

def min_points
  @min_points
end

#nameObject

The name of the tier.



34
35
36
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 34

def name
  @name
end

#program_idObject

The ID of the loyalty program that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 25

def program_id
  @program_id
end

#program_nameObject

The integration name of the loyalty program that owns this entity.



28
29
30
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 28

def program_name
  @program_name
end

#program_titleObject

The Campaign Manager-displayed name of the loyalty program that owns this entity.



31
32
33
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 31

def program_title
  @program_title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'program_id' => :'programID',
    :'program_name' => :'programName',
    :'program_title' => :'programTitle',
    :'name' => :'name',
    :'min_points' => :'minPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 82

def self.openapi_all_of
  [
  :'Entity',
  :'LoyaltyProgramEntity',
  :'NewLoyaltyTier'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 63

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'program_id' => :'Integer',
    :'program_name' => :'String',
    :'program_title' => :'String',
    :'name' => :'String',
    :'min_points' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      program_id == o.program_id &&
      program_name == o.program_name &&
      program_title == o.program_title &&
      name == o.name &&
      min_points == o.min_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 275

def hash
  [id, created, program_id, program_name, program_title, name, min_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @min_points.nil?
    invalid_properties.push('invalid value for "min_points", min_points cannot be nil.')
  end

  if @min_points > 999999999999.99
    invalid_properties.push('invalid value for "min_points", must be smaller than or equal to 999999999999.99.')
  end

  if @min_points < 0
    invalid_properties.push('invalid value for "min_points", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
193
# File 'lib/talon_one_sdk/models/loyalty_tier.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @program_id.nil?
  return false if @name.nil?
  return false if @min_points.nil?
  return false if @min_points > 999999999999.99
  return false if @min_points < 0
  true
end