Class: TalonOne::MCPOAuthServerMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::MCPOAuthServerMetadata
- Defined in:
- lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb
Instance Attribute Summary collapse
-
#authorization_endpoint ⇒ Object
URL of the authorization endpoint.
-
#code_challenge_methods_supported ⇒ Object
List of supported PKCE code challenge methods.
-
#grant_types_supported ⇒ Object
List of supported OAuth2 grant types.
-
#issuer ⇒ Object
The authorization server's issuer identifier (its base URL).
-
#registration_endpoint ⇒ Object
URL of the client registration endpoint.
-
#response_types_supported ⇒ Object
List of supported OAuth2 response types.
-
#token_endpoint ⇒ Object
URL of the token endpoint.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MCPOAuthServerMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MCPOAuthServerMetadata
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MCPOAuthServerMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MCPOAuthServerMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] else self.issuer = nil end if attributes.key?(:'authorization_endpoint') self. = attributes[:'authorization_endpoint'] else self. = nil end if attributes.key?(:'token_endpoint') self.token_endpoint = attributes[:'token_endpoint'] else self.token_endpoint = nil end if attributes.key?(:'registration_endpoint') self.registration_endpoint = attributes[:'registration_endpoint'] else self.registration_endpoint = nil end if attributes.key?(:'response_types_supported') if (value = attributes[:'response_types_supported']).is_a?(Array) self.response_types_supported = value end else self.response_types_supported = nil end if attributes.key?(:'grant_types_supported') if (value = attributes[:'grant_types_supported']).is_a?(Array) self.grant_types_supported = value end else self.grant_types_supported = nil end if attributes.key?(:'code_challenge_methods_supported') if (value = attributes[:'code_challenge_methods_supported']).is_a?(Array) self.code_challenge_methods_supported = value end else self.code_challenge_methods_supported = nil end end |
Instance Attribute Details
#authorization_endpoint ⇒ Object
URL of the authorization endpoint.
22 23 24 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 22 def @authorization_endpoint end |
#code_challenge_methods_supported ⇒ Object
List of supported PKCE code challenge methods.
37 38 39 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 37 def code_challenge_methods_supported @code_challenge_methods_supported end |
#grant_types_supported ⇒ Object
List of supported OAuth2 grant types.
34 35 36 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 34 def grant_types_supported @grant_types_supported end |
#issuer ⇒ Object
The authorization server's issuer identifier (its base URL).
19 20 21 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 19 def issuer @issuer end |
#registration_endpoint ⇒ Object
URL of the client registration endpoint.
28 29 30 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 28 def registration_endpoint @registration_endpoint end |
#response_types_supported ⇒ Object
List of supported OAuth2 response types.
31 32 33 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 31 def response_types_supported @response_types_supported end |
#token_endpoint ⇒ Object
URL of the token endpoint.
25 26 27 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 25 def token_endpoint @token_endpoint end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 40 def self.attribute_map { :'issuer' => :'issuer', :'authorization_endpoint' => :'authorization_endpoint', :'token_endpoint' => :'token_endpoint', :'registration_endpoint' => :'registration_endpoint', :'response_types_supported' => :'response_types_supported', :'grant_types_supported' => :'grant_types_supported', :'code_challenge_methods_supported' => :'code_challenge_methods_supported' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 295 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 63 def self.openapi_types { :'issuer' => :'String', :'authorization_endpoint' => :'String', :'token_endpoint' => :'String', :'registration_endpoint' => :'String', :'response_types_supported' => :'Array<String>', :'grant_types_supported' => :'Array<String>', :'code_challenge_methods_supported' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 268 def ==(o) return true if self.equal?(o) self.class == o.class && issuer == o.issuer && == o. && token_endpoint == o.token_endpoint && registration_endpoint == o.registration_endpoint && response_types_supported == o.response_types_supported && grant_types_supported == o.grant_types_supported && code_challenge_methods_supported == o.code_challenge_methods_supported end |
#eql?(o) ⇒ Boolean
282 283 284 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 282 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
288 289 290 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 288 def hash [issuer, , token_endpoint, registration_endpoint, response_types_supported, grant_types_supported, code_challenge_methods_supported].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @issuer.nil? invalid_properties.push('invalid value for "issuer", issuer cannot be nil.') end if @authorization_endpoint.nil? invalid_properties.push('invalid value for "authorization_endpoint", authorization_endpoint cannot be nil.') end if @token_endpoint.nil? invalid_properties.push('invalid value for "token_endpoint", token_endpoint cannot be nil.') end if @registration_endpoint.nil? invalid_properties.push('invalid value for "registration_endpoint", registration_endpoint cannot be nil.') end if @response_types_supported.nil? invalid_properties.push('invalid value for "response_types_supported", response_types_supported cannot be nil.') end if @grant_types_supported.nil? invalid_properties.push('invalid value for "grant_types_supported", grant_types_supported cannot be nil.') end if @code_challenge_methods_supported.nil? invalid_properties.push('invalid value for "code_challenge_methods_supported", code_challenge_methods_supported cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/talon_one_sdk/models/mcpo_auth_server_metadata.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @issuer.nil? return false if @authorization_endpoint.nil? return false if @token_endpoint.nil? return false if @registration_endpoint.nil? return false if @response_types_supported.nil? return false if @grant_types_supported.nil? return false if @code_challenge_methods_supported.nil? true end |