Class: TalonOne::MCPOAuthTokenRequest

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/mcpo_auth_token_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MCPOAuthTokenRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MCPOAuthTokenRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MCPOAuthTokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'grant_type')
    self.grant_type = attributes[:'grant_type']
  else
    self.grant_type = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'redirect_uri')
    self.redirect_uri = attributes[:'redirect_uri']
  end

  if attributes.key?(:'code_verifier')
    self.code_verifier = attributes[:'code_verifier']
  end

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end
end

Instance Attribute Details

#client_idObject

Client ID. Required for authorization_code grant.



25
26
27
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 25

def client_id
  @client_id
end

#codeObject

Authorization code. Required for authorization_code grant.



22
23
24
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 22

def code
  @code
end

#code_verifierObject

PKCE code verifier. Required for authorization_code grant.



31
32
33
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 31

def code_verifier
  @code_verifier
end

#grant_typeObject

OAuth2 grant type.



19
20
21
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 19

def grant_type
  @grant_type
end

#redirect_uriObject

Redirect URI. Required for authorization_code grant.



28
29
30
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 28

def redirect_uri
  @redirect_uri
end

#refresh_tokenObject

Refresh token. Required for refresh_token grant.



34
35
36
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 34

def refresh_token
  @refresh_token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 59

def self.attribute_map
  {
    :'grant_type' => :'grant_type',
    :'code' => :'code',
    :'client_id' => :'client_id',
    :'redirect_uri' => :'redirect_uri',
    :'code_verifier' => :'code_verifier',
    :'refresh_token' => :'refresh_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 81

def self.openapi_types
  {
    :'grant_type' => :'String',
    :'code' => :'String',
    :'client_id' => :'String',
    :'redirect_uri' => :'String',
    :'code_verifier' => :'String',
    :'refresh_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      grant_type == o.grant_type &&
      code == o.code &&
      client_id == o.client_id &&
      redirect_uri == o.redirect_uri &&
      code_verifier == o.code_verifier &&
      refresh_token == o.refresh_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 194

def hash
  [grant_type, code, client_id, redirect_uri, code_verifier, refresh_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @grant_type.nil?
    invalid_properties.push('invalid value for "grant_type", grant_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/mcpo_auth_token_request.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @grant_type.nil?
  grant_type_validator = EnumAttributeValidator.new('String', ["authorization_code", "refresh_token"])
  return false unless grant_type_validator.valid?(@grant_type)
  true
end