Class: TalonOne::ManagementKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ManagementKey
- Defined in:
- lib/talon_one_sdk/models/management_key.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
ID of account the key is used for.
-
#allowed_application_ids ⇒ Object
A list of Application IDs that you can access with the management key.
-
#created ⇒ Object
The date the management key was created.
-
#created_by ⇒ Object
ID of the user who created it.
-
#disabled ⇒ Object
The management key is disabled (this property is set to ‘true`) when the user who created the key is disabled or deleted.
-
#endpoints ⇒ Object
The list of endpoints that can be accessed with the key.
-
#expiry_date ⇒ Object
The date the management key expires.
-
#id ⇒ Object
ID of the management key.
-
#last_used ⇒ Object
The last time the management key was used.
-
#name ⇒ Object
Name for management key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ManagementKey
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ManagementKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ManagementKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] else self.expiry_date = nil end if attributes.key?(:'endpoints') if (value = attributes[:'endpoints']).is_a?(Array) self.endpoints = value end else self.endpoints = nil end if attributes.key?(:'allowed_application_ids') if (value = attributes[:'allowed_application_ids']).is_a?(Array) self.allowed_application_ids = value end end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'last_used') self.last_used = attributes[:'last_used'] end end |
Instance Attribute Details
#account_id ⇒ Object
ID of account the key is used for.
37 38 39 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 37 def account_id @account_id end |
#allowed_application_ids ⇒ Object
A list of Application IDs that you can access with the management key. An empty or missing list means the management key can be used for all Applications in the account.
28 29 30 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 28 def allowed_application_ids @allowed_application_ids end |
#created ⇒ Object
The date the management key was created.
40 41 42 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 40 def created @created end |
#created_by ⇒ Object
ID of the user who created it.
34 35 36 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 34 def created_by @created_by end |
#disabled ⇒ Object
The management key is disabled (this property is set to ‘true`) when the user who created the key is disabled or deleted.
43 44 45 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 43 def disabled @disabled end |
#endpoints ⇒ Object
The list of endpoints that can be accessed with the key
25 26 27 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 25 def endpoints @endpoints end |
#expiry_date ⇒ Object
The date the management key expires.
22 23 24 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 22 def expiry_date @expiry_date end |
#id ⇒ Object
ID of the management key.
31 32 33 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 31 def id @id end |
#last_used ⇒ Object
The last time the management key was used.
46 47 48 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 46 def last_used @last_used end |
#name ⇒ Object
Name for management key.
19 20 21 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 19 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 49 def self.attribute_map { :'name' => :'name', :'expiry_date' => :'expiryDate', :'endpoints' => :'endpoints', :'allowed_application_ids' => :'allowedApplicationIds', :'id' => :'id', :'created_by' => :'createdBy', :'account_id' => :'accountID', :'created' => :'created', :'disabled' => :'disabled', :'last_used' => :'lastUsed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 330 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
97 98 99 100 101 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 97 def self.openapi_all_of [ :'CreateManagementKey' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 75 def self.openapi_types { :'name' => :'String', :'expiry_date' => :'Time', :'endpoints' => :'Array<Endpoint>', :'allowed_application_ids' => :'Array<Integer>', :'id' => :'Integer', :'created_by' => :'Integer', :'account_id' => :'Integer', :'created' => :'Time', :'disabled' => :'Boolean', :'last_used' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 300 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && expiry_date == o.expiry_date && endpoints == o.endpoints && allowed_application_ids == o.allowed_application_ids && id == o.id && created_by == o.created_by && account_id == o.account_id && created == o.created && disabled == o.disabled && last_used == o.last_used end |
#eql?(o) ⇒ Boolean
317 318 319 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 317 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 323 def hash [name, expiry_date, endpoints, allowed_application_ids, id, created_by, account_id, created, disabled, last_used].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 180 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @expiry_date.nil? invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.') end if @endpoints.nil? invalid_properties.push('invalid value for "endpoints", endpoints cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/talon_one_sdk/models/management_key.rb', line 216 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @expiry_date.nil? return false if @endpoints.nil? return false if @id.nil? return false if @created_by.nil? return false if @account_id.nil? return false if @created.nil? true end |