Class: TalonOne::MultipleAudiencesItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::MultipleAudiencesItem
- Defined in:
- lib/talon_one_sdk/models/multiple_audiences_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created ⇒ Object
The time this entity was created.
-
#id ⇒ Object
The internal ID of this entity.
-
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
-
#name ⇒ Object
The human-friendly display name for this audience.
-
#status ⇒ Object
Indicates whether the audience is new, updated or unmodified by the request.
-
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MultipleAudiencesItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MultipleAudiencesItem
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MultipleAudiencesItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MultipleAudiencesItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'subscribed_applications_ids') if (value = attributes[:'subscribed_applications_ids']).is_a?(Array) self.subscribed_applications_ids = value end end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 22 def created @created end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 19 def id @id end |
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
31 32 33 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 31 def integration_id @integration_id end |
#name ⇒ Object
The human-friendly display name for this audience.
25 26 27 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 25 def name @name end |
#status ⇒ Object
Indicates whether the audience is new, updated or unmodified by the request.
34 35 36 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 34 def status @status end |
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
28 29 30 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 28 def subscribed_applications_ids @subscribed_applications_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 59 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'name' => :'name', :'subscribed_applications_ids' => :'subscribedApplicationsIds', :'integration_id' => :'integrationId', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
99 100 101 102 103 104 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 99 def self.openapi_all_of [ :'Entity', :'NewMultipleAudiencesItem' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 81 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'name' => :'String', :'subscribed_applications_ids' => :'Array<Integer>', :'integration_id' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 283 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && name == o.name && subscribed_applications_ids == o.subscribed_applications_ids && integration_id == o.integration_id && status == o.status end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 302 def hash [id, created, name, subscribed_applications_ids, integration_id, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@integration_id.nil? && @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if !@integration_id.nil? && @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if !@integration_id.nil? && @integration_id.to_s.length > 1000 return false if !@integration_id.nil? && @integration_id.to_s.length < 1 return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["unmodified", "updated", "new"]) return false unless status_validator.valid?(@status) true end |