Class: TalonOne::MultipleCustomerProfileIntegrationRequestItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::MultipleCustomerProfileIntegrationRequestItem
- Defined in:
- lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with this item.
-
#integration_id ⇒ Object
The identifier of this profile, set by your integration layer.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MultipleCustomerProfileIntegrationRequestItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MultipleCustomerProfileIntegrationRequestItem
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MultipleCustomerProfileIntegrationRequestItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MultipleCustomerProfileIntegrationRequestItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with this item.
19 20 21 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 19 def attributes @attributes end |
#integration_id ⇒ Object
The identifier of this profile, set by your integration layer. It must be unique within the account. To get the ‘integrationId` of the profile from a `sessionId`, use the [Update customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2).
22 23 24 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 22 def integration_id @integration_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 25 def self.attribute_map { :'attributes' => :'attributes', :'integration_id' => :'integrationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
57 58 59 60 61 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 57 def self.openapi_all_of [ :'NewCustomerProfile' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 43 def self.openapi_types { :'attributes' => :'Hash<String, Object>', :'integration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && attributes == o.attributes && integration_id == o.integration_id end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 148 def hash [attributes, integration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 94 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 |
# File 'lib/talon_one_sdk/models/multiple_customer_profile_integration_request_item.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @integration_id.nil? return false if @integration_id.to_s.length > 1000 true end |