Class: TalonOne::NewAccountSignUp

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_account_sign_up.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewAccountSignUp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewAccountSignUp` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewAccountSignUp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  else
    self.password = nil
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  else
    self.company_name = nil
  end
end

Instance Attribute Details

#company_nameObject

Returns the value of attribute company_name.



24
25
26
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 24

def company_name
  @company_name
end

#emailObject

The email address associated with the user profile.



19
20
21
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 19

def email
  @email
end

#passwordObject

The password for your account.



22
23
24
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 22

def password
  @password
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



36
37
38
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 27

def self.attribute_map
  {
    :'email' => :'email',
    :'password' => :'password',
    :'company_name' => :'companyName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 61

def self.openapi_all_of
  [
  :'LoginParams',
  :'NewAccount'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 46

def self.openapi_types
  {
    :'email' => :'String',
    :'password' => :'String',
    :'company_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      password == o.password &&
      company_name == o.company_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 190

def hash
  [email, password, company_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @password.nil?
    invalid_properties.push('invalid value for "password", password cannot be nil.')
  end

  if @company_name.nil?
    invalid_properties.push('invalid value for "company_name", company_name cannot be nil.')
  end

  if @company_name.to_s.length < 1
    invalid_properties.push('invalid value for "company_name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/new_account_sign_up.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @password.nil?
  return false if @company_name.nil?
  return false if @company_name.to_s.length < 1
  true
end