Class: TalonOne::NewApplication

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_application.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewApplication

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/new_application.rb', line 153

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewApplication` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewApplication`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'case_sensitivity')
    self.case_sensitivity = attributes[:'case_sensitivity']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'default_discount_scope')
    self.default_discount_scope = attributes[:'default_discount_scope']
  end

  if attributes.key?(:'enable_cascading_discounts')
    self.enable_cascading_discounts = attributes[:'enable_cascading_discounts']
  end

  if attributes.key?(:'enable_flattened_cart_items')
    self.enable_flattened_cart_items = attributes[:'enable_flattened_cart_items']
  end

  if attributes.key?(:'attributes_settings')
    self.attributes_settings = attributes[:'attributes_settings']
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'enable_partial_discounts')
    self.enable_partial_discounts = attributes[:'enable_partial_discounts']
  end

  if attributes.key?(:'default_discount_additional_cost_per_item_scope')
    self.default_discount_additional_cost_per_item_scope = attributes[:'default_discount_additional_cost_per_item_scope']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'enable_campaign_state_management')
    self.enable_campaign_state_management = attributes[:'enable_campaign_state_management']
  end

  if attributes.key?(:'best_prior_price_settings')
    self.best_prior_price_settings = attributes[:'best_prior_price_settings']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary properties associated with this campaign.



34
35
36
# File 'lib/talon_one_sdk/models/new_application.rb', line 34

def attributes
  @attributes
end

#attributes_settingsObject

Returns the value of attribute attributes_settings.



48
49
50
# File 'lib/talon_one_sdk/models/new_application.rb', line 48

def attributes_settings
  @attributes_settings
end

#best_prior_price_settingsObject

Returns the value of attribute best_prior_price_settings.



65
66
67
# File 'lib/talon_one_sdk/models/new_application.rb', line 65

def best_prior_price_settings
  @best_prior_price_settings
end

#case_sensitivityObject

The case sensitivity behavior to check coupon codes in the campaigns of this Application.



31
32
33
# File 'lib/talon_one_sdk/models/new_application.rb', line 31

def case_sensitivity
  @case_sensitivity
end

#currencyObject

The default currency for new customer sessions.



28
29
30
# File 'lib/talon_one_sdk/models/new_application.rb', line 28

def currency
  @currency
end

#default_discount_additional_cost_per_item_scopeObject

The default scope to apply setDiscountPerItem effects on if no scope was provided with the effect.



57
58
59
# File 'lib/talon_one_sdk/models/new_application.rb', line 57

def default_discount_additional_cost_per_item_scope
  @default_discount_additional_cost_per_item_scope
end

#default_discount_scopeObject

The default scope to apply setDiscount effects on if no scope was provided with the effect.



40
41
42
# File 'lib/talon_one_sdk/models/new_application.rb', line 40

def default_discount_scope
  @default_discount_scope
end

#descriptionObject

A longer description of the application.



22
23
24
# File 'lib/talon_one_sdk/models/new_application.rb', line 22

def description
  @description
end

#enable_campaign_state_managementObject

Indicates whether the campaign staging and revisions feature is enabled for the Application. Important: After this feature is enabled, it cannot be disabled.



63
64
65
# File 'lib/talon_one_sdk/models/new_application.rb', line 63

def enable_campaign_state_management
  @enable_campaign_state_management
end

#enable_cascading_discountsObject

Indicates if discounts should cascade for this Application.



43
44
45
# File 'lib/talon_one_sdk/models/new_application.rb', line 43

def enable_cascading_discounts
  @enable_cascading_discounts
end

#enable_flattened_cart_itemsObject

Indicates if cart items of quantity larger than one should be separated into different items of quantity one.



46
47
48
# File 'lib/talon_one_sdk/models/new_application.rb', line 46

def enable_flattened_cart_items
  @enable_flattened_cart_items
end

#enable_partial_discountsObject

Indicates if this Application supports partial discounts.



54
55
56
# File 'lib/talon_one_sdk/models/new_application.rb', line 54

def enable_partial_discounts
  @enable_partial_discounts
end

#keyObject

Hex key for HMAC-signing API calls as coming from this application (16 hex digits).



60
61
62
# File 'lib/talon_one_sdk/models/new_application.rb', line 60

def key
  @key
end

#limitsObject

Default limits for campaigns created in this application.



37
38
39
# File 'lib/talon_one_sdk/models/new_application.rb', line 37

def limits
  @limits
end

#nameObject

The name of this application.



19
20
21
# File 'lib/talon_one_sdk/models/new_application.rb', line 19

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox Application.



51
52
53
# File 'lib/talon_one_sdk/models/new_application.rb', line 51

def sandbox
  @sandbox
end

#timezoneObject

A string containing an IANA timezone descriptor.



25
26
27
# File 'lib/talon_one_sdk/models/new_application.rb', line 25

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



113
114
115
# File 'lib/talon_one_sdk/models/new_application.rb', line 113

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/talon_one_sdk/models/new_application.rb', line 118

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/talon_one_sdk/models/new_application.rb', line 90

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'timezone' => :'timezone',
    :'currency' => :'currency',
    :'case_sensitivity' => :'caseSensitivity',
    :'attributes' => :'attributes',
    :'limits' => :'limits',
    :'default_discount_scope' => :'defaultDiscountScope',
    :'enable_cascading_discounts' => :'enableCascadingDiscounts',
    :'enable_flattened_cart_items' => :'enableFlattenedCartItems',
    :'attributes_settings' => :'attributesSettings',
    :'sandbox' => :'sandbox',
    :'enable_partial_discounts' => :'enablePartialDiscounts',
    :'default_discount_additional_cost_per_item_scope' => :'defaultDiscountAdditionalCostPerItemScope',
    :'key' => :'key',
    :'enable_campaign_state_management' => :'enableCampaignStateManagement',
    :'best_prior_price_settings' => :'bestPriorPriceSettings'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/talon_one_sdk/models/new_application.rb', line 427

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



146
147
148
149
# File 'lib/talon_one_sdk/models/new_application.rb', line 146

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/talon_one_sdk/models/new_application.rb', line 123

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'timezone' => :'String',
    :'currency' => :'String',
    :'case_sensitivity' => :'String',
    :'attributes' => :'Object',
    :'limits' => :'Array<LimitConfig>',
    :'default_discount_scope' => :'String',
    :'enable_cascading_discounts' => :'Boolean',
    :'enable_flattened_cart_items' => :'Boolean',
    :'attributes_settings' => :'AttributesSettings',
    :'sandbox' => :'Boolean',
    :'enable_partial_discounts' => :'Boolean',
    :'default_discount_additional_cost_per_item_scope' => :'String',
    :'key' => :'String',
    :'enable_campaign_state_management' => :'Boolean',
    :'best_prior_price_settings' => :'BestPriorPriceSettings'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/talon_one_sdk/models/new_application.rb', line 390

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      timezone == o.timezone &&
      currency == o.currency &&
      case_sensitivity == o.case_sensitivity &&
      attributes == o.attributes &&
      limits == o.limits &&
      default_discount_scope == o.default_discount_scope &&
      enable_cascading_discounts == o.enable_cascading_discounts &&
      enable_flattened_cart_items == o.enable_flattened_cart_items &&
      attributes_settings == o.attributes_settings &&
      sandbox == o.sandbox &&
      enable_partial_discounts == o.enable_partial_discounts &&
      default_discount_additional_cost_per_item_scope == o.default_discount_additional_cost_per_item_scope &&
      key == o.key &&
      enable_campaign_state_management == o.enable_campaign_state_management &&
      best_prior_price_settings == o.best_prior_price_settings
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


414
415
416
# File 'lib/talon_one_sdk/models/new_application.rb', line 414

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



420
421
422
# File 'lib/talon_one_sdk/models/new_application.rb', line 420

def hash
  [name, description, timezone, currency, case_sensitivity, attributes, limits, default_discount_scope, enable_cascading_discounts, enable_flattened_cart_items, attributes_settings, sandbox, enable_partial_discounts, default_discount_additional_cost_per_item_scope, key, enable_campaign_state_management, best_prior_price_settings].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/talon_one_sdk/models/new_application.rb', line 246

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  if @timezone.to_s.length < 1
    invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length < 1
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{16}$/)
  if !@key.nil? && @key !~ pattern
    invalid_properties.push("invalid value for \"key\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/talon_one_sdk/models/new_application.rb', line 449

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/talon_one_sdk/models/new_application.rb', line 283

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @timezone.nil?
  return false if @timezone.to_s.length < 1
  return false if @currency.nil?
  return false if @currency.to_s.length < 1
  case_sensitivity_validator = EnumAttributeValidator.new('String', ["sensitive", "insensitive-uppercase", "insensitive-lowercase"])
  return false unless case_sensitivity_validator.valid?(@case_sensitivity)
  default_discount_scope_validator = EnumAttributeValidator.new('String', ["sessionTotal", "cartItems", "additionalCosts"])
  return false unless default_discount_scope_validator.valid?(@default_discount_scope)
  default_discount_additional_cost_per_item_scope_validator = EnumAttributeValidator.new('String', ["price", "itemTotal", "additionalCosts"])
  return false unless default_discount_additional_cost_per_item_scope_validator.valid?(@default_discount_additional_cost_per_item_scope)
  return false if !@key.nil? && @key !~ Regexp.new(/^[a-fA-F0-9]{16}$/)
  true
end