Class: TalonOne::NewAttribute

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_attribute.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewAttribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewAttribute` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewAttribute`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  else
    self.entity = nil
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'suggestions')
    if (value = attributes[:'suggestions']).is_a?(Array)
      self.suggestions = value
    end
  else
    self.suggestions = nil
  end

  if attributes.key?(:'has_allowed_list')
    self.has_allowed_list = attributes[:'has_allowed_list']
  else
    self.has_allowed_list = false
  end

  if attributes.key?(:'restricted_by_suggestions')
    self.restricted_by_suggestions = attributes[:'restricted_by_suggestions']
  else
    self.restricted_by_suggestions = false
  end

  if attributes.key?(:'editable')
    self.editable = attributes[:'editable']
  else
    self.editable = nil
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'subscribed_catalogs_ids')
    if (value = attributes[:'subscribed_catalogs_ids']).is_a?(Array)
      self.subscribed_catalogs_ids = value
    end
  end

  if attributes.key?(:'allowed_subscriptions')
    if (value = attributes[:'allowed_subscriptions']).is_a?(Array)
      self.allowed_subscriptions = value
    end
  end
end

Instance Attribute Details

#allowed_subscriptionsObject

A list of allowed subscription types for this attribute. Note: This only applies to attributes associated with the ‘CartItem` entity.



54
55
56
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 54

def allowed_subscriptions
  @allowed_subscriptions
end

#descriptionObject

A description of this attribute.



33
34
35
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 33

def description
  @description
end

#editableObject

Whether or not this attribute can be edited.



45
46
47
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 45

def editable
  @editable
end

#entityObject

The name of the entity that can have this attribute. When creating or updating the entities of a given type, you can include an ‘attributes` object with keys corresponding to the `name` of the custom attributes for that type.



19
20
21
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 19

def entity
  @entity
end

#event_typeObject

Returns the value of attribute event_type.



21
22
23
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 21

def event_type
  @event_type
end

#has_allowed_listObject

Whether or not this attribute has an allowed list of values associated with it.



39
40
41
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 39

def has_allowed_list
  @has_allowed_list
end

#nameObject

The attribute name that will be used in API requests and Talang. E.g. if ‘name == "region"` then you would set the region attribute by including an `attributes.region` property in your request payload.



24
25
26
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 24

def name
  @name
end

#restricted_by_suggestionsObject

Whether or not this attribute’s value is restricted by suggestions (‘suggestions` property) or by an allowed list of value (`hasAllowedList` property).



42
43
44
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 42

def restricted_by_suggestions
  @restricted_by_suggestions
end

#subscribed_applications_idsObject

A list of the IDs of the applications where this attribute is available.



48
49
50
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 48

def subscribed_applications_ids
  @subscribed_applications_ids
end

#subscribed_catalogs_idsObject

A list of the IDs of the catalogs where this attribute is available.



51
52
53
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 51

def subscribed_catalogs_ids
  @subscribed_catalogs_ids
end

#suggestionsObject

A list of suggestions for the attribute.



36
37
38
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 36

def suggestions
  @suggestions
end

#titleObject

The human-readable name for the attribute that will be shown in the Campaign Manager. Like ‘name`, the combination of entity and title must also be unique.



27
28
29
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 27

def title
  @title
end

#typeObject

The data type of the attribute, a ‘time` attribute must be sent as a string that conforms to the [RFC3339](www.ietf.org/rfc/rfc3339.txt) timestamp format.



30
31
32
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 30

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 79

def self.attribute_map
  {
    :'entity' => :'entity',
    :'event_type' => :'eventType',
    :'name' => :'name',
    :'title' => :'title',
    :'type' => :'type',
    :'description' => :'description',
    :'suggestions' => :'suggestions',
    :'has_allowed_list' => :'hasAllowedList',
    :'restricted_by_suggestions' => :'restrictedBySuggestions',
    :'editable' => :'editable',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'subscribed_catalogs_ids' => :'subscribedCatalogsIds',
    :'allowed_subscriptions' => :'allowedSubscriptions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 422

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 108

def self.openapi_types
  {
    :'entity' => :'String',
    :'event_type' => :'String',
    :'name' => :'String',
    :'title' => :'String',
    :'type' => :'String',
    :'description' => :'String',
    :'suggestions' => :'Array<String>',
    :'has_allowed_list' => :'Boolean',
    :'restricted_by_suggestions' => :'Boolean',
    :'editable' => :'Boolean',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'subscribed_catalogs_ids' => :'Array<Integer>',
    :'allowed_subscriptions' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 389

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      entity == o.entity &&
      event_type == o.event_type &&
      name == o.name &&
      title == o.title &&
      type == o.type &&
      description == o.description &&
      suggestions == o.suggestions &&
      has_allowed_list == o.has_allowed_list &&
      restricted_by_suggestions == o.restricted_by_suggestions &&
      editable == o.editable &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      subscribed_catalogs_ids == o.subscribed_catalogs_ids &&
      allowed_subscriptions == o.allowed_subscriptions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


409
410
411
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 409

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



415
416
417
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 415

def hash
  [entity, event_type, name, title, type, description, suggestions, has_allowed_list, restricted_by_suggestions, editable, subscribed_applications_ids, subscribed_catalogs_ids, allowed_subscriptions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @entity.nil?
    invalid_properties.push('invalid value for "entity", entity cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z]\w*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @suggestions.nil?
    invalid_properties.push('invalid value for "suggestions", suggestions cannot be nil.')
  end

  if @suggestions.length > 50
    invalid_properties.push('invalid value for "suggestions", number of items must be less than or equal to 50.')
  end

  if @editable.nil?
    invalid_properties.push('invalid value for "editable", editable cannot be nil.')
  end

  if !@allowed_subscriptions.nil? && @allowed_subscriptions.length > 2
    invalid_properties.push('invalid value for "allowed_subscriptions", number of items must be less than or equal to 2.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 444

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/talon_one_sdk/models/new_attribute.rb', line 283

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @entity.nil?
  entity_validator = EnumAttributeValidator.new('String', ["Application", "Campaign", "CustomerProfile", "CustomerSession", "CartItem", "Coupon", "Event", "Giveaway", "LoyaltyCard", "Referral", "Store"])
  return false unless entity_validator.valid?(@entity)
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[A-Za-z]\w*$/)
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["string", "number", "boolean", "time", "(list string)", "(list number)", "(list time)", "location", "(list location)"])
  return false unless type_validator.valid?(@type)
  return false if @description.nil?
  return false if @suggestions.nil?
  return false if @suggestions.length > 50
  return false if @editable.nil?
  return false if !@allowed_subscriptions.nil? && @allowed_subscriptions.length > 2
  true
end