Class: TalonOne::NewAudience

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_audience.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewAudience

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/new_audience.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewAudience` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewAudience`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'integration')
    self.integration = attributes[:'integration']
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'created_in3rd_party')
    self.created_in3rd_party = attributes[:'created_in3rd_party']
  end

  if attributes.key?(:'last_update')
    self.last_update = attributes[:'last_update']
  end
end

Instance Attribute Details

#created_in3rd_partyObject

Determines if this audience is a 3rd party audience or not.



37
38
39
# File 'lib/talon_one_sdk/models/new_audience.rb', line 37

def created_in3rd_party
  @created_in3rd_party
end

#descriptionObject

A description of the audience.



25
26
27
# File 'lib/talon_one_sdk/models/new_audience.rb', line 25

def description
  @description
end

#integrationObject

The Talon.One-supported [3rd-party platform](docs.talon.one/docs/dev/technology-partners/overview) that this audience was created in. For example, ‘mParticle`, `Segment`, `Shopify`, `Braze`, or `Iterable`. Note: If you do not integrate with any of these platforms, do not use this property.



31
32
33
# File 'lib/talon_one_sdk/models/new_audience.rb', line 31

def integration
  @integration
end

#integration_idObject

The ID of this audience in the third-party integration. Note: To create an audience that doesn’t come from a 3rd party platform, do not use this property.



34
35
36
# File 'lib/talon_one_sdk/models/new_audience.rb', line 34

def integration_id
  @integration_id
end

#last_updateObject

The last time that the audience memberships changed.



40
41
42
# File 'lib/talon_one_sdk/models/new_audience.rb', line 40

def last_update
  @last_update
end

#nameObject

The human-friendly display name for this audience.



19
20
21
# File 'lib/talon_one_sdk/models/new_audience.rb', line 19

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox Application.



22
23
24
# File 'lib/talon_one_sdk/models/new_audience.rb', line 22

def sandbox
  @sandbox
end

#subscribed_applications_idsObject

A list of the IDs of the Applications that are connected to this audience.



28
29
30
# File 'lib/talon_one_sdk/models/new_audience.rb', line 28

def subscribed_applications_ids
  @subscribed_applications_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/new_audience.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/new_audience.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/new_audience.rb', line 43

def self.attribute_map
  {
    :'name' => :'name',
    :'sandbox' => :'sandbox',
    :'description' => :'description',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'integration' => :'integration',
    :'integration_id' => :'integrationId',
    :'created_in3rd_party' => :'createdIn3rdParty',
    :'last_update' => :'lastUpdate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/talon_one_sdk/models/new_audience.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



87
88
89
90
91
# File 'lib/talon_one_sdk/models/new_audience.rb', line 87

def self.openapi_all_of
  [
  :'NewInternalAudience'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/new_audience.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/new_audience.rb', line 67

def self.openapi_types
  {
    :'name' => :'String',
    :'sandbox' => :'Boolean',
    :'description' => :'String',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'integration' => :'String',
    :'integration_id' => :'String',
    :'created_in3rd_party' => :'Boolean',
    :'last_update' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/talon_one_sdk/models/new_audience.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      sandbox == o.sandbox &&
      description == o.description &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      integration == o.integration &&
      integration_id == o.integration_id &&
      created_in3rd_party == o.created_in3rd_party &&
      last_update == o.last_update
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/talon_one_sdk/models/new_audience.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/talon_one_sdk/models/new_audience.rb', line 246

def hash
  [name, sandbox, description, subscribed_applications_ids, integration, integration_id, created_in3rd_party, last_update].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/talon_one_sdk/models/new_audience.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/talon_one_sdk/models/new_audience.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/new_audience.rb', line 172

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@integration_id.nil? && @integration_id.to_s.length > 1000
  return false if !@integration_id.nil? && @integration_id.to_s.length < 1
  true
end