Class: TalonOne::NewCampaignCollection

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_campaign_collection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewCampaignCollection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCampaignCollection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCampaignCollection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end
end

Instance Attribute Details

#descriptionObject

A short description of the purpose of this collection.



19
20
21
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 19

def description
  @description
end

#nameObject

The name of this collection.



22
23
24
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 22

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 25

def self.attribute_map
  {
    :'description' => :'description',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 164

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



57
58
59
60
61
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 57

def self.openapi_all_of
  [
  :'UpdateCampaignCollection'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 43

def self.openapi_types
  {
    :'description' => :'String',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 151

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



157
158
159
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 157

def hash
  [description, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/new_campaign_collection.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  true
end