Class: TalonOne::NewCampaignStoreBudget

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_campaign_store_budget.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewCampaignStoreBudget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCampaignStoreBudget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCampaignStoreBudget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'store_limits')
    if (value = attributes[:'store_limits']).is_a?(Array)
      self.store_limits = value
    end
  else
    self.store_limits = nil
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



18
19
20
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 18

def action
  @action
end

#periodObject

Returns the value of attribute period.



23
24
25
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 23

def period
  @period
end

#store_limitsObject

The set of budget limits for stores linked to the campaign.



21
22
23
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 21

def store_limits
  @store_limits
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 48

def self.attribute_map
  {
    :'action' => :'action',
    :'store_limits' => :'storeLimits',
    :'period' => :'period'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 67

def self.openapi_types
  {
    :'action' => :'String',
    :'store_limits' => :'Array<NewCampaignStoreBudgetStoreLimit>',
    :'period' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      store_limits == o.store_limits &&
      period == o.period
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 193

def hash
  [action, store_limits, period].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @store_limits.nil?
    invalid_properties.push('invalid value for "store_limits", store_limits cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
142
143
# File 'lib/talon_one_sdk/models/new_campaign_store_budget.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  action_validator = EnumAttributeValidator.new('String', ["setDiscount"])
  return false unless action_validator.valid?(@action)
  return false if @store_limits.nil?
  period_validator = EnumAttributeValidator.new('String', ["daily", "weekly", "monthly", "yearly"])
  return false unless period_validator.valid?(@period)
  true
end