Class: TalonOne::NewCollection

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_collection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewCollection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/talon_one_sdk/models/new_collection.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCollection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCollection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end
end

Instance Attribute Details

#descriptionObject

A short description of the purpose of this collection.



19
20
21
# File 'lib/talon_one_sdk/models/new_collection.rb', line 19

def description
  @description
end

#nameObject

The name of this collection.



25
26
27
# File 'lib/talon_one_sdk/models/new_collection.rb', line 25

def name
  @name
end

#subscribed_applications_idsObject

A list of the IDs of the Applications where this collection is enabled.



22
23
24
# File 'lib/talon_one_sdk/models/new_collection.rb', line 22

def subscribed_applications_ids
  @subscribed_applications_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/talon_one_sdk/models/new_collection.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/talon_one_sdk/models/new_collection.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/talon_one_sdk/models/new_collection.rb', line 28

def self.attribute_map
  {
    :'description' => :'description',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/talon_one_sdk/models/new_collection.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



62
63
64
65
66
# File 'lib/talon_one_sdk/models/new_collection.rb', line 62

def self.openapi_all_of
  [
  :'UpdateCollection'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/talon_one_sdk/models/new_collection.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/talon_one_sdk/models/new_collection.rb', line 47

def self.openapi_types
  {
    :'description' => :'String',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/new_collection.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/talon_one_sdk/models/new_collection.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/talon_one_sdk/models/new_collection.rb', line 169

def hash
  [description, subscribed_applications_ids, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/new_collection.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/new_collection.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/new_collection.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  true
end