Class: TalonOne::NewCustomEffect

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_custom_effect.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewCustomEffect

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCustomEffect` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCustomEffect`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  else
    self.application_ids = nil
  end

  if attributes.key?(:'is_per_item')
    self.is_per_item = attributes[:'is_per_item']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  else
    self.payload = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Array)
      self.params = value
    end
  end
end

Instance Attribute Details

#application_idsObject

The IDs of the Applications that are related to this entity.



19
20
21
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 19

def application_ids
  @application_ids
end

#descriptionObject

The description of this effect.



34
35
36
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 34

def description
  @description
end

#enabledObject

Determines if this effect is active.



37
38
39
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 37

def enabled
  @enabled
end

#is_per_itemObject

Indicates if this effect is per item or not.



22
23
24
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 22

def is_per_item
  @is_per_item
end

#nameObject

The name of this effect.



25
26
27
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 25

def name
  @name
end

#paramsObject

Array of template argument definitions.



40
41
42
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 40

def params
  @params
end

#payloadObject

The JSON payload of this effect.



31
32
33
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 31

def payload
  @payload
end

#titleObject

The title of this effect.



28
29
30
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 28

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 43

def self.attribute_map
  {
    :'application_ids' => :'applicationIds',
    :'is_per_item' => :'isPerItem',
    :'name' => :'name',
    :'title' => :'title',
    :'payload' => :'payload',
    :'description' => :'description',
    :'enabled' => :'enabled',
    :'params' => :'params'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 307

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



87
88
89
90
91
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 87

def self.openapi_all_of
  [
  :'MultiApplicationEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 67

def self.openapi_types
  {
    :'application_ids' => :'Array<Integer>',
    :'is_per_item' => :'Boolean',
    :'name' => :'String',
    :'title' => :'String',
    :'payload' => :'String',
    :'description' => :'String',
    :'enabled' => :'Boolean',
    :'params' => :'Array<TemplateArgDef>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      application_ids == o.application_ids &&
      is_per_item == o.is_per_item &&
      name == o.name &&
      title == o.title &&
      payload == o.payload &&
      description == o.description &&
      enabled == o.enabled &&
      params == o.params
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 294

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



300
301
302
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 300

def hash
  [application_ids, is_per_item, name, title, payload, description, enabled, params].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @application_ids.length < 1
    invalid_properties.push('invalid value for "application_ids", number of items must be greater than or equal to 1.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z](\w|\s)*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @payload.nil?
    invalid_properties.push('invalid value for "payload", payload cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/talon_one_sdk/models/new_custom_effect.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @application_ids.nil?
  return false if @application_ids.length < 1
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[A-Za-z](\w|\s)*$/)
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/)
  return false if @payload.nil?
  return false if @enabled.nil?
  true
end