Class: TalonOne::NewCustomerSession

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_customer_session.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewCustomerSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCustomerSession` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCustomerSession`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'coupon')
    self.coupon = attributes[:'coupon']
  end

  if attributes.key?(:'referral')
    self.referral = attributes[:'referral']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'open'
  end

  if attributes.key?(:'cart_items')
    if (value = attributes[:'cart_items']).is_a?(Array)
      self.cart_items = value
    end
  end

  if attributes.key?(:'identifiers')
    if (value = attributes[:'identifiers']).is_a?(Array)
      self.identifiers = value
    end
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end
end

Instance Attribute Details

#attributesObject

A key-value map of the sessions attributes. The potentially valid attributes are configured in your accounts developer settings.



40
41
42
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 40

def attributes
  @attributes
end

#cart_itemsObject

Serialized JSON representation.



31
32
33
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 31

def cart_items
  @cart_items
end

#couponObject

Any coupon code entered.



22
23
24
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 22

def coupon
  @coupon
end

#identifiersObject

Session custom identifiers that you can set limits on or use inside your rules. For example, you can use IP addresses as identifiers to potentially identify devices and limit discounts abuse in case of customers creating multiple accounts. See the [tutorial](docs.talon.one/docs/dev/tutorials/using-identifiers).



34
35
36
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 34

def identifiers
  @identifiers
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.



19
20
21
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 19

def profile_id
  @profile_id
end

#referralObject

Any referral code entered.



25
26
27
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 25

def referral
  @referral
end

#stateObject

Indicates the current state of the session. Sessions can be created as ‘open` or `closed`. The state transitions are: 1. `open` → `closed` 2. `open` → `cancelled` 3. `closed` → `cancelled` or `partially_returned` 4. `partially_returned` → `cancelled` For more information, see [Customer session states](docs.talon.one/docs/dev/concepts/entities/customer-sessions).



28
29
30
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 28

def state
  @state
end

#totalObject

The total sum of the cart in one session.



37
38
39
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 37

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 65

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'coupon' => :'coupon',
    :'referral' => :'referral',
    :'state' => :'state',
    :'cart_items' => :'cartItems',
    :'identifiers' => :'identifiers',
    :'total' => :'total',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 284

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



109
110
111
112
113
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 109

def self.openapi_all_of
  [
  :'IntegrationProfileEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 89

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'coupon' => :'String',
    :'referral' => :'String',
    :'state' => :'String',
    :'cart_items' => :'Array<CartItem>',
    :'identifiers' => :'Array<String>',
    :'total' => :'Float',
    :'attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      coupon == o.coupon &&
      referral == o.referral &&
      state == o.state &&
      cart_items == o.cart_items &&
      identifiers == o.identifiers &&
      total == o.total &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 277

def hash
  [profile_id, coupon, referral, state, cart_items, identifiers, total, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@coupon.nil? && @coupon.to_s.length > 100
    invalid_properties.push('invalid value for "coupon", the character length must be smaller than or equal to 100.')
  end

  if !@referral.nil? && @referral.to_s.length > 100
    invalid_properties.push('invalid value for "referral", the character length must be smaller than or equal to 100.')
  end

  if !@identifiers.nil? && @identifiers.length > 5
    invalid_properties.push('invalid value for "identifiers", number of items must be less than or equal to 5.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
# File 'lib/talon_one_sdk/models/new_customer_session.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@coupon.nil? && @coupon.to_s.length > 100
  return false if !@referral.nil? && @referral.to_s.length > 100
  state_validator = EnumAttributeValidator.new('String', ["open", "closed", "partially_returned", "cancelled"])
  return false unless state_validator.valid?(@state)
  return false if !@identifiers.nil? && @identifiers.length > 5
  true
end