Class: TalonOne::NewDigitalPass
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewDigitalPass
- Defined in:
- lib/talon_one_sdk/models/new_digital_pass.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
A map of placeholder values that you provide to fill in the pass template.
-
#loyalty_card_id ⇒ Object
The identifier of the loyalty card the pass is issued for.
-
#loyalty_program_id ⇒ Object
The ID of the associated loyalty program.
-
#pass_template_id ⇒ Object
The ID of the digital pass template used to generate the pass.
-
#platform ⇒ Object
The wallet platform the pass is generated for.
-
#profile_id ⇒ Object
The integration ID of the customer profile the pass is issued for.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewDigitalPass
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewDigitalPass
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewDigitalPass` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewDigitalPass`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] else self.loyalty_program_id = nil end if attributes.key?(:'pass_template_id') self.pass_template_id = attributes[:'pass_template_id'] else self.pass_template_id = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] else self.profile_id = nil end if attributes.key?(:'loyalty_card_id') self.loyalty_card_id = attributes[:'loyalty_card_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end end |
Instance Attribute Details
#attributes ⇒ Object
A map of placeholder values that you provide to fill in the pass template. These values are not validated against the template.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 34 def attributes @attributes end |
#loyalty_card_id ⇒ Object
The identifier of the loyalty card the pass is issued for. Note: Only applicable for card-based loyalty programs.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 28 def loyalty_card_id @loyalty_card_id end |
#loyalty_program_id ⇒ Object
The ID of the associated loyalty program.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 19 def loyalty_program_id @loyalty_program_id end |
#pass_template_id ⇒ Object
The ID of the digital pass template used to generate the pass.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 22 def pass_template_id @pass_template_id end |
#platform ⇒ Object
The wallet platform the pass is generated for.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 31 def platform @platform end |
#profile_id ⇒ Object
The integration ID of the customer profile the pass is issued for.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 25 def profile_id @profile_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 59 def self.attribute_map { :'loyalty_program_id' => :'loyaltyProgramId', :'pass_template_id' => :'passTemplateId', :'profile_id' => :'profileId', :'loyalty_card_id' => :'loyaltyCardId', :'platform' => :'platform', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 81 def self.openapi_types { :'loyalty_program_id' => :'Integer', :'pass_template_id' => :'String', :'profile_id' => :'String', :'loyalty_card_id' => :'String', :'platform' => :'String', :'attributes' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 255 def ==(o) return true if self.equal?(o) self.class == o.class && loyalty_program_id == o.loyalty_program_id && pass_template_id == o.pass_template_id && profile_id == o.profile_id && loyalty_card_id == o.loyalty_card_id && platform == o.platform && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 274 def hash [loyalty_program_id, pass_template_id, profile_id, loyalty_card_id, platform, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @loyalty_program_id.nil? invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.') end if @loyalty_program_id < 1 invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.') end if @pass_template_id.nil? invalid_properties.push('invalid value for "pass_template_id", pass_template_id cannot be nil.') end if @pass_template_id.to_s.length < 1 invalid_properties.push('invalid value for "pass_template_id", the character length must be greater than or equal to 1.') end if @profile_id.nil? invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.') end if @profile_id.to_s.length < 1 invalid_properties.push('invalid value for "profile_id", the character length must be greater than or equal to 1.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/new_digital_pass.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @loyalty_program_id.nil? return false if @loyalty_program_id < 1 return false if @pass_template_id.nil? return false if @pass_template_id.to_s.length < 1 return false if @profile_id.nil? return false if @profile_id.to_s.length < 1 return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["apple", "google"]) return false unless platform_validator.valid?(@platform) true end |