Class: TalonOne::NewExperiment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewExperiment
- Defined in:
- lib/talon_one_sdk/models/new_experiment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#campaign ⇒ Object
Returns the value of attribute campaign.
-
#goal_description ⇒ Object
A description of the experiment goal.
-
#goal_type ⇒ Object
The goal of the experiment.
-
#is_variant_assignment_external ⇒ Object
The source of the assignment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewExperiment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewExperiment
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewExperiment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewExperiment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_variant_assignment_external') self.is_variant_assignment_external = attributes[:'is_variant_assignment_external'] else self.is_variant_assignment_external = nil end if attributes.key?(:'campaign') self.campaign = attributes[:'campaign'] else self.campaign = nil end if attributes.key?(:'goal_type') self.goal_type = attributes[:'goal_type'] else self.goal_type = nil end if attributes.key?(:'goal_description') self.goal_description = attributes[:'goal_description'] end end |
Instance Attribute Details
#campaign ⇒ Object
Returns the value of attribute campaign.
21 22 23 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 21 def campaign @campaign end |
#goal_description ⇒ Object
A description of the experiment goal. Provides context for the AI summary and helps it interpret the outcome of the experiment against the stated goal.
27 28 29 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 27 def goal_description @goal_description end |
#goal_type ⇒ Object
The goal of the experiment. Determines which single metric is used to decide the winning variant. When set to ‘other`, multiple metrics are used.
24 25 26 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 24 def goal_type @goal_type end |
#is_variant_assignment_external ⇒ Object
The source of the assignment. - false - The variant assignment is handled internally by Talon.One. - true - The variant assignment is handled externally.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 19 def is_variant_assignment_external @is_variant_assignment_external end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 52 def self.attribute_map { :'is_variant_assignment_external' => :'isVariantAssignmentExternal', :'campaign' => :'campaign', :'goal_type' => :'goalType', :'goal_description' => :'goalDescription' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 72 def self.openapi_types { :'is_variant_assignment_external' => :'Boolean', :'campaign' => :'NewCampaign', :'goal_type' => :'String', :'goal_description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && is_variant_assignment_external == o.is_variant_assignment_external && campaign == o.campaign && goal_type == o.goal_type && goal_description == o.goal_description end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 207 def hash [is_variant_assignment_external, campaign, goal_type, goal_description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @is_variant_assignment_external.nil? invalid_properties.push('invalid value for "is_variant_assignment_external", is_variant_assignment_external cannot be nil.') end if @campaign.nil? invalid_properties.push('invalid value for "campaign", campaign cannot be nil.') end if @goal_type.nil? invalid_properties.push('invalid value for "goal_type", goal_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 154 155 156 |
# File 'lib/talon_one_sdk/models/new_experiment.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @is_variant_assignment_external.nil? return false if @campaign.nil? return false if @goal_type.nil? goal_type_validator = EnumAttributeValidator.new('String', ["other", "maximize_revenue", "optimize_discount_efficiency", "maximize_items_sold"]) return false unless goal_type_validator.valid?(@goal_type) true end |