Class: TalonOne::NewMCPKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewMCPKey
- Defined in:
- lib/talon_one_sdk/models/new_mcp_key.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
ID of account the key is used for.
-
#created ⇒ Object
The date the MCP key was created.
-
#created_by ⇒ Object
ID of the user who created it.
-
#disabled ⇒ Object
The MCP key is disabled (this property is set to ‘true`) when the user who created the key is disabled or deleted.
-
#expiry_date ⇒ Object
The date the MCP key expires.
-
#id ⇒ Object
ID of the MCP key.
-
#key ⇒ Object
The generated MCP key.
-
#last_used ⇒ Object
The last time the MCP key was used.
-
#name ⇒ Object
Name for the MCP key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewMCPKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewMCPKey
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewMCPKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewMCPKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] else self.expiry_date = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'last_used') self.last_used = attributes[:'last_used'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end end |
Instance Attribute Details
#account_id ⇒ Object
ID of account the key is used for.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 31 def account_id @account_id end |
#created ⇒ Object
The date the MCP key was created.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 34 def created @created end |
#created_by ⇒ Object
ID of the user who created it.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 28 def created_by @created_by end |
#disabled ⇒ Object
The MCP key is disabled (this property is set to ‘true`) when the user who created the key is disabled or deleted.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 37 def disabled @disabled end |
#expiry_date ⇒ Object
The date the MCP key expires.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 22 def expiry_date @expiry_date end |
#id ⇒ Object
ID of the MCP key.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 25 def id @id end |
#key ⇒ Object
The generated MCP key. Only returned once on creation.
43 44 45 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 43 def key @key end |
#last_used ⇒ Object
The last time the MCP key was used.
40 41 42 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 40 def last_used @last_used end |
#name ⇒ Object
Name for the MCP key.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 19 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 46 def self.attribute_map { :'name' => :'name', :'expiry_date' => :'expiryDate', :'id' => :'id', :'created_by' => :'createdBy', :'account_id' => :'accountID', :'created' => :'created', :'disabled' => :'disabled', :'last_used' => :'lastUsed', :'key' => :'key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 92 def self.openapi_all_of [ :'MCPKey' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 71 def self.openapi_types { :'name' => :'String', :'expiry_date' => :'Time', :'id' => :'Integer', :'created_by' => :'Integer', :'account_id' => :'Integer', :'created' => :'Time', :'disabled' => :'Boolean', :'last_used' => :'Time', :'key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && expiry_date == o.expiry_date && id == o.id && created_by == o.created_by && account_id == o.account_id && created == o.created && disabled == o.disabled && last_used == o.last_used && key == o.key end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 309 def hash [name, expiry_date, id, created_by, account_id, created, disabled, last_used, key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @expiry_date.nil? invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/talon_one_sdk/models/new_mcp_key.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @expiry_date.nil? return false if @id.nil? return false if @created_by.nil? return false if @account_id.nil? return false if @created.nil? return false if @key.nil? true end |