Class: TalonOne::NewManagementKey

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_management_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewManagementKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewManagementKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewManagementKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  else
    self.expiry_date = nil
  end

  if attributes.key?(:'endpoints')
    if (value = attributes[:'endpoints']).is_a?(Array)
      self.endpoints = value
    end
  else
    self.endpoints = nil
  end

  if attributes.key?(:'allowed_application_ids')
    if (value = attributes[:'allowed_application_ids']).is_a?(Array)
      self.allowed_application_ids = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'disabled')
    self.disabled = attributes[:'disabled']
  end

  if attributes.key?(:'last_used')
    self.last_used = attributes[:'last_used']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end
end

Instance Attribute Details

#account_idObject

ID of account the key is used for.



37
38
39
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 37

def 
  @account_id
end

#allowed_application_idsObject

A list of Application IDs that you can access with the management key. An empty or missing list means the management key can be used for all Applications in the account.



28
29
30
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 28

def allowed_application_ids
  @allowed_application_ids
end

#createdObject

The date the management key was created.



40
41
42
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 40

def created
  @created
end

#created_byObject

ID of the user who created it.



34
35
36
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 34

def created_by
  @created_by
end

#disabledObject

The management key is disabled (this property is set to ‘true`) when the user who created the key is disabled or deleted.



43
44
45
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 43

def disabled
  @disabled
end

#endpointsObject

The list of endpoints that can be accessed with the key



25
26
27
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 25

def endpoints
  @endpoints
end

#expiry_dateObject

The date the management key expires.



22
23
24
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 22

def expiry_date
  @expiry_date
end

#idObject

ID of the management key.



31
32
33
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 31

def id
  @id
end

#keyObject

The management key.



49
50
51
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 49

def key
  @key
end

#last_usedObject

The last time the management key was used.



46
47
48
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 46

def last_used
  @last_used
end

#nameObject

Name for management key.



19
20
21
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 19

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 52

def self.attribute_map
  {
    :'name' => :'name',
    :'expiry_date' => :'expiryDate',
    :'endpoints' => :'endpoints',
    :'allowed_application_ids' => :'allowedApplicationIds',
    :'id' => :'id',
    :'created_by' => :'createdBy',
    :'account_id' => :'accountID',
    :'created' => :'created',
    :'disabled' => :'disabled',
    :'last_used' => :'lastUsed',
    :'key' => :'key'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 357

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 102

def self.openapi_all_of
  [
  :'ManagementKey'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 79

def self.openapi_types
  {
    :'name' => :'String',
    :'expiry_date' => :'Time',
    :'endpoints' => :'Array<Endpoint>',
    :'allowed_application_ids' => :'Array<Integer>',
    :'id' => :'Integer',
    :'created_by' => :'Integer',
    :'account_id' => :'Integer',
    :'created' => :'Time',
    :'disabled' => :'Boolean',
    :'last_used' => :'Time',
    :'key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 326

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      expiry_date == o.expiry_date &&
      endpoints == o.endpoints &&
      allowed_application_ids == o.allowed_application_ids &&
      id == o.id &&
      created_by == o.created_by &&
       == o. &&
      created == o.created &&
      disabled == o.disabled &&
      last_used == o.last_used &&
      key == o.key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


344
345
346
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



350
351
352
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 350

def hash
  [name, expiry_date, endpoints, allowed_application_ids, id, created_by, , created, disabled, last_used, key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @endpoints.nil?
    invalid_properties.push('invalid value for "endpoints", endpoints cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 379

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/new_management_key.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @expiry_date.nil?
  return false if @endpoints.nil?
  return false if @id.nil?
  return false if @created_by.nil?
  return false if @account_id.nil?
  return false if @created.nil?
  return false if @key.nil?
  true
end