Class: TalonOne::NewMessageTest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewMessageTest
- Defined in:
- lib/talon_one_sdk/models/new_message_test.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_ids ⇒ Object
The IDs of the Applications in which this webhook is available.
-
#authentication_id ⇒ Object
The ID of the credential that this webhook is using.
-
#headers ⇒ Object
List of API HTTP headers for the given message.
-
#params ⇒ Object
Array of template argument definitions.
-
#payload ⇒ Object
API payload of this message.
-
#url ⇒ Object
API URL for the given message.
-
#verb ⇒ Object
API method for this message.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewMessageTest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewMessageTest
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewMessageTest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewMessageTest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Hash) self.headers = value end end if attributes.key?(:'verb') self.verb = attributes[:'verb'] else self.verb = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'params') if (value = attributes[:'params']).is_a?(Array) self.params = value end end if attributes.key?(:'application_ids') if (value = attributes[:'application_ids']).is_a?(Array) self.application_ids = value end end if attributes.key?(:'authentication_id') self.authentication_id = attributes[:'authentication_id'] end end |
Instance Attribute Details
#application_ids ⇒ Object
The IDs of the Applications in which this webhook is available. An empty array means the webhook is available in ‘All Applications`.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 34 def application_ids @application_ids end |
#authentication_id ⇒ Object
The ID of the credential that this webhook is using.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 37 def authentication_id @authentication_id end |
#headers ⇒ Object
List of API HTTP headers for the given message.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 19 def headers @headers end |
#params ⇒ Object
Array of template argument definitions.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 31 def params @params end |
#payload ⇒ Object
API payload of this message.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 28 def payload @payload end |
#url ⇒ Object
API URL for the given message.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 25 def url @url end |
#verb ⇒ Object
API method for this message.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 22 def verb @verb end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 62 def self.attribute_map { :'headers' => :'headers', :'verb' => :'verb', :'url' => :'url', :'payload' => :'payload', :'params' => :'params', :'application_ids' => :'applicationIds', :'authentication_id' => :'authenticationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 234 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 85 def self.openapi_types { :'headers' => :'Hash<String, String>', :'verb' => :'String', :'url' => :'String', :'payload' => :'String', :'params' => :'Array<TemplateArgDef>', :'application_ids' => :'Array<Integer>', :'authentication_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && headers == o.headers && verb == o.verb && url == o.url && payload == o.payload && params == o.params && application_ids == o.application_ids && authentication_id == o.authentication_id end |
#eql?(o) ⇒ Boolean
221 222 223 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 221 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 227 def hash [headers, verb, url, payload, params, application_ids, authentication_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @verb.nil? invalid_properties.push('invalid value for "verb", verb cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 |
# File 'lib/talon_one_sdk/models/new_message_test.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @verb.nil? verb_validator = EnumAttributeValidator.new('String', ["POST", "PUT", "GET", "DELETE", "PATCH"]) return false unless verb_validator.valid?(@verb) return false if @url.nil? true end |