Class: TalonOne::NewMultipleAudiencesItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewMultipleAudiencesItem
- Defined in:
- lib/talon_one_sdk/models/new_multiple_audiences_item.rb
Instance Attribute Summary collapse
-
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
-
#name ⇒ Object
The human-friendly display name for this audience.
-
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewMultipleAudiencesItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewMultipleAudiencesItem
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewMultipleAudiencesItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewMultipleAudiencesItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'subscribed_applications_ids') if (value = attributes[:'subscribed_applications_ids']).is_a?(Array) self.subscribed_applications_ids = value end end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end end |
Instance Attribute Details
#integration_id ⇒ Object
The ID of this audience in the third-party integration.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 25 def integration_id @integration_id end |
#name ⇒ Object
The human-friendly display name for this audience.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 19 def name @name end |
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications that are connected to this audience.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 22 def subscribed_applications_ids @subscribed_applications_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 28 def self.attribute_map { :'name' => :'name', :'subscribed_applications_ids' => :'subscribedApplicationsIds', :'integration_id' => :'integrationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
62 63 64 65 66 67 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 62 def self.openapi_all_of [ :'AudienceIntegrationID', :'UpdateAudience' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 47 def self.openapi_types { :'name' => :'String', :'subscribed_applications_ids' => :'Array<Integer>', :'integration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && subscribed_applications_ids == o.subscribed_applications_ids && integration_id == o.integration_id end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 197 def hash [name, subscribed_applications_ids, integration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@integration_id.nil? && @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if !@integration_id.nil? && @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 135 |
# File 'lib/talon_one_sdk/models/new_multiple_audiences_item.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if !@integration_id.nil? && @integration_id.to_s.length > 1000 return false if !@integration_id.nil? && @integration_id.to_s.length < 1 true end |