Class: TalonOne::NewPriceAdjustment

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_price_adjustment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewPriceAdjustment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewPriceAdjustment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewPriceAdjustment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'price_type')
    self.price_type = attributes[:'price_type']
  else
    self.price_type = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  else
    self.reference_id = nil
  end

  if attributes.key?(:'calculated_at')
    self.calculated_at = attributes[:'calculated_at']
  end

  if attributes.key?(:'effective_from')
    self.effective_from = attributes[:'effective_from']
  end

  if attributes.key?(:'effective_until')
    self.effective_until = attributes[:'effective_until']
  end

  if attributes.key?(:'context_id')
    self.context_id = attributes[:'context_id']
  end
end

Instance Attribute Details

#calculated_atObject

The time at which this price was calculated. If provided, this is used to determine the most recent price adjustment to choose if price adjustments overlap. Defaults to internal creation time if not provided.



28
29
30
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 28

def calculated_at
  @calculated_at
end

#context_idObject

Identifier of the context of this price adjustment (e.g. summer sale).



37
38
39
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 37

def context_id
  @context_id
end

#effective_fromObject

The date and time from which the price adjustment is effective.



31
32
33
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 31

def effective_from
  @effective_from
end

#effective_untilObject

The date and time until which the price adjustment is effective.



34
35
36
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 34

def effective_until
  @effective_until
end

#priceObject

The value of the price type applied to the SKU. When set to ‘null`, the defined price type no longer applies to the SKU.



22
23
24
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 22

def price
  @price
end

#price_typeObject

The price type (e.g. the price for members only) to apply to a given SKU.



19
20
21
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 19

def price_type
  @price_type
end

#reference_idObject

A unique reference identifier, e.g. a UUID.



25
26
27
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 25

def reference_id
  @reference_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 40

def self.attribute_map
  {
    :'price_type' => :'priceType',
    :'price' => :'price',
    :'reference_id' => :'referenceId',
    :'calculated_at' => :'calculatedAt',
    :'effective_from' => :'effectiveFrom',
    :'effective_until' => :'effectiveUntil',
    :'context_id' => :'contextId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 76

def self.openapi_nullable
  Set.new([
    :'price',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 63

def self.openapi_types
  {
    :'price_type' => :'String',
    :'price' => :'Float',
    :'reference_id' => :'String',
    :'calculated_at' => :'Time',
    :'effective_from' => :'Time',
    :'effective_until' => :'Time',
    :'context_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      price_type == o.price_type &&
      price == o.price &&
      reference_id == o.reference_id &&
      calculated_at == o.calculated_at &&
      effective_from == o.effective_from &&
      effective_until == o.effective_until &&
      context_id == o.context_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 207

def hash
  [price_type, price, reference_id, calculated_at, effective_from, effective_until, context_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @price_type.nil?
    invalid_properties.push('invalid value for "price_type", price_type cannot be nil.')
  end

  if @reference_id.nil?
    invalid_properties.push('invalid value for "reference_id", reference_id cannot be nil.')
  end

  if @reference_id.to_s.length < 1
    invalid_properties.push('invalid value for "reference_id", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/new_price_adjustment.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @price_type.nil?
  return false if @reference_id.nil?
  return false if @reference_id.to_s.length < 1
  true
end