Class: TalonOne::NewPriceType
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewPriceType
- Defined in:
- lib/talon_one_sdk/models/new_price_type.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A description of the price type.
-
#name ⇒ Object
The API name of the price type.
-
#targeted_audiences_ids ⇒ Object
A list of the IDs of the audiences targeted by this price type.
-
#title ⇒ Object
The name displayed in the Campaign Manager for the price type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewPriceType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewPriceType
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewPriceType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewPriceType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'targeted_audiences_ids') if (value = attributes[:'targeted_audiences_ids']).is_a?(Array) self.targeted_audiences_ids = value end end end |
Instance Attribute Details
#description ⇒ Object
A description of the price type.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 25 def description @description end |
#name ⇒ Object
The API name of the price type. This is an immutable value.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 19 def name @name end |
#targeted_audiences_ids ⇒ Object
A list of the IDs of the audiences targeted by this price type.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 28 def targeted_audiences_ids @targeted_audiences_ids end |
#title ⇒ Object
The name displayed in the Campaign Manager for the price type.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 22 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 31 def self.attribute_map { :'name' => :'name', :'title' => :'title', :'description' => :'description', :'targeted_audiences_ids' => :'targetedAudiencesIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 187 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 51 def self.openapi_types { :'name' => :'String', :'title' => :'String', :'description' => :'String', :'targeted_audiences_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 163 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && title == o.title && description == o.description && targeted_audiences_ids == o.targeted_audiences_ids end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 180 def hash [name, title, description, targeted_audiences_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end pattern = Regexp.new(/^[A-Za-z]\w*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 |
# File 'lib/talon_one_sdk/models/new_price_type.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name !~ Regexp.new(/^[A-Za-z]\w*$/) return false if @title.nil? true end |