Class: TalonOne::NewReferral

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_referral.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewReferral

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/new_referral.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewReferral` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewReferral`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'advocate_profile_integration_id')
    self.advocate_profile_integration_id = attributes[:'advocate_profile_integration_id']
  else
    self.advocate_profile_integration_id = nil
  end

  if attributes.key?(:'friend_profile_integration_id')
    self.friend_profile_integration_id = attributes[:'friend_profile_integration_id']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end
end

Instance Attribute Details

#advocate_profile_integration_idObject

The Integration ID of the Advocate’s Profile.



31
32
33
# File 'lib/talon_one_sdk/models/new_referral.rb', line 31

def advocate_profile_integration_id
  @advocate_profile_integration_id
end

#attributesObject

Arbitrary properties associated with this item.



37
38
39
# File 'lib/talon_one_sdk/models/new_referral.rb', line 37

def attributes
  @attributes
end

#campaign_idObject

ID of the campaign from which the referral received the referral code.



28
29
30
# File 'lib/talon_one_sdk/models/new_referral.rb', line 28

def campaign_id
  @campaign_id
end

#expiry_dateObject

Expiration date of the referral code. Referral never expires if this is omitted.



22
23
24
# File 'lib/talon_one_sdk/models/new_referral.rb', line 22

def expiry_date
  @expiry_date
end

#friend_profile_integration_idObject

An optional Integration ID of the Friend’s Profile.



34
35
36
# File 'lib/talon_one_sdk/models/new_referral.rb', line 34

def friend_profile_integration_id
  @friend_profile_integration_id
end

#start_dateObject

Timestamp at which point the referral code becomes valid.



19
20
21
# File 'lib/talon_one_sdk/models/new_referral.rb', line 19

def start_date
  @start_date
end

#usage_limitObject

The number of times a referral code can be used. ‘0` means no limit but any campaign usage limits will still apply.



25
26
27
# File 'lib/talon_one_sdk/models/new_referral.rb', line 25

def usage_limit
  @usage_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/new_referral.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/new_referral.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/new_referral.rb', line 40

def self.attribute_map
  {
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'usage_limit' => :'usageLimit',
    :'campaign_id' => :'campaignId',
    :'advocate_profile_integration_id' => :'advocateProfileIntegrationId',
    :'friend_profile_integration_id' => :'friendProfileIntegrationId',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/talon_one_sdk/models/new_referral.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



82
83
84
85
86
# File 'lib/talon_one_sdk/models/new_referral.rb', line 82

def self.openapi_all_of
  [
  :'ReferralConstraints'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/new_referral.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/new_referral.rb', line 63

def self.openapi_types
  {
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'usage_limit' => :'Integer',
    :'campaign_id' => :'Integer',
    :'advocate_profile_integration_id' => :'String',
    :'friend_profile_integration_id' => :'String',
    :'attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
# File 'lib/talon_one_sdk/models/new_referral.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      usage_limit == o.usage_limit &&
      campaign_id == o.campaign_id &&
      advocate_profile_integration_id == o.advocate_profile_integration_id &&
      friend_profile_integration_id == o.friend_profile_integration_id &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/talon_one_sdk/models/new_referral.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/talon_one_sdk/models/new_referral.rb', line 241

def hash
  [start_date, expiry_date, usage_limit, campaign_id, advocate_profile_integration_id, friend_profile_integration_id, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/new_referral.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@usage_limit.nil? && @usage_limit > 999999
    invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.')
  end

  if !@usage_limit.nil? && @usage_limit < 0
    invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @advocate_profile_integration_id.nil?
    invalid_properties.push('invalid value for "advocate_profile_integration_id", advocate_profile_integration_id cannot be nil.')
  end

  if @advocate_profile_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "advocate_profile_integration_id", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/talon_one_sdk/models/new_referral.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/new_referral.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@usage_limit.nil? && @usage_limit > 999999
  return false if !@usage_limit.nil? && @usage_limit < 0
  return false if @campaign_id.nil?
  return false if @advocate_profile_integration_id.nil?
  return false if @advocate_profile_integration_id.to_s.length > 1000
  true
end