Class: TalonOne::NewReferralsForMultipleAdvocates

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewReferralsForMultipleAdvocates

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewReferralsForMultipleAdvocates` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewReferralsForMultipleAdvocates`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'advocate_profile_integration_ids')
    if (value = attributes[:'advocate_profile_integration_ids']).is_a?(Array)
      self.advocate_profile_integration_ids = value
    end
  else
    self.advocate_profile_integration_ids = nil
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'valid_characters')
    if (value = attributes[:'valid_characters']).is_a?(Array)
      self.valid_characters = value
    end
  end

  if attributes.key?(:'referral_pattern')
    self.referral_pattern = attributes[:'referral_pattern']
  end
end

Instance Attribute Details

#advocate_profile_integration_idsObject

An array containing all the respective advocate profiles.



31
32
33
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 31

def advocate_profile_integration_ids
  @advocate_profile_integration_ids
end

#attributesObject

Arbitrary properties associated with this referral code.



34
35
36
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 34

def attributes
  @attributes
end

#campaign_idObject

The ID of the campaign from which the referral received the referral code.



28
29
30
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 28

def campaign_id
  @campaign_id
end

#expiry_dateObject

Expiration date of the referral code. Referral never expires if this is omitted.



22
23
24
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 22

def expiry_date
  @expiry_date
end

#referral_patternObject

The pattern used to generate referrals. The character ‘#` is a placeholder and is replaced by a random character from the `validCharacters` set.



40
41
42
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 40

def referral_pattern
  @referral_pattern
end

#start_dateObject

Timestamp at which point the referral code becomes valid.



19
20
21
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 19

def start_date
  @start_date
end

#usage_limitObject

The number of times a referral code can be used. ‘0` means no limit but any campaign usage limits will still apply.



25
26
27
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 25

def usage_limit
  @usage_limit
end

#valid_charactersObject

List of characters used to generate the random parts of a code. By default, the list of characters is equivalent to the ‘[A-Z, 0-9]` regular expression.



37
38
39
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 37

def valid_characters
  @valid_characters
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 43

def self.attribute_map
  {
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'usage_limit' => :'usageLimit',
    :'campaign_id' => :'campaignId',
    :'advocate_profile_integration_ids' => :'advocateProfileIntegrationIds',
    :'attributes' => :'attributes',
    :'valid_characters' => :'validCharacters',
    :'referral_pattern' => :'referralPattern'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 299

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



87
88
89
90
91
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 87

def self.openapi_all_of
  [
  :'ReferralConstraints'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 67

def self.openapi_types
  {
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'usage_limit' => :'Integer',
    :'campaign_id' => :'Integer',
    :'advocate_profile_integration_ids' => :'Array<String>',
    :'attributes' => :'Object',
    :'valid_characters' => :'Array<String>',
    :'referral_pattern' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 271

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      usage_limit == o.usage_limit &&
      campaign_id == o.campaign_id &&
      advocate_profile_integration_ids == o.advocate_profile_integration_ids &&
      attributes == o.attributes &&
      valid_characters == o.valid_characters &&
      referral_pattern == o.referral_pattern
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 292

def hash
  [start_date, expiry_date, usage_limit, campaign_id, advocate_profile_integration_ids, attributes, valid_characters, referral_pattern].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@usage_limit.nil? && @usage_limit > 999999
    invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.')
  end

  if !@usage_limit.nil? && @usage_limit < 0
    invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @advocate_profile_integration_ids.nil?
    invalid_properties.push('invalid value for "advocate_profile_integration_ids", advocate_profile_integration_ids cannot be nil.')
  end

  if @advocate_profile_integration_ids.length > 1000
    invalid_properties.push('invalid value for "advocate_profile_integration_ids", number of items must be less than or equal to 1000.')
  end

  if @advocate_profile_integration_ids.length < 1
    invalid_properties.push('invalid value for "advocate_profile_integration_ids", number of items must be greater than or equal to 1.')
  end

  if !@referral_pattern.nil? && @referral_pattern.to_s.length > 100
    invalid_properties.push('invalid value for "referral_pattern", the character length must be smaller than or equal to 100.')
  end

  if !@referral_pattern.nil? && @referral_pattern.to_s.length < 3
    invalid_properties.push('invalid value for "referral_pattern", the character length must be greater than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/new_referrals_for_multiple_advocates.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@usage_limit.nil? && @usage_limit > 999999
  return false if !@usage_limit.nil? && @usage_limit < 0
  return false if @campaign_id.nil?
  return false if @advocate_profile_integration_ids.nil?
  return false if @advocate_profile_integration_ids.length > 1000
  return false if @advocate_profile_integration_ids.length < 1
  return false if !@referral_pattern.nil? && @referral_pattern.to_s.length > 100
  return false if !@referral_pattern.nil? && @referral_pattern.to_s.length < 3
  true
end