Class: TalonOne::NewReward
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewReward
- Defined in:
- lib/talon_one_sdk/models/new_reward.rb
Instance Attribute Summary collapse
-
#api_name ⇒ Object
A unique identifier used to reference the reward in API integrations.
-
#application_ids ⇒ Object
The IDs of the Applications this reward is connected to.
-
#bindings ⇒ Object
A list of named variables created before the reward's rules are evaluated.
-
#description ⇒ Object
A description of the reward.
-
#eligibility_conditions ⇒ Object
An optional rule that manages who can see this reward.
-
#name ⇒ Object
The name of the reward.
-
#points_required ⇒ Object
The loyalty points required to activate the reward.
-
#rule ⇒ Object
Rule to apply.
-
#sandbox ⇒ Object
Indicates if this is a live or sandbox reward.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewReward
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewReward
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewReward` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewReward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'api_name') self.api_name = attributes[:'api_name'] else self.api_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'application_ids') if (value = attributes[:'application_ids']).is_a?(Array) self.application_ids = value end else self.application_ids = nil end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] else self.sandbox = nil end if attributes.key?(:'eligibility_conditions') self.eligibility_conditions = attributes[:'eligibility_conditions'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'bindings') if (value = attributes[:'bindings']).is_a?(Array) self.bindings = value end end if attributes.key?(:'points_required') if (value = attributes[:'points_required']).is_a?(Array) self.points_required = value end end end |
Instance Attribute Details
#api_name ⇒ Object
A unique identifier used to reference the reward in API integrations.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 22 def api_name @api_name end |
#application_ids ⇒ Object
The IDs of the Applications this reward is connected to. Note: Currently, a reward can only be connected to one Application.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 28 def application_ids @application_ids end |
#bindings ⇒ Object
A list of named variables created before the reward's rules are evaluated. Each binding pairs a name with a talang expression. The expression is evaluated once and its result is available by name in any rule condition or effect. Bindings must be defined outside of individual rules.
40 41 42 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 40 def bindings @bindings end |
#description ⇒ Object
A description of the reward.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 25 def description @description end |
#eligibility_conditions ⇒ Object
An optional rule that manages who can see this reward. If not specified, the reward is visible to all customers. Note: Only the condition field is evaluated within this rule. The effects field must be an empty array, and bindings are not supported.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 34 def eligibility_conditions @eligibility_conditions end |
#name ⇒ Object
The name of the reward.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 19 def name @name end |
#points_required ⇒ Object
The loyalty points required to activate the reward. Each object defines the specific loyalty program and subledger from which points are deducted when activating the reward. Note: When creating a reward, the id of each entry is ignored and a new entry is always created.
43 44 45 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 43 def points_required @points_required end |
#rule ⇒ Object
Rule to apply. Note: The bindings field inside the rule must not be used in this endpoint. All bindings should be defined at the reward level via the top-level bindings field.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 37 def rule @rule end |
#sandbox ⇒ Object
Indicates if this is a live or sandbox reward. Rewards of a given type can only be connected to Applications of the same type.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 31 def sandbox @sandbox end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 46 def self.attribute_map { :'name' => :'name', :'api_name' => :'apiName', :'description' => :'description', :'application_ids' => :'applicationIds', :'sandbox' => :'sandbox', :'eligibility_conditions' => :'eligibilityConditions', :'rule' => :'rule', :'bindings' => :'bindings', :'points_required' => :'pointsRequired' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 71 def self.openapi_types { :'name' => :'String', :'api_name' => :'String', :'description' => :'String', :'application_ids' => :'Array<Integer>', :'sandbox' => :'Boolean', :'eligibility_conditions' => :'Rule', :'rule' => :'Rule', :'bindings' => :'Array<Binding>', :'points_required' => :'Array<RewardPointsRequired>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 253 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && api_name == o.api_name && description == o.description && application_ids == o.application_ids && sandbox == o.sandbox && eligibility_conditions == o.eligibility_conditions && rule == o.rule && bindings == o.bindings && points_required == o.points_required end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 275 def hash [name, api_name, description, application_ids, sandbox, eligibility_conditions, rule, bindings, points_required].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @api_name.nil? invalid_properties.push('invalid value for "api_name", api_name cannot be nil.') end if @api_name.to_s.length < 1 invalid_properties.push('invalid value for "api_name", the character length must be greater than or equal to 1.') end if @application_ids.nil? invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.') end if @sandbox.nil? invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/talon_one_sdk/models/new_reward.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @api_name.nil? return false if @api_name.to_s.length < 1 return false if @application_ids.nil? return false if @sandbox.nil? true end |