Class: TalonOne::NewRuleset
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewRuleset
- Defined in:
- lib/talon_one_sdk/models/new_ruleset.rb
Instance Attribute Summary collapse
-
#activate ⇒ Object
Indicates whether this created ruleset should be activated for the campaign that owns it.
-
#bindings ⇒ Object
An array that provides objects with variable names (name) and talang expressions to whose result they are bound (expression) during rule evaluation.
-
#rb_version ⇒ Object
The version of the rulebuilder used to create this ruleset.
-
#rules ⇒ Object
Set of rules to apply.
-
#strikethrough_rules ⇒ Object
Set of rules to apply for strikethrough.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewRuleset
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewRuleset
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewRuleset` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewRuleset`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end else self.rules = nil end if attributes.key?(:'strikethrough_rules') if (value = attributes[:'strikethrough_rules']).is_a?(Array) self.strikethrough_rules = value end end if attributes.key?(:'bindings') if (value = attributes[:'bindings']).is_a?(Array) self.bindings = value end else self.bindings = nil end if attributes.key?(:'rb_version') self.rb_version = attributes[:'rb_version'] end if attributes.key?(:'activate') self.activate = attributes[:'activate'] end end |
Instance Attribute Details
#activate ⇒ Object
Indicates whether this created ruleset should be activated for the campaign that owns it.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 31 def activate @activate end |
#bindings ⇒ Object
An array that provides objects with variable names (name) and talang expressions to whose result they are bound (expression) during rule evaluation. The order of the evaluation is decided by the position in the array.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 25 def bindings @bindings end |
#rb_version ⇒ Object
The version of the rulebuilder used to create this ruleset.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 28 def rb_version @rb_version end |
#rules ⇒ Object
Set of rules to apply.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 19 def rules @rules end |
#strikethrough_rules ⇒ Object
Set of rules to apply for strikethrough.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 22 def strikethrough_rules @strikethrough_rules end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 34 def self.attribute_map { :'rules' => :'rules', :'strikethrough_rules' => :'strikethroughRules', :'bindings' => :'bindings', :'rb_version' => :'rbVersion', :'activate' => :'activate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 55 def self.openapi_types { :'rules' => :'Array<Rule>', :'strikethrough_rules' => :'Array<Rule>', :'bindings' => :'Array<Binding>', :'rb_version' => :'String', :'activate' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 171 172 173 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 165 def ==(o) return true if self.equal?(o) self.class == o.class && rules == o.rules && strikethrough_rules == o.strikethrough_rules && bindings == o.bindings && rb_version == o.rb_version && activate == o.activate end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 183 def hash [rules, strikethrough_rules, bindings, rb_version, activate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @rules.nil? invalid_properties.push('invalid value for "rules", rules cannot be nil.') end if @bindings.nil? invalid_properties.push('invalid value for "bindings", bindings cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 |
# File 'lib/talon_one_sdk/models/new_ruleset.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @rules.nil? return false if @bindings.nil? true end |