Class: TalonOne::NewTemplateDef

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_template_def.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewTemplateDef

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewTemplateDef` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewTemplateDef`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'help')
    self.help = attributes[:'help']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'expr')
    if (value = attributes[:'expr']).is_a?(Array)
      self.expr = value
    end
  else
    self.expr = nil
  end

  if attributes.key?(:'args')
    if (value = attributes[:'args']).is_a?(Array)
      self.args = value
    end
  else
    self.args = nil
  end

  if attributes.key?(:'expose')
    self.expose = attributes[:'expose']
  else
    self.expose = false
  end
end

Instance Attribute Details

#argsObject

An array of argument definitions.



34
35
36
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 34

def args
  @args
end

#categoryObject

Used for grouping templates in the rule editor sidebar.



28
29
30
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 28

def category
  @category
end

#descriptionObject

A short description of the template that will be shown in the rule editor.



22
23
24
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 22

def description
  @description
end

#exposeObject

A flag to control exposure in Rule Builder.



37
38
39
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 37

def expose
  @expose
end

#exprObject

A Talang expression that contains variable bindings referring to args.



31
32
33
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 31

def expr
  @expr
end

#helpObject

Extended help text for the template.



25
26
27
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 25

def help
  @help
end

#titleObject

Campaigner-friendly name for the template that will be shown in the rule editor.



19
20
21
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 40

def self.attribute_map
  {
    :'title' => :'title',
    :'description' => :'description',
    :'help' => :'help',
    :'category' => :'category',
    :'expr' => :'expr',
    :'args' => :'args',
    :'expose' => :'expose'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 63

def self.openapi_types
  {
    :'title' => :'String',
    :'description' => :'String',
    :'help' => :'String',
    :'category' => :'String',
    :'expr' => :'Array<Object>',
    :'args' => :'Array<TemplateArgDef>',
    :'expose' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      description == o.description &&
      help == o.help &&
      category == o.category &&
      expr == o.expr &&
      args == o.args &&
      expose == o.expose
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 255

def hash
  [title, description, help, category, expr, args, expose].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @category.to_s.length < 1
    invalid_properties.push('invalid value for "category", the character length must be greater than or equal to 1.')
  end

  if @expr.nil?
    invalid_properties.push('invalid value for "expr", expr cannot be nil.')
  end

  if @args.nil?
    invalid_properties.push('invalid value for "args", args cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/new_template_def.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @title.nil?
  return false if @title.to_s.length < 1
  return false if @category.nil?
  return false if @category.to_s.length < 1
  return false if @expr.nil?
  return false if @args.nil?
  true
end