Class: TalonOne::NewUser

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/talon_one_sdk/models/new_user.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  else
    self.password = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'invite_token')
    self.invite_token = attributes[:'invite_token']
  else
    self.invite_token = nil
  end
end

Instance Attribute Details

#emailObject

The email address associated with the user profile.



19
20
21
# File 'lib/talon_one_sdk/models/new_user.rb', line 19

def email
  @email
end

#invite_tokenObject

Returns the value of attribute invite_token.



27
28
29
# File 'lib/talon_one_sdk/models/new_user.rb', line 27

def invite_token
  @invite_token
end

#nameObject

Your name.



25
26
27
# File 'lib/talon_one_sdk/models/new_user.rb', line 25

def name
  @name
end

#passwordObject

The password for your account.



22
23
24
# File 'lib/talon_one_sdk/models/new_user.rb', line 22

def password
  @password
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/talon_one_sdk/models/new_user.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/new_user.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/talon_one_sdk/models/new_user.rb', line 30

def self.attribute_map
  {
    :'email' => :'email',
    :'password' => :'password',
    :'name' => :'name',
    :'invite_token' => :'inviteToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/talon_one_sdk/models/new_user.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



66
67
68
69
70
# File 'lib/talon_one_sdk/models/new_user.rb', line 66

def self.openapi_all_of
  [
  :'LoginParams'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/talon_one_sdk/models/new_user.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/talon_one_sdk/models/new_user.rb', line 50

def self.openapi_types
  {
    :'email' => :'String',
    :'password' => :'String',
    :'name' => :'String',
    :'invite_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
# File 'lib/talon_one_sdk/models/new_user.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      password == o.password &&
      name == o.name &&
      invite_token == o.invite_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/talon_one_sdk/models/new_user.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/talon_one_sdk/models/new_user.rb', line 199

def hash
  [email, password, name, invite_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/talon_one_sdk/models/new_user.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @password.nil?
    invalid_properties.push('invalid value for "password", password cannot be nil.')
  end

  if @invite_token.nil?
    invalid_properties.push('invalid value for "invite_token", invite_token cannot be nil.')
  end

  if @invite_token.to_s.length < 1
    invalid_properties.push('invalid value for "invite_token", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/talon_one_sdk/models/new_user.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/new_user.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @password.nil?
  return false if @invite_token.nil?
  return false if @invite_token.to_s.length < 1
  true
end