Class: TalonOne::OutgoingIntegrationConfiguration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::OutgoingIntegrationConfiguration
- Defined in:
- lib/talon_one_sdk/models/outgoing_integration_configuration.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account to which this configuration belongs.
-
#id ⇒ Object
Unique ID for this entity.
-
#policy ⇒ Object
The outgoing integration policy specific to each integration type.
-
#type_id ⇒ Object
The outgoing integration type ID.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OutgoingIntegrationConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OutgoingIntegrationConfiguration
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::OutgoingIntegrationConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::OutgoingIntegrationConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'type_id') self.type_id = attributes[:'type_id'] else self.type_id = nil end if attributes.key?(:'policy') self.policy = attributes[:'policy'] else self.policy = nil end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account to which this configuration belongs.
22 23 24 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 22 def account_id @account_id end |
#id ⇒ Object
Unique ID for this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 19 def id @id end |
#policy ⇒ Object
The outgoing integration policy specific to each integration type.
28 29 30 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 28 def policy @policy end |
#type_id ⇒ Object
The outgoing integration type ID.
25 26 27 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 25 def type_id @type_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 31 def self.attribute_map { :'id' => :'id', :'account_id' => :'accountId', :'type_id' => :'typeId', :'policy' => :'policy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 208 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 51 def self.openapi_types { :'id' => :'Integer', :'account_id' => :'Integer', :'type_id' => :'Integer', :'policy' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && account_id == o.account_id && type_id == o.type_id && policy == o.policy end |
#eql?(o) ⇒ Boolean
195 196 197 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 195 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 201 def hash [id, account_id, type_id, policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @type_id.nil? invalid_properties.push('invalid value for "type_id", type_id cannot be nil.') end if @policy.nil? invalid_properties.push('invalid value for "policy", policy cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/outgoing_integration_configuration.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @account_id.nil? return false if @type_id.nil? return false if @policy.nil? true end |