Class: TalonOne::OutgoingIntegrationMoEngagePolicy

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OutgoingIntegrationMoEngagePolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::OutgoingIntegrationMoEngagePolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::OutgoingIntegrationMoEngagePolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  else
    self.base_url = nil
  end

  if attributes.key?(:'app_id')
    self.app_id = attributes[:'app_id']
  else
    self.app_id = nil
  end

  if attributes.key?(:'data_api_id')
    self.data_api_id = attributes[:'data_api_id']
  else
    self.data_api_id = nil
  end

  if attributes.key?(:'data_api_key')
    self.data_api_key = attributes[:'data_api_key']
  else
    self.data_api_key = nil
  end
end

Instance Attribute Details

#app_idObject

MoEngage APP ID. See [MoEngage Developer Guide](developers.moengage.com/hc/en-us/articles/4404674776724-Overview).



22
23
24
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 22

def app_id
  @app_id
end

#base_urlObject

The base URL of your MoEngage deployment, containing the MoEngage data center number (represented by ‘0X`).



19
20
21
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 19

def base_url
  @base_url
end

#data_api_idObject

MoEngage DATA API ID. See [MoEngage Developer Guide](developers.moengage.com/hc/en-us/articles/4404674776724-Overview).



25
26
27
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 25

def data_api_id
  @data_api_id
end

#data_api_keyObject

MoEngage DATA API Key. See [MoEngage Developer Guide](developers.moengage.com/hc/en-us/articles/4404674776724-Overview).



28
29
30
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 28

def data_api_key
  @data_api_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 31

def self.attribute_map
  {
    :'base_url' => :'baseUrl',
    :'app_id' => :'appId',
    :'data_api_id' => :'dataApiId',
    :'data_api_key' => :'dataApiKey'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 51

def self.openapi_types
  {
    :'base_url' => :'String',
    :'app_id' => :'String',
    :'data_api_id' => :'String',
    :'data_api_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      base_url == o.base_url &&
      app_id == o.app_id &&
      data_api_id == o.data_api_id &&
      data_api_key == o.data_api_key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 201

def hash
  [base_url, app_id, data_api_id, data_api_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @base_url.nil?
    invalid_properties.push('invalid value for "base_url", base_url cannot be nil.')
  end

  if @app_id.nil?
    invalid_properties.push('invalid value for "app_id", app_id cannot be nil.')
  end

  if @data_api_id.nil?
    invalid_properties.push('invalid value for "data_api_id", data_api_id cannot be nil.')
  end

  if @data_api_key.nil?
    invalid_properties.push('invalid value for "data_api_key", data_api_key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
140
# File 'lib/talon_one_sdk/models/outgoing_integration_mo_engage_policy.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @base_url.nil?
  return false if @app_id.nil?
  return false if @data_api_id.nil?
  return false if @data_api_key.nil?
  true
end