Class: TalonOne::OutgoingIntegrationTemplateWithConfigurationDetails

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OutgoingIntegrationTemplateWithConfigurationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::OutgoingIntegrationTemplateWithConfigurationDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::OutgoingIntegrationTemplateWithConfigurationDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'integration_type')
    self.integration_type = attributes[:'integration_type']
  else
    self.integration_type = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  else
    self.payload = nil
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'relative_url')
    self.relative_url = attributes[:'relative_url']
  else
    self.relative_url = nil
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  else
    self.headers = nil
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  else
    self.policy = nil
  end
end

Instance Attribute Details

#descriptionObject

The description of the specific outgoing integration template.



28
29
30
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 28

def description
  @description
end

#headersObject

The list of HTTP headers for this integration template.



40
41
42
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 40

def headers
  @headers
end

#idObject

Unique ID for this entity.



19
20
21
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 19

def id
  @id
end

#integration_typeObject

Unique ID of outgoing integration type.



22
23
24
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 22

def integration_type
  @integration_type
end

#methodObject

API method for this webhook.



34
35
36
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 34

def method
  @method
end

#payloadObject

The API payload (supports templating using parameters) for this integration template.



31
32
33
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 31

def payload
  @payload
end

#policyObject

The outgoing integration policy specific to each integration type.



43
44
45
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 43

def policy
  @policy
end

#relative_urlObject

The relative URL corresponding to each integration template.



37
38
39
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 37

def relative_url
  @relative_url
end

#titleObject

The title of the integration template.



25
26
27
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 25

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 68

def self.attribute_map
  {
    :'id' => :'id',
    :'integration_type' => :'integrationType',
    :'title' => :'title',
    :'description' => :'description',
    :'payload' => :'payload',
    :'method' => :'method',
    :'relative_url' => :'relativeUrl',
    :'headers' => :'headers',
    :'policy' => :'policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 412

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



114
115
116
117
118
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 114

def self.openapi_all_of
  [
  :'OutgoingIntegrationTemplate'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 93

def self.openapi_types
  {
    :'id' => :'Integer',
    :'integration_type' => :'Integer',
    :'title' => :'String',
    :'description' => :'String',
    :'payload' => :'String',
    :'method' => :'String',
    :'relative_url' => :'String',
    :'headers' => :'Array<String>',
    :'policy' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 383

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      integration_type == o.integration_type &&
      title == o.title &&
      description == o.description &&
      payload == o.payload &&
      method == o.method &&
      relative_url == o.relative_url &&
      headers == o.headers &&
      policy == o.policy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


399
400
401
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 399

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



405
406
407
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 405

def hash
  [id, integration_type, title, description, payload, method, relative_url, headers, policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @integration_type.nil?
    invalid_properties.push('invalid value for "integration_type", integration_type cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length > 255
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 255.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  if @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be greater than or equal to 1.')
  end

  if @payload.nil?
    invalid_properties.push('invalid value for "payload", payload cannot be nil.')
  end

  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  if @relative_url.nil?
    invalid_properties.push('invalid value for "relative_url", relative_url cannot be nil.')
  end

  if @headers.nil?
    invalid_properties.push('invalid value for "headers", headers cannot be nil.')
  end

  if @policy.nil?
    invalid_properties.push('invalid value for "policy", policy cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 434

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/talon_one_sdk/models/outgoing_integration_template_with_configuration_details.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @integration_type.nil?
  return false if @title.nil?
  return false if @title.to_s.length > 255
  return false if @title.to_s.length < 1
  return false if @description.nil?
  return false if @description.to_s.length > 1000
  return false if @description.to_s.length < 1
  return false if @payload.nil?
  return false if @method.nil?
  method_validator = EnumAttributeValidator.new('String', ["POST", "PUT", "GET", "DELETE", "PATCH"])
  return false unless method_validator.valid?(@method)
  return false if @relative_url.nil?
  return false if @headers.nil?
  return false if @policy.nil?
  true
end