Class: TalonOne::OutgoingIntegrationType

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/outgoing_integration_type.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OutgoingIntegrationType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::OutgoingIntegrationType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::OutgoingIntegrationType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'documentation_link')
    self.documentation_link = attributes[:'documentation_link']
  end
end

Instance Attribute Details

#categoryObject

Category of the outgoing integration.



28
29
30
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 28

def category
  @category
end

#descriptionObject

Description of the outgoing integration.



25
26
27
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 25

def description
  @description
end

Http link to the outgoing integration’s documentation.



31
32
33
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 31

def documentation_link
  @documentation_link
end

#idObject

Unique ID for this entity.



19
20
21
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 19

def id
  @id
end

#nameObject

Name of the outgoing integration.



22
23
24
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 22

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'category' => :'category',
    :'documentation_link' => :'documentationLink'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 55

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'documentation_link' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      category == o.category &&
      documentation_link == o.documentation_link
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 279

def hash
  [id, name, description, category, documentation_link].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 64
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 64.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  if !@description.nil? && @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be greater than or equal to 1.')
  end

  if !@category.nil? && @category.to_s.length > 64
    invalid_properties.push('invalid value for "category", the character length must be smaller than or equal to 64.')
  end

  if !@category.nil? && @category.to_s.length < 1
    invalid_properties.push('invalid value for "category", the character length must be greater than or equal to 1.')
  end

  if !@documentation_link.nil? && @documentation_link.to_s.length > 255
    invalid_properties.push('invalid value for "documentation_link", the character length must be smaller than or equal to 255.')
  end

  if !@documentation_link.nil? && @documentation_link.to_s.length < 1
    invalid_properties.push('invalid value for "documentation_link", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/outgoing_integration_type.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 64
  return false if @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length > 1000
  return false if !@description.nil? && @description.to_s.length < 1
  return false if !@category.nil? && @category.to_s.length > 64
  return false if !@category.nil? && @category.to_s.length < 1
  return false if !@documentation_link.nil? && @documentation_link.to_s.length > 255
  return false if !@documentation_link.nil? && @documentation_link.to_s.length < 1
  true
end