Class: TalonOne::PendingActivePointsData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/pending_active_points_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PendingActivePointsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::PendingActivePointsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::PendingActivePointsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = ''
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  else
    self.customer_profile_id = nil
  end

  if attributes.key?(:'points')
    self.points = attributes[:'points']
  else
    self.points = nil
  end

  if attributes.key?(:'active_on')
    self.active_on = attributes[:'active_on']
  end

  if attributes.key?(:'expire_on')
    self.expire_on = attributes[:'expire_on']
  end

  if attributes.key?(:'session_integration_id')
    self.session_integration_id = attributes[:'session_integration_id']
  end
end

Instance Attribute Details

#active_onObject

The date and time the loyalty points become active.



31
32
33
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 31

def active_on
  @active_on
end

#customer_profile_idObject

The integration ID of the customer profile whose loyalty points are becoming active.



25
26
27
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 25

def customer_profile_id
  @customer_profile_id
end

#expire_onObject

The date and time the loyalty points expire.



34
35
36
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 34

def expire_on
  @expire_on
end

#loyalty_program_idObject

The ID of the loyalty program.



19
20
21
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 19

def loyalty_program_id
  @loyalty_program_id
end

#pointsObject

The amount of pending loyalty points becoming active.



28
29
30
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 28

def points
  @points
end

#session_integration_idObject

The integration ID of the session through which the points were earned.



37
38
39
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 37

def session_integration_id
  @session_integration_id
end

#subledger_idObject

The ID of the subledger, when applicable. If this field is empty, the main ledger is used.



22
23
24
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 22

def subledger_id
  @subledger_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 40

def self.attribute_map
  {
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'subledger_id' => :'SubledgerID',
    :'customer_profile_id' => :'CustomerProfileID',
    :'points' => :'Points',
    :'active_on' => :'ActiveOn',
    :'expire_on' => :'ExpireOn',
    :'session_integration_id' => :'SessionIntegrationID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 63

def self.openapi_types
  {
    :'loyalty_program_id' => :'Integer',
    :'subledger_id' => :'String',
    :'customer_profile_id' => :'String',
    :'points' => :'Float',
    :'active_on' => :'Time',
    :'expire_on' => :'Time',
    :'session_integration_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
229
230
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      loyalty_program_id == o.loyalty_program_id &&
      subledger_id == o.subledger_id &&
      customer_profile_id == o.customer_profile_id &&
      points == o.points &&
      active_on == o.active_on &&
      expire_on == o.expire_on &&
      session_integration_id == o.session_integration_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 240

def hash
  [loyalty_program_id, subledger_id, customer_profile_id, points, active_on, expire_on, session_integration_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @customer_profile_id.nil?
    invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.')
  end

  if @points.nil?
    invalid_properties.push('invalid value for "points", points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
172
# File 'lib/talon_one_sdk/models/pending_active_points_data.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @subledger_id.nil?
  return false if @customer_profile_id.nil?
  return false if @points.nil?
  true
end