Class: TalonOne::Picklist
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Picklist
- Defined in:
- lib/talon_one_sdk/models/picklist.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#created ⇒ Object
The time this entity was created.
-
#created_by ⇒ Object
ID of the user who created this effect.
-
#id ⇒ Object
The internal ID of this entity.
-
#imported ⇒ Object
Imported flag shows that a picklist is imported by a CSV file or not.
-
#modified_by ⇒ Object
ID of the user who last updated this effect if available.
-
#type ⇒ Object
The type of allowed values in the picklist.
-
#values ⇒ Object
The list of allowed values provided by this picklist.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Picklist
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Picklist
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Picklist` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Picklist`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'values') if (value = attributes[:'values']).is_a?(Array) self.values = value end else self.values = nil end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'imported') self.imported = attributes[:'imported'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
37 38 39 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 37 def account_id @account_id end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 22 def created @created end |
#created_by ⇒ Object
ID of the user who created this effect.
34 35 36 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 34 def created_by @created_by end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 19 def id @id end |
#imported ⇒ Object
Imported flag shows that a picklist is imported by a CSV file or not
40 41 42 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 40 def imported @imported end |
#modified_by ⇒ Object
ID of the user who last updated this effect if available.
31 32 33 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 31 def modified_by @modified_by end |
#type ⇒ Object
The type of allowed values in the picklist. If the type ‘time` is chosen, it must be an RFC3339 timestamp string.
25 26 27 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 25 def type @type end |
#values ⇒ Object
The list of allowed values provided by this picklist.
28 29 30 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 28 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 65 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'type' => :'type', :'values' => :'values', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'account_id' => :'accountId', :'imported' => :'imported' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 308 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
109 110 111 112 113 114 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 109 def self.openapi_all_of [ :'Entity', :'NewPicklist' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 89 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'type' => :'String', :'values' => :'Array<String>', :'modified_by' => :'Integer', :'created_by' => :'Integer', :'account_id' => :'Integer', :'imported' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && type == o.type && values == o.values && modified_by == o.modified_by && created_by == o.created_by && account_id == o.account_id && imported == o.imported end |
#eql?(o) ⇒ Boolean
295 296 297 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 295 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 301 def hash [id, created, type, values, modified_by, created_by, account_id, imported].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @values.nil? invalid_properties.push('invalid value for "values", values cannot be nil.') end if @values.length > 50 invalid_properties.push('invalid value for "values", number of items must be less than or equal to 50.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/talon_one_sdk/models/picklist.rb', line 211 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["string", "boolean", "number", "time"]) return false unless type_validator.valid?(@type) return false if @values.nil? return false if @values.length > 50 return false if @created_by.nil? true end |