Class: TalonOne::PriceTypeReferenceDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::PriceTypeReferenceDetail
- Defined in:
- lib/talon_one_sdk/models/price_type_reference_detail.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
The ID of the Application that contains the entity that references the price type.
-
#referencing_id ⇒ Object
The ID of the entity that references the price type.
-
#referencing_name ⇒ Object
The name of the entity that references the price type.
-
#referencing_type ⇒ Object
The entity type that references the price type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PriceTypeReferenceDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PriceTypeReferenceDetail
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::PriceTypeReferenceDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::PriceTypeReferenceDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'referencing_type') self.referencing_type = attributes[:'referencing_type'] else self.referencing_type = nil end if attributes.key?(:'referencing_id') self.referencing_id = attributes[:'referencing_id'] else self.referencing_id = nil end if attributes.key?(:'referencing_name') self.referencing_name = attributes[:'referencing_name'] else self.referencing_name = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end end |
Instance Attribute Details
#application_id ⇒ Object
The ID of the Application that contains the entity that references the price type.
28 29 30 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 28 def application_id @application_id end |
#referencing_id ⇒ Object
The ID of the entity that references the price type.
22 23 24 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 22 def referencing_id @referencing_id end |
#referencing_name ⇒ Object
The name of the entity that references the price type.
25 26 27 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 25 def referencing_name @referencing_name end |
#referencing_type ⇒ Object
The entity type that references the price type. For example, a campaign or an Application cart item filter.
19 20 21 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 19 def referencing_type @referencing_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 53 def self.attribute_map { :'referencing_type' => :'referencingType', :'referencing_id' => :'referencingId', :'referencing_name' => :'referencingName', :'application_id' => :'applicationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 73 def self.openapi_types { :'referencing_type' => :'String', :'referencing_id' => :'Integer', :'referencing_name' => :'String', :'application_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && referencing_type == o.referencing_type && referencing_id == o.referencing_id && referencing_name == o.referencing_name && application_id == o.application_id end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 208 def hash [referencing_type, referencing_id, referencing_name, application_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @referencing_type.nil? invalid_properties.push('invalid value for "referencing_type", referencing_type cannot be nil.') end if @referencing_id.nil? invalid_properties.push('invalid value for "referencing_id", referencing_id cannot be nil.') end if @referencing_name.nil? invalid_properties.push('invalid value for "referencing_name", referencing_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 157 |
# File 'lib/talon_one_sdk/models/price_type_reference_detail.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @referencing_type.nil? referencing_type_validator = EnumAttributeValidator.new('String', ["Campaign", "ApplicationCartItemFilter", "Template"]) return false unless referencing_type_validator.valid?(@referencing_type) return false if @referencing_id.nil? return false if @referencing_name.nil? true end |