Class: TalonOne::RedeemLoyaltyPointsBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RedeemLoyaltyPointsBlock
- Defined in:
- lib/talon_one_sdk/models/redeem_loyalty_points_block.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier for this block.
-
#name ⇒ Object
A custom description recorded as the reason for the point deduction.
-
#on_failure ⇒ Object
Promotion blocks evaluated when this block fails or returns false.
-
#program ⇒ Object
Returns the value of attribute program.
-
#subledger ⇒ Object
The name of the subledger to deduct points from.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RedeemLoyaltyPointsBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RedeemLoyaltyPointsBlock
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RedeemLoyaltyPointsBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RedeemLoyaltyPointsBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'program') self.program = attributes[:'program'] else self.program = nil end if attributes.key?(:'subledger') self.subledger = attributes[:'subledger'] else self.subledger = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'on_failure') if (value = attributes[:'on_failure']).is_a?(Array) self.on_failure = value end end end |
Instance Attribute Details
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 19 def id @id end |
#name ⇒ Object
A custom description recorded as the reason for the point deduction.
35 36 37 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 35 def name @name end |
#on_failure ⇒ Object
Promotion blocks evaluated when this block fails or returns false.
38 39 40 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 38 def on_failure @on_failure end |
#program ⇒ Object
Returns the value of attribute program.
27 28 29 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 27 def program @program end |
#subledger ⇒ Object
The name of the subledger to deduct points from. Can be empty if this block deducts from the loyalty program's main ledger instead of a subledger.
30 31 32 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 30 def subledger @subledger end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 25 def @tags end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 22 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
32 33 34 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 32 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 41 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'program' => :'program', :'subledger' => :'subledger', :'value' => :'value', :'name' => :'name', :'on_failure' => :'onFailure' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 274 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
85 86 87 88 89 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 85 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 65 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'program' => :'RedeemLoyaltyPointsBlock1Program', :'subledger' => :'String', :'value' => :'RedeemLoyaltyPointsBlock1Value', :'name' => :'String', :'on_failure' => :'Array<PromotionBlock>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && program == o.program && subledger == o.subledger && value == o.value && name == o.name && on_failure == o.on_failure end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 267 def hash [id, type, , program, subledger, value, name, on_failure].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @program.nil? invalid_properties.push('invalid value for "program", program cannot be nil.') end if @subledger.nil? invalid_properties.push('invalid value for "subledger", subledger cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 192 |
# File 'lib/talon_one_sdk/models/redeem_loyalty_points_block.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @program.nil? return false if @subledger.nil? return false if @value.nil? true end |