Class: TalonOne::RejectCouponEffectProps

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/reject_coupon_effect_props.rb

Overview

This effect indicates that the coupon code supplied couldn’t be used. You should handle this effect by informing their user the coupon code is invalid.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RejectCouponEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RejectCouponEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RejectCouponEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'rejection_reason')
    self.rejection_reason = attributes[:'rejection_reason']
  else
    self.rejection_reason = nil
  end

  if attributes.key?(:'condition_index')
    self.condition_index = attributes[:'condition_index']
  end

  if attributes.key?(:'effect_index')
    self.effect_index = attributes[:'effect_index']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'campaign_exclusion_reason')
    self.campaign_exclusion_reason = attributes[:'campaign_exclusion_reason']
  end
end

Instance Attribute Details

#campaign_exclusion_reasonObject

The reason why the campaign the coupon belongs to was excluded during [campaign evaluation](docs.talon.one/docs/product/applications/manage-campaign-evaluation), when ‘rejectionReason` was `CouponPartOfNotTriggeredCampaign`. Its possible values are: - `CampaignGaveLowerDiscount`: The required campaign and coupon conditions were met, but another campaign in a [Highest discount value](docs.talon.one/docs/product/applications/manage-campaign-evaluation#set-campaign-evaluation-mode) group offered a higher discount value. - `CampaignIsNotFirst`: The campaign was not evaluated because another campaign in a [First campaign](docs.talon.one/docs/product/applications/manage-campaign-evaluation#set-campaign-evaluation-mode) group was picked and evaluated first. - `CampaignNotInEvaluationSet`: The campaign did not meet other evaluation requirements, for example, because the coupon is part of an archived campaign.



35
36
37
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 35

def campaign_exclusion_reason
  @campaign_exclusion_reason
end

#condition_indexObject

The index of the condition that caused the rejection of the coupon.



26
27
28
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 26

def condition_index
  @condition_index
end

#detailsObject

More details about the failure.



32
33
34
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 32

def details
  @details
end

#effect_indexObject

The index of the effect that caused the rejection of the coupon.



29
30
31
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 29

def effect_index
  @effect_index
end

#rejection_reasonObject

The reason why the code was rejected. - ‘CampaignLimitReached`: The campaign-wide coupon code redemption limit has been reached. - `CouponExpired`: The coupon is expired. - `CouponLimitReached`: The coupon redemption limit or a campaign budget was reached. - `CouponNotFound`: The coupon code is incorrect. - `CouponPartOfNotRunningCampaign`: The campaign the coupon belongs to is currently not active. The campaignId field contains the ID of that campaign. - `CouponRecipientDoesNotMatch`: The given coupon value does not match the recipient or the coupon is linked to a `recipientIntegrationID` but there is no profile in the session. - `CouponRejectedByCondition`: Other conditions failed in the rule or all conditions passed but the `Coupon code is valid` condition is not present. - `CouponStartDateInFuture`: The coupon isn’t active yet. - ‘EffectCouldNotBeApplied`: One of the effects in the campaign wasn’t applied because a limit for that effect was reached (most common use case will be ‘setDiscount` cannot be applied because a discount limit is reached). - `ProfileLimitReached`: The profile-specific coupon redemption limit has been reached. - `CouponPartOfNotTriggeredCampaign`: The campaign the coupon belongs to was not triggered during evaluation (an exclusive or stackable campaign). The `campaignId` field contains the ID of that campaign. - `CouponReservationRequired`: The coupon’s ‘isReservationMandatory` property is `true`, but the profile does not have a reservation. - `ProfileRequired`: The coupon’s ‘isReservationMandatory` property is `true` or a [campaign profile budget](docs.talon.one/docs/product/campaigns/settings/manage-campaign-budgets) was set, but no profile exists in the session.



23
24
25
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 23

def rejection_reason
  @rejection_reason
end

#valueObject

The coupon code that was rejected.



20
21
22
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 20

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 38

def self.attribute_map
  {
    :'value' => :'value',
    :'rejection_reason' => :'rejectionReason',
    :'condition_index' => :'conditionIndex',
    :'effect_index' => :'effectIndex',
    :'details' => :'details',
    :'campaign_exclusion_reason' => :'campaignExclusionReason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 195

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 60

def self.openapi_types
  {
    :'value' => :'String',
    :'rejection_reason' => :'String',
    :'condition_index' => :'Integer',
    :'effect_index' => :'Integer',
    :'details' => :'String',
    :'campaign_exclusion_reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      value == o.value &&
      rejection_reason == o.rejection_reason &&
      condition_index == o.condition_index &&
      effect_index == o.effect_index &&
      details == o.details &&
      campaign_exclusion_reason == o.campaign_exclusion_reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 182

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



188
189
190
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 188

def hash
  [value, rejection_reason, condition_index, effect_index, details, campaign_exclusion_reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @rejection_reason.nil?
    invalid_properties.push('invalid value for "rejection_reason", rejection_reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
145
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @value.nil?
  return false if @rejection_reason.nil?
  true
end