Class: TalonOne::ReturnIntegrationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ReturnIntegrationRequest
- Defined in:
- lib/talon_one_sdk/models/return_integration_request.rb
Overview
The body of a return integration API request. Next to the cart items details, this contains an optional listing of extra properties that should be returned in the response.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_return ⇒ Object
The returned cart items details.
-
#response_content ⇒ Object
Extends the response with the chosen data entities.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReturnIntegrationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReturnIntegrationRequest
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ReturnIntegrationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ReturnIntegrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_return') self._return = attributes[:'_return'] else self._return = nil end if attributes.key?(:'response_content') if (value = attributes[:'response_content']).is_a?(Array) self.response_content = value end end end |
Instance Attribute Details
#_return ⇒ Object
The returned cart items details.
20 21 22 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 20 def _return @_return end |
#response_content ⇒ Object
Extends the response with the chosen data entities. Use this property to get as much data as you need in one _Update customer session_ request instead of sending extra requests to other endpoints.
23 24 25 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 23 def response_content @response_content end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 48 def self.attribute_map { :'_return' => :'return', :'response_content' => :'responseContent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 66 def self.openapi_types { :'_return' => :'NewReturn', :'response_content' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && _return == o._return && response_content == o.response_content end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 155 def hash [_return, response_content].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_return.nil? invalid_properties.push('invalid value for "_return", _return cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 |
# File 'lib/talon_one_sdk/models/return_integration_request.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_return.nil? true end |