Class: TalonOne::ReturnedCartItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ReturnedCartItem
- Defined in:
- lib/talon_one_sdk/models/returned_cart_item.rb
Instance Attribute Summary collapse
-
#position ⇒ Object
The index of the cart item in the provided customer session’s ‘cartItems` property.
-
#quantity ⇒ Object
Number of cart items to return.
-
#sku ⇒ Object
The SKU of the cart item in the provided customer session’s ‘cartItems` property.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReturnedCartItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReturnedCartItem
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ReturnedCartItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ReturnedCartItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end end |
Instance Attribute Details
#position ⇒ Object
The index of the cart item in the provided customer session’s ‘cartItems` property.
19 20 21 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 19 def position @position end |
#quantity ⇒ Object
Number of cart items to return.
22 23 24 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 22 def quantity @quantity end |
#sku ⇒ Object
The SKU of the cart item in the provided customer session’s ‘cartItems` property.
25 26 27 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 25 def sku @sku end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 28 def self.attribute_map { :'position' => :'position', :'quantity' => :'quantity', :'sku' => :'sku' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 47 def self.openapi_types { :'position' => :'Integer', :'quantity' => :'Integer', :'sku' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && position == o.position && quantity == o.quantity && sku == o.sku end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 142 def hash [position, quantity, sku].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 97 98 99 100 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@sku.nil? && @sku.to_s.length < 1 invalid_properties.push('invalid value for "sku", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 |
# File 'lib/talon_one_sdk/models/returned_cart_item.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@sku.nil? && @sku.to_s.length < 1 true end |