Class: TalonOne::RevisionVersion

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/revision_version.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RevisionVersion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/talon_one_sdk/models/revision_version.rb', line 174

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RevisionVersion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RevisionVersion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'active_ruleset_id')
    self.active_ruleset_id = attributes[:'active_ruleset_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'coupon_settings')
    self.coupon_settings = attributes[:'coupon_settings']
  end

  if attributes.key?(:'referral_settings')
    self.referral_settings = attributes[:'referral_settings']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'reevaluate_on_return')
    self.reevaluate_on_return = attributes[:'reevaluate_on_return']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  end

  if attributes.key?(:'coupon_attributes')
    self.coupon_attributes = attributes[:'coupon_attributes']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'revision_id')
    self.revision_id = attributes[:'revision_id']
  else
    self.revision_id = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



58
59
60
# File 'lib/talon_one_sdk/models/revision_version.rb', line 58

def 
  @account_id
end

#active_ruleset_idObject

The ID of the ruleset this campaign will use.



37
38
39
# File 'lib/talon_one_sdk/models/revision_version.rb', line 37

def active_ruleset_id
  @active_ruleset_id
end

#application_idObject

Returns the value of attribute application_id.



60
61
62
# File 'lib/talon_one_sdk/models/revision_version.rb', line 60

def application_id
  @application_id
end

#attributesObject

Arbitrary properties associated with this campaign.



31
32
33
# File 'lib/talon_one_sdk/models/revision_version.rb', line 31

def attributes
  @attributes
end

#campaign_idObject

Returns the value of attribute campaign_id.



62
63
64
# File 'lib/talon_one_sdk/models/revision_version.rb', line 62

def campaign_id
  @campaign_id
end

#coupon_attributesObject

Arbitrary properties associated with coupons in this campaign.



56
57
58
# File 'lib/talon_one_sdk/models/revision_version.rb', line 56

def coupon_attributes
  @coupon_attributes
end

#coupon_settingsObject

Returns the value of attribute coupon_settings.



42
43
44
# File 'lib/talon_one_sdk/models/revision_version.rb', line 42

def coupon_settings
  @coupon_settings
end

#createdObject

Returns the value of attribute created.



64
65
66
# File 'lib/talon_one_sdk/models/revision_version.rb', line 64

def created
  @created
end

#created_byObject

Returns the value of attribute created_by.



66
67
68
# File 'lib/talon_one_sdk/models/revision_version.rb', line 66

def created_by
  @created_by
end

#descriptionObject

A detailed description of the campaign.



34
35
36
# File 'lib/talon_one_sdk/models/revision_version.rb', line 34

def description
  @description
end

#end_timeObject

Timestamp when the campaign will become inactive.



28
29
30
# File 'lib/talon_one_sdk/models/revision_version.rb', line 28

def end_time
  @end_time
end

#featuresObject

A list of features for the campaign.



53
54
55
# File 'lib/talon_one_sdk/models/revision_version.rb', line 53

def features
  @features
end

#idObject

Unique ID for this entity. Not to be confused with the Integration ID, which is set by your integration layer and used in most endpoints.



19
20
21
# File 'lib/talon_one_sdk/models/revision_version.rb', line 19

def id
  @id
end

#limitsObject

The set of limits that will operate for this campaign version.



47
48
49
# File 'lib/talon_one_sdk/models/revision_version.rb', line 47

def limits
  @limits
end

#nameObject

A user-facing name for this campaign.



22
23
24
# File 'lib/talon_one_sdk/models/revision_version.rb', line 22

def name
  @name
end

#reevaluate_on_returnObject

Indicates whether this campaign should be reevaluated when a customer returns an item.



50
51
52
# File 'lib/talon_one_sdk/models/revision_version.rb', line 50

def reevaluate_on_return
  @reevaluate_on_return
end

#referral_settingsObject

Returns the value of attribute referral_settings.



44
45
46
# File 'lib/talon_one_sdk/models/revision_version.rb', line 44

def referral_settings
  @referral_settings
end

#revision_idObject

Returns the value of attribute revision_id.



68
69
70
# File 'lib/talon_one_sdk/models/revision_version.rb', line 68

def revision_id
  @revision_id
end

#start_timeObject

Timestamp when the campaign will become active.



25
26
27
# File 'lib/talon_one_sdk/models/revision_version.rb', line 25

def start_time
  @start_time
end

#tagsObject

A list of tags for the campaign.



40
41
42
# File 'lib/talon_one_sdk/models/revision_version.rb', line 40

def tags
  @tags
end

#versionObject

Returns the value of attribute version.



70
71
72
# File 'lib/talon_one_sdk/models/revision_version.rb', line 70

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



122
123
124
# File 'lib/talon_one_sdk/models/revision_version.rb', line 122

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



127
128
129
# File 'lib/talon_one_sdk/models/revision_version.rb', line 127

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/revision_version.rb', line 95

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'attributes' => :'attributes',
    :'description' => :'description',
    :'active_ruleset_id' => :'activeRulesetId',
    :'tags' => :'tags',
    :'coupon_settings' => :'couponSettings',
    :'referral_settings' => :'referralSettings',
    :'limits' => :'limits',
    :'reevaluate_on_return' => :'reevaluateOnReturn',
    :'features' => :'features',
    :'coupon_attributes' => :'couponAttributes',
    :'account_id' => :'accountId',
    :'application_id' => :'applicationId',
    :'campaign_id' => :'campaignId',
    :'created' => :'created',
    :'created_by' => :'createdBy',
    :'revision_id' => :'revisionId',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/talon_one_sdk/models/revision_version.rb', line 511

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



165
166
167
168
169
170
# File 'lib/talon_one_sdk/models/revision_version.rb', line 165

def self.openapi_all_of
  [
  :'IdentifiableEntity',
  :'NewRevisionVersion'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



159
160
161
162
# File 'lib/talon_one_sdk/models/revision_version.rb', line 159

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/talon_one_sdk/models/revision_version.rb', line 132

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'attributes' => :'Object',
    :'description' => :'String',
    :'active_ruleset_id' => :'Integer',
    :'tags' => :'Array<String>',
    :'coupon_settings' => :'CodeGeneratorSettings',
    :'referral_settings' => :'CodeGeneratorSettings',
    :'limits' => :'Array<LimitConfig>',
    :'reevaluate_on_return' => :'Boolean',
    :'features' => :'Array<String>',
    :'coupon_attributes' => :'Object',
    :'account_id' => :'Integer',
    :'application_id' => :'Integer',
    :'campaign_id' => :'Integer',
    :'created' => :'Time',
    :'created_by' => :'Integer',
    :'revision_id' => :'Integer',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/talon_one_sdk/models/revision_version.rb', line 470

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      attributes == o.attributes &&
      description == o.description &&
      active_ruleset_id == o.active_ruleset_id &&
      tags == o.tags &&
      coupon_settings == o.coupon_settings &&
      referral_settings == o.referral_settings &&
      limits == o.limits &&
      reevaluate_on_return == o.reevaluate_on_return &&
      features == o.features &&
      coupon_attributes == o.coupon_attributes &&
       == o. &&
      application_id == o.application_id &&
      campaign_id == o.campaign_id &&
      created == o.created &&
      created_by == o.created_by &&
      revision_id == o.revision_id &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


498
499
500
# File 'lib/talon_one_sdk/models/revision_version.rb', line 498

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



504
505
506
# File 'lib/talon_one_sdk/models/revision_version.rb', line 504

def hash
  [id, name, start_time, end_time, attributes, description, active_ruleset_id, tags, coupon_settings, referral_settings, limits, reevaluate_on_return, features, coupon_attributes, , application_id, campaign_id, created, created_by, revision_id, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/talon_one_sdk/models/revision_version.rb', line 297

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@tags.nil? && @tags.length > 50
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @revision_id.nil?
    invalid_properties.push('invalid value for "revision_id", revision_id cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/talon_one_sdk/models/revision_version.rb', line 533

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/talon_one_sdk/models/revision_version.rb', line 345

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@tags.nil? && @tags.length > 50
  return false if @account_id.nil?
  return false if @application_id.nil?
  return false if @campaign_id.nil?
  return false if @created.nil?
  return false if @created_by.nil?
  return false if @revision_id.nil?
  return false if @version.nil?
  true
end