Class: TalonOne::RewardCatalogItem

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/reward_catalog_item.rb

Overview

A reward returned by the rewards catalog Integration API endpoint.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RewardCatalogItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RewardCatalogItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RewardCatalogItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'points_required')
    if (value = attributes[:'points_required']).is_a?(Array)
      self.points_required = value
    end
  end

  if attributes.key?(:'rule')
    self.rule = attributes[:'rule']
  else
    self.rule = nil
  end

  if attributes.key?(:'eligibility')
    self.eligibility = attributes[:'eligibility']
  end
end

Instance Attribute Details

#descriptionObject

The customer-facing description of the reward.



26
27
28
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 26

def description
  @description
end

#eligibilityObject

The customer's eligibility for the reward. Returned only when the request includes a profileIntegrationId or loyaltyCardId.



35
36
37
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 35

def eligibility
  @eligibility
end

#idObject

The unique ID of the reward.



20
21
22
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 20

def id
  @id
end

#nameObject

The customer-facing name of the reward.



23
24
25
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 23

def name
  @name
end

#points_requiredObject

The loyalty points required to activate the reward.



29
30
31
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 29

def points_required
  @points_required
end

#ruleObject

Customer-facing rule metadata for the reward.



32
33
34
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 32

def rule
  @rule
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'points_required' => :'pointsRequired',
    :'rule' => :'rule',
    :'eligibility' => :'eligibility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 60

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'points_required' => :'Array<RewardPointsRequired>',
    :'rule' => :'RuleMetadata',
    :'eligibility' => :'RewardEligibility'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      points_required == o.points_required &&
      rule == o.rule &&
      eligibility == o.eligibility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 207

def hash
  [id, name, description, points_required, rule, eligibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @rule.nil?
    invalid_properties.push('invalid value for "rule", rule cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
# File 'lib/talon_one_sdk/models/reward_catalog_item.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @rule.nil?
  true
end