Class: TalonOne::RiskAffectedEntityItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RiskAffectedEntityItem
- Defined in:
- lib/talon_one_sdk/models/risk_affected_entity_item.rb
Overview
A single entity flagged as anomalous within a risk.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activity_value ⇒ Object
The observed value of the monitored activity metric for this entity.
-
#criticality ⇒ Object
The critical classification bucket of this entity.
-
#entity_id ⇒ Object
The integration ID of the affected entity.
-
#severity_ratio ⇒ Object
The ratio of the observed value to the threshold.
-
#threshold ⇒ Object
The anomaly threshold computed for the entity’s Application group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RiskAffectedEntityItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RiskAffectedEntityItem
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RiskAffectedEntityItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RiskAffectedEntityItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] else self.entity_id = nil end if attributes.key?(:'activity_value') self.activity_value = attributes[:'activity_value'] else self.activity_value = nil end if attributes.key?(:'threshold') self.threshold = attributes[:'threshold'] else self.threshold = nil end if attributes.key?(:'severity_ratio') self.severity_ratio = attributes[:'severity_ratio'] else self.severity_ratio = nil end if attributes.key?(:'criticality') self.criticality = attributes[:'criticality'] else self.criticality = nil end end |
Instance Attribute Details
#activity_value ⇒ Object
The observed value of the monitored activity metric for this entity.
23 24 25 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 23 def activity_value @activity_value end |
#criticality ⇒ Object
The critical classification bucket of this entity.
32 33 34 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 32 def criticality @criticality end |
#entity_id ⇒ Object
The integration ID of the affected entity.
20 21 22 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 20 def entity_id @entity_id end |
#severity_ratio ⇒ Object
The ratio of the observed value to the threshold.
29 30 31 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 29 def severity_ratio @severity_ratio end |
#threshold ⇒ Object
The anomaly threshold computed for the entity’s Application group.
26 27 28 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 26 def threshold @threshold end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 57 def self.attribute_map { :'entity_id' => :'entityId', :'activity_value' => :'activityValue', :'threshold' => :'threshold', :'severity_ratio' => :'severityRatio', :'criticality' => :'criticality' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 260 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 78 def self.openapi_types { :'entity_id' => :'String', :'activity_value' => :'Float', :'threshold' => :'Float', :'severity_ratio' => :'Float', :'criticality' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && entity_id == o.entity_id && activity_value == o.activity_value && threshold == o.threshold && severity_ratio == o.severity_ratio && criticality == o.criticality end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 253 def hash [entity_id, activity_value, threshold, severity_ratio, criticality].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @entity_id.nil? invalid_properties.push('invalid value for "entity_id", entity_id cannot be nil.') end if @activity_value.nil? invalid_properties.push('invalid value for "activity_value", activity_value cannot be nil.') end if @threshold.nil? invalid_properties.push('invalid value for "threshold", threshold cannot be nil.') end if @severity_ratio.nil? invalid_properties.push('invalid value for "severity_ratio", severity_ratio cannot be nil.') end if @criticality.nil? invalid_properties.push('invalid value for "criticality", criticality cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/talon_one_sdk/models/risk_affected_entity_item.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @entity_id.nil? return false if @activity_value.nil? return false if @threshold.nil? return false if @severity_ratio.nil? return false if @criticality.nil? criticality_validator = EnumAttributeValidator.new('String', ["critical", "not_critical"]) return false unless criticality_validator.valid?(@criticality) true end |