Class: TalonOne::RiskCriticalityUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/risk_criticality_update.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RiskCriticalityUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RiskCriticalityUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RiskCriticalityUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'risk_ids')
    if (value = attributes[:'risk_ids']).is_a?(Array)
      self.risk_ids = value
    end
  else
    self.risk_ids = nil
  end

  if attributes.key?(:'criticality')
    self.criticality = attributes[:'criticality']
  else
    self.criticality = nil
  end
end

Instance Attribute Details

#criticalityObject

The criticality to assign to risks. Only not_critical is accepted: critical risks can be reclassified as non-critical, but not the other way around.



22
23
24
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 22

def criticality
  @criticality
end

#risk_idsObject

The IDs of the risks to reclassify.



19
20
21
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 19

def risk_ids
  @risk_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 47

def self.attribute_map
  {
    :'risk_ids' => :'riskIds',
    :'criticality' => :'criticality'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 65

def self.openapi_types
  {
    :'risk_ids' => :'Array<Integer>',
    :'criticality' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      risk_ids == o.risk_ids &&
      criticality == o.criticality
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 191

def hash
  [risk_ids, criticality].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @risk_ids.nil?
    invalid_properties.push('invalid value for "risk_ids", risk_ids cannot be nil.')
  end

  if @risk_ids.length > 1000
    invalid_properties.push('invalid value for "risk_ids", number of items must be less than or equal to 1000.')
  end

  if @risk_ids.length < 1
    invalid_properties.push('invalid value for "risk_ids", number of items must be greater than or equal to 1.')
  end

  if @criticality.nil?
    invalid_properties.push('invalid value for "criticality", criticality cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/risk_criticality_update.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @risk_ids.nil?
  return false if @risk_ids.length > 1000
  return false if @risk_ids.length < 1
  return false if @criticality.nil?
  criticality_validator = EnumAttributeValidator.new('String', ["not_critical"])
  return false unless criticality_validator.valid?(@criticality)
  true
end