Class: TalonOne::Role

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/role.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Role

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/talon_one_sdk/models/role.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Role` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Role`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'campaign_group_id')
    self.campaign_group_id = attributes[:'campaign_group_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'members')
    if (value = attributes[:'members']).is_a?(Array)
      self.members = value
    end
  end

  if attributes.key?(:'acl')
    self.acl = attributes[:'acl']
  else
    self.acl = nil
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



28
29
30
# File 'lib/talon_one_sdk/models/role.rb', line 28

def 
  @account_id
end

#aclObject

The ‘Access Control List` json defining the role of the user. This represents the access control on the user level.



43
44
45
# File 'lib/talon_one_sdk/models/role.rb', line 43

def acl
  @acl
end

#campaign_group_idObject

The ID of the [Campaign Group](docs.talon.one/docs/product/account/account-settings/managing-campaign-groups) this role was created for.



31
32
33
# File 'lib/talon_one_sdk/models/role.rb', line 31

def campaign_group_id
  @campaign_group_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/role.rb', line 22

def created
  @created
end

#descriptionObject

Description of the role.



37
38
39
# File 'lib/talon_one_sdk/models/role.rb', line 37

def description
  @description
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/role.rb', line 19

def id
  @id
end

#membersObject

A list of user identifiers assigned to this role.



40
41
42
# File 'lib/talon_one_sdk/models/role.rb', line 40

def members
  @members
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/role.rb', line 25

def modified
  @modified
end

#nameObject

Name of the role.



34
35
36
# File 'lib/talon_one_sdk/models/role.rb', line 34

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/talon_one_sdk/models/role.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/talon_one_sdk/models/role.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/role.rb', line 46

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'account_id' => :'accountId',
    :'campaign_group_id' => :'campaignGroupID',
    :'name' => :'name',
    :'description' => :'description',
    :'members' => :'members',
    :'acl' => :'acl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/talon_one_sdk/models/role.rb', line 303

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



92
93
94
95
96
97
98
# File 'lib/talon_one_sdk/models/role.rb', line 92

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'MutableEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/talon_one_sdk/models/role.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/talon_one_sdk/models/role.rb', line 71

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'account_id' => :'Integer',
    :'campaign_group_id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'members' => :'Array<Integer>',
    :'acl' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/talon_one_sdk/models/role.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
       == o. &&
      campaign_group_id == o.campaign_group_id &&
      name == o.name &&
      description == o.description &&
      members == o.members &&
      acl == o.acl
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


290
291
292
# File 'lib/talon_one_sdk/models/role.rb', line 290

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



296
297
298
# File 'lib/talon_one_sdk/models/role.rb', line 296

def hash
  [id, created, modified, , campaign_group_id, name, description, members, acl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/talon_one_sdk/models/role.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @acl.nil?
    invalid_properties.push('invalid value for "acl", acl cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/talon_one_sdk/models/role.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/role.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @acl.nil?
  true
end