Class: TalonOne::RoleV2Permissions
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RoleV2Permissions
- Defined in:
- lib/talon_one_sdk/models/role_v2_permissions.rb
Instance Attribute Summary collapse
-
#permission_sets ⇒ Object
List of grouped logical operations referenced by roles.
-
#roles ⇒ Object
Returns the value of attribute roles.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoleV2Permissions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RoleV2Permissions
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RoleV2Permissions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RoleV2Permissions`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'permission_sets') if (value = attributes[:'permission_sets']).is_a?(Array) self. = value end end if attributes.key?(:'roles') self.roles = attributes[:'roles'] end end |
Instance Attribute Details
#permission_sets ⇒ Object
List of grouped logical operations referenced by roles.
19 20 21 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 19 def @permission_sets end |
#roles ⇒ Object
Returns the value of attribute roles.
21 22 23 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 21 def roles @roles end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 24 def self.attribute_map { :'permission_sets' => :'permissionSets', :'roles' => :'roles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 140 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 42 def self.openapi_types { :'permission_sets' => :'Array<RoleV2PermissionSet>', :'roles' => :'RoleV2RolesGroup' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && roles == o.roles end |
#eql?(o) ⇒ Boolean
127 128 129 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 127 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 133 def hash [, roles].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 89 90 91 92 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@permission_sets.nil? && @permission_sets.length > 500 invalid_properties.push('invalid value for "permission_sets", number of items must be less than or equal to 500.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
96 97 98 99 100 |
# File 'lib/talon_one_sdk/models/role_v2_permissions.rb', line 96 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@permission_sets.nil? && @permission_sets.length > 500 true end |