Class: TalonOne::RoleV2Readonly

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/role_v2_readonly.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RoleV2Readonly

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 53

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RoleV2Readonly` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RoleV2Readonly`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_readonly')
    self.is_readonly = attributes[:'is_readonly']
  else
    self.is_readonly = false
  end
end

Instance Attribute Details

#is_readonlyObject

Identifies if the role is read-only. For read-only roles, you can only assign or unassign users. You cannot edit any other properties, such as the name, description, or permissions. The ‘isReadonly’ property cannot be set for new or existing roles. It is reserved for predefined roles, such as the Talon.One support role.



19
20
21
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 19

def is_readonly
  @is_readonly
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



29
30
31
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 29

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



34
35
36
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 34

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 22

def self.attribute_map
  {
    :'is_readonly' => :'isReadonly'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 112

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



46
47
48
49
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 46

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



39
40
41
42
43
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 39

def self.openapi_types
  {
    :'is_readonly' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



91
92
93
94
95
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 91

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_readonly == o.is_readonly
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


99
100
101
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 99

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



105
106
107
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 105

def hash
  [is_readonly].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



76
77
78
79
80
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 76

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 134

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



84
85
86
87
# File 'lib/talon_one_sdk/models/role_v2_readonly.rb', line 84

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end