Class: TalonOne::RoleV2RolesGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RoleV2RolesGroup
- Defined in:
- lib/talon_one_sdk/models/role_v2_roles_group.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
Name of the account-level permission set.
-
#applications ⇒ Object
A map of the link between the Application, campaign, or draft campaign-related permission set and the Application ID the permissions apply to.
-
#campaign_access_groups ⇒ Object
A map of the link between the campaign access group-related permission set and the Application ID the permissions apply to.
-
#loyalty_programs ⇒ Object
A map of the link between the loyalty program-related permission set and the Application ID the permissions apply to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoleV2RolesGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RoleV2RolesGroup
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RoleV2RolesGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RoleV2RolesGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'applications') if (value = attributes[:'applications']).is_a?(Hash) self.applications = value end end if attributes.key?(:'loyalty_programs') if (value = attributes[:'loyalty_programs']).is_a?(Hash) self.loyalty_programs = value end end if attributes.key?(:'campaign_access_groups') if (value = attributes[:'campaign_access_groups']).is_a?(Hash) self.campaign_access_groups = value end end if attributes.key?(:'account') self.account = attributes[:'account'] end end |
Instance Attribute Details
#account ⇒ Object
Name of the account-level permission set
28 29 30 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 28 def account @account end |
#applications ⇒ Object
A map of the link between the Application, campaign, or draft campaign-related permission set and the Application ID the permissions apply to.
19 20 21 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 19 def applications @applications end |
#campaign_access_groups ⇒ Object
A map of the link between the campaign access group-related permission set and the Application ID the permissions apply to.
25 26 27 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 25 def campaign_access_groups @campaign_access_groups end |
#loyalty_programs ⇒ Object
A map of the link between the loyalty program-related permission set and the Application ID the permissions apply to.
22 23 24 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 22 def loyalty_programs @loyalty_programs end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 31 def self.attribute_map { :'applications' => :'applications', :'loyalty_programs' => :'loyaltyPrograms', :'campaign_access_groups' => :'campaignAccessGroups', :'account' => :'account' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 146 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 51 def self.openapi_types { :'applications' => :'Hash<String, RoleV2ApplicationDetails>', :'loyalty_programs' => :'Hash<String, String>', :'campaign_access_groups' => :'Hash<String, String>', :'account' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 122 def ==(o) return true if self.equal?(o) self.class == o.class && applications == o.applications && loyalty_programs == o.loyalty_programs && campaign_access_groups == o.campaign_access_groups && account == o.account end |
#eql?(o) ⇒ Boolean
133 134 135 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 133 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 139 def hash [applications, loyalty_programs, campaign_access_groups, account].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 |
# File 'lib/talon_one_sdk/models/role_v2_roles_group.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |