Class: TalonOne::RollbackDeductedLoyaltyPointsEffectProps

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb

Overview

The properties specific to the "rollbackDeductedLoyaltyPoints" effect. This effect is triggered whenever a previously closed session is cancelled and a deductLoyaltyPoints effect was revoked.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RollbackDeductedLoyaltyPointsEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RollbackDeductedLoyaltyPointsEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RollbackDeductedLoyaltyPointsEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'sub_ledger_id')
    self.sub_ledger_id = attributes[:'sub_ledger_id']
  else
    self.sub_ledger_id = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'recipient_integration_id')
    self.recipient_integration_id = attributes[:'recipient_integration_id']
  else
    self.recipient_integration_id = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  else
    self.transaction_uuid = nil
  end

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  end
end

Instance Attribute Details

#card_identifierObject

The card on which these points were added.



41
42
43
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 41

def card_identifier
  @card_identifier
end

#expiry_dateObject

Date after which the reimbursed points will expire.



35
36
37
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 35

def expiry_date
  @expiry_date
end

#program_idObject

The ID of the loyalty program where these points were reimbursed.



20
21
22
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 20

def program_id
  @program_id
end

#recipient_integration_idObject

The user for whom these points were reimbursed.



29
30
31
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 29

def recipient_integration_id
  @recipient_integration_id
end

#start_dateObject

Date after which the reimbursed points will be valid.



32
33
34
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 32

def start_date
  @start_date
end

#sub_ledger_idObject

The ID of the subledger within the loyalty program where these points were reimbursed.



23
24
25
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 23

def sub_ledger_id
  @sub_ledger_id
end

#transaction_uuidObject

The identifier of ‘addition’ entries added to the ledger as the ‘deductLoyaltyPoints` effect is rolled back.



38
39
40
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 38

def transaction_uuid
  @transaction_uuid
end

#valueObject

The amount of reimbursed points that were added.



26
27
28
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 26

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 44

def self.attribute_map
  {
    :'program_id' => :'programId',
    :'sub_ledger_id' => :'subLedgerId',
    :'value' => :'value',
    :'recipient_integration_id' => :'recipientIntegrationId',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'transaction_uuid' => :'transactionUUID',
    :'card_identifier' => :'cardIdentifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 68

def self.openapi_types
  {
    :'program_id' => :'Integer',
    :'sub_ledger_id' => :'String',
    :'value' => :'Float',
    :'recipient_integration_id' => :'String',
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'transaction_uuid' => :'String',
    :'card_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 286

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      program_id == o.program_id &&
      sub_ledger_id == o.sub_ledger_id &&
      value == o.value &&
      recipient_integration_id == o.recipient_integration_id &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      transaction_uuid == o.transaction_uuid &&
      card_identifier == o.card_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 307

def hash
  [program_id, sub_ledger_id, value, recipient_integration_id, start_date, expiry_date, transaction_uuid, card_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @sub_ledger_id.nil?
    invalid_properties.push('invalid value for "sub_ledger_id", sub_ledger_id cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @recipient_integration_id.nil?
    invalid_properties.push('invalid value for "recipient_integration_id", recipient_integration_id cannot be nil.')
  end

  if @recipient_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length > 108
    invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.')
  end

  if !@card_identifier.nil? && @card_identifier.to_s.length < 4
    invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.')
  end

  pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  if !@card_identifier.nil? && @card_identifier !~ pattern
    invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/talon_one_sdk/models/rollback_deducted_loyalty_points_effect_props.rb', line 193

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @program_id.nil?
  return false if @sub_ledger_id.nil?
  return false if @value.nil?
  return false if @recipient_integration_id.nil?
  return false if @recipient_integration_id.to_s.length > 1000
  return false if @transaction_uuid.nil?
  return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108
  return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4
  return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/)
  true
end