Class: TalonOne::RollbackIncreasedAchievementProgressEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RollbackIncreasedAchievementProgressEffectProps
- Defined in:
- lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb
Overview
The properties specific to the "rollbackIncreasedAchievementProgress" effect. This gets triggered whenever a closed session where the ‘increaseAchievementProgress` effect was triggered is cancelled. This is applicable only when the customer has not completed the achievement.
Instance Attribute Summary collapse
-
#achievement_id ⇒ Object
The internal ID of the achievement.
-
#achievement_name ⇒ Object
The name of the achievement.
-
#current_progress ⇒ Object
The current progress of the customer in the achievement.
-
#decrease_progress_by ⇒ Object
The value by which the customer’s current progress in the achievement is decreased.
-
#progress_tracker_id ⇒ Object
The internal ID of the achievement progress tracker.
-
#target ⇒ Object
The target value to complete the achievement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RollbackIncreasedAchievementProgressEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RollbackIncreasedAchievementProgressEffectProps
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RollbackIncreasedAchievementProgressEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RollbackIncreasedAchievementProgressEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'achievement_id') self.achievement_id = attributes[:'achievement_id'] else self.achievement_id = nil end if attributes.key?(:'achievement_name') self.achievement_name = attributes[:'achievement_name'] else self.achievement_name = nil end if attributes.key?(:'progress_tracker_id') self.progress_tracker_id = attributes[:'progress_tracker_id'] else self.progress_tracker_id = nil end if attributes.key?(:'decrease_progress_by') self.decrease_progress_by = attributes[:'decrease_progress_by'] else self.decrease_progress_by = nil end if attributes.key?(:'current_progress') self.current_progress = attributes[:'current_progress'] else self.current_progress = nil end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end end |
Instance Attribute Details
#achievement_id ⇒ Object
The internal ID of the achievement.
20 21 22 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 20 def achievement_id @achievement_id end |
#achievement_name ⇒ Object
The name of the achievement.
23 24 25 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 23 def achievement_name @achievement_name end |
#current_progress ⇒ Object
The current progress of the customer in the achievement.
32 33 34 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 32 def current_progress @current_progress end |
#decrease_progress_by ⇒ Object
The value by which the customer’s current progress in the achievement is decreased.
29 30 31 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 29 def decrease_progress_by @decrease_progress_by end |
#progress_tracker_id ⇒ Object
The internal ID of the achievement progress tracker.
26 27 28 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 26 def progress_tracker_id @progress_tracker_id end |
#target ⇒ Object
The target value to complete the achievement.
35 36 37 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 35 def target @target end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 38 def self.attribute_map { :'achievement_id' => :'achievementId', :'achievement_name' => :'achievementName', :'progress_tracker_id' => :'progressTrackerId', :'decrease_progress_by' => :'decreaseProgressBy', :'current_progress' => :'currentProgress', :'target' => :'target' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 263 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 60 def self.openapi_types { :'achievement_id' => :'Integer', :'achievement_name' => :'String', :'progress_tracker_id' => :'Integer', :'decrease_progress_by' => :'Float', :'current_progress' => :'Float', :'target' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && achievement_id == o.achievement_id && achievement_name == o.achievement_name && progress_tracker_id == o.progress_tracker_id && decrease_progress_by == o.decrease_progress_by && current_progress == o.current_progress && target == o.target end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 256 def hash [achievement_id, achievement_name, progress_tracker_id, decrease_progress_by, current_progress, target].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @achievement_id.nil? invalid_properties.push('invalid value for "achievement_id", achievement_id cannot be nil.') end if @achievement_name.nil? invalid_properties.push('invalid value for "achievement_name", achievement_name cannot be nil.') end if @progress_tracker_id.nil? invalid_properties.push('invalid value for "progress_tracker_id", progress_tracker_id cannot be nil.') end if @decrease_progress_by.nil? invalid_properties.push('invalid value for "decrease_progress_by", decrease_progress_by cannot be nil.') end if @current_progress.nil? invalid_properties.push('invalid value for "current_progress", current_progress cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/talon_one_sdk/models/rollback_increased_achievement_progress_effect_props.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @achievement_id.nil? return false if @achievement_name.nil? return false if @progress_tracker_id.nil? return false if @decrease_progress_by.nil? return false if @current_progress.nil? return false if @target.nil? true end |