Class: TalonOne::Rule

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/rule.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Rule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/rule.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Rule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Rule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'bindings')
    if (value = attributes[:'bindings']).is_a?(Array)
      self.bindings = value
    end
  end

  if attributes.key?(:'condition')
    if (value = attributes[:'condition']).is_a?(Array)
      self.condition = value
    end
  else
    self.condition = nil
  end

  if attributes.key?(:'effects')
    if (value = attributes[:'effects']).is_a?(Array)
      self.effects = value
    end
  else
    self.effects = nil
  end
end

Instance Attribute Details

#bindingsObject

An array that provides objects with variable names (name) and talang expressions to whose result they are bound (expression) during rule evaluation. The order of the evaluation is decided by the position in the array.



31
32
33
# File 'lib/talon_one_sdk/models/rule.rb', line 31

def bindings
  @bindings
end

#conditionObject

A Talang expression that will be evaluated in the context of the given event.



34
35
36
# File 'lib/talon_one_sdk/models/rule.rb', line 34

def condition
  @condition
end

#descriptionObject

A longer, more detailed description of the rule.



28
29
30
# File 'lib/talon_one_sdk/models/rule.rb', line 28

def description
  @description
end

#effectsObject

An array of effectful Talang expressions in arrays that will be evaluated when a rule matches.



37
38
39
# File 'lib/talon_one_sdk/models/rule.rb', line 37

def effects
  @effects
end

#idObject

A unique identifier for the rule.



19
20
21
# File 'lib/talon_one_sdk/models/rule.rb', line 19

def id
  @id
end

#parent_idObject

The ID of the rule that was copied to create this rule.



22
23
24
# File 'lib/talon_one_sdk/models/rule.rb', line 22

def parent_id
  @parent_id
end

#titleObject

A short description of the rule.



25
26
27
# File 'lib/talon_one_sdk/models/rule.rb', line 25

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/rule.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/rule.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/rule.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'parent_id' => :'parentId',
    :'title' => :'title',
    :'description' => :'description',
    :'bindings' => :'bindings',
    :'condition' => :'condition',
    :'effects' => :'effects'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/talon_one_sdk/models/rule.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/talon_one_sdk/models/rule.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/rule.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'parent_id' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'bindings' => :'Array<Binding>',
    :'condition' => :'Array<Object>',
    :'effects' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
# File 'lib/talon_one_sdk/models/rule.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      parent_id == o.parent_id &&
      title == o.title &&
      description == o.description &&
      bindings == o.bindings &&
      condition == o.condition &&
      effects == o.effects
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/talon_one_sdk/models/rule.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/talon_one_sdk/models/rule.rb', line 229

def hash
  [id, parent_id, title, description, bindings, condition, effects].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/rule.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @condition.nil?
    invalid_properties.push('invalid value for "condition", condition cannot be nil.')
  end

  if @condition.length < 1
    invalid_properties.push('invalid value for "condition", number of items must be greater than or equal to 1.')
  end

  if @effects.nil?
    invalid_properties.push('invalid value for "effects", effects cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/rule.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
# File 'lib/talon_one_sdk/models/rule.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @title.nil?
  return false if @condition.nil?
  return false if @condition.length < 1
  return false if @effects.nil?
  true
end