Class: TalonOne::RuleEligibilityFailureDetails

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/rule_eligibility_failure_details.rb

Overview

The details about why the customer was not eligible for the rule in the current session.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RuleEligibilityFailureDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RuleEligibilityFailureDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RuleEligibilityFailureDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  else
    self.failure_code = nil
  end

  if attributes.key?(:'coupon_id')
    self.coupon_id = attributes[:'coupon_id']
  end

  if attributes.key?(:'coupon_value')
    self.coupon_value = attributes[:'coupon_value']
  end

  if attributes.key?(:'referral_id')
    self.referral_id = attributes[:'referral_id']
  end

  if attributes.key?(:'referral_value')
    self.referral_value = attributes[:'referral_value']
  end

  if attributes.key?(:'condition_index')
    self.condition_index = attributes[:'condition_index']
  end

  if attributes.key?(:'effect_index')
    self.effect_index = attributes[:'effect_index']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  else
    self.details = nil
  end
end

Instance Attribute Details

#condition_indexObject

The index of the condition that caused the rule to fail.



35
36
37
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 35

def condition_index
  @condition_index
end

#coupon_idObject

The ID of the coupon that was being evaluated when the rule failed.



23
24
25
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 23

def coupon_id
  @coupon_id
end

#coupon_valueObject

The coupon code that was being evaluated when the rule failed.



26
27
28
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 26

def coupon_value
  @coupon_value
end

#detailsObject

Additional details about the failure.



41
42
43
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 41

def details
  @details
end

#effect_indexObject

The index of the effect that caused the rule to fail.



38
39
40
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 38

def effect_index
  @effect_index
end

#failure_codeObject

A code identifying why the customer was not eligible for the rule in the current session.



20
21
22
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 20

def failure_code
  @failure_code
end

#referral_idObject

The ID of the referral that was being evaluated when the rule failed.



29
30
31
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 29

def referral_id
  @referral_id
end

#referral_valueObject

The referral code that was being evaluated when the rule failed.



32
33
34
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 32

def referral_value
  @referral_value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 66

def self.attribute_map
  {
    :'failure_code' => :'failureCode',
    :'coupon_id' => :'couponID',
    :'coupon_value' => :'couponValue',
    :'referral_id' => :'referralID',
    :'referral_value' => :'referralValue',
    :'condition_index' => :'conditionIndex',
    :'effect_index' => :'effectIndex',
    :'details' => :'details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 90

def self.openapi_types
  {
    :'failure_code' => :'String',
    :'coupon_id' => :'Integer',
    :'coupon_value' => :'String',
    :'referral_id' => :'Integer',
    :'referral_value' => :'String',
    :'condition_index' => :'Integer',
    :'effect_index' => :'Integer',
    :'details' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      failure_code == o.failure_code &&
      coupon_id == o.coupon_id &&
      coupon_value == o.coupon_value &&
      referral_id == o.referral_id &&
      referral_value == o.referral_value &&
      condition_index == o.condition_index &&
      effect_index == o.effect_index &&
      details == o.details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 232

def hash
  [failure_code, coupon_id, coupon_value, referral_id, referral_value, condition_index, effect_index, details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @failure_code.nil?
    invalid_properties.push('invalid value for "failure_code", failure_code cannot be nil.')
  end

  if @details.nil?
    invalid_properties.push('invalid value for "details", details cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
184
185
186
187
# File 'lib/talon_one_sdk/models/rule_eligibility_failure_details.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @failure_code.nil?
  failure_code_validator = EnumAttributeValidator.new('String', ["CONDITION_NOT_MET", "EFFECT_FAILED"])
  return false unless failure_code_validator.valid?(@failure_code)
  return false if @details.nil?
  true
end