Class: TalonOne::RuleMetadata

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/rule_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RuleMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RuleMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RuleMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'display_description')
    self.display_description = attributes[:'display_description']
  end

  if attributes.key?(:'related_data')
    self.related_data = attributes[:'related_data']
  end

  if attributes.key?(:'eligibility')
    if (value = attributes[:'eligibility']).is_a?(Array)
      self.eligibility = value
    end
  end
end

Instance Attribute Details

#display_descriptionObject

A customer-facing description that explains the details of the rule. For example, this property can contain details about eligibility requirements, reward timelines, or terms and conditions.



25
26
27
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 25

def display_description
  @display_description
end

#display_nameObject

A customer-facing name for the rule.



22
23
24
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 22

def display_name
  @display_name
end

#eligibilityObject

Returns the value of attribute eligibility.



30
31
32
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 30

def eligibility
  @eligibility
end

Any additional data associated with the rule, such as an image URL, vendor name, or a content management system (CMS) ID.



28
29
30
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 28

def related_data
  @related_data
end

#titleObject

A short description of the rule.



19
20
21
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 33

def self.attribute_map
  {
    :'title' => :'title',
    :'display_name' => :'displayName',
    :'display_description' => :'displayDescription',
    :'related_data' => :'relatedData',
    :'eligibility' => :'eligibility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 54

def self.openapi_types
  {
    :'title' => :'String',
    :'display_name' => :'String',
    :'display_description' => :'String',
    :'related_data' => :'String',
    :'eligibility' => :'Array<RuleEligibility>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
150
151
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      display_name == o.display_name &&
      display_description == o.display_description &&
      related_data == o.related_data &&
      eligibility == o.eligibility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 161

def hash
  [title, display_name, display_description, related_data, eligibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
129
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @title.nil?
  true
end