Class: TalonOne::Ruleset

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/ruleset.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ruleset

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/talon_one_sdk/models/ruleset.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Ruleset` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Ruleset`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  else
    self.rules = nil
  end

  if attributes.key?(:'strikethrough_rules')
    if (value = attributes[:'strikethrough_rules']).is_a?(Array)
      self.strikethrough_rules = value
    end
  end

  if attributes.key?(:'bindings')
    if (value = attributes[:'bindings']).is_a?(Array)
      self.bindings = value
    end
  else
    self.bindings = nil
  end

  if attributes.key?(:'rb_version')
    self.rb_version = attributes[:'rb_version']
  end

  if attributes.key?(:'activate')
    self.activate = attributes[:'activate']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'activated_at')
    self.activated_at = attributes[:'activated_at']
  end
end

Instance Attribute Details

#activateObject

Indicates whether this created ruleset should be activated for the campaign that owns it.



40
41
42
# File 'lib/talon_one_sdk/models/ruleset.rb', line 40

def activate
  @activate
end

#activated_atObject

Timestamp indicating when this Ruleset was activated.



49
50
51
# File 'lib/talon_one_sdk/models/ruleset.rb', line 49

def activated_at
  @activated_at
end

#bindingsObject

An array that provides objects with variable names (name) and talang expressions to whose result they are bound (expression) during rule evaluation. The order of the evaluation is decided by the position in the array.



34
35
36
# File 'lib/talon_one_sdk/models/ruleset.rb', line 34

def bindings
  @bindings
end

#campaign_idObject

The ID of the campaign that owns this entity.



43
44
45
# File 'lib/talon_one_sdk/models/ruleset.rb', line 43

def campaign_id
  @campaign_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/ruleset.rb', line 22

def created
  @created
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/ruleset.rb', line 19

def id
  @id
end

#rb_versionObject

The version of the rulebuilder used to create this ruleset.



37
38
39
# File 'lib/talon_one_sdk/models/ruleset.rb', line 37

def rb_version
  @rb_version
end

#rulesObject

Set of rules to apply.



28
29
30
# File 'lib/talon_one_sdk/models/ruleset.rb', line 28

def rules
  @rules
end

#strikethrough_rulesObject

Set of rules to apply for strikethrough.



31
32
33
# File 'lib/talon_one_sdk/models/ruleset.rb', line 31

def strikethrough_rules
  @strikethrough_rules
end

#template_idObject

The ID of the campaign template that owns this entity.



46
47
48
# File 'lib/talon_one_sdk/models/ruleset.rb', line 46

def template_id
  @template_id
end

#user_idObject

The ID of the user associated with this entity.



25
26
27
# File 'lib/talon_one_sdk/models/ruleset.rb', line 25

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/ruleset.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/ruleset.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/ruleset.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'user_id' => :'userId',
    :'rules' => :'rules',
    :'strikethrough_rules' => :'strikethroughRules',
    :'bindings' => :'bindings',
    :'rb_version' => :'rbVersion',
    :'activate' => :'activate',
    :'campaign_id' => :'campaignId',
    :'template_id' => :'templateId',
    :'activated_at' => :'activatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/talon_one_sdk/models/ruleset.rb', line 310

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/ruleset.rb', line 102

def self.openapi_all_of
  [
  :'Entity',
  :'NewRuleset',
  :'UserEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/ruleset.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/ruleset.rb', line 79

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'user_id' => :'Integer',
    :'rules' => :'Array<Rule>',
    :'strikethrough_rules' => :'Array<Rule>',
    :'bindings' => :'Array<Binding>',
    :'rb_version' => :'String',
    :'activate' => :'Boolean',
    :'campaign_id' => :'Integer',
    :'template_id' => :'Integer',
    :'activated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/talon_one_sdk/models/ruleset.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      user_id == o.user_id &&
      rules == o.rules &&
      strikethrough_rules == o.strikethrough_rules &&
      bindings == o.bindings &&
      rb_version == o.rb_version &&
      activate == o.activate &&
      campaign_id == o.campaign_id &&
      template_id == o.template_id &&
      activated_at == o.activated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/talon_one_sdk/models/ruleset.rb', line 297

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



303
304
305
# File 'lib/talon_one_sdk/models/ruleset.rb', line 303

def hash
  [id, created, user_id, rules, strikethrough_rules, bindings, rb_version, activate, campaign_id, template_id, activated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/talon_one_sdk/models/ruleset.rb', line 189

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @rules.nil?
    invalid_properties.push('invalid value for "rules", rules cannot be nil.')
  end

  if @bindings.nil?
    invalid_properties.push('invalid value for "bindings", bindings cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/talon_one_sdk/models/ruleset.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
# File 'lib/talon_one_sdk/models/ruleset.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @user_id.nil?
  return false if @rules.nil?
  return false if @bindings.nil?
  true
end