Class: TalonOne::RulesetV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RulesetV2
- Defined in:
- lib/talon_one_sdk/models/ruleset_v2.rb
Overview
Ruleset in the V2 JSON block format.
Instance Attribute Summary collapse
-
#activated_at ⇒ Object
Timestamp indicating when this ruleset was activated.
-
#bundles ⇒ Object
Variable bindings of type bundle.
-
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
-
#created ⇒ Object
The time this entity was created.
-
#id ⇒ Object
Internal ID of this entity.
-
#parameters ⇒ Object
Variable bindings of type template parameter.
-
#promotion_rules ⇒ Object
Set of promotion rules.
-
#selectors ⇒ Object
Variable bindings of type selector.
-
#strikethrough_rules ⇒ Object
Set of strikethrough rules.
-
#template_id ⇒ Object
The ID of the campaign template that owns this entity.
-
#user_id ⇒ Object
The ID of the user that created this ruleset.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RulesetV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RulesetV2
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RulesetV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RulesetV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'activated_at') self.activated_at = attributes[:'activated_at'] end if attributes.key?(:'promotion_rules') if (value = attributes[:'promotion_rules']).is_a?(Array) self.promotion_rules = value end else self.promotion_rules = nil end if attributes.key?(:'strikethrough_rules') if (value = attributes[:'strikethrough_rules']).is_a?(Array) self.strikethrough_rules = value end else self.strikethrough_rules = nil end if attributes.key?(:'selectors') if (value = attributes[:'selectors']).is_a?(Array) self.selectors = value end end if attributes.key?(:'bundles') if (value = attributes[:'bundles']).is_a?(Array) self.bundles = value end end if attributes.key?(:'parameters') if (value = attributes[:'parameters']).is_a?(Array) self.parameters = value end end end |
Instance Attribute Details
#activated_at ⇒ Object
Timestamp indicating when this ruleset was activated.
35 36 37 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 35 def activated_at @activated_at end |
#bundles ⇒ Object
Variable bindings of type bundle.
47 48 49 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 47 def bundles @bundles end |
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
29 30 31 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 29 def campaign_id @campaign_id end |
#created ⇒ Object
The time this entity was created.
23 24 25 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 23 def created @created end |
#id ⇒ Object
Internal ID of this entity.
20 21 22 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 20 def id @id end |
#parameters ⇒ Object
Variable bindings of type template parameter.
50 51 52 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 50 def parameters @parameters end |
#promotion_rules ⇒ Object
Set of promotion rules.
38 39 40 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 38 def promotion_rules @promotion_rules end |
#selectors ⇒ Object
Variable bindings of type selector.
44 45 46 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 44 def selectors @selectors end |
#strikethrough_rules ⇒ Object
Set of strikethrough rules.
41 42 43 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 41 def strikethrough_rules @strikethrough_rules end |
#template_id ⇒ Object
The ID of the campaign template that owns this entity.
32 33 34 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 32 def template_id @template_id end |
#user_id ⇒ Object
The ID of the user that created this ruleset.
26 27 28 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 26 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 53 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'user_id' => :'userId', :'campaign_id' => :'campaignId', :'template_id' => :'templateId', :'activated_at' => :'activatedAt', :'promotion_rules' => :'promotionRules', :'strikethrough_rules' => :'strikethroughRules', :'selectors' => :'selectors', :'bundles' => :'bundles', :'parameters' => :'parameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 80 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'user_id' => :'Integer', :'campaign_id' => :'Integer', :'template_id' => :'Integer', :'activated_at' => :'Time', :'promotion_rules' => :'Array<PromotionRuleV2>', :'strikethrough_rules' => :'Array<StrikethroughRuleV2>', :'selectors' => :'Array<Hash<String, Object>>', :'bundles' => :'Array<Hash<String, Object>>', :'parameters' => :'Array<Hash<String, Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && user_id == o.user_id && campaign_id == o.campaign_id && template_id == o.template_id && activated_at == o.activated_at && promotion_rules == o.promotion_rules && strikethrough_rules == o.strikethrough_rules && selectors == o.selectors && bundles == o.bundles && parameters == o.parameters end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 299 def hash [id, created, user_id, campaign_id, template_id, activated_at, promotion_rules, strikethrough_rules, selectors, bundles, parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @promotion_rules.nil? invalid_properties.push('invalid value for "promotion_rules", promotion_rules cannot be nil.') end if @strikethrough_rules.nil? invalid_properties.push('invalid value for "strikethrough_rules", strikethrough_rules cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 |
# File 'lib/talon_one_sdk/models/ruleset_v2.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @user_id.nil? return false if @promotion_rules.nil? return false if @strikethrough_rules.nil? true end |