Class: TalonOne::SamlConnection

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/saml_connection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SamlConnection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SamlConnection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SamlConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  else
    self.issuer = nil
  end

  if attributes.key?(:'sign_on_url')
    self.sign_on_url = attributes[:'sign_on_url']
  else
    self.sign_on_url = nil
  end

  if attributes.key?(:'sign_out_url')
    self.sign_out_url = attributes[:'sign_out_url']
  end

  if attributes.key?(:'metadata_url')
    self. = attributes[:'metadata_url']
  end

  if attributes.key?(:'audience_uri')
    self.audience_uri = attributes[:'audience_uri']
  else
    self.audience_uri = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'assertion_consumer_service_url')
    self.assertion_consumer_service_url = attributes[:'assertion_consumer_service_url']
  else
    self.assertion_consumer_service_url = nil
  end

  if attributes.key?(:'certificate_expiry')
    self.certificate_expiry = attributes[:'certificate_expiry']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



19
20
21
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 19

def 
  @account_id
end

#assertion_consumer_service_urlObject

The location where the SAML assertion is sent with a HTTP POST.



49
50
51
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 49

def assertion_consumer_service_url
  @assertion_consumer_service_url
end

#audience_uriObject

The application-defined unique identifier that is the intended audience of the SAML assertion. This is most often the SP Entity ID of your application. When not specified, the ACS URL will be used.



40
41
42
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 40

def audience_uri
  @audience_uri
end

#certificate_expiryObject

The expiry date of the X.509 certificate.



52
53
54
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 52

def certificate_expiry
  @certificate_expiry
end

#createdObject

The time this entity was created.



46
47
48
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 46

def created
  @created
end

#enabledObject

Determines if this SAML connection active.



25
26
27
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 25

def enabled
  @enabled
end

#idObject

The internal ID of this entity.



43
44
45
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 43

def id
  @id
end

#issuerObject

Identity Provider Entity ID.



28
29
30
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 28

def issuer
  @issuer
end

#metadata_urlObject

Metadata URL.



37
38
39
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 37

def 
  @metadata_url
end

#nameObject

ID of the SAML service.



22
23
24
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 22

def name
  @name
end

#sign_on_urlObject

Single Sign-On URL.



31
32
33
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 31

def sign_on_url
  @sign_on_url
end

#sign_out_urlObject

Single Sign-Out URL.



34
35
36
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 34

def sign_out_url
  @sign_out_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 55

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'issuer' => :'issuer',
    :'sign_on_url' => :'signOnURL',
    :'sign_out_url' => :'signOutURL',
    :'metadata_url' => :'metadataURL',
    :'audience_uri' => :'audienceURI',
    :'id' => :'id',
    :'created' => :'created',
    :'assertion_consumer_service_url' => :'assertionConsumerServiceURL',
    :'certificate_expiry' => :'certificateExpiry'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 408

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



107
108
109
110
111
112
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 107

def self.openapi_all_of
  [
  :'BaseSamlConnection',
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 83

def self.openapi_types
  {
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'enabled' => :'Boolean',
    :'issuer' => :'String',
    :'sign_on_url' => :'String',
    :'sign_out_url' => :'String',
    :'metadata_url' => :'String',
    :'audience_uri' => :'String',
    :'id' => :'Integer',
    :'created' => :'Time',
    :'assertion_consumer_service_url' => :'String',
    :'certificate_expiry' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 376

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      enabled == o.enabled &&
      issuer == o.issuer &&
      sign_on_url == o.sign_on_url &&
      sign_out_url == o.sign_out_url &&
       == o. &&
      audience_uri == o.audience_uri &&
      id == o.id &&
      created == o.created &&
      assertion_consumer_service_url == o.assertion_consumer_service_url &&
      certificate_expiry == o.certificate_expiry
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


395
396
397
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 395

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



401
402
403
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 401

def hash
  [, name, enabled, issuer, sign_on_url, sign_out_url, , audience_uri, id, created, assertion_consumer_service_url, certificate_expiry].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @issuer.nil?
    invalid_properties.push('invalid value for "issuer", issuer cannot be nil.')
  end

  if @issuer.to_s.length < 1
    invalid_properties.push('invalid value for "issuer", the character length must be greater than or equal to 1.')
  end

  if @sign_on_url.nil?
    invalid_properties.push('invalid value for "sign_on_url", sign_on_url cannot be nil.')
  end

  if @sign_on_url.to_s.length < 1
    invalid_properties.push('invalid value for "sign_on_url", the character length must be greater than or equal to 1.')
  end

  if @audience_uri.nil?
    invalid_properties.push('invalid value for "audience_uri", audience_uri cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @assertion_consumer_service_url.nil?
    invalid_properties.push('invalid value for "assertion_consumer_service_url", assertion_consumer_service_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 430

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/saml_connection.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @enabled.nil?
  return false if @issuer.nil?
  return false if @issuer.to_s.length < 1
  return false if @sign_on_url.nil?
  return false if @sign_on_url.to_s.length < 1
  return false if @audience_uri.nil?
  return false if @id.nil?
  return false if @created.nil?
  return false if @assertion_consumer_service_url.nil?
  true
end