Class: TalonOne::ScimGroup

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/scim_group.rb

Overview

Define the schema for groups created using the SCIM provisioning protocol. In Talon.One, a ‘Group` corresponds to a [role](docs.talon.one/docs/product/account/account-settings/managing-roles), and `members` are the [users](docs.talon.one/docs/product/account/account-settings/managing-users) assigned to that role.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScimGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/scim_group.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ScimGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ScimGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'members')
    if (value = attributes[:'members']).is_a?(Array)
      self.members = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end
end

Instance Attribute Details

#display_nameObject

Display name of the group (Talon.One role).



20
21
22
# File 'lib/talon_one_sdk/models/scim_group.rb', line 20

def display_name
  @display_name
end

#idObject

ID of the group.



26
27
28
# File 'lib/talon_one_sdk/models/scim_group.rb', line 26

def id
  @id
end

#membersObject

List of members to assign to the new Talon.One role.



23
24
25
# File 'lib/talon_one_sdk/models/scim_group.rb', line 23

def members
  @members
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/talon_one_sdk/models/scim_group.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/talon_one_sdk/models/scim_group.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/talon_one_sdk/models/scim_group.rb', line 29

def self.attribute_map
  {
    :'display_name' => :'displayName',
    :'members' => :'members',
    :'id' => :'id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/scim_group.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



63
64
65
66
67
# File 'lib/talon_one_sdk/models/scim_group.rb', line 63

def self.openapi_all_of
  [
  :'ScimBaseGroup'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/talon_one_sdk/models/scim_group.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/scim_group.rb', line 48

def self.openapi_types
  {
    :'display_name' => :'String',
    :'members' => :'Array<ScimGroupMember>',
    :'id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
140
# File 'lib/talon_one_sdk/models/scim_group.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_name == o.display_name &&
      members == o.members &&
      id == o.id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


144
145
146
# File 'lib/talon_one_sdk/models/scim_group.rb', line 144

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



150
151
152
# File 'lib/talon_one_sdk/models/scim_group.rb', line 150

def hash
  [display_name, members, id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
# File 'lib/talon_one_sdk/models/scim_group.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/scim_group.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
120
# File 'lib/talon_one_sdk/models/scim_group.rb', line 116

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end