Class: TalonOne::ScimNewUser

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/scim_new_user.rb

Overview

Payload for users that are created using the SCIM provisioning protocol with an identity provider, for example, Microsoft Entra ID.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScimNewUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ScimNewUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ScimNewUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  else
    self.user_name = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#activeObject

Status of the user.



20
21
22
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 20

def active
  @active
end

#display_nameObject

Display name of the user.



23
24
25
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 23

def display_name
  @display_name
end

#nameObject

Returns the value of attribute name.



28
29
30
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 28

def name
  @name
end

#user_nameObject

Unique identifier of the user. This is usually an email address.



26
27
28
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 26

def user_name
  @user_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 31

def self.attribute_map
  {
    :'active' => :'active',
    :'display_name' => :'displayName',
    :'user_name' => :'userName',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 164

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



67
68
69
70
71
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 67

def self.openapi_all_of
  [
  :'ScimBaseUser'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 51

def self.openapi_types
  {
    :'active' => :'Boolean',
    :'display_name' => :'String',
    :'user_name' => :'String',
    :'name' => :'ScimBaseUserName'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      display_name == o.display_name &&
      user_name == o.user_name &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 151

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



157
158
159
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 157

def hash
  [active, display_name, user_name, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @user_name.nil?
    invalid_properties.push('invalid value for "user_name", user_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
125
126
# File 'lib/talon_one_sdk/models/scim_new_user.rb', line 122

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @user_name.nil?
  true
end