Class: TalonOne::ScimServiceProviderConfigResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/scim_service_provider_config_response.rb

Overview

Service provider configuration details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScimServiceProviderConfigResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ScimServiceProviderConfigResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ScimServiceProviderConfigResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bulk')
    self.bulk = attributes[:'bulk']
  end

  if attributes.key?(:'change_password')
    self.change_password = attributes[:'change_password']
  end

  if attributes.key?(:'documentation_uri')
    self.documentation_uri = attributes[:'documentation_uri']
  end

  if attributes.key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.key?(:'patch')
    self.patch = attributes[:'patch']
  end

  if attributes.key?(:'schemas')
    if (value = attributes[:'schemas']).is_a?(Array)
      self.schemas = value
    end
  end

  if attributes.key?(:'sort')
    self.sort = attributes[:'sort']
  end
end

Instance Attribute Details

#bulkObject

Returns the value of attribute bulk.



19
20
21
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 19

def bulk
  @bulk
end

#change_passwordObject

Returns the value of attribute change_password.



21
22
23
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 21

def change_password
  @change_password
end

#documentation_uriObject

The URI that points to the SCIM service provider’s documentation, providing further details about the service’s capabilities and usage.



24
25
26
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 24

def documentation_uri
  @documentation_uri
end

#filterObject

Returns the value of attribute filter.



26
27
28
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 26

def filter
  @filter
end

#patchObject

Returns the value of attribute patch.



28
29
30
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 28

def patch
  @patch
end

#schemasObject

A list of SCIM schemas that define the structure and data types supported by the service provider.



31
32
33
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 31

def schemas
  @schemas
end

#sortObject

Returns the value of attribute sort.



33
34
35
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 33

def sort
  @sort
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 36

def self.attribute_map
  {
    :'bulk' => :'bulk',
    :'change_password' => :'changePassword',
    :'documentation_uri' => :'documentationUri',
    :'filter' => :'filter',
    :'patch' => :'patch',
    :'schemas' => :'schemas',
    :'sort' => :'sort'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 59

def self.openapi_types
  {
    :'bulk' => :'ScimServiceProviderConfigResponseBulk',
    :'change_password' => :'ScimServiceProviderConfigResponseChangePassword',
    :'documentation_uri' => :'String',
    :'filter' => :'ScimServiceProviderConfigResponseFilter',
    :'patch' => :'ScimServiceProviderConfigResponsePatch',
    :'schemas' => :'Array<String>',
    :'sort' => :'ScimServiceProviderConfigResponseSort'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bulk == o.bulk &&
      change_password == o.change_password &&
      documentation_uri == o.documentation_uri &&
      filter == o.filter &&
      patch == o.patch &&
      schemas == o.schemas &&
      sort == o.sort
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 161

def hash
  [bulk, change_password, documentation_uri, filter, patch, schemas, sort].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
# File 'lib/talon_one_sdk/models/scim_service_provider_config_response.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end