Class: TalonOne::SecondaryDeployment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::SecondaryDeployment
- Defined in:
- lib/talon_one_sdk/models/secondary_deployment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_at ⇒ Object
Timestamp when the deployment became active.
-
#created_at ⇒ Object
Timestamp when the deployment was created.
-
#deleted_at ⇒ Object
Timestamp when the deployment was deleted.
-
#failed_at ⇒ Object
Timestamp when the deployment failed.
-
#id ⇒ Object
Unique ID for this entity.
-
#name ⇒ Object
The name of the deployment.
-
#status ⇒ Object
The status of the deployment.
-
#user_id ⇒ Object
The ID of the user who created the deployment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecondaryDeployment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SecondaryDeployment
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SecondaryDeployment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SecondaryDeployment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'active_at') self.active_at = attributes[:'active_at'] end if attributes.key?(:'failed_at') self.failed_at = attributes[:'failed_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end end |
Instance Attribute Details
#active_at ⇒ Object
Timestamp when the deployment became active.
34 35 36 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 34 def active_at @active_at end |
#created_at ⇒ Object
Timestamp when the deployment was created.
31 32 33 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 31 def created_at @created_at end |
#deleted_at ⇒ Object
Timestamp when the deployment was deleted.
40 41 42 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 40 def deleted_at @deleted_at end |
#failed_at ⇒ Object
Timestamp when the deployment failed.
37 38 39 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 37 def failed_at @failed_at end |
#id ⇒ Object
Unique ID for this entity. Not to be confused with the Integration ID, which is set by your integration layer and used in most endpoints.
19 20 21 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 19 def id @id end |
#name ⇒ Object
The name of the deployment. Used as subdomain, e.g. experimental.your-company.europe-west1.talon.one
22 23 24 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 22 def name @name end |
#status ⇒ Object
The status of the deployment.
28 29 30 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 28 def status @status end |
#user_id ⇒ Object
The ID of the user who created the deployment.
25 26 27 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 25 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 65 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'user_id' => :'userId', :'status' => :'status', :'created_at' => :'createdAt', :'active_at' => :'activeAt', :'failed_at' => :'failedAt', :'deleted_at' => :'deletedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 317 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
109 110 111 112 113 114 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 109 def self.openapi_all_of [ :'IdentifiableEntity', :'NewSecondaryDeployment' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 89 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'user_id' => :'Integer', :'status' => :'String', :'created_at' => :'Time', :'active_at' => :'Time', :'failed_at' => :'Time', :'deleted_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 289 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && user_id == o.user_id && status == o.status && created_at == o.created_at && active_at == o.active_at && failed_at == o.failed_at && deleted_at == o.deleted_at end |
#eql?(o) ⇒ Boolean
304 305 306 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 304 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
310 311 312 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 310 def hash [id, name, user_id, status, created_at, active_at, failed_at, deleted_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-z0-9]+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/talon_one_sdk/models/secondary_deployment.rb', line 214 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^[a-z0-9]+$/) return false if @user_id.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["created", "active", "failed", "deleted"]) return false unless status_validator.valid?(@status) return false if @created_at.nil? true end |