Class: TalonOne::SetDiscountPerItemEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::SetDiscountPerItemEffectProps
- Defined in:
- lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb
Overview
This effect schema is returned when you use the **Discount individual items**, **Discount individual items pro rata**, or **Discount individual item in bundles** effect in a rule. It indicates that a discount per item should be applied on the specific item specified in the effect. The properties it contains depends on: - Whether you used a pro rata effect or not. - Whether you used an effect with bundles or not. - Whether the partial discount feature is enabled.
Instance Attribute Summary collapse
-
#bundle_index ⇒ Object
_(Discounts with bundles only)_ The position of the specific item bundle in the list of bundles created from the same bundle definition.
-
#bundle_name ⇒ Object
_(Discounts with bundles only)_ The name of the bundle definition.
-
#desired_total_discount ⇒ Object
_(Pro rata discounts only)_ The monetary value of the total discount to be applied without considering budget limitations.
-
#desired_value ⇒ Object
_(Partial discounts enabled only)_ The monetary value of the discount to be applied to the item without considering budget limitations.
-
#excluded_from_price_history ⇒ Object
When set to ‘true`, the applied discount is excluded from the item’s price history.
-
#name ⇒ Object
The description of this discount.
-
#position ⇒ Object
The index of the item in the ‘cartItem` object on which this discount should be applied.
-
#scope ⇒ Object
What the discount applies to.
-
#sub_position ⇒ Object
The index of the item unit in its line item.
-
#targeted_item_position ⇒ Object
_(Discounting individual item in bundles only)_ The index of the targeted bundle item on which the applied discount is based.
-
#targeted_item_sub_position ⇒ Object
_(Discounting individual item in bundles only)_ The sub-position of the targeted bundle item on which the applied discount is based.
-
#total_discount ⇒ Object
_(Pro rata discounts only)_ The monetary value of the total effective discount.
-
#value ⇒ Object
The monetary value of the effective discount applied to the item.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SetDiscountPerItemEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SetDiscountPerItemEffectProps
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SetDiscountPerItemEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SetDiscountPerItemEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'position') self.position = attributes[:'position'] else self.position = nil end if attributes.key?(:'sub_position') self.sub_position = attributes[:'sub_position'] end if attributes.key?(:'desired_value') self.desired_value = attributes[:'desired_value'] end if attributes.key?(:'scope') self.scope = attributes[:'scope'] end if attributes.key?(:'total_discount') self.total_discount = attributes[:'total_discount'] end if attributes.key?(:'desired_total_discount') self.desired_total_discount = attributes[:'desired_total_discount'] end if attributes.key?(:'bundle_index') self.bundle_index = attributes[:'bundle_index'] end if attributes.key?(:'bundle_name') self.bundle_name = attributes[:'bundle_name'] end if attributes.key?(:'targeted_item_position') self.targeted_item_position = attributes[:'targeted_item_position'] end if attributes.key?(:'targeted_item_sub_position') self.targeted_item_sub_position = attributes[:'targeted_item_sub_position'] end if attributes.key?(:'excluded_from_price_history') self.excluded_from_price_history = attributes[:'excluded_from_price_history'] end end |
Instance Attribute Details
#bundle_index ⇒ Object
_(Discounts with bundles only)_ The position of the specific item bundle in the list of bundles created from the same bundle definition.
44 45 46 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 44 def bundle_index @bundle_index end |
#bundle_name ⇒ Object
_(Discounts with bundles only)_ The name of the bundle definition.
47 48 49 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 47 def bundle_name @bundle_name end |
#desired_total_discount ⇒ Object
_(Pro rata discounts only)_ The monetary value of the total discount to be applied without considering budget limitations
41 42 43 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 41 def desired_total_discount @desired_total_discount end |
#desired_value ⇒ Object
_(Partial discounts enabled only)_ The monetary value of the discount to be applied to the item without considering budget limitations.
32 33 34 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 32 def desired_value @desired_value end |
#excluded_from_price_history ⇒ Object
When set to ‘true`, the applied discount is excluded from the item’s price history.
56 57 58 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 56 def excluded_from_price_history @excluded_from_price_history end |
#name ⇒ Object
The description of this discount. ‘#number` is equal to the `position` property.
20 21 22 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 20 def name @name end |
#position ⇒ Object
The index of the item in the ‘cartItem` object on which this discount should be applied.
26 27 28 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 26 def position @position end |
#scope ⇒ Object
What the discount applies to. Possible values: - ‘price`: discount on the price of the item. - `additionalCosts`: discount on the [additional cost](docs.talon.one/docs/product/account/dev-tools/manage-additional-costs) of the item. - `itemTotal`: discount on the sum of price + additional cost of the item.
35 36 37 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 35 def scope @scope end |
#sub_position ⇒ Object
The index of the item unit in its line item.
29 30 31 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 29 def sub_position @sub_position end |
#targeted_item_position ⇒ Object
_(Discounting individual item in bundles only)_ The index of the targeted bundle item on which the applied discount is based.
50 51 52 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 50 def targeted_item_position @targeted_item_position end |
#targeted_item_sub_position ⇒ Object
_(Discounting individual item in bundles only)_ The sub-position of the targeted bundle item on which the applied discount is based.
53 54 55 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 53 def targeted_item_sub_position @targeted_item_sub_position end |
#total_discount ⇒ Object
_(Pro rata discounts only)_ The monetary value of the total effective discount
38 39 40 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 38 def total_discount @total_discount end |
#value ⇒ Object
The monetary value of the effective discount applied to the item.
23 24 25 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 23 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 59 def self.attribute_map { :'name' => :'name', :'value' => :'value', :'position' => :'position', :'sub_position' => :'subPosition', :'desired_value' => :'desiredValue', :'scope' => :'scope', :'total_discount' => :'totalDiscount', :'desired_total_discount' => :'desiredTotalDiscount', :'bundle_index' => :'bundleIndex', :'bundle_name' => :'bundleName', :'targeted_item_position' => :'targetedItemPosition', :'targeted_item_sub_position' => :'targetedItemSubPosition', :'excluded_from_price_history' => :'excludedFromPriceHistory' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 88 def self.openapi_types { :'name' => :'String', :'value' => :'Float', :'position' => :'Float', :'sub_position' => :'Float', :'desired_value' => :'Float', :'scope' => :'String', :'total_discount' => :'Float', :'desired_total_discount' => :'Float', :'bundle_index' => :'Integer', :'bundle_name' => :'String', :'targeted_item_position' => :'Float', :'targeted_item_sub_position' => :'Float', :'excluded_from_price_history' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && value == o.value && position == o.position && sub_position == o.sub_position && desired_value == o.desired_value && scope == o.scope && total_discount == o.total_discount && desired_total_discount == o.desired_total_discount && bundle_index == o.bundle_index && bundle_name == o.bundle_name && targeted_item_position == o.targeted_item_position && targeted_item_sub_position == o.targeted_item_sub_position && excluded_from_price_history == o.excluded_from_price_history end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 275 def hash [name, value, position, sub_position, desired_value, scope, total_discount, desired_total_discount, bundle_index, bundle_name, targeted_item_position, targeted_item_sub_position, excluded_from_price_history].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @position.nil? invalid_properties.push('invalid value for "position", position cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 |
# File 'lib/talon_one_sdk/models/set_discount_per_item_effect_props.rb', line 209 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @value.nil? return false if @position.nil? true end |