Class: TalonOne::ShowBundleMetadataEffectProps

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb

Overview

This effect is deprecated. The properties specific to the "ShowBundleMetadata" effect. This effect contains information that allows you to associate the discounts from a rule in a bundle campaign with specific cart items. This way you can distinguish from "normal" discounts that were not the result of a product bundle.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ShowBundleMetadataEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ShowBundleMetadataEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ShowBundleMetadataEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'bundle_attributes')
    if (value = attributes[:'bundle_attributes']).is_a?(Array)
      self.bundle_attributes = value
    end
  else
    self.bundle_attributes = nil
  end

  if attributes.key?(:'items_indices')
    if (value = attributes[:'items_indices']).is_a?(Array)
      self.items_indices = value
    end
  else
    self.items_indices = nil
  end
end

Instance Attribute Details

#bundle_attributesObject

The cart item attributes that determined which items are being bundled together.



23
24
25
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 23

def bundle_attributes
  @bundle_attributes
end

#descriptionObject

Description of the product bundle.



20
21
22
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 20

def description
  @description
end

#items_indicesObject

The indices in the cart items array of the bundled items.



26
27
28
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 26

def items_indices
  @items_indices
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 29

def self.attribute_map
  {
    :'description' => :'description',
    :'bundle_attributes' => :'bundleAttributes',
    :'items_indices' => :'itemsIndices'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 48

def self.openapi_types
  {
    :'description' => :'String',
    :'bundle_attributes' => :'Array<String>',
    :'items_indices' => :'Array<Float>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      bundle_attributes == o.bundle_attributes &&
      items_indices == o.items_indices
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 179

def hash
  [description, bundle_attributes, items_indices].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @bundle_attributes.nil?
    invalid_properties.push('invalid value for "bundle_attributes", bundle_attributes cannot be nil.')
  end

  if @items_indices.nil?
    invalid_properties.push('invalid value for "items_indices", items_indices cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
# File 'lib/talon_one_sdk/models/show_bundle_metadata_effect_props.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @description.nil?
  return false if @bundle_attributes.nil?
  return false if @items_indices.nil?
  true
end