Class: TalonOne::StrikethroughChangedItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::StrikethroughChangedItem
- Defined in:
- lib/talon_one_sdk/models/strikethrough_changed_item.rb
Overview
The information of affected items.
Instance Attribute Summary collapse
-
#catalog_id ⇒ Object
The ID of the catalog that the changed item belongs to.
-
#effects ⇒ Object
Returns the value of attribute effects.
-
#evaluated_at ⇒ Object
The evaluation time of the changed item.
-
#id ⇒ Object
The ID of the event that triggered the strikethrough labeling.
-
#price ⇒ Object
The price of the changed item.
-
#prices ⇒ Object
A map of keys and values representing the price types and related price adjustment details for this cart item.
-
#sku ⇒ Object
The unique SKU of the changed item.
-
#version ⇒ Object
The version of the changed item.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StrikethroughChangedItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StrikethroughChangedItem
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StrikethroughChangedItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StrikethroughChangedItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] else self.catalog_id = nil end if attributes.key?(:'sku') self.sku = attributes[:'sku'] else self.sku = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'price') self.price = attributes[:'price'] else self.price = nil end if attributes.key?(:'prices') if (value = attributes[:'prices']).is_a?(Hash) self.prices = value end end if attributes.key?(:'evaluated_at') self.evaluated_at = attributes[:'evaluated_at'] else self.evaluated_at = nil end if attributes.key?(:'effects') if (value = attributes[:'effects']).is_a?(Array) self.effects = value end end end |
Instance Attribute Details
#catalog_id ⇒ Object
The ID of the catalog that the changed item belongs to.
23 24 25 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 23 def catalog_id @catalog_id end |
#effects ⇒ Object
Returns the value of attribute effects.
40 41 42 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 40 def effects @effects end |
#evaluated_at ⇒ Object
The evaluation time of the changed item.
38 39 40 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 38 def evaluated_at @evaluated_at end |
#id ⇒ Object
The ID of the event that triggered the strikethrough labeling.
20 21 22 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 20 def id @id end |
#price ⇒ Object
The price of the changed item.
32 33 34 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 32 def price @price end |
#prices ⇒ Object
A map of keys and values representing the price types and related price adjustment details for this cart item. The keys correspond to the ‘priceType` names.
35 36 37 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 35 def prices @prices end |
#sku ⇒ Object
The unique SKU of the changed item.
26 27 28 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 26 def sku @sku end |
#version ⇒ Object
The version of the changed item.
29 30 31 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 29 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 43 def self.attribute_map { :'id' => :'id', :'catalog_id' => :'catalogId', :'sku' => :'sku', :'version' => :'version', :'price' => :'price', :'prices' => :'prices', :'evaluated_at' => :'evaluatedAt', :'effects' => :'effects' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 295 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 67 def self.openapi_types { :'id' => :'Integer', :'catalog_id' => :'Integer', :'sku' => :'String', :'version' => :'Integer', :'price' => :'Float', :'prices' => :'Hash<String, PriceDetail>', :'evaluated_at' => :'Time', :'effects' => :'Array<StrikethroughEffect>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 267 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && catalog_id == o.catalog_id && sku == o.sku && version == o.version && price == o.price && prices == o.prices && evaluated_at == o.evaluated_at && effects == o.effects end |
#eql?(o) ⇒ Boolean
282 283 284 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 282 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
288 289 290 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 288 def hash [id, catalog_id, sku, version, price, prices, evaluated_at, effects].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @catalog_id.nil? invalid_properties.push('invalid value for "catalog_id", catalog_id cannot be nil.') end if @sku.nil? invalid_properties.push('invalid value for "sku", sku cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @version < 1 invalid_properties.push('invalid value for "version", must be greater than or equal to 1.') end if @price.nil? invalid_properties.push('invalid value for "price", price cannot be nil.') end if @evaluated_at.nil? invalid_properties.push('invalid value for "evaluated_at", evaluated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/strikethrough_changed_item.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @catalog_id.nil? return false if @sku.nil? return false if @version.nil? return false if @version < 1 return false if @price.nil? return false if @evaluated_at.nil? true end |