Class: TalonOne::StrikethroughCheckAttributeBlock
- Inherits:
-
CheckAttributeBlock
- Object
- ApiModelBase
- CheckAttributeBlock
- TalonOne::StrikethroughCheckAttributeBlock
- Defined in:
- lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#on_failure ⇒ Object
Strikethrough blocks evaluated when this block fails or returns false.
Attributes inherited from CheckAttributeBlock
#attribute, #count, #id, #max, #min, #operator, #tags, #type, #value, #values
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StrikethroughCheckAttributeBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from CheckAttributeBlock
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StrikethroughCheckAttributeBlock
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StrikethroughCheckAttributeBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StrikethroughCheckAttributeBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'on_failure') if (value = attributes[:'on_failure']).is_a?(Array) self.on_failure = value end end end |
Instance Attribute Details
#on_failure ⇒ Object
Strikethrough blocks evaluated when this block fails or returns false.
19 20 21 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 19 def on_failure @on_failure end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about, including the ones defined in its parent(s)
51 52 53 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 51 def self.acceptable_attribute_map superclass.acceptable_attribute_map.merge(attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
56 57 58 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 44 def self.attribute_map { :'on_failure' => :'onFailure' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 144 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 74 def self.openapi_all_of [ :'CheckAttributeBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 61 def self.openapi_types { :'on_failure' => :'Array<Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 123 def ==(o) return true if self.equal?(o) self.class == o.class && on_failure == o.on_failure && super(o) end |
#eql?(o) ⇒ Boolean
131 132 133 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 131 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 137 def hash [on_failure].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = super invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 167 def to_hash hash = super self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 |
# File 'lib/talon_one_sdk/models/strikethrough_check_attribute_block.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true && super end |