Class: TalonOne::StrikethroughEffect

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/strikethrough_effect.rb

Overview

The effect produced for the catalog item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StrikethroughEffect

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StrikethroughEffect` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StrikethroughEffect`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'ruleset_id')
    self.ruleset_id = attributes[:'ruleset_id']
  else
    self.ruleset_id = nil
  end

  if attributes.key?(:'rule_index')
    self.rule_index = attributes[:'rule_index']
  else
    self.rule_index = nil
  end

  if attributes.key?(:'rule_name')
    self.rule_name = attributes[:'rule_name']
  else
    self.rule_name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'props')
    self.props = attributes[:'props']
  else
    self.props = nil
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'selected_price_type')
    self.selected_price_type = attributes[:'selected_price_type']
  end

  if attributes.key?(:'selected_price')
    self.selected_price = attributes[:'selected_price']
  end

  if attributes.key?(:'adjustment_reference_id')
    self.adjustment_reference_id = attributes[:'adjustment_reference_id']
  end

  if attributes.key?(:'targets')
    if (value = attributes[:'targets']).is_a?(Array)
      self.targets = value
    end
  end
end

Instance Attribute Details

#adjustment_reference_idObject

The reference identifier of the selected price adjustment for this cart item.



50
51
52
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 50

def adjustment_reference_id
  @adjustment_reference_id
end

#campaign_idObject

The ID of the campaign that effect belongs to.



20
21
22
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 20

def campaign_id
  @campaign_id
end

#end_timeObject

The end of the time frame where the effect is active in UTC.



41
42
43
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 41

def end_time
  @end_time
end

#propsObject

Arbitrary properties associated with this effect type.



35
36
37
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 35

def props
  @props
end

#rule_indexObject

The position of the rule that triggered this effect within the ruleset.



26
27
28
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 26

def rule_index
  @rule_index
end

#rule_nameObject

The name of the rule that triggered this effect.



29
30
31
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 29

def rule_name
  @rule_name
end

#ruleset_idObject

The ID of the ruleset containing the rule that triggered this effect.



23
24
25
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 23

def ruleset_id
  @ruleset_id
end

#selected_priceObject

The value of the selected price type to apply to the SKU targeted by this effect, before any discounts are applied.



47
48
49
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 47

def selected_price
  @selected_price
end

#selected_price_typeObject

The selected price type for this cart item (e.g. the price for members only).



44
45
46
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 44

def selected_price_type
  @selected_price_type
end

#start_timeObject

The start of the time frame where the effect is active in UTC.



38
39
40
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 38

def start_time
  @start_time
end

#targetsObject

A list of entities (e.g. audiences) targeted by this effect.



53
54
55
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 53

def targets
  @targets
end

#typeObject

The type of this effect.



32
33
34
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 32

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 56

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'ruleset_id' => :'rulesetId',
    :'rule_index' => :'ruleIndex',
    :'rule_name' => :'ruleName',
    :'type' => :'type',
    :'props' => :'props',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'selected_price_type' => :'selectedPriceType',
    :'selected_price' => :'selectedPrice',
    :'adjustment_reference_id' => :'adjustmentReferenceId',
    :'targets' => :'targets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 325

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 84

def self.openapi_types
  {
    :'campaign_id' => :'Integer',
    :'ruleset_id' => :'Integer',
    :'rule_index' => :'Integer',
    :'rule_name' => :'String',
    :'type' => :'String',
    :'props' => :'Object',
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'selected_price_type' => :'String',
    :'selected_price' => :'Float',
    :'adjustment_reference_id' => :'String',
    :'targets' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      ruleset_id == o.ruleset_id &&
      rule_index == o.rule_index &&
      rule_name == o.rule_name &&
      type == o.type &&
      props == o.props &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      selected_price_type == o.selected_price_type &&
      selected_price == o.selected_price &&
      adjustment_reference_id == o.adjustment_reference_id &&
      targets == o.targets
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 312

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



318
319
320
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 318

def hash
  [campaign_id, ruleset_id, rule_index, rule_name, type, props, start_time, end_time, selected_price_type, selected_price, adjustment_reference_id, targets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 188

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @ruleset_id.nil?
    invalid_properties.push('invalid value for "ruleset_id", ruleset_id cannot be nil.')
  end

  if @rule_index.nil?
    invalid_properties.push('invalid value for "rule_index", rule_index cannot be nil.')
  end

  if @rule_name.nil?
    invalid_properties.push('invalid value for "rule_name", rule_name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @props.nil?
    invalid_properties.push('invalid value for "props", props cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
229
# File 'lib/talon_one_sdk/models/strikethrough_effect.rb', line 220

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @campaign_id.nil?
  return false if @ruleset_id.nil?
  return false if @rule_index.nil?
  return false if @rule_name.nil?
  return false if @type.nil?
  return false if @props.nil?
  true
end