Class: TalonOne::StrikethroughLabelingNotification

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/strikethrough_labeling_notification.rb

Overview

The strikethrough labels notification for an application.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StrikethroughLabelingNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StrikethroughLabelingNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StrikethroughLabelingNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'valid_from')
    self.valid_from = attributes[:'valid_from']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'current_batch')
    self.current_batch = attributes[:'current_batch']
  else
    self.current_batch = nil
  end

  if attributes.key?(:'total_batches')
    self.total_batches = attributes[:'total_batches']
  else
    self.total_batches = nil
  end

  if attributes.key?(:'trigger')
    self.trigger = attributes[:'trigger']
  else
    self.trigger = nil
  end

  if attributes.key?(:'changed_items')
    if (value = attributes[:'changed_items']).is_a?(Array)
      self.changed_items = value
    end
  else
    self.changed_items = nil
  end

  if attributes.key?(:'notification_type')
    self.notification_type = attributes[:'notification_type']
  else
    self.notification_type = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  else
    self.sent_at = nil
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application to which the catalog items labels belongs.



26
27
28
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 26

def application_id
  @application_id
end

#changed_itemsObject

Returns the value of attribute changed_items.



36
37
38
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 36

def changed_items
  @changed_items
end

#current_batchObject

The batch number of the notification. Notifications might be sent in different batches.



29
30
31
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 29

def current_batch
  @current_batch
end

#notification_typeObject

The type of notification.



39
40
41
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 39

def notification_type
  @notification_type
end

#sent_atObject

Timestamp at which the notification was sent.



42
43
44
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 42

def sent_at
  @sent_at
end

#total_batchesObject

The total number of batches for the notification.



32
33
34
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 32

def total_batches
  @total_batches
end

#triggerObject

Returns the value of attribute trigger.



34
35
36
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 34

def trigger
  @trigger
end

#valid_fromObject

Timestamp at which the strikethrough pricing update becomes valid. Set for scheduled strikethrough pricing updates (version: v2) only.



23
24
25
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 23

def valid_from
  @valid_from
end

#versionObject

The version of the strikethrough pricing notification.



20
21
22
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 20

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 67

def self.attribute_map
  {
    :'version' => :'version',
    :'valid_from' => :'validFrom',
    :'application_id' => :'applicationId',
    :'current_batch' => :'currentBatch',
    :'total_batches' => :'totalBatches',
    :'trigger' => :'trigger',
    :'changed_items' => :'changedItems',
    :'notification_type' => :'NotificationType',
    :'sent_at' => :'sentAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 346

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 92

def self.openapi_types
  {
    :'version' => :'String',
    :'valid_from' => :'Time',
    :'application_id' => :'Integer',
    :'current_batch' => :'Integer',
    :'total_batches' => :'Integer',
    :'trigger' => :'StrikethroughTrigger',
    :'changed_items' => :'Array<StrikethroughChangedItem>',
    :'notification_type' => :'String',
    :'sent_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      valid_from == o.valid_from &&
      application_id == o.application_id &&
      current_batch == o.current_batch &&
      total_batches == o.total_batches &&
      trigger == o.trigger &&
      changed_items == o.changed_items &&
      notification_type == o.notification_type &&
      sent_at == o.sent_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


333
334
335
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



339
340
341
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 339

def hash
  [version, valid_from, application_id, current_batch, total_batches, trigger, changed_items, notification_type, sent_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @current_batch.nil?
    invalid_properties.push('invalid value for "current_batch", current_batch cannot be nil.')
  end

  if @total_batches.nil?
    invalid_properties.push('invalid value for "total_batches", total_batches cannot be nil.')
  end

  if @trigger.nil?
    invalid_properties.push('invalid value for "trigger", trigger cannot be nil.')
  end

  if @changed_items.nil?
    invalid_properties.push('invalid value for "changed_items", changed_items cannot be nil.')
  end

  if @notification_type.nil?
    invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.')
  end

  if @sent_at.nil?
    invalid_properties.push('invalid value for "sent_at", sent_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/talon_one_sdk/models/strikethrough_labeling_notification.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  version_validator = EnumAttributeValidator.new('String', ["v2"])
  return false unless version_validator.valid?(@version)
  return false if @application_id.nil?
  return false if @current_batch.nil?
  return false if @total_batches.nil?
  return false if @trigger.nil?
  return false if @changed_items.nil?
  return false if @notification_type.nil?
  notification_type_validator = EnumAttributeValidator.new('String', ["StrikethroughPrice"])
  return false unless notification_type_validator.valid?(@notification_type)
  return false if @sent_at.nil?
  true
end