Class: TalonOne::SummaryCampaignStoreBudget
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::SummaryCampaignStoreBudget
- Defined in:
- lib/talon_one_sdk/models/summary_campaign_store_budget.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#imported ⇒ Object
Returns the value of attribute imported.
-
#period ⇒ Object
Returns the value of attribute period.
-
#store_count ⇒ Object
Returns the value of attribute store_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummaryCampaignStoreBudget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SummaryCampaignStoreBudget
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SummaryCampaignStoreBudget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SummaryCampaignStoreBudget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'period') self.period = attributes[:'period'] end if attributes.key?(:'store_count') self.store_count = attributes[:'store_count'] else self.store_count = nil end if attributes.key?(:'imported') self.imported = attributes[:'imported'] else self.imported = nil end end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
18 19 20 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 18 def action @action end |
#imported ⇒ Object
Returns the value of attribute imported.
24 25 26 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 24 def imported @imported end |
#period ⇒ Object
Returns the value of attribute period.
20 21 22 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 20 def period @period end |
#store_count ⇒ Object
Returns the value of attribute store_count.
22 23 24 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 22 def store_count @store_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 49 def self.attribute_map { :'action' => :'action', :'period' => :'period', :'store_count' => :'storeCount', :'imported' => :'imported' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 69 def self.openapi_types { :'action' => :'String', :'period' => :'String', :'store_count' => :'Integer', :'imported' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && period == o.period && store_count == o.store_count && imported == o.imported end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 216 def hash [action, period, store_count, imported].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @store_count.nil? invalid_properties.push('invalid value for "store_count", store_count cannot be nil.') end if @imported.nil? invalid_properties.push('invalid value for "imported", imported cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/talon_one_sdk/models/summary_campaign_store_budget.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["redeemCoupon", "redeemReferral", "setDiscount", "setDiscountEffect", "createCoupon", "createReferral", "createLoyaltyPoints", "redeemLoyaltyPoints", "customEffect", "createLoyaltyPointsEffect", "redeemLoyaltyPointsEffect", "callApi", "awardGiveaway", "addFreeItemEffect", "reserveCoupon"]) return false unless action_validator.valid?(@action) period_validator = EnumAttributeValidator.new('String', ["overall", "daily", "weekly", "monthly", "yearly"]) return false unless period_validator.valid?(@period) return false if @store_count.nil? return false if @imported.nil? true end |