Class: TalonOne::SupportRequestInput

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/support_request_input.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SupportRequestInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SupportRequestInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SupportRequestInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  else
    self.customer_profile_id = nil
  end

  if attributes.key?(:'request_type')
    self.request_type = attributes[:'request_type']
  else
    self.request_type = nil
  end

  if attributes.key?(:'request_value')
    self.request_value = attributes[:'request_value']
  end

  if attributes.key?(:'request_note')
    self.request_note = attributes[:'request_note']
  else
    self.request_note = nil
  end
end

Instance Attribute Details

#application_idObject

Identifier of the Application connected to the loyalty program or the campaign. It is displayed in your Talon.One deployment URL.



19
20
21
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 19

def application_id
  @application_id
end

#campaign_idObject

Identifier of the campaign where the coupon or gift card is created.



22
23
24
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 22

def campaign_id
  @campaign_id
end

#customer_profile_idObject

Integration ID of the customer profile linked to the support request.



31
32
33
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 31

def customer_profile_id
  @customer_profile_id
end

#loyalty_program_idObject

Identifier of the loyalty program. You can get the ID with the [List loyalty programs](docs.talon.one/management-api#tag/Loyalty/operation/getLoyaltyPrograms) endpoint.



25
26
27
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 25

def loyalty_program_id
  @loyalty_program_id
end

#request_noteObject

Notes attached to the support request.



40
41
42
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 40

def request_note
  @request_note
end

#request_typeObject

Type of reward requested, including gift cards, personal coupons, and loyalty point additions or deductions.



34
35
36
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 34

def request_type
  @request_type
end

#request_valueObject

Requested monetary balance of the gift card or the number of loyalty points to be added or deducted.



37
38
39
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 37

def request_value
  @request_value
end

#subledger_idObject

Identifier of the subledger the points are added to or deducted from. If there is no existing subledger with this ID, the subledger is created automatically.



28
29
30
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 28

def subledger_id
  @subledger_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 65

def self.attribute_map
  {
    :'application_id' => :'applicationId',
    :'campaign_id' => :'campaignId',
    :'loyalty_program_id' => :'loyaltyProgramId',
    :'subledger_id' => :'subledgerId',
    :'customer_profile_id' => :'customerProfileId',
    :'request_type' => :'requestType',
    :'request_value' => :'requestValue',
    :'request_note' => :'requestNote'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 89

def self.openapi_types
  {
    :'application_id' => :'Integer',
    :'campaign_id' => :'Integer',
    :'loyalty_program_id' => :'Integer',
    :'subledger_id' => :'Integer',
    :'customer_profile_id' => :'String',
    :'request_type' => :'String',
    :'request_value' => :'Float',
    :'request_note' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 263

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      application_id == o.application_id &&
      campaign_id == o.campaign_id &&
      loyalty_program_id == o.loyalty_program_id &&
      subledger_id == o.subledger_id &&
      customer_profile_id == o.customer_profile_id &&
      request_type == o.request_type &&
      request_value == o.request_value &&
      request_note == o.request_note
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 284

def hash
  [application_id, campaign_id, loyalty_program_id, subledger_id, customer_profile_id, request_type, request_value, request_note].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @customer_profile_id.nil?
    invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.')
  end

  if @request_type.nil?
    invalid_properties.push('invalid value for "request_type", request_type cannot be nil.')
  end

  if !@request_value.nil? && @request_value <= 0
    invalid_properties.push('invalid value for "request_value", must be greater than 0.')
  end

  if @request_note.nil?
    invalid_properties.push('invalid value for "request_note", request_note cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
201
202
203
204
205
# File 'lib/talon_one_sdk/models/support_request_input.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @application_id.nil?
  return false if @customer_profile_id.nil?
  return false if @request_type.nil?
  request_type_validator = EnumAttributeValidator.new('String', ["gift_card", "personal_coupon", "loyalty_points_added", "loyalty_points_deducted"])
  return false unless request_type_validator.valid?(@request_type)
  return false if !@request_value.nil? && @request_value <= 0
  return false if @request_note.nil?
  true
end