Class: TalonOne::TalangAttribute

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/talang_attribute.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TalangAttribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TalangAttribute` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TalangAttribute`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'visible')
    self.visible = attributes[:'visible']
  else
    self.visible = true
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'campaigns_count')
    self.campaigns_count = attributes[:'campaigns_count']
  else
    self.campaigns_count = nil
  end

  if attributes.key?(:'example_value')
    if (value = attributes[:'example_value']).is_a?(Array)
      self.example_value = value
    end
  end
end

Instance Attribute Details

#campaigns_countObject

The number of campaigns that refer to the attribute.



40
41
42
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 40

def campaigns_count
  @campaigns_count
end

#descriptionObject

A description of the attribute.



31
32
33
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 31

def description
  @description
end

#entityObject

The name of the entity of the attribute.



19
20
21
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 19

def entity
  @entity
end

#example_valueObject

Examples of values that can be assigned to the attribute.



43
44
45
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 43

def example_value
  @example_value
end

#kindObject

Indicate the kind of the attribute.



37
38
39
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 37

def kind
  @kind
end

#nameObject

The attribute name that will be used in API requests and Talang. E.g. if ‘name == "region"` then you would set the region attribute by including an `attributes.region` property in your request payload.



22
23
24
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 22

def name
  @name
end

#titleObject

The name of the attribute that is displayed to the user in the Campaign Manager.



25
26
27
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 25

def title
  @title
end

#typeObject

The talang type of the attribute.



28
29
30
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 28

def type
  @type
end

#visibleObject

Indicates whether the attribute is visible in the UI or not.



34
35
36
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 34

def visible
  @visible
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 68

def self.attribute_map
  {
    :'entity' => :'entity',
    :'name' => :'name',
    :'title' => :'title',
    :'type' => :'type',
    :'description' => :'description',
    :'visible' => :'visible',
    :'kind' => :'kind',
    :'campaigns_count' => :'campaignsCount',
    :'example_value' => :'exampleValue'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 313

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 93

def self.openapi_types
  {
    :'entity' => :'String',
    :'name' => :'String',
    :'title' => :'String',
    :'type' => :'String',
    :'description' => :'String',
    :'visible' => :'Boolean',
    :'kind' => :'String',
    :'campaigns_count' => :'Integer',
    :'example_value' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      entity == o.entity &&
      name == o.name &&
      title == o.title &&
      type == o.type &&
      description == o.description &&
      visible == o.visible &&
      kind == o.kind &&
      campaigns_count == o.campaigns_count &&
      example_value == o.example_value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


300
301
302
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 300

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



306
307
308
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 306

def hash
  [entity, name, title, type, description, visible, kind, campaigns_count, example_value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @visible.nil?
    invalid_properties.push('invalid value for "visible", visible cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @campaigns_count.nil?
    invalid_properties.push('invalid value for "campaigns_count", campaigns_count cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/talang_attribute.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  entity_validator = EnumAttributeValidator.new('String', ["AdvocateProfile", "Account", "Application", "AwardedGiveaway", "Bundle", "Campaign", "CartItem", "Coupon", "CustomerProfile", "CustomerSession", "Event", "Item", "Loyalty", "LoyaltyCard", "Profile", "Giveaway", "Referral", "Session", "Store", "Achievements"])
  return false unless entity_validator.valid?(@entity)
  return false if @name.nil?
  return false if @type.nil?
  return false if @visible.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["built-in", "custom"])
  return false unless kind_validator.valid?(@kind)
  return false if @campaigns_count.nil?
  true
end