Class: TalonOne::TemplateArgDef

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/template_arg_def.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateArgDef

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TemplateArgDef` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TemplateArgDef`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'ui')
    self.ui = attributes[:'ui']
  else
    self.ui = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'picklist_id')
    self.picklist_id = attributes[:'picklist_id']
  end

  if attributes.key?(:'restricted_by_picklist')
    self.restricted_by_picklist = attributes[:'restricted_by_picklist']
  end
end

Instance Attribute Details

#descriptionObject

A campaigner-friendly description of the argument, this will also be shown in the rule editor.



22
23
24
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 22

def description
  @description
end

#keyObject

The identifier for the associated value within the JSON object.



31
32
33
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 31

def key
  @key
end

#picklist_idObject

ID of the picklist linked to a template.



34
35
36
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 34

def picklist_id
  @picklist_id
end

#restricted_by_picklistObject

Whether or not this attribute’s value is restricted by picklist (‘picklist` property)



37
38
39
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 37

def restricted_by_picklist
  @restricted_by_picklist
end

#titleObject

A campaigner friendly name for the argument, this will be shown in the rule editor.



25
26
27
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 25

def title
  @title
end

#typeObject

The type of value this argument expects.



19
20
21
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 19

def type
  @type
end

#uiObject

Arbitrary metadata that may be used to render an input for this argument.



28
29
30
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 28

def ui
  @ui
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 62

def self.attribute_map
  {
    :'type' => :'type',
    :'description' => :'description',
    :'title' => :'title',
    :'ui' => :'ui',
    :'key' => :'key',
    :'picklist_id' => :'picklistID',
    :'restricted_by_picklist' => :'restrictedByPicklist'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



104
105
106
107
108
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 104

def self.openapi_all_of
  [
  :'FuncArgDef'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 85

def self.openapi_types
  {
    :'type' => :'String',
    :'description' => :'String',
    :'title' => :'String',
    :'ui' => :'Object',
    :'key' => :'String',
    :'picklist_id' => :'Integer',
    :'restricted_by_picklist' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      description == o.description &&
      title == o.title &&
      ui == o.ui &&
      key == o.key &&
      picklist_id == o.picklist_id &&
      restricted_by_picklist == o.restricted_by_picklist
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 259

def hash
  [type, description, title, ui, key, picklist_id, restricted_by_picklist].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length < 1
    invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if @ui.nil?
    invalid_properties.push('invalid value for "ui", ui cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
200
201
# File 'lib/talon_one_sdk/models/template_arg_def.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["string", "boolean", "number", "time", "(list string)", "(list number)"])
  return false unless type_validator.valid?(@type)
  return false if @type.to_s.length < 1
  return false if @title.nil?
  return false if @title.to_s.length < 1
  return false if @ui.nil?
  true
end