Class: TalonOne::TemplateDef

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/template_def.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateDef

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/template_def.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TemplateDef` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TemplateDef`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'help')
    self.help = attributes[:'help']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'expr')
    if (value = attributes[:'expr']).is_a?(Array)
      self.expr = value
    end
  else
    self.expr = nil
  end

  if attributes.key?(:'args')
    if (value = attributes[:'args']).is_a?(Array)
      self.args = value
    end
  else
    self.args = nil
  end

  if attributes.key?(:'expose')
    self.expose = attributes[:'expose']
  else
    self.expose = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/template_def.rb', line 25

def application_id
  @application_id
end

#argsObject

An array of argument definitions.



43
44
45
# File 'lib/talon_one_sdk/models/template_def.rb', line 43

def args
  @args
end

#categoryObject

Used for grouping templates in the rule editor sidebar.



37
38
39
# File 'lib/talon_one_sdk/models/template_def.rb', line 37

def category
  @category
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/template_def.rb', line 22

def created
  @created
end

#descriptionObject

A short description of the template that will be shown in the rule editor.



31
32
33
# File 'lib/talon_one_sdk/models/template_def.rb', line 31

def description
  @description
end

#exposeObject

A flag to control exposure in Rule Builder.



46
47
48
# File 'lib/talon_one_sdk/models/template_def.rb', line 46

def expose
  @expose
end

#exprObject

A Talang expression that contains variable bindings referring to args.



40
41
42
# File 'lib/talon_one_sdk/models/template_def.rb', line 40

def expr
  @expr
end

#helpObject

Extended help text for the template.



34
35
36
# File 'lib/talon_one_sdk/models/template_def.rb', line 34

def help
  @help
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/template_def.rb', line 19

def id
  @id
end

#nameObject

The template name used in Talang.



49
50
51
# File 'lib/talon_one_sdk/models/template_def.rb', line 49

def name
  @name
end

#titleObject

Campaigner-friendly name for the template that will be shown in the rule editor.



28
29
30
# File 'lib/talon_one_sdk/models/template_def.rb', line 28

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/template_def.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/talon_one_sdk/models/template_def.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/talon_one_sdk/models/template_def.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'application_id' => :'applicationId',
    :'title' => :'title',
    :'description' => :'description',
    :'help' => :'help',
    :'category' => :'category',
    :'expr' => :'expr',
    :'args' => :'args',
    :'expose' => :'expose',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/talon_one_sdk/models/template_def.rb', line 388

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/template_def.rb', line 102

def self.openapi_all_of
  [
  :'ApplicationEntity',
  :'Entity',
  :'NewTemplateDef'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one_sdk/models/template_def.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/template_def.rb', line 79

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'application_id' => :'Integer',
    :'title' => :'String',
    :'description' => :'String',
    :'help' => :'String',
    :'category' => :'String',
    :'expr' => :'Array<Object>',
    :'args' => :'Array<TemplateArgDef>',
    :'expose' => :'Boolean',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/talon_one_sdk/models/template_def.rb', line 357

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      application_id == o.application_id &&
      title == o.title &&
      description == o.description &&
      help == o.help &&
      category == o.category &&
      expr == o.expr &&
      args == o.args &&
      expose == o.expose &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


375
376
377
# File 'lib/talon_one_sdk/models/template_def.rb', line 375

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



381
382
383
# File 'lib/talon_one_sdk/models/template_def.rb', line 381

def hash
  [id, created, application_id, title, description, help, category, expr, args, expose, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/talon_one_sdk/models/template_def.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @category.to_s.length < 1
    invalid_properties.push('invalid value for "category", the character length must be greater than or equal to 1.')
  end

  if @expr.nil?
    invalid_properties.push('invalid value for "expr", expr cannot be nil.')
  end

  if @args.nil?
    invalid_properties.push('invalid value for "args", args cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/talon_one_sdk/models/template_def.rb', line 410

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/talon_one_sdk/models/template_def.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  return false if @title.nil?
  return false if @title.to_s.length < 1
  return false if @category.nil?
  return false if @category.to_s.length < 1
  return false if @expr.nil?
  return false if @args.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  true
end