Class: TalonOne::TemplateLimitConfig

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/template_limit_config.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateLimitConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TemplateLimitConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TemplateLimitConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  else
    self.limit = nil
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'entities')
    if (value = attributes[:'entities']).is_a?(Array)
      self.entities = value
    end
  else
    self.entities = nil
  end
end

Instance Attribute Details

#actionObject

The limitable action to which this limit applies. For example: - ‘setDiscount` - `setDiscountEffect` - `redeemCoupon` - `createCoupon`



19
20
21
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 19

def action
  @action
end

#entitiesObject

The entity that this limit applies to.



28
29
30
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 28

def entities
  @entities
end

#limitObject

The value to set for the limit.



22
23
24
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 22

def limit
  @limit
end

#periodObject

The period on which the budget limit recurs.



25
26
27
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 25

def period
  @period
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 53

def self.attribute_map
  {
    :'action' => :'action',
    :'limit' => :'limit',
    :'period' => :'period',
    :'entities' => :'entities'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



89
90
91
92
93
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 89

def self.openapi_all_of
  [
  :'LimitConfig'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 73

def self.openapi_types
  {
    :'action' => :'String',
    :'limit' => :'Float',
    :'period' => :'String',
    :'entities' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      limit == o.limit &&
      period == o.period &&
      entities == o.entities
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 226

def hash
  [action, limit, period, entities].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @limit.nil?
    invalid_properties.push('invalid value for "limit", limit cannot be nil.')
  end

  if @limit < 0
    invalid_properties.push('invalid value for "limit", must be greater than or equal to 0.')
  end

  if @entities.nil?
    invalid_properties.push('invalid value for "entities", entities cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
171
# File 'lib/talon_one_sdk/models/template_limit_config.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  return false if @limit.nil?
  return false if @limit < 0
  period_validator = EnumAttributeValidator.new('String', ["daily", "weekly", "monthly", "yearly"])
  return false unless period_validator.valid?(@period)
  return false if @entities.nil?
  true
end