Class: TalonOne::TemplateParameter

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/template_parameter.rb

Overview

A named parameter definition that exposes a configurable value in a campaign template. Replaces templateParameter bindings in V1 rulesets.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateParameter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TemplateParameter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TemplateParameter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'value_type')
    self.value_type = attributes[:'value_type']
  else
    self.value_type = nil
  end

  if attributes.key?(:'min_value')
    self.min_value = attributes[:'min_value']
  end

  if attributes.key?(:'max_value')
    self.max_value = attributes[:'max_value']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'attribute')
    self.attribute = attributes[:'attribute']
  end
end

Instance Attribute Details

#attributeObject

The ID of the attribute linked to this parameter. Omitted when the parameter is not linked to an attribute.



37
38
39
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 37

def attribute
  @attribute
end

#descriptionObject

A human-readable description of the parameter shown when creating campaigns from the template.



34
35
36
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 34

def description
  @description
end

#max_valueObject

The maximum value allowed for this parameter.



31
32
33
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 31

def max_value
  @max_value
end

#min_valueObject

The minimum value allowed for this parameter.



28
29
30
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 28

def min_value
  @min_value
end

#nameObject

The name of the template parameter.



20
21
22
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 20

def name
  @name
end

#valueObject

Returns the value of attribute value.



22
23
24
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 22

def value
  @value
end

#value_typeObject

The data type of the value, derived from the bound expression (for example number, string, boolean, percent, time, (list string), or (list number)).



25
26
27
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 25

def value_type
  @value_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 40

def self.attribute_map
  {
    :'name' => :'name',
    :'value' => :'value',
    :'value_type' => :'valueType',
    :'min_value' => :'minValue',
    :'max_value' => :'maxValue',
    :'description' => :'description',
    :'attribute' => :'attribute'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 76

def self.openapi_nullable
  Set.new([
    :'value',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 63

def self.openapi_types
  {
    :'name' => :'String',
    :'value' => :'Object',
    :'value_type' => :'String',
    :'min_value' => :'Float',
    :'max_value' => :'Float',
    :'description' => :'String',
    :'attribute' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
207
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      value == o.value &&
      value_type == o.value_type &&
      min_value == o.min_value &&
      max_value == o.max_value &&
      description == o.description &&
      attribute == o.attribute
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 217

def hash
  [name, value, value_type, min_value, max_value, description, attribute].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @value_type.nil?
    invalid_properties.push('invalid value for "value_type", value_type cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/template_parameter.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @value_type.nil?
  return false if @description.nil?
  true
end