Class: TalonOne::TierUpgradeData

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/tier_upgrade_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TierUpgradeData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TierUpgradeData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TierUpgradeData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  else
    self.customer_profile_id = nil
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = ''
  end

  if attributes.key?(:'current_tier')
    self.current_tier = attributes[:'current_tier']
  else
    self.current_tier = nil
  end

  if attributes.key?(:'current_points')
    self.current_points = attributes[:'current_points']
  else
    self.current_points = nil
  end

  if attributes.key?(:'old_tier')
    self.old_tier = attributes[:'old_tier']
  end

  if attributes.key?(:'points_required_to_the_next_tier')
    self.points_required_to_the_next_tier = attributes[:'points_required_to_the_next_tier']
  end

  if attributes.key?(:'next_tier')
    self.next_tier = attributes[:'next_tier']
  end

  if attributes.key?(:'tier_expiration_date')
    self.tier_expiration_date = attributes[:'tier_expiration_date']
  else
    self.tier_expiration_date = nil
  end

  if attributes.key?(:'timestamp_of_tier_change')
    self.timestamp_of_tier_change = attributes[:'timestamp_of_tier_change']
  else
    self.timestamp_of_tier_change = nil
  end
end

Instance Attribute Details

#current_pointsObject

The number of points the customer had at the time of tier upgrade.



31
32
33
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 31

def current_points
  @current_points
end

#current_tierObject

The name of the customer’s current tier.



28
29
30
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 28

def current_tier
  @current_tier
end

#customer_profile_idObject

The integration ID of the customer profile whose tier was upgraded.



19
20
21
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 19

def customer_profile_id
  @customer_profile_id
end

#loyalty_program_idObject

The ID of the loyalty program.



22
23
24
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 22

def loyalty_program_id
  @loyalty_program_id
end

#next_tierObject

The name of the customer’s next tier.



40
41
42
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 40

def next_tier
  @next_tier
end

#old_tierObject

The name of the customer’s previous tier.



34
35
36
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 34

def old_tier
  @old_tier
end

#points_required_to_the_next_tierObject

The number of points needed for a customer to reach the next tier.



37
38
39
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 37

def points_required_to_the_next_tier
  @points_required_to_the_next_tier
end

#subledger_idObject

The ID of the subledger, when applicable. If this field is empty, the main ledger is used.



25
26
27
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 25

def subledger_id
  @subledger_id
end

#tier_expiration_dateObject

The exact date and time the tier expires.



43
44
45
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 43

def tier_expiration_date
  @tier_expiration_date
end

#timestamp_of_tier_changeObject

The exact date and time the tier was changed.



46
47
48
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 46

def timestamp_of_tier_change
  @timestamp_of_tier_change
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 49

def self.attribute_map
  {
    :'customer_profile_id' => :'CustomerProfileID',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'subledger_id' => :'SubledgerID',
    :'current_tier' => :'CurrentTier',
    :'current_points' => :'CurrentPoints',
    :'old_tier' => :'OldTier',
    :'points_required_to_the_next_tier' => :'PointsRequiredToTheNextTier',
    :'next_tier' => :'NextTier',
    :'tier_expiration_date' => :'TierExpirationDate',
    :'timestamp_of_tier_change' => :'TimestampOfTierChange'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 75

def self.openapi_types
  {
    :'customer_profile_id' => :'String',
    :'loyalty_program_id' => :'Integer',
    :'subledger_id' => :'String',
    :'current_tier' => :'String',
    :'current_points' => :'Float',
    :'old_tier' => :'String',
    :'points_required_to_the_next_tier' => :'Float',
    :'next_tier' => :'String',
    :'tier_expiration_date' => :'Time',
    :'timestamp_of_tier_change' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_profile_id == o.customer_profile_id &&
      loyalty_program_id == o.loyalty_program_id &&
      subledger_id == o.subledger_id &&
      current_tier == o.current_tier &&
      current_points == o.current_points &&
      old_tier == o.old_tier &&
      points_required_to_the_next_tier == o.points_required_to_the_next_tier &&
      next_tier == o.next_tier &&
      tier_expiration_date == o.tier_expiration_date &&
      timestamp_of_tier_change == o.timestamp_of_tier_change
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 321

def hash
  [customer_profile_id, loyalty_program_id, subledger_id, current_tier, current_points, old_tier, points_required_to_the_next_tier, next_tier, tier_expiration_date, timestamp_of_tier_change].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @customer_profile_id.nil?
    invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @current_tier.nil?
    invalid_properties.push('invalid value for "current_tier", current_tier cannot be nil.')
  end

  if @current_points.nil?
    invalid_properties.push('invalid value for "current_points", current_points cannot be nil.')
  end

  if @tier_expiration_date.nil?
    invalid_properties.push('invalid value for "tier_expiration_date", tier_expiration_date cannot be nil.')
  end

  if @timestamp_of_tier_change.nil?
    invalid_properties.push('invalid value for "timestamp_of_tier_change", timestamp_of_tier_change cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/tier_upgrade_data.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @customer_profile_id.nil?
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @subledger_id.nil?
  return false if @current_tier.nil?
  return false if @current_points.nil?
  return false if @tier_expiration_date.nil?
  return false if @timestamp_of_tier_change.nil?
  true
end