Class: TalonOne::TimePoint

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/time_point.rb

Overview

The absolute duration after which the achievement ends and resets for a particular customer profile. Note: The duration follows the time zone of the Application this achievement belongs to.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TimePoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/talon_one_sdk/models/time_point.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TimePoint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TimePoint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'month')
    self.month = attributes[:'month']
  end

  if attributes.key?(:'day_of_month')
    self.day_of_month = attributes[:'day_of_month']
  end

  if attributes.key?(:'day_of_week')
    self.day_of_week = attributes[:'day_of_week']
  end

  if attributes.key?(:'hour')
    self.hour = attributes[:'hour']
  else
    self.hour = nil
  end

  if attributes.key?(:'minute')
    self.minute = attributes[:'minute']
  else
    self.minute = nil
  end

  if attributes.key?(:'second')
    self.second = attributes[:'second']
  else
    self.second = nil
  end
end

Instance Attribute Details

#day_of_monthObject

The achievement ends and resets on this day of the month. Note: Only applicable if the period is set to ‘Y` or `M`.



23
24
25
# File 'lib/talon_one_sdk/models/time_point.rb', line 23

def day_of_month
  @day_of_month
end

#day_of_weekObject

The achievement ends and resets on this day of the week. ‘1` represents `Monday` and `7` represents `Sunday`. Note: Only applicable if the period is set to `W`.



26
27
28
# File 'lib/talon_one_sdk/models/time_point.rb', line 26

def day_of_week
  @day_of_week
end

#hourObject

The achievement ends and resets at this hour.



29
30
31
# File 'lib/talon_one_sdk/models/time_point.rb', line 29

def hour
  @hour
end

#minuteObject

The achievement ends and resets at this minute.



32
33
34
# File 'lib/talon_one_sdk/models/time_point.rb', line 32

def minute
  @minute
end

#monthObject

The achievement ends and resets in this month. Note: Only applicable if the period is set to ‘Y`.



20
21
22
# File 'lib/talon_one_sdk/models/time_point.rb', line 20

def month
  @month
end

#secondObject

The achievement ends and resets at this second.



35
36
37
# File 'lib/talon_one_sdk/models/time_point.rb', line 35

def second
  @second
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/time_point.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/time_point.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/talon_one_sdk/models/time_point.rb', line 38

def self.attribute_map
  {
    :'month' => :'month',
    :'day_of_month' => :'dayOfMonth',
    :'day_of_week' => :'dayOfWeek',
    :'hour' => :'hour',
    :'minute' => :'minute',
    :'second' => :'second'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/talon_one_sdk/models/time_point.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/talon_one_sdk/models/time_point.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/talon_one_sdk/models/time_point.rb', line 60

def self.openapi_types
  {
    :'month' => :'Integer',
    :'day_of_month' => :'Integer',
    :'day_of_week' => :'Integer',
    :'hour' => :'Integer',
    :'minute' => :'Integer',
    :'second' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



270
271
272
273
274
275
276
277
278
279
# File 'lib/talon_one_sdk/models/time_point.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      month == o.month &&
      day_of_month == o.day_of_month &&
      day_of_week == o.day_of_week &&
      hour == o.hour &&
      minute == o.minute &&
      second == o.second
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/talon_one_sdk/models/time_point.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/talon_one_sdk/models/time_point.rb', line 289

def hash
  [month, day_of_month, day_of_week, hour, minute, second].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/talon_one_sdk/models/time_point.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@month.nil? && @month > 12
    invalid_properties.push('invalid value for "month", must be smaller than or equal to 12.')
  end

  if !@month.nil? && @month < 1
    invalid_properties.push('invalid value for "month", must be greater than or equal to 1.')
  end

  if !@day_of_month.nil? && @day_of_month > 31
    invalid_properties.push('invalid value for "day_of_month", must be smaller than or equal to 31.')
  end

  if !@day_of_month.nil? && @day_of_month < 1
    invalid_properties.push('invalid value for "day_of_month", must be greater than or equal to 1.')
  end

  if !@day_of_week.nil? && @day_of_week > 7
    invalid_properties.push('invalid value for "day_of_week", must be smaller than or equal to 7.')
  end

  if !@day_of_week.nil? && @day_of_week < 1
    invalid_properties.push('invalid value for "day_of_week", must be greater than or equal to 1.')
  end

  if @hour.nil?
    invalid_properties.push('invalid value for "hour", hour cannot be nil.')
  end

  if @minute.nil?
    invalid_properties.push('invalid value for "minute", minute cannot be nil.')
  end

  if @second.nil?
    invalid_properties.push('invalid value for "second", second cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/talon_one_sdk/models/time_point.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/time_point.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@month.nil? && @month > 12
  return false if !@month.nil? && @month < 1
  return false if !@day_of_month.nil? && @day_of_month > 31
  return false if !@day_of_month.nil? && @day_of_month < 1
  return false if !@day_of_week.nil? && @day_of_week > 7
  return false if !@day_of_week.nil? && @day_of_week < 1
  return false if @hour.nil?
  return false if @minute.nil?
  return false if @second.nil?
  true
end