Class: TalonOne::TransferLoyaltyCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::TransferLoyaltyCard
- Defined in:
- lib/talon_one_sdk/models/transfer_loyalty_card.rb
Instance Attribute Summary collapse
-
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
-
#new_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransferLoyaltyCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TransferLoyaltyCard
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TransferLoyaltyCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TransferLoyaltyCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'new_card_identifier') self.new_card_identifier = attributes[:'new_card_identifier'] else self.new_card_identifier = nil end if attributes.key?(:'block_reason') self.block_reason = attributes[:'block_reason'] end end |
Instance Attribute Details
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
22 23 24 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 22 def block_reason @block_reason end |
#new_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
19 20 21 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 19 def new_card_identifier @new_card_identifier end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 25 def self.attribute_map { :'new_card_identifier' => :'newCardIdentifier', :'block_reason' => :'blockReason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 166 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 43 def self.openapi_types { :'new_card_identifier' => :'String', :'block_reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && new_card_identifier == o.new_card_identifier && block_reason == o.block_reason end |
#eql?(o) ⇒ Boolean
153 154 155 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 153 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 159 def hash [new_card_identifier, block_reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @new_card_identifier.nil? invalid_properties.push('invalid value for "new_card_identifier", new_card_identifier cannot be nil.') end if @new_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "new_card_identifier", the character length must be smaller than or equal to 108.') end if @new_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "new_card_identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if @new_card_identifier !~ pattern invalid_properties.push("invalid value for \"new_card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 116 117 |
# File 'lib/talon_one_sdk/models/transfer_loyalty_card.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @new_card_identifier.nil? return false if @new_card_identifier.to_s.length > 108 return false if @new_card_identifier.to_s.length < 4 return false if @new_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |