Class: TalonOne::TriggerCustomEffectBlock

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/trigger_custom_effect_block.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TriggerCustomEffectBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TriggerCustomEffectBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TriggerCustomEffectBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'custom_effect')
    self.custom_effect = attributes[:'custom_effect']
  else
    self.custom_effect = nil
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Hash)
      self.params = value
    end
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'on_error')
    if (value = attributes[:'on_error']).is_a?(Hash)
      self.on_error = value
    end
  end
end

Instance Attribute Details

#custom_effectObject

Returns the value of attribute custom_effect.



27
28
29
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 27

def custom_effect
  @custom_effect
end

#idObject

Unique identifier for this block.



19
20
21
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 19

def id
  @id
end

#on_errorObject

Named error handlers evaluated when a specific error occurs.



35
36
37
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 35

def on_error
  @on_error
end

#paramsObject

The custom effect's parameters, in configured order. Each property name is the parameter's title, lowercased with spaces replaced by underscores (for example, Order ID becomes order_id); falls back to param_0, param_1, and so on if a title is blank or collides with another.



30
31
32
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 30

def params
  @params
end

#tagsObject

Semantic labels attached to this block.



25
26
27
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 25

def tags
  @tags
end

#targetObject

Returns the value of attribute target.



32
33
34
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 32

def target
  @target
end

#typeObject

Identifies the block variant and determines which additional properties are present in it.



22
23
24
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 22

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'tags' => :'tags',
    :'custom_effect' => :'customEffect',
    :'params' => :'params',
    :'target' => :'target',
    :'on_error' => :'onError'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



80
81
82
83
84
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 80

def self.openapi_all_of
  [
  :'BaseBlock'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 61

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'tags' => :'Array<String>',
    :'custom_effect' => :'TriggerCustomEffectBlock1CustomEffect',
    :'params' => :'Hash<String, Object>',
    :'target' => :'TriggerCustomEffectBlock1Target',
    :'on_error' => :'Hash<String, Array<PromotionBlock>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      tags == o.tags &&
      custom_effect == o.custom_effect &&
      params == o.params &&
      target == o.target &&
      on_error == o.on_error
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 242

def hash
  [id, type, tags, custom_effect, params, target, on_error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @custom_effect.nil?
    invalid_properties.push('invalid value for "custom_effect", custom_effect cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
178
# File 'lib/talon_one_sdk/models/trigger_custom_effect_block.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  return false if @custom_effect.nil?
  return false if @target.nil?
  true
end