Class: TalonOne::TriggerWebhookBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::TriggerWebhookBlock
- Defined in:
- lib/talon_one_sdk/models/trigger_webhook_block.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier for this block.
-
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
-
#params ⇒ Object
The webhook's parameters, in configured order.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
-
#webhook ⇒ Object
Returns the value of attribute webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TriggerWebhookBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TriggerWebhookBlock
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TriggerWebhookBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TriggerWebhookBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'webhook') self.webhook = attributes[:'webhook'] else self.webhook = nil end if attributes.key?(:'params') if (value = attributes[:'params']).is_a?(Hash) self.params = value end end if attributes.key?(:'on_error') if (value = attributes[:'on_error']).is_a?(Hash) self.on_error = value end end end |
Instance Attribute Details
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 19 def id @id end |
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
33 34 35 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 33 def on_error @on_error end |
#params ⇒ Object
The webhook's parameters, in configured order. Each property name is the parameter's title, lowercased with spaces replaced by underscores (for example, Order ID becomes order_id); falls back to param_0, param_1, and so on if a title is blank or collides with another.
30 31 32 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 30 def params @params end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 25 def @tags end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 22 def type @type end |
#webhook ⇒ Object
Returns the value of attribute webhook.
27 28 29 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 27 def webhook @webhook end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 36 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'webhook' => :'webhook', :'params' => :'params', :'on_error' => :'onError' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 76 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 70 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 58 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'webhook' => :'TriggerWebhookBlock1Webhook', :'params' => :'Hash<String, Object>', :'on_error' => :'Hash<String, Array<PromotionBlock>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && webhook == o.webhook && params == o.params && on_error == o.on_error end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 216 def hash [id, type, , webhook, params, on_error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @webhook.nil? invalid_properties.push('invalid value for "webhook", webhook cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/trigger_webhook_block.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @webhook.nil? true end |