Class: TalonOne::UpdateAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateAccount
- Defined in:
- lib/talon_one_sdk/models/update_account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#billing_email ⇒ Object
The billing email address associated with your company account.
-
#company_name ⇒ Object
Name of your company.
-
#plan_expires ⇒ Object
The point in time at which your current plan expires.
-
#state ⇒ Object
State of the account (active, deactivated).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAccount
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] else self.company_name = nil end if attributes.key?(:'billing_email') self.billing_email = attributes[:'billing_email'] else self.billing_email = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'plan_expires') self.plan_expires = attributes[:'plan_expires'] end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 19 def attributes @attributes end |
#billing_email ⇒ Object
The billing email address associated with your company account.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 25 def billing_email @billing_email end |
#company_name ⇒ Object
Name of your company.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 22 def company_name @company_name end |
#plan_expires ⇒ Object
The point in time at which your current plan expires.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 31 def plan_expires @plan_expires end |
#state ⇒ Object
State of the account (active, deactivated).
28 29 30 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 28 def state @state end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 56 def self.attribute_map { :'attributes' => :'attributes', :'company_name' => :'companyName', :'billing_email' => :'billingEmail', :'state' => :'state', :'plan_expires' => :'planExpires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 77 def self.openapi_types { :'attributes' => :'Object', :'company_name' => :'String', :'billing_email' => :'String', :'state' => :'String', :'plan_expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && attributes == o.attributes && company_name == o.company_name && billing_email == o.billing_email && state == o.state && plan_expires == o.plan_expires end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 220 def hash [attributes, company_name, billing_email, state, plan_expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 136 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @company_name.nil? invalid_properties.push('invalid value for "company_name", company_name cannot be nil.') end if @company_name.to_s.length < 1 invalid_properties.push('invalid value for "company_name", the character length must be greater than or equal to 1.') end if @billing_email.nil? invalid_properties.push('invalid value for "billing_email", billing_email cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 164 |
# File 'lib/talon_one_sdk/models/update_account.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @company_name.nil? return false if @company_name.to_s.length < 1 return false if @billing_email.nil? state_validator = EnumAttributeValidator.new('String', ["active", "deactivated"]) return false unless state_validator.valid?(@state) true end |