Class: TalonOne::UpdateAchievement
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateAchievement
- Defined in:
- lib/talon_one_sdk/models/update_achievement.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activation_policy ⇒ Object
The policy that determines how the achievement starts, ends, or resets.
-
#allow_rollback_after_completion ⇒ Object
When ‘true`, customer progress can be rolled back in completed achievements.
-
#description ⇒ Object
A description of the achievement.
-
#end_date ⇒ Object
The achievement’s end date.
-
#fixed_start_date ⇒ Object
The achievement’s start date when ‘activationPolicy` is set to `fixed_schedule`.
-
#name ⇒ Object
The internal name of the achievement used in API requests.
-
#period ⇒ Object
The relative duration after which the achievement ends and resets for a particular customer profile.
-
#period_end_override ⇒ Object
Returns the value of attribute period_end_override.
-
#recurrence_policy ⇒ Object
The policy that determines if and how the achievement recurs.
-
#target ⇒ Object
The required number of actions or the transactional milestone to complete the achievement.
-
#title ⇒ Object
The display name for the achievement in the Campaign Manager.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAchievement
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAchievement
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 131 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateAchievement` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateAchievement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'period') self.period = attributes[:'period'] end if attributes.key?(:'period_end_override') self.period_end_override = attributes[:'period_end_override'] end if attributes.key?(:'recurrence_policy') self.recurrence_policy = attributes[:'recurrence_policy'] end if attributes.key?(:'activation_policy') self.activation_policy = attributes[:'activation_policy'] end if attributes.key?(:'fixed_start_date') self.fixed_start_date = attributes[:'fixed_start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'allow_rollback_after_completion') self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion'] end end |
Instance Attribute Details
#activation_policy ⇒ Object
The policy that determines how the achievement starts, ends, or resets. - ‘user_action`: The achievement ends or resets relative to when the customer started the achievement. - `fixed_schedule`: The achievement starts, ends, or resets for all customers following a fixed schedule.
39 40 41 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 39 def activation_policy @activation_policy end |
#allow_rollback_after_completion ⇒ Object
When ‘true`, customer progress can be rolled back in completed achievements.
48 49 50 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 48 def allow_rollback_after_completion @allow_rollback_after_completion end |
#description ⇒ Object
A description of the achievement.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 25 def description @description end |
#end_date ⇒ Object
The achievement’s end date. If defined, customers cannot participate in the achievement after this date. Note: It must be an RFC3339 timestamp string.
45 46 47 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 45 def end_date @end_date end |
#fixed_start_date ⇒ Object
The achievement’s start date when ‘activationPolicy` is set to `fixed_schedule`. Note: It must be an RFC3339 timestamp string.
42 43 44 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 42 def fixed_start_date @fixed_start_date end |
#name ⇒ Object
The internal name of the achievement used in API requests. Note: The name should start with a letter. This cannot be changed after the achievement has been created.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 19 def name @name end |
#period ⇒ Object
The relative duration after which the achievement ends and resets for a particular customer profile. Note: The ‘period` does not start when the achievement is created. The period is a **positive real number** followed by one letter indicating the time unit. Examples: `30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can also round certain units down to the beginning of period and up to the end of period.: - `_D` for rounding down days only. Signifies the start of the day. Example: `30D_D` - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. Example: `23W_U` Note: You can either use the round down and round up option or set an absolute period.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 31 def period @period end |
#period_end_override ⇒ Object
Returns the value of attribute period_end_override.
33 34 35 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 33 def period_end_override @period_end_override end |
#recurrence_policy ⇒ Object
The policy that determines if and how the achievement recurs. - ‘no_recurrence`: The achievement can be completed only once. - `on_expiration`: The achievement resets after it expires and becomes available again. - `on_completion`: When the customer progress status reaches `completed`, the achievement resets and becomes available again.
36 37 38 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 36 def recurrence_policy @recurrence_policy end |
#target ⇒ Object
The required number of actions or the transactional milestone to complete the achievement.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 28 def target @target end |
#title ⇒ Object
The display name for the achievement in the Campaign Manager.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 22 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 73 def self.attribute_map { :'name' => :'name', :'title' => :'title', :'description' => :'description', :'target' => :'target', :'period' => :'period', :'period_end_override' => :'periodEndOverride', :'recurrence_policy' => :'recurrencePolicy', :'activation_policy' => :'activationPolicy', :'fixed_start_date' => :'fixedStartDate', :'end_date' => :'endDate', :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
123 124 125 126 127 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 123 def self.openapi_all_of [ :'AchievementBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
117 118 119 120 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 117 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 100 def self.openapi_types { :'name' => :'String', :'title' => :'String', :'description' => :'String', :'target' => :'Float', :'period' => :'String', :'period_end_override' => :'TimePoint', :'recurrence_policy' => :'String', :'activation_policy' => :'String', :'fixed_start_date' => :'Time', :'end_date' => :'Time', :'allow_rollback_after_completion' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 270 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && title == o.title && description == o.description && target == o.target && period == o.period && period_end_override == o.period_end_override && recurrence_policy == o.recurrence_policy && activation_policy == o.activation_policy && fixed_start_date == o.fixed_start_date && end_date == o.end_date && allow_rollback_after_completion == o.allow_rollback_after_completion end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 294 def hash [name, title, description, target, period, period_end_override, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 192 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 1000 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-zA-Z]\w+$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/talon_one_sdk/models/update_achievement.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 1000 return false if !@name.nil? && @name.to_s.length < 1 return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z]\w+$/) recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"]) return false unless recurrence_policy_validator.valid?(@recurrence_policy) activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"]) return false unless activation_policy_validator.valid?(@activation_policy) true end |