Class: TalonOne::UpdateAttributeValueBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateAttributeValueBlock
- Defined in:
- lib/talon_one_sdk/models/update_attribute_value_block.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attribute ⇒ Object
Returns the value of attribute attribute.
-
#id ⇒ Object
Unique identifier for this block.
-
#operator ⇒ Object
The update operation applied to the attribute.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#target ⇒ Object
Returns the value of attribute target.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAttributeValueBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAttributeValueBlock
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateAttributeValueBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateAttributeValueBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'attribute') self.attribute = attributes[:'attribute'] else self.attribute = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end end |
Instance Attribute Details
#attribute ⇒ Object
Returns the value of attribute attribute.
30 31 32 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 30 def attribute @attribute end |
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 19 def id @id end |
#operator ⇒ Object
The update operation applied to the attribute.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 28 def operator @operator end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 25 def @tags end |
#target ⇒ Object
Returns the value of attribute target.
34 35 36 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 34 def target @target end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 22 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
32 33 34 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 32 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 59 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'operator' => :'operator', :'attribute' => :'attribute', :'value' => :'value', :'target' => :'target' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 102 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 95 def self.openapi_nullable Set.new([ :'value', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 82 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'operator' => :'String', :'attribute' => :'UpdateAttributeValueBlock1Attribute', :'value' => :'Object', :'target' => :'UpdateAttributeValueBlock1Target' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && operator == o.operator && attribute == o.attribute && value == o.value && target == o.target end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 279 def hash [id, type, , operator, attribute, value, target].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end if @attribute.nil? invalid_properties.push('invalid value for "attribute", attribute cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/update_attribute_value_block.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["setTo", "increaseBy", "decreaseBy", "multiplyBy", "divideBy", "toggle", "laterBy", "earlierBy"]) return false unless operator_validator.valid?(@operator) return false if @attribute.nil? return false if @target.nil? true end |