Class: TalonOne::UpdateCampaign

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_campaign.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaign

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 158

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCampaign` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCampaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'enabled'
  end

  if attributes.key?(:'active_ruleset_id')
    self.active_ruleset_id = attributes[:'active_ruleset_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'reevaluate_on_return')
    self.reevaluate_on_return = attributes[:'reevaluate_on_return']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  else
    self.features = nil
  end

  if attributes.key?(:'coupon_settings')
    self.coupon_settings = attributes[:'coupon_settings']
  end

  if attributes.key?(:'referral_settings')
    self.referral_settings = attributes[:'referral_settings']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  else
    self.limits = nil
  end

  if attributes.key?(:'campaign_groups')
    if (value = attributes[:'campaign_groups']).is_a?(Array)
      self.campaign_groups = value
    end
  end

  if attributes.key?(:'evaluation_group_id')
    self.evaluation_group_id = attributes[:'evaluation_group_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'advanced'
  end

  if attributes.key?(:'linked_store_ids')
    if (value = attributes[:'linked_store_ids']).is_a?(Array)
      self.linked_store_ids = value
    end
  end

  if attributes.key?(:'coupon_attributes')
    self.coupon_attributes = attributes[:'coupon_attributes']
  end
end

Instance Attribute Details

#active_ruleset_idObject

[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.



37
38
39
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 37

def active_ruleset_id
  @active_ruleset_id
end

#attributesObject

Arbitrary properties associated with this campaign.



31
32
33
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 31

def attributes
  @attributes
end

#campaign_groupsObject

The IDs of the [campaign groups](docs.talon.one/docs/product/account/account-settings/managing-campaign-groups) this campaign belongs to.



56
57
58
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 56

def campaign_groups
  @campaign_groups
end

#coupon_attributesObject

Arbitrary properties associated with coupons in this campaign.



68
69
70
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 68

def coupon_attributes
  @coupon_attributes
end

#coupon_settingsObject

Returns the value of attribute coupon_settings.



48
49
50
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 48

def coupon_settings
  @coupon_settings
end

#descriptionObject

A detailed description of the campaign.



22
23
24
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 22

def description
  @description
end

#end_timeObject

Timestamp when the campaign will become inactive.



28
29
30
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 28

def end_time
  @end_time
end

#evaluation_group_idObject

The ID of the campaign evaluation group the campaign belongs to.



59
60
61
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 59

def evaluation_group_id
  @evaluation_group_id
end

#featuresObject

A list of features for the campaign.



46
47
48
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 46

def features
  @features
end

#limitsObject

The set of limits that will operate for this campaign.



53
54
55
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 53

def limits
  @limits
end

#linked_store_idsObject

A list of store IDs that you want to link to the campaign. > [!note] Note > - Campaigns with linked store IDs will only be evaluated when there is a > [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) > that references a linked store. > - If you linked stores to the campaign by uploading a CSV file, you cannot use this property and it should be empty. > - Use of this property is limited to 50 stores. To link more than 50 stores, upload them via a CSV file.



65
66
67
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 65

def linked_store_ids
  @linked_store_ids
end

#nameObject

A user-facing name for this campaign.



19
20
21
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 19

def name
  @name
end

#reevaluate_on_returnObject

Indicates whether this campaign should be reevaluated when a customer returns an item.



43
44
45
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 43

def reevaluate_on_return
  @reevaluate_on_return
end

#referral_settingsObject

Returns the value of attribute referral_settings.



50
51
52
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 50

def referral_settings
  @referral_settings
end

#start_timeObject

Timestamp when the campaign will become active.



25
26
27
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 25

def start_time
  @start_time
end

#stateObject

A disabled or archived campaign is not evaluated for rules or coupons.



34
35
36
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 34

def state
  @state
end

#tagsObject

A list of tags for the campaign.



40
41
42
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 40

def tags
  @tags
end

#typeObject

The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.



62
63
64
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 62

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



117
118
119
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 117

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



122
123
124
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 122

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 93

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'attributes' => :'attributes',
    :'state' => :'state',
    :'active_ruleset_id' => :'activeRulesetId',
    :'tags' => :'tags',
    :'reevaluate_on_return' => :'reevaluateOnReturn',
    :'features' => :'features',
    :'coupon_settings' => :'couponSettings',
    :'referral_settings' => :'referralSettings',
    :'limits' => :'limits',
    :'campaign_groups' => :'campaignGroups',
    :'evaluation_group_id' => :'evaluationGroupId',
    :'type' => :'type',
    :'linked_store_ids' => :'linkedStoreIds',
    :'coupon_attributes' => :'couponAttributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 414

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 151

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 127

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'attributes' => :'Object',
    :'state' => :'String',
    :'active_ruleset_id' => :'Integer',
    :'tags' => :'Array<String>',
    :'reevaluate_on_return' => :'Boolean',
    :'features' => :'Array<String>',
    :'coupon_settings' => :'CodeGeneratorSettings',
    :'referral_settings' => :'CodeGeneratorSettings',
    :'limits' => :'Array<LimitConfig>',
    :'campaign_groups' => :'Array<Integer>',
    :'evaluation_group_id' => :'Integer',
    :'type' => :'String',
    :'linked_store_ids' => :'Array<Integer>',
    :'coupon_attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 376

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      attributes == o.attributes &&
      state == o.state &&
      active_ruleset_id == o.active_ruleset_id &&
      tags == o.tags &&
      reevaluate_on_return == o.reevaluate_on_return &&
      features == o.features &&
      coupon_settings == o.coupon_settings &&
      referral_settings == o.referral_settings &&
      limits == o.limits &&
      campaign_groups == o.campaign_groups &&
      evaluation_group_id == o.evaluation_group_id &&
      type == o.type &&
      linked_store_ids == o.linked_store_ids &&
      coupon_attributes == o.coupon_attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


401
402
403
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 401

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



407
408
409
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 407

def hash
  [name, description, start_time, end_time, attributes, state, active_ruleset_id, tags, reevaluate_on_return, features, coupon_settings, referral_settings, limits, campaign_groups, evaluation_group_id, type, linked_store_ids, coupon_attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 269

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @tags.length > 50
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.')
  end

  if @features.nil?
    invalid_properties.push('invalid value for "features", features cannot be nil.')
  end

  if @limits.nil?
    invalid_properties.push('invalid value for "limits", limits cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/talon_one_sdk/models/update_campaign.rb', line 301

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"])
  return false unless state_validator.valid?(@state)
  return false if @tags.nil?
  return false if @tags.length > 50
  return false if @features.nil?
  return false if @limits.nil?
  type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"])
  return false unless type_validator.valid?(@type)
  true
end