Class: TalonOne::UpdateCampaignEvaluationGroup

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/update_campaign_evaluation_group.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignEvaluationGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCampaignEvaluationGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCampaignEvaluationGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  else
    self.parent_id = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'evaluation_mode')
    self.evaluation_mode = attributes[:'evaluation_mode']
  else
    self.evaluation_mode = nil
  end

  if attributes.key?(:'evaluation_scope')
    self.evaluation_scope = attributes[:'evaluation_scope']
  else
    self.evaluation_scope = nil
  end

  if attributes.key?(:'locked')
    self.locked = attributes[:'locked']
  else
    self.locked = nil
  end
end

Instance Attribute Details

#descriptionObject

A description of the campaign evaluation group.



25
26
27
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 25

def description
  @description
end

#evaluation_modeObject

The mode by which campaigns in the campaign evaluation group are evaluated.



28
29
30
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 28

def evaluation_mode
  @evaluation_mode
end

#evaluation_scopeObject

The evaluation scope of the campaign evaluation group.



31
32
33
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 31

def evaluation_scope
  @evaluation_scope
end

#lockedObject

An indicator of whether the campaign evaluation group is locked for modification.



34
35
36
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 34

def locked
  @locked
end

#nameObject

The name of the campaign evaluation group.



19
20
21
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 19

def name
  @name
end

#parent_idObject

The ID of the parent group that contains the campaign evaluation group.



22
23
24
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 22

def parent_id
  @parent_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 59

def self.attribute_map
  {
    :'name' => :'name',
    :'parent_id' => :'parentId',
    :'description' => :'description',
    :'evaluation_mode' => :'evaluationMode',
    :'evaluation_scope' => :'evaluationScope',
    :'locked' => :'locked'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 287

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



99
100
101
102
103
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 99

def self.openapi_all_of
  [
  :'NewCampaignEvaluationGroup'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 81

def self.openapi_types
  {
    :'name' => :'String',
    :'parent_id' => :'Integer',
    :'description' => :'String',
    :'evaluation_mode' => :'String',
    :'evaluation_scope' => :'String',
    :'locked' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      parent_id == o.parent_id &&
      description == o.description &&
      evaluation_mode == o.evaluation_mode &&
      evaluation_scope == o.evaluation_scope &&
      locked == o.locked
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 280

def hash
  [name, parent_id, description, evaluation_mode, evaluation_scope, locked].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @parent_id.nil?
    invalid_properties.push('invalid value for "parent_id", parent_id cannot be nil.')
  end

  if @parent_id < 1
    invalid_properties.push('invalid value for "parent_id", must be greater than or equal to 1.')
  end

  if @evaluation_mode.nil?
    invalid_properties.push('invalid value for "evaluation_mode", evaluation_mode cannot be nil.')
  end

  if @evaluation_scope.nil?
    invalid_properties.push('invalid value for "evaluation_scope", evaluation_scope cannot be nil.')
  end

  if @locked.nil?
    invalid_properties.push('invalid value for "locked", locked cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/talon_one_sdk/models/update_campaign_evaluation_group.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @parent_id.nil?
  return false if @parent_id < 1
  return false if @evaluation_mode.nil?
  evaluation_mode_validator = EnumAttributeValidator.new('String', ["stackable", "listOrder", "lowestDiscount", "highestDiscount"])
  return false unless evaluation_mode_validator.valid?(@evaluation_mode)
  return false if @evaluation_scope.nil?
  evaluation_scope_validator = EnumAttributeValidator.new('String', ["cartItem", "session"])
  return false unless evaluation_scope_validator.valid?(@evaluation_scope)
  return false if @locked.nil?
  true
end