Class: TalonOne::UpdateCampaignGroup

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_campaign_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCampaignGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCampaignGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribed_applications_ids')
    if (value = attributes[:'subscribed_applications_ids']).is_a?(Array)
      self.subscribed_applications_ids = value
    end
  end

  if attributes.key?(:'campaign_ids')
    if (value = attributes[:'campaign_ids']).is_a?(Array)
      self.campaign_ids = value
    end
  end
end

Instance Attribute Details

#campaign_idsObject

A list of IDs of the campaigns that are part of the campaign access group.



28
29
30
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 28

def campaign_ids
  @campaign_ids
end

#descriptionObject

A longer description of the campaign access group.



22
23
24
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 22

def description
  @description
end

#nameObject

The name of the campaign access group.



19
20
21
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 19

def name
  @name
end

#subscribed_applications_idsObject

A list of IDs of the Applications that this campaign access group is enabled for.



25
26
27
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 25

def subscribed_applications_ids
  @subscribed_applications_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'subscribed_applications_ids' => :'subscribedApplicationsIds',
    :'campaign_ids' => :'campaignIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



67
68
69
70
71
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 67

def self.openapi_all_of
  [
  :'NewCampaignGroup'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 51

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'subscribed_applications_ids' => :'Array<Integer>',
    :'campaign_ids' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      subscribed_applications_ids == o.subscribed_applications_ids &&
      campaign_ids == o.campaign_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 170

def hash
  [name, description, subscribed_applications_ids, campaign_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/update_campaign_group.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  true
end