Class: TalonOne::UpdateCampaignTemplate

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_campaign_template.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCampaignTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCampaignTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'instructions')
    self.instructions = attributes[:'instructions']
  else
    self.instructions = nil
  end

  if attributes.key?(:'campaign_attributes')
    self.campaign_attributes = attributes[:'campaign_attributes']
  end

  if attributes.key?(:'coupon_attributes')
    self.coupon_attributes = attributes[:'coupon_attributes']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'active_ruleset_id')
    self.active_ruleset_id = attributes[:'active_ruleset_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'reevaluate_on_return')
    self.reevaluate_on_return = attributes[:'reevaluate_on_return']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  end

  if attributes.key?(:'coupon_settings')
    self.coupon_settings = attributes[:'coupon_settings']
  end

  if attributes.key?(:'coupon_reservation_settings')
    self.coupon_reservation_settings = attributes[:'coupon_reservation_settings']
  end

  if attributes.key?(:'referral_settings')
    self.referral_settings = attributes[:'referral_settings']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'template_params')
    if (value = attributes[:'template_params']).is_a?(Array)
      self.template_params = value
    end
  end

  if attributes.key?(:'applications_ids')
    if (value = attributes[:'applications_ids']).is_a?(Array)
      self.applications_ids = value
    end
  else
    self.applications_ids = nil
  end

  if attributes.key?(:'campaign_collections')
    if (value = attributes[:'campaign_collections']).is_a?(Array)
      self.campaign_collections = value
    end
  end

  if attributes.key?(:'default_campaign_group_id')
    self.default_campaign_group_id = attributes[:'default_campaign_group_id']
  end

  if attributes.key?(:'campaign_type')
    self.campaign_type = attributes[:'campaign_type']
  else
    self.campaign_type = 'advanced'
  end
end

Instance Attribute Details

#active_ruleset_idObject

The ID of the ruleset this campaign template will use.



37
38
39
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 37

def active_ruleset_id
  @active_ruleset_id
end

#applications_idsObject

A list of IDs of the Applications that are subscribed to this campaign template.



61
62
63
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 61

def applications_ids
  @applications_ids
end

#campaign_attributesObject

The campaign attributes that campaigns created from this template will have by default.



28
29
30
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 28

def campaign_attributes
  @campaign_attributes
end

#campaign_collectionsObject

The campaign collections from the blueprint campaign for the template.



64
65
66
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 64

def campaign_collections
  @campaign_collections
end

#campaign_typeObject

The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.



70
71
72
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 70

def campaign_type
  @campaign_type
end

#coupon_attributesObject

The campaign attributes that coupons created from this template will have by default.



31
32
33
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 31

def coupon_attributes
  @coupon_attributes
end

#coupon_reservation_settingsObject

Returns the value of attribute coupon_reservation_settings.



50
51
52
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 50

def coupon_reservation_settings
  @coupon_reservation_settings
end

#coupon_settingsObject

Returns the value of attribute coupon_settings.



48
49
50
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 48

def coupon_settings
  @coupon_settings
end

#default_campaign_group_idObject

The default campaign group ID.



67
68
69
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 67

def default_campaign_group_id
  @default_campaign_group_id
end

#descriptionObject

Customer-facing text that explains the objective of the template.



22
23
24
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 22

def description
  @description
end

#featuresObject

A list of features for the campaign template.



46
47
48
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 46

def features
  @features
end

#instructionsObject

Customer-facing text that explains how to use the template. For example, you can use this property to explain the available attributes of this template, and how they can be modified when a user uses this template to create a new campaign.



25
26
27
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 25

def instructions
  @instructions
end

#limitsObject

The set of limits that operate for this campaign template.



55
56
57
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 55

def limits
  @limits
end

#nameObject

The campaign template name.



19
20
21
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 19

def name
  @name
end

#reevaluate_on_returnObject

Indicates whether campaigns created from this template should be reevaluated when a customer returns an item.



43
44
45
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 43

def reevaluate_on_return
  @reevaluate_on_return
end

#referral_settingsObject

Returns the value of attribute referral_settings.



52
53
54
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 52

def referral_settings
  @referral_settings
end

#stateObject

Only campaign templates in ‘available’ state may be used to create campaigns.



34
35
36
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 34

def state
  @state
end

#tagsObject

A list of tags for the campaign template.



40
41
42
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 40

def tags
  @tags
end

#template_paramsObject

Fields which can be used to replace values in a rule.



58
59
60
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 58

def template_params
  @template_params
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



120
121
122
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 120

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 125

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 95

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'instructions' => :'instructions',
    :'campaign_attributes' => :'campaignAttributes',
    :'coupon_attributes' => :'couponAttributes',
    :'state' => :'state',
    :'active_ruleset_id' => :'activeRulesetId',
    :'tags' => :'tags',
    :'reevaluate_on_return' => :'reevaluateOnReturn',
    :'features' => :'features',
    :'coupon_settings' => :'couponSettings',
    :'coupon_reservation_settings' => :'couponReservationSettings',
    :'referral_settings' => :'referralSettings',
    :'limits' => :'limits',
    :'template_params' => :'templateParams',
    :'applications_ids' => :'applicationsIds',
    :'campaign_collections' => :'campaignCollections',
    :'default_campaign_group_id' => :'defaultCampaignGroupId',
    :'campaign_type' => :'campaignType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 450

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



155
156
157
158
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 155

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 130

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'instructions' => :'String',
    :'campaign_attributes' => :'Object',
    :'coupon_attributes' => :'Object',
    :'state' => :'String',
    :'active_ruleset_id' => :'Integer',
    :'tags' => :'Array<String>',
    :'reevaluate_on_return' => :'Boolean',
    :'features' => :'Array<String>',
    :'coupon_settings' => :'CodeGeneratorSettings',
    :'coupon_reservation_settings' => :'CampaignTemplateCouponReservationSettings',
    :'referral_settings' => :'CodeGeneratorSettings',
    :'limits' => :'Array<TemplateLimitConfig>',
    :'template_params' => :'Array<CampaignTemplateParams>',
    :'applications_ids' => :'Array<Integer>',
    :'campaign_collections' => :'Array<CampaignTemplateCollection>',
    :'default_campaign_group_id' => :'Integer',
    :'campaign_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 411

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      instructions == o.instructions &&
      campaign_attributes == o.campaign_attributes &&
      coupon_attributes == o.coupon_attributes &&
      state == o.state &&
      active_ruleset_id == o.active_ruleset_id &&
      tags == o.tags &&
      reevaluate_on_return == o.reevaluate_on_return &&
      features == o.features &&
      coupon_settings == o.coupon_settings &&
      coupon_reservation_settings == o.coupon_reservation_settings &&
      referral_settings == o.referral_settings &&
      limits == o.limits &&
      template_params == o.template_params &&
      applications_ids == o.applications_ids &&
      campaign_collections == o.campaign_collections &&
      default_campaign_group_id == o.default_campaign_group_id &&
      campaign_type == o.campaign_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


437
438
439
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 437

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



443
444
445
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 443

def hash
  [name, description, instructions, campaign_attributes, coupon_attributes, state, active_ruleset_id, tags, reevaluate_on_return, features, coupon_settings, coupon_reservation_settings, referral_settings, limits, template_params, applications_ids, campaign_collections, default_campaign_group_id, campaign_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 279

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @instructions.nil?
    invalid_properties.push('invalid value for "instructions", instructions cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if !@tags.nil? && @tags.length > 50
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.')
  end

  if @applications_ids.nil?
    invalid_properties.push('invalid value for "applications_ids", applications_ids cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 472

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/talon_one_sdk/models/update_campaign_template.rb', line 315

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @description.nil?
  return false if @instructions.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["draft", "enabled", "disabled"])
  return false unless state_validator.valid?(@state)
  return false if !@tags.nil? && @tags.length > 50
  return false if @applications_ids.nil?
  campaign_type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"])
  return false unless campaign_type_validator.valid?(@campaign_type)
  true
end