Class: TalonOne::UpdatePicklist

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_picklist.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdatePicklist

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdatePicklist` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdatePicklist`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'values')
    if (value = attributes[:'values']).is_a?(Array)
      self.values = value
    end
  else
    self.values = nil
  end
end

Instance Attribute Details

#typeObject

The type of allowed values in the picklist. If the type ‘time` is chosen, it must be an RFC3339 timestamp string.



19
20
21
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 19

def type
  @type
end

#valuesObject

The list of allowed values provided by this picklist.



22
23
24
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 22

def values
  @values
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 47

def self.attribute_map
  {
    :'type' => :'type',
    :'values' => :'values'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



79
80
81
82
83
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 79

def self.openapi_all_of
  [
  :'NewPicklist'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 65

def self.openapi_types
  {
    :'type' => :'String',
    :'values' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      values == o.values
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 189

def hash
  [type, values].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @values.nil?
    invalid_properties.push('invalid value for "values", values cannot be nil.')
  end

  if @values.length > 50
    invalid_properties.push('invalid value for "values", number of items must be less than or equal to 50.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
143
144
145
146
# File 'lib/talon_one_sdk/models/update_picklist.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["string", "boolean", "number", "time"])
  return false unless type_validator.valid?(@type)
  return false if @values.nil?
  return false if @values.length > 50
  true
end