Class: TalonOne::UpdateReferral

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_referral.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateReferral

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/talon_one_sdk/models/update_referral.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateReferral` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateReferral`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'friend_profile_integration_id')
    self.friend_profile_integration_id = attributes[:'friend_profile_integration_id']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary properties associated with this item.



31
32
33
# File 'lib/talon_one_sdk/models/update_referral.rb', line 31

def attributes
  @attributes
end

#expiry_dateObject

Expiration date of the referral code. Referral never expires if this is omitted.



25
26
27
# File 'lib/talon_one_sdk/models/update_referral.rb', line 25

def expiry_date
  @expiry_date
end

#friend_profile_integration_idObject

An optional Integration ID of the Friend’s Profile.



19
20
21
# File 'lib/talon_one_sdk/models/update_referral.rb', line 19

def friend_profile_integration_id
  @friend_profile_integration_id
end

#start_dateObject

Timestamp at which point the referral code becomes valid.



22
23
24
# File 'lib/talon_one_sdk/models/update_referral.rb', line 22

def start_date
  @start_date
end

#usage_limitObject

The number of times a referral code can be used. This can be set to 0 for no limit, but any campaign usage limits will still apply.



28
29
30
# File 'lib/talon_one_sdk/models/update_referral.rb', line 28

def usage_limit
  @usage_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/update_referral.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/update_referral.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/update_referral.rb', line 34

def self.attribute_map
  {
    :'friend_profile_integration_id' => :'friendProfileIntegrationId',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'usage_limit' => :'usageLimit',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one_sdk/models/update_referral.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/update_referral.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/update_referral.rb', line 55

def self.openapi_types
  {
    :'friend_profile_integration_id' => :'String',
    :'start_date' => :'Time',
    :'expiry_date' => :'Time',
    :'usage_limit' => :'Integer',
    :'attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/update_referral.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      friend_profile_integration_id == o.friend_profile_integration_id &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      usage_limit == o.usage_limit &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/talon_one_sdk/models/update_referral.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/talon_one_sdk/models/update_referral.rb', line 190

def hash
  [friend_profile_integration_id, start_date, expiry_date, usage_limit, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/talon_one_sdk/models/update_referral.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@friend_profile_integration_id.nil? && @friend_profile_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "friend_profile_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@usage_limit.nil? && @usage_limit > 999999
    invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.')
  end

  if !@usage_limit.nil? && @usage_limit < 0
    invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/talon_one_sdk/models/update_referral.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/update_referral.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@friend_profile_integration_id.nil? && @friend_profile_integration_id.to_s.length > 1000
  return false if !@usage_limit.nil? && @usage_limit > 999999
  return false if !@usage_limit.nil? && @usage_limit < 0
  true
end