Class: TalonOne::UpdateRiskNotification

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_risk_notification.rb

Overview

Data for updating a risk notification.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateRiskNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateRiskNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateRiskNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'entity')
    self.entity = attributes[:'entity']
  else
    self.entity = nil
  end

  if attributes.key?(:'activity')
    self.activity = attributes[:'activity']
  else
    self.activity = nil
  end

  if attributes.key?(:'time_frame')
    self.time_frame = attributes[:'time_frame']
  else
    self.time_frame = nil
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  else
    self.active = nil
  end
end

Instance Attribute Details

#activeObject

Indicates whether this risk notification is active.



29
30
31
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 29

def active
  @active
end

#activityObject

The activity metric to analyze within the given entity.



23
24
25
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 23

def activity
  @activity
end

#entityObject

The entity type to analyze within the given time frame.



20
21
22
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 20

def entity
  @entity
end

#time_frameObject

The rolling time window for risk evaluation.



26
27
28
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 26

def time_frame
  @time_frame
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 54

def self.attribute_map
  {
    :'entity' => :'entity',
    :'activity' => :'activity',
    :'time_frame' => :'timeFrame',
    :'active' => :'active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



90
91
92
93
94
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 90

def self.openapi_all_of
  [
  :'NewRiskNotification'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 74

def self.openapi_types
  {
    :'entity' => :'String',
    :'activity' => :'String',
    :'time_frame' => :'String',
    :'active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      entity == o.entity &&
      activity == o.activity &&
      time_frame == o.time_frame &&
      active == o.active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 237

def hash
  [entity, activity, time_frame, active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @entity.nil?
    invalid_properties.push('invalid value for "entity", entity cannot be nil.')
  end

  if @activity.nil?
    invalid_properties.push('invalid value for "activity", activity cannot be nil.')
  end

  if @time_frame.nil?
    invalid_properties.push('invalid value for "time_frame", time_frame cannot be nil.')
  end

  if @active.nil?
    invalid_properties.push('invalid value for "active", active cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/talon_one_sdk/models/update_risk_notification.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @entity.nil?
  entity_validator = EnumAttributeValidator.new('String', ["customer_profile", "customer_session"])
  return false unless entity_validator.valid?(@entity)
  return false if @activity.nil?
  activity_validator = EnumAttributeValidator.new('String', ["loyalty_points_earned", "discounted_amount", "completed_orders", "coupon_attempts"])
  return false unless activity_validator.valid?(@activity)
  return false if @time_frame.nil?
  time_frame_validator = EnumAttributeValidator.new('String', ["1_day", "1_week", "1_month"])
  return false unless time_frame_validator.valid?(@time_frame)
  return false if @active.nil?
  true
end