Class: TalonOne::UpdateUser

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/update_user.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/talon_one_sdk/models/update_user.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'is_admin')
    self.is_admin = attributes[:'is_admin']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'roles')
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
  end

  if attributes.key?(:'application_notification_subscriptions')
    self.application_notification_subscriptions = attributes[:'application_notification_subscriptions']
  end
end

Instance Attribute Details

#application_notification_subscriptionsObject

Application notifications that the user is subscribed to.



34
35
36
# File 'lib/talon_one_sdk/models/update_user.rb', line 34

def application_notification_subscriptions
  @application_notification_subscriptions
end

#is_adminObject

Indicates whether the user is an ‘admin`.



25
26
27
# File 'lib/talon_one_sdk/models/update_user.rb', line 25

def is_admin
  @is_admin
end

#nameObject

Name of the user.



19
20
21
# File 'lib/talon_one_sdk/models/update_user.rb', line 19

def name
  @name
end

#policyObject

Indicates the access level of the user.



28
29
30
# File 'lib/talon_one_sdk/models/update_user.rb', line 28

def policy
  @policy
end

#rolesObject

A list of the IDs of the roles assigned to the user. Note: To find the ID of a role, use the [List roles](/management-api#tag/Roles/operation/listAllRolesV2) endpoint.



31
32
33
# File 'lib/talon_one_sdk/models/update_user.rb', line 31

def roles
  @roles
end

#stateObject

The state of the user. - ‘deactivated`: The user has been deactivated. - `active`: The user is active. Note: Only `admin` users can update the state of another user.



22
23
24
# File 'lib/talon_one_sdk/models/update_user.rb', line 22

def state
  @state
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/talon_one_sdk/models/update_user.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/talon_one_sdk/models/update_user.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/talon_one_sdk/models/update_user.rb', line 59

def self.attribute_map
  {
    :'name' => :'name',
    :'state' => :'state',
    :'is_admin' => :'isAdmin',
    :'policy' => :'policy',
    :'roles' => :'roles',
    :'application_notification_subscriptions' => :'applicationNotificationSubscriptions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/talon_one_sdk/models/update_user.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/talon_one_sdk/models/update_user.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/talon_one_sdk/models/update_user.rb', line 81

def self.openapi_types
  {
    :'name' => :'String',
    :'state' => :'String',
    :'is_admin' => :'Boolean',
    :'policy' => :'String',
    :'roles' => :'Array<Integer>',
    :'application_notification_subscriptions' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
# File 'lib/talon_one_sdk/models/update_user.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      state == o.state &&
      is_admin == o.is_admin &&
      policy == o.policy &&
      roles == o.roles &&
      application_notification_subscriptions == o.application_notification_subscriptions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/talon_one_sdk/models/update_user.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/talon_one_sdk/models/update_user.rb', line 189

def hash
  [name, state, is_admin, policy, roles, application_notification_subscriptions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
# File 'lib/talon_one_sdk/models/update_user.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/talon_one_sdk/models/update_user.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
156
# File 'lib/talon_one_sdk/models/update_user.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  state_validator = EnumAttributeValidator.new('String', ["deactivated", "active"])
  return false unless state_validator.valid?(@state)
  true
end