Class: TalonOne::User

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/user.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/talon_one_sdk/models/user.rb', line 165

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'invite_token')
    self.invite_token = attributes[:'invite_token']
  else
    self.invite_token = nil
  end

  if attributes.key?(:'is_admin')
    self.is_admin = attributes[:'is_admin']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  else
    self.policy = nil
  end

  if attributes.key?(:'roles')
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
  end

  if attributes.key?(:'auth_method')
    self.auth_method = attributes[:'auth_method']
  end

  if attributes.key?(:'application_notification_subscriptions')
    self.application_notification_subscriptions = attributes[:'application_notification_subscriptions']
  end

  if attributes.key?(:'last_signed_in')
    self.last_signed_in = attributes[:'last_signed_in']
  end

  if attributes.key?(:'last_accessed')
    self.last_accessed = attributes[:'last_accessed']
  end

  if attributes.key?(:'latest_feed_timestamp')
    self.latest_feed_timestamp = attributes[:'latest_feed_timestamp']
  end

  if attributes.key?(:'additional_attributes')
    self.additional_attributes = attributes[:'additional_attributes']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



31
32
33
# File 'lib/talon_one_sdk/models/user.rb', line 31

def 
  @account_id
end

#additional_attributesObject

Additional user attributes, created and used by external identity providers.



67
68
69
# File 'lib/talon_one_sdk/models/user.rb', line 67

def additional_attributes
  @additional_attributes
end

#application_notification_subscriptionsObject

Application notifications that the user is subscribed to.



55
56
57
# File 'lib/talon_one_sdk/models/user.rb', line 55

def application_notification_subscriptions
  @application_notification_subscriptions
end

#auth_methodObject

Authentication method for this user.



52
53
54
# File 'lib/talon_one_sdk/models/user.rb', line 52

def auth_method
  @auth_method
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/user.rb', line 22

def created
  @created
end

#emailObject

The email address associated with the user profile.



28
29
30
# File 'lib/talon_one_sdk/models/user.rb', line 28

def email
  @email
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/user.rb', line 19

def id
  @id
end

#invite_tokenObject

Invitation token of the user. Note: If the user has already accepted their invitation, this is ‘null`.



40
41
42
# File 'lib/talon_one_sdk/models/user.rb', line 40

def invite_token
  @invite_token
end

#is_adminObject

Indicates whether the user is an ‘admin`.



43
44
45
# File 'lib/talon_one_sdk/models/user.rb', line 43

def is_admin
  @is_admin
end

#last_accessedObject

Timestamp of the user’s last activity after signing in to Talon.One.



61
62
63
# File 'lib/talon_one_sdk/models/user.rb', line 61

def last_accessed
  @last_accessed
end

#last_signed_inObject

Timestamp when the user last signed in to Talon.One.



58
59
60
# File 'lib/talon_one_sdk/models/user.rb', line 58

def last_signed_in
  @last_signed_in
end

#latest_feed_timestampObject

Timestamp when the user was notified for feed.



64
65
66
# File 'lib/talon_one_sdk/models/user.rb', line 64

def latest_feed_timestamp
  @latest_feed_timestamp
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/user.rb', line 25

def modified
  @modified
end

#nameObject

Name of the user.



34
35
36
# File 'lib/talon_one_sdk/models/user.rb', line 34

def name
  @name
end

#policyObject

Access level of the user.



46
47
48
# File 'lib/talon_one_sdk/models/user.rb', line 46

def policy
  @policy
end

#rolesObject

A list of the IDs of the roles assigned to the user.



49
50
51
# File 'lib/talon_one_sdk/models/user.rb', line 49

def roles
  @roles
end

#stateObject

State of the user.



37
38
39
# File 'lib/talon_one_sdk/models/user.rb', line 37

def state
  @state
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



115
116
117
# File 'lib/talon_one_sdk/models/user.rb', line 115

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/talon_one_sdk/models/user.rb', line 120

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/talon_one_sdk/models/user.rb', line 92

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'email' => :'email',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'state' => :'state',
    :'invite_token' => :'inviteToken',
    :'is_admin' => :'isAdmin',
    :'policy' => :'policy',
    :'roles' => :'roles',
    :'auth_method' => :'authMethod',
    :'application_notification_subscriptions' => :'applicationNotificationSubscriptions',
    :'last_signed_in' => :'lastSignedIn',
    :'last_accessed' => :'lastAccessed',
    :'latest_feed_timestamp' => :'latestFeedTimestamp',
    :'additional_attributes' => :'additionalAttributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/talon_one_sdk/models/user.rb', line 459

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/user.rb', line 154

def self.openapi_all_of
  [
  :'AccountEntity',
  :'EmailEntity',
  :'Entity',
  :'MutableEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



148
149
150
151
# File 'lib/talon_one_sdk/models/user.rb', line 148

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/talon_one_sdk/models/user.rb', line 125

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'email' => :'String',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'state' => :'String',
    :'invite_token' => :'String',
    :'is_admin' => :'Boolean',
    :'policy' => :'Object',
    :'roles' => :'Array<Integer>',
    :'auth_method' => :'String',
    :'application_notification_subscriptions' => :'Object',
    :'last_signed_in' => :'Time',
    :'last_accessed' => :'Time',
    :'latest_feed_timestamp' => :'Time',
    :'additional_attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/talon_one_sdk/models/user.rb', line 422

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
      email == o.email &&
       == o. &&
      name == o.name &&
      state == o.state &&
      invite_token == o.invite_token &&
      is_admin == o.is_admin &&
      policy == o.policy &&
      roles == o.roles &&
      auth_method == o.auth_method &&
      application_notification_subscriptions == o.application_notification_subscriptions &&
      last_signed_in == o.last_signed_in &&
      last_accessed == o.last_accessed &&
      latest_feed_timestamp == o.latest_feed_timestamp &&
      additional_attributes == o.additional_attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


446
447
448
# File 'lib/talon_one_sdk/models/user.rb', line 446

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



452
453
454
# File 'lib/talon_one_sdk/models/user.rb', line 452

def hash
  [id, created, modified, email, , name, state, invite_token, is_admin, policy, roles, auth_method, application_notification_subscriptions, last_signed_in, last_accessed, latest_feed_timestamp, additional_attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/talon_one_sdk/models/user.rb', line 270

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @invite_token.nil?
    invalid_properties.push('invalid value for "invite_token", invite_token cannot be nil.')
  end

  if @policy.nil?
    invalid_properties.push('invalid value for "policy", policy cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/talon_one_sdk/models/user.rb', line 481

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/talon_one_sdk/models/user.rb', line 314

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @email.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["invited", "active", "deactivated"])
  return false unless state_validator.valid?(@state)
  return false if @invite_token.nil?
  return false if @policy.nil?
  true
end