Class: TalonOne::ValueMap
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ValueMap
- Defined in:
- lib/talon_one_sdk/models/value_map.rb
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#created ⇒ Object
Returns the value of attribute created.
-
#created_by ⇒ Object
The ID of the user who created the value map.
-
#id ⇒ Object
Unique ID for this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ValueMap
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ValueMap
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ValueMap` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ValueMap`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end end |
Instance Attribute Details
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
26 27 28 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 26 def campaign_id @campaign_id end |
#created ⇒ Object
Returns the value of attribute created.
21 22 23 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 21 def created @created end |
#created_by ⇒ Object
The ID of the user who created the value map.
24 25 26 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 24 def created_by @created_by end |
#id ⇒ Object
Unique ID for this entity. Not to be confused with the Integration ID, which is set by your integration layer and used in most endpoints.
19 20 21 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 19 def id @id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 29 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'created_by' => :'createdBy', :'campaign_id' => :'campaignId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 65 def self.openapi_all_of [ :'IdentifiableEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 49 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'created_by' => :'Integer', :'campaign_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && created_by == o.created_by && campaign_id == o.campaign_id end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 172 def hash [id, created, created_by, campaign_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 130 131 |
# File 'lib/talon_one_sdk/models/value_map.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @campaign_id.nil? true end |