Class: TalonOne::Webhook

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/webhook.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Webhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/talon_one_sdk/models/webhook.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Webhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  else
    self.application_ids = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'draft')
    self.draft = attributes[:'draft']
  else
    self.draft = nil
  end

  if attributes.key?(:'verb')
    self.verb = attributes[:'verb']
  else
    self.verb = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  else
    self.headers = nil
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Array)
      self.params = value
    end
  else
    self.params = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'authentication_id')
    self.authentication_id = attributes[:'authentication_id']
  end
end

Instance Attribute Details

#application_idsObject

The IDs of the Applications in which this webhook is available. An empty array means the webhook is available in ‘All Applications`.



28
29
30
# File 'lib/talon_one_sdk/models/webhook.rb', line 28

def application_ids
  @application_ids
end

#authentication_idObject

The ID of the credential that this webhook is using.



58
59
60
# File 'lib/talon_one_sdk/models/webhook.rb', line 58

def authentication_id
  @authentication_id
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/webhook.rb', line 22

def created
  @created
end

#descriptionObject

A description of the webhook.



34
35
36
# File 'lib/talon_one_sdk/models/webhook.rb', line 34

def description
  @description
end

#draftObject

Indicates if the webhook is a draft.



37
38
39
# File 'lib/talon_one_sdk/models/webhook.rb', line 37

def draft
  @draft
end

#enabledObject

Enables or disables webhook from showing in the Rule Builder.



55
56
57
# File 'lib/talon_one_sdk/models/webhook.rb', line 55

def enabled
  @enabled
end

#headersObject

List of API HTTP headers for this webhook.



46
47
48
# File 'lib/talon_one_sdk/models/webhook.rb', line 46

def headers
  @headers
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/webhook.rb', line 19

def id
  @id
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/webhook.rb', line 25

def modified
  @modified
end

#paramsObject

Array of template argument definitions.



52
53
54
# File 'lib/talon_one_sdk/models/webhook.rb', line 52

def params
  @params
end

#payloadObject

API payload (supports templating using parameters) for this webhook.



49
50
51
# File 'lib/talon_one_sdk/models/webhook.rb', line 49

def payload
  @payload
end

#titleObject

Name or title for this webhook.



31
32
33
# File 'lib/talon_one_sdk/models/webhook.rb', line 31

def title
  @title
end

#urlObject

API URL (supports templating using parameters) for this webhook.



43
44
45
# File 'lib/talon_one_sdk/models/webhook.rb', line 43

def url
  @url
end

#verbObject

API method for this webhook.



40
41
42
# File 'lib/talon_one_sdk/models/webhook.rb', line 40

def verb
  @verb
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



103
104
105
# File 'lib/talon_one_sdk/models/webhook.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/talon_one_sdk/models/webhook.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/talon_one_sdk/models/webhook.rb', line 83

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'application_ids' => :'applicationIds',
    :'title' => :'title',
    :'description' => :'description',
    :'draft' => :'draft',
    :'verb' => :'verb',
    :'url' => :'url',
    :'headers' => :'headers',
    :'payload' => :'payload',
    :'params' => :'params',
    :'enabled' => :'enabled',
    :'authentication_id' => :'authenticationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/talon_one_sdk/models/webhook.rb', line 477

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



139
140
141
142
143
144
145
# File 'lib/talon_one_sdk/models/webhook.rb', line 139

def self.openapi_all_of
  [
  :'Entity',
  :'MutableEntity',
  :'NewWebhook'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/talon_one_sdk/models/webhook.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/webhook.rb', line 113

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'application_ids' => :'Array<Integer>',
    :'title' => :'String',
    :'description' => :'String',
    :'draft' => :'Boolean',
    :'verb' => :'String',
    :'url' => :'String',
    :'headers' => :'Array<String>',
    :'payload' => :'String',
    :'params' => :'Array<TemplateArgDef>',
    :'enabled' => :'Boolean',
    :'authentication_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/talon_one_sdk/models/webhook.rb', line 443

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
      application_ids == o.application_ids &&
      title == o.title &&
      description == o.description &&
      draft == o.draft &&
      verb == o.verb &&
      url == o.url &&
      headers == o.headers &&
      payload == o.payload &&
      params == o.params &&
      enabled == o.enabled &&
      authentication_id == o.authentication_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


464
465
466
# File 'lib/talon_one_sdk/models/webhook.rb', line 464

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



470
471
472
# File 'lib/talon_one_sdk/models/webhook.rb', line 470

def hash
  [id, created, modified, application_ids, title, description, draft, verb, url, headers, payload, params, enabled, authentication_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/talon_one_sdk/models/webhook.rb', line 250

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  pattern = Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  if @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if @draft.nil?
    invalid_properties.push('invalid value for "draft", draft cannot be nil.')
  end

  if @verb.nil?
    invalid_properties.push('invalid value for "verb", verb cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @headers.nil?
    invalid_properties.push('invalid value for "headers", headers cannot be nil.')
  end

  if @params.nil?
    invalid_properties.push('invalid value for "params", params cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/talon_one_sdk/models/webhook.rb', line 499

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/talon_one_sdk/models/webhook.rb', line 307

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @application_ids.nil?
  return false if @title.nil?
  return false if @title !~ Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/)
  return false if @draft.nil?
  return false if @verb.nil?
  verb_validator = EnumAttributeValidator.new('String', ["POST", "PUT", "GET", "DELETE", "PATCH"])
  return false unless verb_validator.valid?(@verb)
  return false if @url.nil?
  return false if @headers.nil?
  return false if @params.nil?
  return false if @enabled.nil?
  true
end