Class: TalonOne::WebhookAuthentication

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/webhook_authentication.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookAuthentication

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::WebhookAuthentication` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::WebhookAuthentication`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  else
    self.modified_by = nil
  end

  if attributes.key?(:'webhooks')
    if (value = attributes[:'webhooks']).is_a?(Array)
      self.webhooks = value
    end
  else
    self.webhooks = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  else
    self.data = nil
  end
end

Instance Attribute Details

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 22

def created
  @created
end

#created_byObject

The name of the user who created the webhook authentication.



28
29
30
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 28

def created_by
  @created_by
end

#dataObject

Returns the value of attribute data.



40
41
42
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 40

def data
  @data
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 19

def id
  @id
end

#modifiedObject

The time this entity was last modified.



25
26
27
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 25

def modified
  @modified
end

#modified_byObject

The name of the user who last modified the webhook authentication.



31
32
33
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 31

def modified_by
  @modified_by
end

#nameObject

The name of the webhook authentication.



36
37
38
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 36

def name
  @name
end

#typeObject

Returns the value of attribute type.



38
39
40
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 38

def type
  @type
end

#webhooksObject

Returns the value of attribute webhooks.



33
34
35
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 33

def webhooks
  @webhooks
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'modified' => :'modified',
    :'created_by' => :'createdBy',
    :'modified_by' => :'modifiedBy',
    :'webhooks' => :'webhooks',
    :'name' => :'name',
    :'type' => :'type',
    :'data' => :'data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



112
113
114
115
116
117
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 112

def self.openapi_all_of
  [
  :'Entity',
  :'MutableEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 105

def self.openapi_nullable
  Set.new([
    :'data'
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 90

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'modified' => :'Time',
    :'created_by' => :'String',
    :'modified_by' => :'String',
    :'webhooks' => :'Array<WebhookAuthenticationWebhookRef>',
    :'name' => :'String',
    :'type' => :'String',
    :'data' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      modified == o.modified &&
      created_by == o.created_by &&
      modified_by == o.modified_by &&
      webhooks == o.webhooks &&
      name == o.name &&
      type == o.type &&
      data == o.data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 353

def hash
  [id, created, modified, created_by, modified_by, webhooks, name, type, data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @webhooks.nil?
    invalid_properties.push('invalid value for "webhooks", webhooks cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/talon_one_sdk/models/webhook_authentication.rb', line 234

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @modified.nil?
  return false if @created_by.nil?
  return false if @modified_by.nil?
  return false if @webhooks.nil?
  return false if @name.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["basic", "custom"])
  return false unless type_validator.valid?(@type)
  true
end