Class: TalonOne::WillAwardGiveawayEffectProps

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb

Overview

The properties specific to the "awardGiveaway" effect when the session is not closed yet. This effect replaces "awardGiveaway" only when updating a session with any state other than "closed". This is to ensure no giveaway codes are leaked when they are still not guaranteed to be awarded.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WillAwardGiveawayEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::WillAwardGiveawayEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::WillAwardGiveawayEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pool_id')
    self.pool_id = attributes[:'pool_id']
  else
    self.pool_id = nil
  end

  if attributes.key?(:'pool_name')
    self.pool_name = attributes[:'pool_name']
  else
    self.pool_name = nil
  end

  if attributes.key?(:'recipient_integration_id')
    self.recipient_integration_id = attributes[:'recipient_integration_id']
  else
    self.recipient_integration_id = nil
  end
end

Instance Attribute Details

#pool_idObject

The ID of the giveaways pool the code will be taken from.



20
21
22
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 20

def pool_id
  @pool_id
end

#pool_nameObject

The name of the giveaways pool the code will be taken from.



23
24
25
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 23

def pool_name
  @pool_name
end

#recipient_integration_idObject

The integration ID of the profile that will be awarded the giveaway.



26
27
28
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 26

def recipient_integration_id
  @recipient_integration_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 29

def self.attribute_map
  {
    :'pool_id' => :'poolId',
    :'pool_name' => :'poolName',
    :'recipient_integration_id' => :'recipientIntegrationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 48

def self.openapi_types
  {
    :'pool_id' => :'Integer',
    :'pool_name' => :'String',
    :'recipient_integration_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pool_id == o.pool_id &&
      pool_name == o.pool_name &&
      recipient_integration_id == o.recipient_integration_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 184

def hash
  [pool_id, pool_name, recipient_integration_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pool_id.nil?
    invalid_properties.push('invalid value for "pool_id", pool_id cannot be nil.')
  end

  if @pool_name.nil?
    invalid_properties.push('invalid value for "pool_name", pool_name cannot be nil.')
  end

  if @recipient_integration_id.nil?
    invalid_properties.push('invalid value for "recipient_integration_id", recipient_integration_id cannot be nil.')
  end

  if @recipient_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
130
# File 'lib/talon_one_sdk/models/will_award_giveaway_effect_props.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pool_id.nil?
  return false if @pool_name.nil?
  return false if @recipient_integration_id.nil?
  return false if @recipient_integration_id.to_s.length > 1000
  true
end