Class: TalonOne::WithinCheckAttributeBlock

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/within_check_attribute_block.rb

Overview

Variant of CheckAttributeBlock for the within and not(within) operators, which require both a start and end value.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WithinCheckAttributeBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::WithinCheckAttributeBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::WithinCheckAttributeBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'operator')
    self.operator = attributes[:'operator']
  end

  if attributes.key?(:'start')
    self.start = attributes[:'start']
  else
    self.start = nil
  end

  if attributes.key?(:'_end')
    self._end = attributes[:'_end']
  else
    self._end = nil
  end

  if attributes.key?(:'start_inclusive')
    self.start_inclusive = attributes[:'start_inclusive']
  end

  if attributes.key?(:'end_inclusive')
    self.end_inclusive = attributes[:'end_inclusive']
  end

  if attributes.key?(:'timezone_insensitive')
    self.timezone_insensitive = attributes[:'timezone_insensitive']
  end
end

Instance Attribute Details

#_endObject

Returns the value of attribute _end.



24
25
26
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 24

def _end
  @_end
end

#end_inclusiveObject

When true, the end value is included in the range for the within operator.



30
31
32
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 30

def end_inclusive
  @end_inclusive
end

#operatorObject

The range comparison operator. Must be within or not(within).



20
21
22
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 20

def operator
  @operator
end

#startObject

Returns the value of attribute start.



22
23
24
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 22

def start
  @start
end

#start_inclusiveObject

When true, the start value is included in the range for the within operator.



27
28
29
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 27

def start_inclusive
  @start_inclusive
end

#timezone_insensitiveObject

Indicates whether the within operator ignores time zones and compares the wall-clock time only. When false, time zones are taken into account.



33
34
35
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 33

def timezone_insensitive
  @timezone_insensitive
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 58

def self.attribute_map
  {
    :'operator' => :'operator',
    :'start' => :'start',
    :'_end' => :'end',
    :'start_inclusive' => :'startInclusive',
    :'end_inclusive' => :'endInclusive',
    :'timezone_insensitive' => :'timezoneInsensitive'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 92

def self.openapi_nullable
  Set.new([
    :'start',
    :'_end',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 80

def self.openapi_types
  {
    :'operator' => :'String',
    :'start' => :'Object',
    :'_end' => :'Object',
    :'start_inclusive' => :'Boolean',
    :'end_inclusive' => :'Boolean',
    :'timezone_insensitive' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      operator == o.operator &&
      start == o.start &&
      _end == o._end &&
      start_inclusive == o.start_inclusive &&
      end_inclusive == o.end_inclusive &&
      timezone_insensitive == o.timezone_insensitive
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 192

def hash
  [operator, start, _end, start_inclusive, end_inclusive, timezone_insensitive].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
# File 'lib/talon_one_sdk/models/within_check_attribute_block.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  operator_validator = EnumAttributeValidator.new('String', ["within", "not(within)"])
  return false unless operator_validator.valid?(@operator)
  true
end