Class: TalonOne::AccessLogEntry
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AccessLogEntry
- Defined in:
- lib/talon_one_sdk/models/access_log_entry.rb
Overview
Log of application accesses.
Instance Attribute Summary collapse
-
#method ⇒ Object
HTTP method of request.
-
#request_payload ⇒ Object
payload of request.
-
#request_uri ⇒ Object
target URI of request.
-
#response_payload ⇒ Object
payload of response.
-
#status ⇒ Object
HTTP status code of response.
-
#time ⇒ Object
timestamp of request.
-
#uuid ⇒ Object
UUID reference of request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccessLogEntry
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccessLogEntry
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AccessLogEntry` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AccessLogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] else self.uuid = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end if attributes.key?(:'request_uri') self.request_uri = attributes[:'request_uri'] else self.request_uri = nil end if attributes.key?(:'time') self.time = attributes[:'time'] else self.time = nil end if attributes.key?(:'request_payload') self.request_payload = attributes[:'request_payload'] else self.request_payload = nil end if attributes.key?(:'response_payload') self.response_payload = attributes[:'response_payload'] else self.response_payload = nil end end |
Instance Attribute Details
#method ⇒ Object
HTTP method of request.
26 27 28 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 26 def method @method end |
#request_payload ⇒ Object
payload of request
35 36 37 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 35 def request_payload @request_payload end |
#request_uri ⇒ Object
target URI of request
29 30 31 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 29 def request_uri @request_uri end |
#response_payload ⇒ Object
payload of response
38 39 40 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 38 def response_payload @response_payload end |
#status ⇒ Object
HTTP status code of response.
23 24 25 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 23 def status @status end |
#time ⇒ Object
timestamp of request
32 33 34 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 32 def time @time end |
#uuid ⇒ Object
UUID reference of request.
20 21 22 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 20 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 41 def self.attribute_map { :'uuid' => :'uuid', :'status' => :'status', :'method' => :'method', :'request_uri' => :'requestUri', :'time' => :'time', :'request_payload' => :'requestPayload', :'response_payload' => :'responsePayload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 290 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 64 def self.openapi_types { :'uuid' => :'String', :'status' => :'Integer', :'method' => :'String', :'request_uri' => :'String', :'time' => :'Time', :'request_payload' => :'String', :'response_payload' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && uuid == o.uuid && status == o.status && method == o.method && request_uri == o.request_uri && time == o.time && request_payload == o.request_payload && response_payload == o.response_payload end |
#eql?(o) ⇒ Boolean
277 278 279 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 277 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 283 def hash [uuid, status, method, request_uri, time, request_payload, response_payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @uuid.nil? invalid_properties.push('invalid value for "uuid", uuid cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end if @request_uri.nil? invalid_properties.push('invalid value for "request_uri", request_uri cannot be nil.') end if @time.nil? invalid_properties.push('invalid value for "time", time cannot be nil.') end if @request_payload.nil? invalid_properties.push('invalid value for "request_payload", request_payload cannot be nil.') end if @response_payload.nil? invalid_properties.push('invalid value for "response_payload", response_payload cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/access_log_entry.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @uuid.nil? return false if @status.nil? return false if @method.nil? return false if @request_uri.nil? return false if @time.nil? return false if @request_payload.nil? return false if @response_payload.nil? true end |