Class: TalonOne::Account
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Account
- Defined in:
- lib/talon_one_sdk/models/account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#api_limit ⇒ Object
The maximum number of Integration API calls covered by your plan per billing period.
-
#application_count ⇒ Object
The current number of Applications in your account.
-
#application_limit ⇒ Object
The maximum number of Applications covered by your plan.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#billing_email ⇒ Object
The billing email address associated with your company account.
-
#campaign_limit ⇒ Object
The maximum number of Campaigns covered by your plan.
-
#campaigns_active_count ⇒ Object
The current number of active Campaigns in your account.
-
#campaigns_inactive_count ⇒ Object
The current number of inactive Campaigns in your account.
-
#company_name ⇒ Object
Returns the value of attribute company_name.
-
#created ⇒ Object
The time this entity was created.
-
#domain_name ⇒ Object
Subdomain Name for yourcompany.talon.one.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
The time this entity was last modified.
-
#plan_expires ⇒ Object
The point in time at which your current plan expires.
-
#plan_name ⇒ Object
The name of your booked plan.
-
#state ⇒ Object
State of the account (active, deactivated).
-
#user_count ⇒ Object
The current number of Campaign Manager Users in your account.
-
#user_limit ⇒ Object
The maximum number of Campaign Manager Users covered by your plan.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Account
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Account
Initializes the object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/talon_one_sdk/models/account.rb', line 168 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Account` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Account`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'modified') self.modified = attributes[:'modified'] else self.modified = nil end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] else self.company_name = nil end if attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] else self.domain_name = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'billing_email') self.billing_email = attributes[:'billing_email'] else self.billing_email = nil end if attributes.key?(:'plan_name') self.plan_name = attributes[:'plan_name'] end if attributes.key?(:'plan_expires') self.plan_expires = attributes[:'plan_expires'] end if attributes.key?(:'application_limit') self.application_limit = attributes[:'application_limit'] end if attributes.key?(:'user_limit') self.user_limit = attributes[:'user_limit'] end if attributes.key?(:'campaign_limit') self.campaign_limit = attributes[:'campaign_limit'] end if attributes.key?(:'api_limit') self.api_limit = attributes[:'api_limit'] end if attributes.key?(:'application_count') self.application_count = attributes[:'application_count'] else self.application_count = nil end if attributes.key?(:'user_count') self.user_count = attributes[:'user_count'] else self.user_count = nil end if attributes.key?(:'campaigns_active_count') self.campaigns_active_count = attributes[:'campaigns_active_count'] else self.campaigns_active_count = nil end if attributes.key?(:'campaigns_inactive_count') self.campaigns_inactive_count = attributes[:'campaigns_inactive_count'] else self.campaigns_inactive_count = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end end |
Instance Attribute Details
#api_limit ⇒ Object
The maximum number of Integration API calls covered by your plan per billing period.
54 55 56 |
# File 'lib/talon_one_sdk/models/account.rb', line 54 def api_limit @api_limit end |
#application_count ⇒ Object
The current number of Applications in your account.
57 58 59 |
# File 'lib/talon_one_sdk/models/account.rb', line 57 def application_count @application_count end |
#application_limit ⇒ Object
The maximum number of Applications covered by your plan.
45 46 47 |
# File 'lib/talon_one_sdk/models/account.rb', line 45 def application_limit @application_limit end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
69 70 71 |
# File 'lib/talon_one_sdk/models/account.rb', line 69 def attributes @attributes end |
#billing_email ⇒ Object
The billing email address associated with your company account.
36 37 38 |
# File 'lib/talon_one_sdk/models/account.rb', line 36 def billing_email @billing_email end |
#campaign_limit ⇒ Object
The maximum number of Campaigns covered by your plan.
51 52 53 |
# File 'lib/talon_one_sdk/models/account.rb', line 51 def campaign_limit @campaign_limit end |
#campaigns_active_count ⇒ Object
The current number of active Campaigns in your account.
63 64 65 |
# File 'lib/talon_one_sdk/models/account.rb', line 63 def campaigns_active_count @campaigns_active_count end |
#campaigns_inactive_count ⇒ Object
The current number of inactive Campaigns in your account.
66 67 68 |
# File 'lib/talon_one_sdk/models/account.rb', line 66 def campaigns_inactive_count @campaigns_inactive_count end |
#company_name ⇒ Object
Returns the value of attribute company_name.
27 28 29 |
# File 'lib/talon_one_sdk/models/account.rb', line 27 def company_name @company_name end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/account.rb', line 22 def created @created end |
#domain_name ⇒ Object
Subdomain Name for yourcompany.talon.one.
30 31 32 |
# File 'lib/talon_one_sdk/models/account.rb', line 30 def domain_name @domain_name end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/account.rb', line 19 def id @id end |
#modified ⇒ Object
The time this entity was last modified.
25 26 27 |
# File 'lib/talon_one_sdk/models/account.rb', line 25 def modified @modified end |
#plan_expires ⇒ Object
The point in time at which your current plan expires.
42 43 44 |
# File 'lib/talon_one_sdk/models/account.rb', line 42 def plan_expires @plan_expires end |
#plan_name ⇒ Object
The name of your booked plan.
39 40 41 |
# File 'lib/talon_one_sdk/models/account.rb', line 39 def plan_name @plan_name end |
#state ⇒ Object
State of the account (active, deactivated).
33 34 35 |
# File 'lib/talon_one_sdk/models/account.rb', line 33 def state @state end |
#user_count ⇒ Object
The current number of Campaign Manager Users in your account.
60 61 62 |
# File 'lib/talon_one_sdk/models/account.rb', line 60 def user_count @user_count end |
#user_limit ⇒ Object
The maximum number of Campaign Manager Users covered by your plan.
48 49 50 |
# File 'lib/talon_one_sdk/models/account.rb', line 48 def user_limit @user_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
118 119 120 |
# File 'lib/talon_one_sdk/models/account.rb', line 118 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
123 124 125 |
# File 'lib/talon_one_sdk/models/account.rb', line 123 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/talon_one_sdk/models/account.rb', line 94 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'modified' => :'modified', :'company_name' => :'companyName', :'domain_name' => :'domainName', :'state' => :'state', :'billing_email' => :'billingEmail', :'plan_name' => :'planName', :'plan_expires' => :'planExpires', :'application_limit' => :'applicationLimit', :'user_limit' => :'userLimit', :'campaign_limit' => :'campaignLimit', :'api_limit' => :'apiLimit', :'application_count' => :'applicationCount', :'user_count' => :'userCount', :'campaigns_active_count' => :'campaignsActiveCount', :'campaigns_inactive_count' => :'campaignsInactiveCount', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/talon_one_sdk/models/account.rb', line 508 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
158 159 160 161 162 163 164 |
# File 'lib/talon_one_sdk/models/account.rb', line 158 def self.openapi_all_of [ :'Entity', :'MutableEntity', :'NewAccount' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
152 153 154 155 |
# File 'lib/talon_one_sdk/models/account.rb', line 152 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/talon_one_sdk/models/account.rb', line 128 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'modified' => :'Time', :'company_name' => :'String', :'domain_name' => :'String', :'state' => :'String', :'billing_email' => :'String', :'plan_name' => :'String', :'plan_expires' => :'Time', :'application_limit' => :'Integer', :'user_limit' => :'Integer', :'campaign_limit' => :'Integer', :'api_limit' => :'Integer', :'application_count' => :'Integer', :'user_count' => :'Integer', :'campaigns_active_count' => :'Integer', :'campaigns_inactive_count' => :'Integer', :'attributes' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/talon_one_sdk/models/account.rb', line 470 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && modified == o.modified && company_name == o.company_name && domain_name == o.domain_name && state == o.state && billing_email == o.billing_email && plan_name == o.plan_name && plan_expires == o.plan_expires && application_limit == o.application_limit && user_limit == o.user_limit && campaign_limit == o.campaign_limit && api_limit == o.api_limit && application_count == o.application_count && user_count == o.user_count && campaigns_active_count == o.campaigns_active_count && campaigns_inactive_count == o.campaigns_inactive_count && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
495 496 497 |
# File 'lib/talon_one_sdk/models/account.rb', line 495 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
501 502 503 |
# File 'lib/talon_one_sdk/models/account.rb', line 501 def hash [id, created, modified, company_name, domain_name, state, billing_email, plan_name, plan_expires, application_limit, user_limit, campaign_limit, api_limit, application_count, user_count, campaigns_active_count, campaigns_inactive_count, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/talon_one_sdk/models/account.rb', line 279 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @modified.nil? invalid_properties.push('invalid value for "modified", modified cannot be nil.') end if @company_name.nil? invalid_properties.push('invalid value for "company_name", company_name cannot be nil.') end if @company_name.to_s.length < 1 invalid_properties.push('invalid value for "company_name", the character length must be greater than or equal to 1.') end if @domain_name.nil? invalid_properties.push('invalid value for "domain_name", domain_name cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @billing_email.nil? invalid_properties.push('invalid value for "billing_email", billing_email cannot be nil.') end if @application_count.nil? invalid_properties.push('invalid value for "application_count", application_count cannot be nil.') end if @user_count.nil? invalid_properties.push('invalid value for "user_count", user_count cannot be nil.') end if @campaigns_active_count.nil? invalid_properties.push('invalid value for "campaigns_active_count", campaigns_active_count cannot be nil.') end if @campaigns_inactive_count.nil? invalid_properties.push('invalid value for "campaigns_inactive_count", campaigns_inactive_count cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/talon_one_sdk/models/account.rb', line 530 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/talon_one_sdk/models/account.rb', line 335 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @modified.nil? return false if @company_name.nil? return false if @company_name.to_s.length < 1 return false if @domain_name.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["active", "deactivated"]) return false unless state_validator.valid?(@state) return false if @billing_email.nil? return false if @application_count.nil? return false if @user_count.nil? return false if @campaigns_active_count.nil? return false if @campaigns_inactive_count.nil? true end |