Class: TalonOne::AccountAnalytics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AccountAnalytics
- Defined in:
- lib/talon_one_sdk/models/account_analytics.rb
Instance Attribute Summary collapse
-
#active_campaigns ⇒ Object
Total number of active campaigns in the account.
-
#active_coupons ⇒ Object
Total number of active coupons in the account.
-
#active_referral_codes ⇒ Object
Total number of active referral codes in the account.
-
#active_rules ⇒ Object
Total number of active rules in the account.
-
#applications ⇒ Object
Total number of applications in the account.
-
#campaigns ⇒ Object
Total number of campaigns in the account.
-
#coupons ⇒ Object
Total number of coupons in the account.
-
#custom_attributes ⇒ Object
Total number of custom attributes in the account.
-
#expired_coupons ⇒ Object
Total number of expired coupons in the account.
-
#expired_referral_codes ⇒ Object
Total number of expired referral codes in the account.
-
#last_updated_at ⇒ Object
The point in time when the analytics numbers were updated last.
-
#live_active_campaigns ⇒ Object
Total number of active campaigns in live applications in the account.
-
#live_applications ⇒ Object
Total number of live applications in the account.
-
#live_loyalty_programs ⇒ Object
Total number of live loyalty programs in the account.
-
#loyalty_programs ⇒ Object
Total number of all loyalty programs in the account.
-
#referral_codes ⇒ Object
Total number of referral codes in the account.
-
#roles ⇒ Object
Total number of roles in the account.
-
#sandbox_applications ⇒ Object
Total number of sandbox applications in the account.
-
#users ⇒ Object
Total number of users in the account.
-
#webhooks ⇒ Object
Total number of webhooks in the account.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountAnalytics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountAnalytics
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AccountAnalytics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AccountAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'applications') self.applications = attributes[:'applications'] else self.applications = nil end if attributes.key?(:'live_applications') self.live_applications = attributes[:'live_applications'] else self.live_applications = nil end if attributes.key?(:'sandbox_applications') self.sandbox_applications = attributes[:'sandbox_applications'] else self.sandbox_applications = nil end if attributes.key?(:'campaigns') self.campaigns = attributes[:'campaigns'] else self.campaigns = nil end if attributes.key?(:'active_campaigns') self.active_campaigns = attributes[:'active_campaigns'] else self.active_campaigns = nil end if attributes.key?(:'live_active_campaigns') self.live_active_campaigns = attributes[:'live_active_campaigns'] else self.live_active_campaigns = nil end if attributes.key?(:'coupons') self.coupons = attributes[:'coupons'] else self.coupons = nil end if attributes.key?(:'active_coupons') self.active_coupons = attributes[:'active_coupons'] else self.active_coupons = nil end if attributes.key?(:'expired_coupons') self.expired_coupons = attributes[:'expired_coupons'] else self.expired_coupons = nil end if attributes.key?(:'referral_codes') self.referral_codes = attributes[:'referral_codes'] else self.referral_codes = nil end if attributes.key?(:'active_referral_codes') self.active_referral_codes = attributes[:'active_referral_codes'] else self.active_referral_codes = nil end if attributes.key?(:'expired_referral_codes') self.expired_referral_codes = attributes[:'expired_referral_codes'] else self.expired_referral_codes = nil end if attributes.key?(:'active_rules') self.active_rules = attributes[:'active_rules'] else self.active_rules = nil end if attributes.key?(:'users') self.users = attributes[:'users'] else self.users = nil end if attributes.key?(:'roles') self.roles = attributes[:'roles'] else self.roles = nil end if attributes.key?(:'custom_attributes') self.custom_attributes = attributes[:'custom_attributes'] else self.custom_attributes = nil end if attributes.key?(:'webhooks') self.webhooks = attributes[:'webhooks'] else self.webhooks = nil end if attributes.key?(:'loyalty_programs') self.loyalty_programs = attributes[:'loyalty_programs'] else self.loyalty_programs = nil end if attributes.key?(:'live_loyalty_programs') self.live_loyalty_programs = attributes[:'live_loyalty_programs'] else self.live_loyalty_programs = nil end if attributes.key?(:'last_updated_at') self.last_updated_at = attributes[:'last_updated_at'] else self.last_updated_at = nil end end |
Instance Attribute Details
#active_campaigns ⇒ Object
Total number of active campaigns in the account.
31 32 33 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 31 def active_campaigns @active_campaigns end |
#active_coupons ⇒ Object
Total number of active coupons in the account.
40 41 42 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 40 def active_coupons @active_coupons end |
#active_referral_codes ⇒ Object
Total number of active referral codes in the account.
49 50 51 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 49 def active_referral_codes @active_referral_codes end |
#active_rules ⇒ Object
Total number of active rules in the account.
55 56 57 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 55 def active_rules @active_rules end |
#applications ⇒ Object
Total number of applications in the account.
19 20 21 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 19 def applications @applications end |
#campaigns ⇒ Object
Total number of campaigns in the account.
28 29 30 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 28 def campaigns @campaigns end |
#coupons ⇒ Object
Total number of coupons in the account.
37 38 39 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 37 def coupons @coupons end |
#custom_attributes ⇒ Object
Total number of custom attributes in the account.
64 65 66 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 64 def custom_attributes @custom_attributes end |
#expired_coupons ⇒ Object
Total number of expired coupons in the account.
43 44 45 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 43 def expired_coupons @expired_coupons end |
#expired_referral_codes ⇒ Object
Total number of expired referral codes in the account.
52 53 54 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 52 def expired_referral_codes @expired_referral_codes end |
#last_updated_at ⇒ Object
The point in time when the analytics numbers were updated last.
76 77 78 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 76 def last_updated_at @last_updated_at end |
#live_active_campaigns ⇒ Object
Total number of active campaigns in live applications in the account.
34 35 36 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 34 def live_active_campaigns @live_active_campaigns end |
#live_applications ⇒ Object
Total number of live applications in the account.
22 23 24 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 22 def live_applications @live_applications end |
#live_loyalty_programs ⇒ Object
Total number of live loyalty programs in the account.
73 74 75 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 73 def live_loyalty_programs @live_loyalty_programs end |
#loyalty_programs ⇒ Object
Total number of all loyalty programs in the account.
70 71 72 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 70 def loyalty_programs @loyalty_programs end |
#referral_codes ⇒ Object
Total number of referral codes in the account.
46 47 48 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 46 def referral_codes @referral_codes end |
#roles ⇒ Object
Total number of roles in the account.
61 62 63 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 61 def roles @roles end |
#sandbox_applications ⇒ Object
Total number of sandbox applications in the account.
25 26 27 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 25 def sandbox_applications @sandbox_applications end |
#users ⇒ Object
Total number of users in the account.
58 59 60 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 58 def users @users end |
#webhooks ⇒ Object
Total number of webhooks in the account.
67 68 69 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 67 def webhooks @webhooks end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
105 106 107 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 105 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 110 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 79 def self.attribute_map { :'applications' => :'applications', :'live_applications' => :'liveApplications', :'sandbox_applications' => :'sandboxApplications', :'campaigns' => :'campaigns', :'active_campaigns' => :'activeCampaigns', :'live_active_campaigns' => :'liveActiveCampaigns', :'coupons' => :'coupons', :'active_coupons' => :'activeCoupons', :'expired_coupons' => :'expiredCoupons', :'referral_codes' => :'referralCodes', :'active_referral_codes' => :'activeReferralCodes', :'expired_referral_codes' => :'expiredReferralCodes', :'active_rules' => :'activeRules', :'users' => :'users', :'roles' => :'roles', :'custom_attributes' => :'customAttributes', :'webhooks' => :'webhooks', :'loyalty_programs' => :'loyaltyPrograms', :'live_loyalty_programs' => :'liveLoyaltyPrograms', :'last_updated_at' => :'lastUpdatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 640 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 141 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 115 def self.openapi_types { :'applications' => :'Integer', :'live_applications' => :'Integer', :'sandbox_applications' => :'Integer', :'campaigns' => :'Integer', :'active_campaigns' => :'Integer', :'live_active_campaigns' => :'Integer', :'coupons' => :'Integer', :'active_coupons' => :'Integer', :'expired_coupons' => :'Integer', :'referral_codes' => :'Integer', :'active_referral_codes' => :'Integer', :'expired_referral_codes' => :'Integer', :'active_rules' => :'Integer', :'users' => :'Integer', :'roles' => :'Integer', :'custom_attributes' => :'Integer', :'webhooks' => :'Integer', :'loyalty_programs' => :'Integer', :'live_loyalty_programs' => :'Integer', :'last_updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 600 def ==(o) return true if self.equal?(o) self.class == o.class && applications == o.applications && live_applications == o.live_applications && sandbox_applications == o.sandbox_applications && campaigns == o.campaigns && active_campaigns == o.active_campaigns && live_active_campaigns == o.live_active_campaigns && coupons == o.coupons && active_coupons == o.active_coupons && expired_coupons == o.expired_coupons && referral_codes == o.referral_codes && active_referral_codes == o.active_referral_codes && expired_referral_codes == o.expired_referral_codes && active_rules == o.active_rules && users == o.users && roles == o.roles && custom_attributes == o.custom_attributes && webhooks == o.webhooks && loyalty_programs == o.loyalty_programs && live_loyalty_programs == o.live_loyalty_programs && last_updated_at == o.last_updated_at end |
#eql?(o) ⇒ Boolean
627 628 629 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 627 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
633 634 635 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 633 def hash [applications, live_applications, sandbox_applications, campaigns, active_campaigns, live_active_campaigns, coupons, active_coupons, expired_coupons, referral_codes, active_referral_codes, expired_referral_codes, active_rules, users, roles, custom_attributes, webhooks, loyalty_programs, live_loyalty_programs, last_updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 285 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @applications.nil? invalid_properties.push('invalid value for "applications", applications cannot be nil.') end if @live_applications.nil? invalid_properties.push('invalid value for "live_applications", live_applications cannot be nil.') end if @sandbox_applications.nil? invalid_properties.push('invalid value for "sandbox_applications", sandbox_applications cannot be nil.') end if @campaigns.nil? invalid_properties.push('invalid value for "campaigns", campaigns cannot be nil.') end if @active_campaigns.nil? invalid_properties.push('invalid value for "active_campaigns", active_campaigns cannot be nil.') end if @live_active_campaigns.nil? invalid_properties.push('invalid value for "live_active_campaigns", live_active_campaigns cannot be nil.') end if @coupons.nil? invalid_properties.push('invalid value for "coupons", coupons cannot be nil.') end if @active_coupons.nil? invalid_properties.push('invalid value for "active_coupons", active_coupons cannot be nil.') end if @expired_coupons.nil? invalid_properties.push('invalid value for "expired_coupons", expired_coupons cannot be nil.') end if @referral_codes.nil? invalid_properties.push('invalid value for "referral_codes", referral_codes cannot be nil.') end if @active_referral_codes.nil? invalid_properties.push('invalid value for "active_referral_codes", active_referral_codes cannot be nil.') end if @expired_referral_codes.nil? invalid_properties.push('invalid value for "expired_referral_codes", expired_referral_codes cannot be nil.') end if @active_rules.nil? invalid_properties.push('invalid value for "active_rules", active_rules cannot be nil.') end if @users.nil? invalid_properties.push('invalid value for "users", users cannot be nil.') end if @roles.nil? invalid_properties.push('invalid value for "roles", roles cannot be nil.') end if @custom_attributes.nil? invalid_properties.push('invalid value for "custom_attributes", custom_attributes cannot be nil.') end if @webhooks.nil? invalid_properties.push('invalid value for "webhooks", webhooks cannot be nil.') end if @loyalty_programs.nil? invalid_properties.push('invalid value for "loyalty_programs", loyalty_programs cannot be nil.') end if @live_loyalty_programs.nil? invalid_properties.push('invalid value for "live_loyalty_programs", live_loyalty_programs cannot be nil.') end if @last_updated_at.nil? invalid_properties.push('invalid value for "last_updated_at", last_updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
662 663 664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 662 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/talon_one_sdk/models/account_analytics.rb', line 373 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @applications.nil? return false if @live_applications.nil? return false if @sandbox_applications.nil? return false if @campaigns.nil? return false if @active_campaigns.nil? return false if @live_active_campaigns.nil? return false if @coupons.nil? return false if @active_coupons.nil? return false if @expired_coupons.nil? return false if @referral_codes.nil? return false if @active_referral_codes.nil? return false if @expired_referral_codes.nil? return false if @active_rules.nil? return false if @users.nil? return false if @roles.nil? return false if @custom_attributes.nil? return false if @webhooks.nil? return false if @loyalty_programs.nil? return false if @live_loyalty_programs.nil? return false if @last_updated_at.nil? true end |