Class: TalonOne::AccountLimits
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AccountLimits
- Defined in:
- lib/talon_one_sdk/models/account_limits.rb
Instance Attribute Summary collapse
-
#active_campaigns ⇒ Object
Total number of allowed active campaigns in live applications in the account.
-
#active_rules ⇒ Object
Total number of allowed active rulesets in the account.
-
#api_volume ⇒ Object
Allowed volume of API requests to the account.
-
#coupons ⇒ Object
Total number of allowed coupons in the account.
-
#currency_code ⇒ Object
The currency of the contract.
-
#live_applications ⇒ Object
Total number of allowed live applications in the account.
-
#live_loyalty_programs ⇒ Object
Total number of allowed live loyalty programs in the account.
-
#promotion_types ⇒ Object
Array of promotion types that are employed in the account.
-
#referral_codes ⇒ Object
Total number of allowed referral codes in the account.
-
#sandbox_applications ⇒ Object
Total number of allowed sandbox applications in the account.
-
#sandbox_loyalty_programs ⇒ Object
Total number of allowed sandbox loyalty programs in the account.
-
#secondary_deployment_price ⇒ Object
The price for a secondary deployment according to contractual agreements.
-
#users ⇒ Object
Total number of allowed users in the account.
-
#webhooks ⇒ Object
Total number of allowed webhooks in the account.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountLimits
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountLimits
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AccountLimits` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AccountLimits`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'live_applications') self.live_applications = attributes[:'live_applications'] else self.live_applications = nil end if attributes.key?(:'sandbox_applications') self.sandbox_applications = attributes[:'sandbox_applications'] else self.sandbox_applications = nil end if attributes.key?(:'active_campaigns') self.active_campaigns = attributes[:'active_campaigns'] else self.active_campaigns = nil end if attributes.key?(:'coupons') self.coupons = attributes[:'coupons'] else self.coupons = nil end if attributes.key?(:'referral_codes') self.referral_codes = attributes[:'referral_codes'] else self.referral_codes = nil end if attributes.key?(:'active_rules') self.active_rules = attributes[:'active_rules'] else self.active_rules = nil end if attributes.key?(:'live_loyalty_programs') self.live_loyalty_programs = attributes[:'live_loyalty_programs'] else self.live_loyalty_programs = nil end if attributes.key?(:'sandbox_loyalty_programs') self.sandbox_loyalty_programs = attributes[:'sandbox_loyalty_programs'] else self.sandbox_loyalty_programs = nil end if attributes.key?(:'webhooks') self.webhooks = attributes[:'webhooks'] else self.webhooks = nil end if attributes.key?(:'users') self.users = attributes[:'users'] else self.users = nil end if attributes.key?(:'api_volume') self.api_volume = attributes[:'api_volume'] else self.api_volume = nil end if attributes.key?(:'promotion_types') if (value = attributes[:'promotion_types']).is_a?(Array) self.promotion_types = value end else self.promotion_types = nil end if attributes.key?(:'secondary_deployment_price') self.secondary_deployment_price = attributes[:'secondary_deployment_price'] else self.secondary_deployment_price = nil end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] else self.currency_code = nil end end |
Instance Attribute Details
#active_campaigns ⇒ Object
Total number of allowed active campaigns in live applications in the account.
25 26 27 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 25 def active_campaigns @active_campaigns end |
#active_rules ⇒ Object
Total number of allowed active rulesets in the account.
34 35 36 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 34 def active_rules @active_rules end |
#api_volume ⇒ Object
Allowed volume of API requests to the account.
49 50 51 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 49 def api_volume @api_volume end |
#coupons ⇒ Object
Total number of allowed coupons in the account.
28 29 30 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 28 def coupons @coupons end |
#currency_code ⇒ Object
The currency of the contract.
58 59 60 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 58 def currency_code @currency_code end |
#live_applications ⇒ Object
Total number of allowed live applications in the account.
19 20 21 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 19 def live_applications @live_applications end |
#live_loyalty_programs ⇒ Object
Total number of allowed live loyalty programs in the account.
37 38 39 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 37 def live_loyalty_programs @live_loyalty_programs end |
#promotion_types ⇒ Object
Array of promotion types that are employed in the account.
52 53 54 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 52 def promotion_types @promotion_types end |
#referral_codes ⇒ Object
Total number of allowed referral codes in the account.
31 32 33 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 31 def referral_codes @referral_codes end |
#sandbox_applications ⇒ Object
Total number of allowed sandbox applications in the account.
22 23 24 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 22 def sandbox_applications @sandbox_applications end |
#sandbox_loyalty_programs ⇒ Object
Total number of allowed sandbox loyalty programs in the account.
40 41 42 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 40 def sandbox_loyalty_programs @sandbox_loyalty_programs end |
#secondary_deployment_price ⇒ Object
The price for a secondary deployment according to contractual agreements.
55 56 57 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 55 def secondary_deployment_price @secondary_deployment_price end |
#users ⇒ Object
Total number of allowed users in the account.
46 47 48 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 46 def users @users end |
#webhooks ⇒ Object
Total number of allowed webhooks in the account.
43 44 45 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 43 def webhooks @webhooks end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 61 def self.attribute_map { :'live_applications' => :'liveApplications', :'sandbox_applications' => :'sandboxApplications', :'active_campaigns' => :'activeCampaigns', :'coupons' => :'coupons', :'referral_codes' => :'referralCodes', :'active_rules' => :'activeRules', :'live_loyalty_programs' => :'liveLoyaltyPrograms', :'sandbox_loyalty_programs' => :'sandboxLoyaltyPrograms', :'webhooks' => :'webhooks', :'users' => :'users', :'api_volume' => :'apiVolume', :'promotion_types' => :'promotionTypes', :'secondary_deployment_price' => :'SecondaryDeploymentPrice', :'currency_code' => :'currencyCode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 480 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 91 def self.openapi_types { :'live_applications' => :'Integer', :'sandbox_applications' => :'Integer', :'active_campaigns' => :'Integer', :'coupons' => :'Integer', :'referral_codes' => :'Integer', :'active_rules' => :'Integer', :'live_loyalty_programs' => :'Integer', :'sandbox_loyalty_programs' => :'Integer', :'webhooks' => :'Integer', :'users' => :'Integer', :'api_volume' => :'Integer', :'promotion_types' => :'Array<String>', :'secondary_deployment_price' => :'Integer', :'currency_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 446 def ==(o) return true if self.equal?(o) self.class == o.class && live_applications == o.live_applications && sandbox_applications == o.sandbox_applications && active_campaigns == o.active_campaigns && coupons == o.coupons && referral_codes == o.referral_codes && active_rules == o.active_rules && live_loyalty_programs == o.live_loyalty_programs && sandbox_loyalty_programs == o.sandbox_loyalty_programs && webhooks == o.webhooks && users == o.users && api_volume == o.api_volume && promotion_types == o.promotion_types && secondary_deployment_price == o.secondary_deployment_price && currency_code == o.currency_code end |
#eql?(o) ⇒ Boolean
467 468 469 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 467 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
473 474 475 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 473 def hash [live_applications, sandbox_applications, active_campaigns, coupons, referral_codes, active_rules, live_loyalty_programs, sandbox_loyalty_programs, webhooks, users, api_volume, promotion_types, secondary_deployment_price, currency_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 221 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @live_applications.nil? invalid_properties.push('invalid value for "live_applications", live_applications cannot be nil.') end if @sandbox_applications.nil? invalid_properties.push('invalid value for "sandbox_applications", sandbox_applications cannot be nil.') end if @active_campaigns.nil? invalid_properties.push('invalid value for "active_campaigns", active_campaigns cannot be nil.') end if @coupons.nil? invalid_properties.push('invalid value for "coupons", coupons cannot be nil.') end if @referral_codes.nil? invalid_properties.push('invalid value for "referral_codes", referral_codes cannot be nil.') end if @active_rules.nil? invalid_properties.push('invalid value for "active_rules", active_rules cannot be nil.') end if @live_loyalty_programs.nil? invalid_properties.push('invalid value for "live_loyalty_programs", live_loyalty_programs cannot be nil.') end if @sandbox_loyalty_programs.nil? invalid_properties.push('invalid value for "sandbox_loyalty_programs", sandbox_loyalty_programs cannot be nil.') end if @webhooks.nil? invalid_properties.push('invalid value for "webhooks", webhooks cannot be nil.') end if @users.nil? invalid_properties.push('invalid value for "users", users cannot be nil.') end if @api_volume.nil? invalid_properties.push('invalid value for "api_volume", api_volume cannot be nil.') end if @promotion_types.nil? invalid_properties.push('invalid value for "promotion_types", promotion_types cannot be nil.') end if @secondary_deployment_price.nil? invalid_properties.push('invalid value for "secondary_deployment_price", secondary_deployment_price cannot be nil.') end if @currency_code.nil? invalid_properties.push('invalid value for "currency_code", currency_code cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 502 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/talon_one_sdk/models/account_limits.rb', line 285 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @live_applications.nil? return false if @sandbox_applications.nil? return false if @active_campaigns.nil? return false if @coupons.nil? return false if @referral_codes.nil? return false if @active_rules.nil? return false if @live_loyalty_programs.nil? return false if @sandbox_loyalty_programs.nil? return false if @webhooks.nil? return false if @users.nil? return false if @api_volume.nil? return false if @promotion_types.nil? return false if @secondary_deployment_price.nil? return false if @currency_code.nil? true end |