Class: TalonOne::AchievementProgressWithDefinition

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/achievement_progress_with_definition.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AchievementProgressWithDefinition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementProgressWithDefinition` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementProgressWithDefinition`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  else
    self.progress = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'completion_date')
    self.completion_date = attributes[:'completion_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'achievement_id')
    self.achievement_id = attributes[:'achievement_id']
  else
    self.achievement_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'achievement_recurrence_policy')
    self.achievement_recurrence_policy = attributes[:'achievement_recurrence_policy']
  else
    self.achievement_recurrence_policy = nil
  end

  if attributes.key?(:'achievement_activation_policy')
    self.achievement_activation_policy = attributes[:'achievement_activation_policy']
  else
    self.achievement_activation_policy = nil
  end

  if attributes.key?(:'achievement_fixed_start_date')
    self.achievement_fixed_start_date = attributes[:'achievement_fixed_start_date']
  end

  if attributes.key?(:'achievement_end_date')
    self.achievement_end_date = attributes[:'achievement_end_date']
  end

  if attributes.key?(:'achievement_allow_rollback_after_completion')
    self.achievement_allow_rollback_after_completion = attributes[:'achievement_allow_rollback_after_completion']
  end
end

Instance Attribute Details

#achievement_activation_policyObject

The policy that determines how the achievement starts, ends, or resets. - ‘user_action`: The achievement ends or resets relative to when the customer started the achievement. - `fixed_schedule`: The achievement starts, ends, or resets for all customers following a fixed schedule.



55
56
57
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 55

def achievement_activation_policy
  @achievement_activation_policy
end

#achievement_allow_rollback_after_completionObject

When ‘true`, customer progress can be rolled back in completed achievements.



64
65
66
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 64

def achievement_allow_rollback_after_completion
  @achievement_allow_rollback_after_completion
end

#achievement_end_dateObject

The achievement’s end date. If defined, customers cannot participate in the achievement after this date. Note: It is an RFC3339 timestamp string.



61
62
63
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 61

def achievement_end_date
  @achievement_end_date
end

#achievement_fixed_start_dateObject

The achievement’s start date when ‘achievementActivationPolicy` is equal to `fixed_schedule`. Note: It is an RFC3339 timestamp string.



58
59
60
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 58

def achievement_fixed_start_date
  @achievement_fixed_start_date
end

#achievement_idObject

The internal ID of the achievement.



34
35
36
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 34

def achievement_id
  @achievement_id
end

#achievement_recurrence_policyObject

The policy that determines if and how the achievement recurs. - ‘no_recurrence`: The achievement can be completed only once. - `on_expiration`: The achievement resets after it expires and becomes available again. - `on_completion`: When the customer progress status reaches `completed`, the achievement resets and becomes available again.



52
53
54
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 52

def achievement_recurrence_policy
  @achievement_recurrence_policy
end

#campaign_idObject

The ID of the campaign the achievement belongs to.



46
47
48
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 46

def campaign_id
  @campaign_id
end

#completion_dateObject

Timestamp at which point the customer completed the achievement.



28
29
30
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 28

def completion_date
  @completion_date
end

#descriptionObject

The description of the achievement in the Campaign Manager.



43
44
45
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 43

def description
  @description
end

#end_dateObject

Timestamp at which point the achievement ends and resets for the customer.



31
32
33
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 31

def end_date
  @end_date
end

#nameObject

The internal name of the achievement used in API requests.



37
38
39
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 37

def name
  @name
end

#progressObject

The current progress of the customer in the achievement.



22
23
24
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 22

def progress
  @progress
end

#start_dateObject

Timestamp at which the customer started the achievement.



25
26
27
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 25

def start_date
  @start_date
end

#statusObject

The status of the achievement.



19
20
21
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 19

def status
  @status
end

#targetObject

The required number of actions or the transactional milestone to complete the achievement.



49
50
51
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 49

def target
  @target
end

#titleObject

The display name of the achievement in the Campaign Manager.



40
41
42
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 40

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



111
112
113
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 111

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 116

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 89

def self.attribute_map
  {
    :'status' => :'status',
    :'progress' => :'progress',
    :'start_date' => :'startDate',
    :'completion_date' => :'completionDate',
    :'end_date' => :'endDate',
    :'achievement_id' => :'achievementId',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'campaign_id' => :'campaignId',
    :'target' => :'target',
    :'achievement_recurrence_policy' => :'achievementRecurrencePolicy',
    :'achievement_activation_policy' => :'achievementActivationPolicy',
    :'achievement_fixed_start_date' => :'achievementFixedStartDate',
    :'achievement_end_date' => :'achievementEndDate',
    :'achievement_allow_rollback_after_completion' => :'achievementAllowRollbackAfterCompletion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 477

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



149
150
151
152
153
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 149

def self.openapi_all_of
  [
  :'AchievementProgress'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 143

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 121

def self.openapi_types
  {
    :'status' => :'String',
    :'progress' => :'Float',
    :'start_date' => :'Time',
    :'completion_date' => :'Time',
    :'end_date' => :'Time',
    :'achievement_id' => :'Integer',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'campaign_id' => :'Integer',
    :'target' => :'Float',
    :'achievement_recurrence_policy' => :'String',
    :'achievement_activation_policy' => :'String',
    :'achievement_fixed_start_date' => :'Time',
    :'achievement_end_date' => :'Time',
    :'achievement_allow_rollback_after_completion' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 441

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      progress == o.progress &&
      start_date == o.start_date &&
      completion_date == o.completion_date &&
      end_date == o.end_date &&
      achievement_id == o.achievement_id &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      campaign_id == o.campaign_id &&
      target == o.target &&
      achievement_recurrence_policy == o.achievement_recurrence_policy &&
      achievement_activation_policy == o.achievement_activation_policy &&
      achievement_fixed_start_date == o.achievement_fixed_start_date &&
      achievement_end_date == o.achievement_end_date &&
      achievement_allow_rollback_after_completion == o.achievement_allow_rollback_after_completion
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


464
465
466
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 464

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



470
471
472
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 470

def hash
  [status, progress, start_date, completion_date, end_date, achievement_id, name, title, description, campaign_id, target, achievement_recurrence_policy, achievement_activation_policy, achievement_fixed_start_date, achievement_end_date, achievement_allow_rollback_after_completion].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 256

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @progress.nil?
    invalid_properties.push('invalid value for "progress", progress cannot be nil.')
  end

  if @achievement_id.nil?
    invalid_properties.push('invalid value for "achievement_id", achievement_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 1000
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]\w+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @achievement_recurrence_policy.nil?
    invalid_properties.push('invalid value for "achievement_recurrence_policy", achievement_recurrence_policy cannot be nil.')
  end

  if @achievement_activation_policy.nil?
    invalid_properties.push('invalid value for "achievement_activation_policy", achievement_activation_policy cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 499

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/talon_one_sdk/models/achievement_progress_with_definition.rb', line 313

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["inprogress", "completed", "expired", "not_started"])
  return false unless status_validator.valid?(@status)
  return false if @progress.nil?
  return false if @achievement_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 1000
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z]\w+$/)
  return false if @title.nil?
  return false if @description.nil?
  return false if @campaign_id.nil?
  return false if @achievement_recurrence_policy.nil?
  achievement_recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"])
  return false unless achievement_recurrence_policy_validator.valid?(@achievement_recurrence_policy)
  return false if @achievement_activation_policy.nil?
  achievement_activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"])
  return false unless achievement_activation_policy_validator.valid?(@achievement_activation_policy)
  true
end