Class: TalonOne::AchievementV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AchievementV2
- Defined in:
- lib/talon_one_sdk/models/achievement_v2.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activation_policy ⇒ Object
The policy that determines how the achievement starts, ends, or resets.
-
#allow_rollback_after_completion ⇒ Object
When
true, customer progress can be rolled back in completed achievements. -
#campaign_id ⇒ Object
This property is deprecated.
-
#created ⇒ Object
The time this entity was created.
-
#created_by ⇒ Object
Name of the user that created the achievement.
-
#description ⇒ Object
A description of the achievement.
-
#end_date ⇒ Object
The achievement's end date.
-
#fixed_start_date ⇒ Object
The achievement's start date when
activationPolicyis set tofixed_schedule. -
#has_progress ⇒ Object
Indicates if a customer has made progress in the achievement.
-
#id ⇒ Object
The internal ID of this entity.
-
#name ⇒ Object
The internal name of the achievement used in API requests.
-
#period ⇒ Object
The relative duration after which the achievement ends and resets for a particular customer profile.
-
#period_end_override ⇒ Object
Returns the value of attribute period_end_override.
-
#recurrence_policy ⇒ Object
The policy that determines if and how the achievement recurs.
-
#referenced_by_campaigns ⇒ Object
The campaigns that reference this achievement.
-
#sandbox ⇒ Object
Indicates if this achievement is a live or sandbox achievement.
-
#status ⇒ Object
The status of the achievement.
-
#subscribed_applications ⇒ Object
A list containing the IDs of all applications that are subscribed to A list containing the IDs of all Applications that are connected to this achievement.
-
#target ⇒ Object
The required number of actions or the transactional milestone to complete the achievement.
-
#timezone ⇒ Object
A string containing an IANA timezone descriptor.
-
#title ⇒ Object
The display name for the achievement in the Campaign Manager.
-
#user_id ⇒ Object
The ID of the user that created this achievement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AchievementV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AchievementV2
Initializes the object
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 188 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'period') self.period = attributes[:'period'] end if attributes.key?(:'recurrence_policy') self.recurrence_policy = attributes[:'recurrence_policy'] end if attributes.key?(:'activation_policy') self.activation_policy = attributes[:'activation_policy'] end if attributes.key?(:'fixed_start_date') self.fixed_start_date = attributes[:'fixed_start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'allow_rollback_after_completion') self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion'] end if attributes.key?(:'subscribed_applications') if (value = attributes[:'subscribed_applications']).is_a?(Array) self.subscribed_applications = value end end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'period_end_override') self.period_end_override = attributes[:'period_end_override'] end if attributes.key?(:'has_progress') self.has_progress = attributes[:'has_progress'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] else self.sandbox = nil end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'referenced_by_campaigns') if (value = attributes[:'referenced_by_campaigns']).is_a?(Array) self.referenced_by_campaigns = value end else self.referenced_by_campaigns = nil end end |
Instance Attribute Details
#activation_policy ⇒ Object
The policy that determines how the achievement starts, ends, or resets. - user_action: The achievement ends or resets relative to when the customer started the achievement. - fixed_schedule: The achievement starts, ends, or resets for all customers following a fixed schedule.
43 44 45 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 43 def activation_policy @activation_policy end |
#allow_rollback_after_completion ⇒ Object
When true, customer progress can be rolled back in completed achievements.
52 53 54 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 52 def allow_rollback_after_completion @allow_rollback_after_completion end |
#campaign_id ⇒ Object
This property is deprecated. Use referencedByCampaigns instead. The ID of the first campaign in referencedByCampaigns. Only returned when referencedByCampaigns is not empty.
78 79 80 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 78 def campaign_id @campaign_id end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 22 def created @created end |
#created_by ⇒ Object
Name of the user that created the achievement. Note: This is not available if the user has been deleted.
61 62 63 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 61 def created_by @created_by end |
#description ⇒ Object
A description of the achievement.
31 32 33 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 31 def description @description end |
#end_date ⇒ Object
The achievement's end date. If defined, customers cannot participate in the achievement after this date. Note: It must be an RFC3339 timestamp string.
49 50 51 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 49 def end_date @end_date end |
#fixed_start_date ⇒ Object
The achievement's start date when activationPolicy is set to fixed_schedule. Note: It must be an RFC3339 timestamp string.
46 47 48 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 46 def fixed_start_date @fixed_start_date end |
#has_progress ⇒ Object
Indicates if a customer has made progress in the achievement.
66 67 68 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 66 def has_progress @has_progress end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 19 def id @id end |
#name ⇒ Object
The internal name of the achievement used in API requests. Note: The name should start with a letter. This cannot be changed after the achievement has been created.
25 26 27 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 25 def name @name end |
#period ⇒ Object
The relative duration after which the achievement ends and resets for a particular customer profile. Note: The period does not start when the achievement is created. The period is a positive real number followed by one letter indicating the time unit. Examples: 30s, 40m, 1h, 5D, 7W, 10M, 15Y. Available units: - s: seconds - m: minutes - h: hours - D: days - W: weeks - M: months - Y: years You can also round certain units down to the beginning of period and up to the end of period.: - _D for rounding down days only. Signifies the start of the day. Example: 30D_D - _U for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. Example: 23W_U Note: You can either use the round down and round up option or set an absolute period.
37 38 39 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 37 def period @period end |
#period_end_override ⇒ Object
Returns the value of attribute period_end_override.
63 64 65 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 63 def period_end_override @period_end_override end |
#recurrence_policy ⇒ Object
The policy that determines if and how the achievement recurs. - no_recurrence: The achievement can be completed only once. - on_expiration: The achievement resets after it expires and becomes available again. - on_completion: When the customer progress status reaches completed, the achievement resets and becomes available again.
40 41 42 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 40 def recurrence_policy @recurrence_policy end |
#referenced_by_campaigns ⇒ Object
The campaigns that reference this achievement. They are sorted in ascending order by their id.
81 82 83 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 81 def referenced_by_campaigns @referenced_by_campaigns end |
#sandbox ⇒ Object
Indicates if this achievement is a live or sandbox achievement. Achievements of a given type can only be connected to Applications of the same type.
72 73 74 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 72 def sandbox @sandbox end |
#status ⇒ Object
The status of the achievement. - active: The achievement is available to customers. - scheduled: The achievement has a fixedStartDate set in the future. - expired: The achievement's endDate is in the past.
69 70 71 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 69 def status @status end |
#subscribed_applications ⇒ Object
A list containing the IDs of all applications that are subscribed to A list containing the IDs of all Applications that are connected to this achievement.
55 56 57 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 55 def subscribed_applications @subscribed_applications end |
#target ⇒ Object
The required number of actions or the transactional milestone to complete the achievement.
34 35 36 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 34 def target @target end |
#timezone ⇒ Object
A string containing an IANA timezone descriptor.
75 76 77 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 75 def timezone @timezone end |
#title ⇒ Object
The display name for the achievement in the Campaign Manager.
28 29 30 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 28 def title @title end |
#user_id ⇒ Object
The ID of the user that created this achievement.
58 59 60 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 58 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
134 135 136 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 134 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
139 140 141 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 139 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 106 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'name' => :'name', :'title' => :'title', :'description' => :'description', :'target' => :'target', :'period' => :'period', :'recurrence_policy' => :'recurrencePolicy', :'activation_policy' => :'activationPolicy', :'fixed_start_date' => :'fixedStartDate', :'end_date' => :'endDate', :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion', :'subscribed_applications' => :'subscribedApplications', :'user_id' => :'userId', :'created_by' => :'createdBy', :'period_end_override' => :'periodEndOverride', :'has_progress' => :'hasProgress', :'status' => :'status', :'sandbox' => :'sandbox', :'timezone' => :'timezone', :'campaign_id' => :'campaignId', :'referenced_by_campaigns' => :'referencedByCampaigns' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 559 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
178 179 180 181 182 183 184 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 178 def self.openapi_all_of [ :'AchievementAdditionalPropertiesV2', :'AchievementBaseV2', :'Entity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
172 173 174 175 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 172 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 144 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'name' => :'String', :'title' => :'String', :'description' => :'String', :'target' => :'Float', :'period' => :'String', :'recurrence_policy' => :'String', :'activation_policy' => :'String', :'fixed_start_date' => :'Time', :'end_date' => :'Time', :'allow_rollback_after_completion' => :'Boolean', :'subscribed_applications' => :'Array<Integer>', :'user_id' => :'Integer', :'created_by' => :'String', :'period_end_override' => :'TimePoint', :'has_progress' => :'Boolean', :'status' => :'String', :'sandbox' => :'Boolean', :'timezone' => :'String', :'campaign_id' => :'Integer', :'referenced_by_campaigns' => :'Array<CampaignReference>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 517 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && name == o.name && title == o.title && description == o.description && target == o.target && period == o.period && recurrence_policy == o.recurrence_policy && activation_policy == o.activation_policy && fixed_start_date == o.fixed_start_date && end_date == o.end_date && allow_rollback_after_completion == o.allow_rollback_after_completion && subscribed_applications == o.subscribed_applications && user_id == o.user_id && created_by == o.created_by && period_end_override == o.period_end_override && has_progress == o.has_progress && status == o.status && sandbox == o.sandbox && timezone == o.timezone && campaign_id == o.campaign_id && referenced_by_campaigns == o.referenced_by_campaigns end |
#eql?(o) ⇒ Boolean
546 547 548 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 546 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
552 553 554 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 552 def hash [id, created, name, title, description, target, period, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion, subscribed_applications, user_id, created_by, period_end_override, has_progress, status, sandbox, timezone, campaign_id, referenced_by_campaigns].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 309 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if !@name.nil? && @name.to_s.length > 1000 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-zA-Z]\w+$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@subscribed_applications.nil? && @subscribed_applications.length < 0 invalid_properties.push('invalid value for "subscribed_applications", number of items must be greater than or equal to 0.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @sandbox.nil? invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.') end if @timezone.nil? invalid_properties.push('invalid value for "timezone", timezone cannot be nil.') end if @timezone.to_s.length < 1 invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.') end if @referenced_by_campaigns.nil? invalid_properties.push('invalid value for "referenced_by_campaigns", referenced_by_campaigns cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 581 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 362 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if !@name.nil? && @name.to_s.length > 1000 return false if !@name.nil? && @name.to_s.length < 1 return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z]\w+$/) recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"]) return false unless recurrence_policy_validator.valid?(@recurrence_policy) activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"]) return false unless activation_policy_validator.valid?(@activation_policy) return false if !@subscribed_applications.nil? && @subscribed_applications.length < 0 return false if @user_id.nil? status_validator = EnumAttributeValidator.new('String', ["active", "scheduled", "expired"]) return false unless status_validator.valid?(@status) return false if @sandbox.nil? return false if @timezone.nil? return false if @timezone.to_s.length < 1 return false if @referenced_by_campaigns.nil? true end |