Class: TalonOne::AchievementV2

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/achievement_v2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AchievementV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 174

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'recurrence_policy')
    self.recurrence_policy = attributes[:'recurrence_policy']
  else
    self.recurrence_policy = nil
  end

  if attributes.key?(:'activation_policy')
    self.activation_policy = attributes[:'activation_policy']
  else
    self.activation_policy = nil
  end

  if attributes.key?(:'fixed_start_date')
    self.fixed_start_date = attributes[:'fixed_start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'allow_rollback_after_completion')
    self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion']
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  else
    self.sandbox = nil
  end

  if attributes.key?(:'subscribed_applications')
    if (value = attributes[:'subscribed_applications']).is_a?(Array)
      self.subscribed_applications = value
    end
  else
    self.subscribed_applications = nil
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'has_progress')
    self.has_progress = attributes[:'has_progress']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#activation_policyObject

The policy that determines how the achievement starts, ends, or resets. - ‘user_action`: The achievement ends or resets relative to when the customer started the achievement. - `fixed_schedule`: The achievement starts, ends, or resets for all customers following a fixed schedule.



43
44
45
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 43

def activation_policy
  @activation_policy
end

#allow_rollback_after_completionObject

When ‘true`, customer progress can be rolled back in completed achievements.



52
53
54
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 52

def allow_rollback_after_completion
  @allow_rollback_after_completion
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 22

def created
  @created
end

#created_byObject

Name of the user that created the achievement. Note: This is not available if the user has been deleted.



67
68
69
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 67

def created_by
  @created_by
end

#descriptionObject

A description of the achievement.



31
32
33
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 31

def description
  @description
end

#end_dateObject

The achievement’s end date. If defined, customers cannot participate in the achievement after this date. Note: It must be an RFC3339 timestamp string.



49
50
51
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 49

def end_date
  @end_date
end

#fixed_start_dateObject

The achievement’s start date when ‘activationPolicy` is set to `fixed_schedule`. Note: It must be an RFC3339 timestamp string.



46
47
48
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 46

def fixed_start_date
  @fixed_start_date
end

#has_progressObject

Indicates if a customer has made progress in the achievement.



70
71
72
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 70

def has_progress
  @has_progress
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 19

def id
  @id
end

#nameObject

The internal name of the achievement used in API requests. Note: The name should start with a letter. This cannot be changed after the achievement has been created.



25
26
27
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 25

def name
  @name
end

#periodObject

The relative duration after which the achievement ends and resets for a particular customer profile. Note: The ‘period` does not start when the achievement is created. The period is a **positive real number** followed by one letter indicating the time unit. Examples: `30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can also round certain units down to the beginning of period and up to the end of period.: - `_D` for rounding down days only. Signifies the start of the day. Example: `30D_D` - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. Example: `23W_U` Note: You can either use the round down and round up option or set an absolute period.



37
38
39
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 37

def period
  @period
end

#recurrence_policyObject

The policy that determines if and how the achievement recurs. - ‘no_recurrence`: The achievement can be completed only once. - `on_expiration`: The achievement resets after it expires and becomes available again. - `on_completion`: When the customer progress status reaches `completed`, the achievement resets and becomes available again.



40
41
42
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 40

def recurrence_policy
  @recurrence_policy
end

#sandboxObject

Indicates if this achievement is a live or sandbox achievement. Achievements of a given type can only be connected to Applications of the same type.



55
56
57
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 55

def sandbox
  @sandbox
end

#statusObject

The status of the achievement.



73
74
75
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 73

def status
  @status
end

#subscribed_applicationsObject

A list containing the IDs of all applications that are subscribed to A list containing the IDs of all Applications that are connected to this achievement.



58
59
60
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 58

def subscribed_applications
  @subscribed_applications
end

#targetObject

The required number of actions or the transactional milestone to complete the achievement.



34
35
36
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 34

def target
  @target
end

#timezoneObject

A string containing an IANA timezone descriptor.



61
62
63
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 61

def timezone
  @timezone
end

#titleObject

The display name for the achievement in the Campaign Manager.



28
29
30
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 28

def title
  @title
end

#user_idObject

The ID of the user that created this achievement.



64
65
66
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 64

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



123
124
125
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 123

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



128
129
130
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 128

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 98

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'target' => :'target',
    :'period' => :'period',
    :'recurrence_policy' => :'recurrencePolicy',
    :'activation_policy' => :'activationPolicy',
    :'fixed_start_date' => :'fixedStartDate',
    :'end_date' => :'endDate',
    :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion',
    :'sandbox' => :'sandbox',
    :'subscribed_applications' => :'subscribedApplications',
    :'timezone' => :'timezone',
    :'user_id' => :'userId',
    :'created_by' => :'createdBy',
    :'has_progress' => :'hasProgress',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 590

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



164
165
166
167
168
169
170
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 164

def self.openapi_all_of
  [
  :'AchievementAdditionalPropertiesV2',
  :'AchievementBaseV2',
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



158
159
160
161
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 158

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 133

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'target' => :'Float',
    :'period' => :'String',
    :'recurrence_policy' => :'String',
    :'activation_policy' => :'String',
    :'fixed_start_date' => :'Time',
    :'end_date' => :'Time',
    :'allow_rollback_after_completion' => :'Boolean',
    :'sandbox' => :'Boolean',
    :'subscribed_applications' => :'Array<Integer>',
    :'timezone' => :'String',
    :'user_id' => :'Integer',
    :'created_by' => :'String',
    :'has_progress' => :'Boolean',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 551

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      target == o.target &&
      period == o.period &&
      recurrence_policy == o.recurrence_policy &&
      activation_policy == o.activation_policy &&
      fixed_start_date == o.fixed_start_date &&
      end_date == o.end_date &&
      allow_rollback_after_completion == o.allow_rollback_after_completion &&
      sandbox == o.sandbox &&
      subscribed_applications == o.subscribed_applications &&
      timezone == o.timezone &&
      user_id == o.user_id &&
      created_by == o.created_by &&
      has_progress == o.has_progress &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


577
578
579
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 577

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



583
584
585
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 583

def hash
  [id, created, name, title, description, target, period, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion, sandbox, subscribed_applications, timezone, user_id, created_by, has_progress, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 293

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 1000
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]\w+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @recurrence_policy.nil?
    invalid_properties.push('invalid value for "recurrence_policy", recurrence_policy cannot be nil.')
  end

  if @activation_policy.nil?
    invalid_properties.push('invalid value for "activation_policy", activation_policy cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  if @subscribed_applications.nil?
    invalid_properties.push('invalid value for "subscribed_applications", subscribed_applications cannot be nil.')
  end

  if @subscribed_applications.length < 0
    invalid_properties.push('invalid value for "subscribed_applications", number of items must be greater than or equal to 0.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  if @timezone.to_s.length < 1
    invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



612
613
614
615
616
617
618
619
620
621
622
623
624
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 612

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/talon_one_sdk/models/achievement_v2.rb', line 370

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 1000
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z]\w+$/)
  return false if @title.nil?
  return false if @description.nil?
  return false if @target.nil?
  return false if @recurrence_policy.nil?
  recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"])
  return false unless recurrence_policy_validator.valid?(@recurrence_policy)
  return false if @activation_policy.nil?
  activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"])
  return false unless activation_policy_validator.valid?(@activation_policy)
  return false if @sandbox.nil?
  return false if @subscribed_applications.nil?
  return false if @subscribed_applications.length < 0
  return false if @timezone.nil?
  return false if @timezone.to_s.length < 1
  return false if @user_id.nil?
  status_validator = EnumAttributeValidator.new('String', ["inprogress", "expired", "not_started", "completed"])
  return false unless status_validator.valid?(@status)
  true
end