Class: TalonOne::ActivateLoyaltyPoints
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ActivateLoyaltyPoints
- Defined in:
- lib/talon_one_sdk/models/activate_loyalty_points.rb
Overview
Activate loyalty points
Instance Attribute Summary collapse
-
#session_id ⇒ Object
The ID of the session containing the pending point transactions to activate.
-
#transaction_uuids ⇒ Object
An array of transaction UUIDs used to activate specific pending point transactions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ActivateLoyaltyPoints
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ActivateLoyaltyPoints
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ActivateLoyaltyPoints` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ActivateLoyaltyPoints`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'transaction_uuids') if (value = attributes[:'transaction_uuids']).is_a?(Array) self.transaction_uuids = value end end if attributes.key?(:'session_id') self.session_id = attributes[:'session_id'] end end |
Instance Attribute Details
#session_id ⇒ Object
The ID of the session containing the pending point transactions to activate. If provided, do not include the ‘transactionUUIDs` parameter.
23 24 25 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 23 def session_id @session_id end |
#transaction_uuids ⇒ Object
An array of transaction UUIDs used to activate specific pending point transactions. If provided, do not include the ‘sessionId` parameter.
20 21 22 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 20 def transaction_uuids @transaction_uuids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 26 def self.attribute_map { :'transaction_uuids' => :'transactionUUIDs', :'session_id' => :'sessionId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 44 def self.openapi_types { :'transaction_uuids' => :'Array<String>', :'session_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && transaction_uuids == o.transaction_uuids && session_id == o.session_id end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 163 def hash [transaction_uuids, session_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@transaction_uuids.nil? && @transaction_uuids.length > 50 invalid_properties.push('invalid value for "transaction_uuids", number of items must be less than or equal to 50.') end if !@transaction_uuids.nil? && @transaction_uuids.length < 1 invalid_properties.push('invalid value for "transaction_uuids", number of items must be greater than or equal to 1.') end if !@session_id.nil? && @session_id.to_s.length < 1 invalid_properties.push('invalid value for "session_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 111 112 |
# File 'lib/talon_one_sdk/models/activate_loyalty_points.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@transaction_uuids.nil? && @transaction_uuids.length > 50 return false if !@transaction_uuids.nil? && @transaction_uuids.length < 1 return false if !@session_id.nil? && @session_id.to_s.length < 1 true end |