Class: TalonOne::AddLoyaltyPointsEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::AddLoyaltyPointsEffectProps
- Defined in:
- lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb
Overview
The properties specific to the "addLoyaltyPoints" effect. This gets triggered whenever a validated rule contained an "add loyalty" effect. These points are automatically stored and managed inside Talon.One.
Instance Attribute Summary collapse
-
#awaits_activation ⇒ Object
If ‘true`, the loyalty points remain pending until a specific action is complete.
-
#bundle_index ⇒ Object
The position of the bundle in a list of item bundles created from the same bundle definition.
-
#bundle_name ⇒ Object
The name of the bundle definition.
-
#card_identifier ⇒ Object
The card on which these points were added.
-
#cart_item_position ⇒ Object
The index of the item in the cart items list on which the loyal points addition should be applied.
-
#cart_item_sub_position ⇒ Object
For cart items with ‘quantity` > 1, the sub position indicates to which item the loyalty points addition is applied.
-
#desired_value ⇒ Object
The original amount of loyalty points to be awarded.
-
#expiry_date ⇒ Object
Date after which points will expire.
-
#name ⇒ Object
The name / description of this loyalty point addition.
-
#program_id ⇒ Object
The ID of the loyalty program where these points were added.
-
#recipient_integration_id ⇒ Object
The user for whom these points were added.
-
#start_date ⇒ Object
Date after which points will be valid.
-
#sub_ledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
-
#transaction_uuid ⇒ Object
The identifier of this addition in the loyalty ledger.
-
#validity_duration ⇒ Object
The duration for which the points remain active, calculated relative to the activation date.
-
#value ⇒ Object
The amount of points that were added.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddLoyaltyPointsEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddLoyaltyPointsEffectProps
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddLoyaltyPointsEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddLoyaltyPointsEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] else self.program_id = nil end if attributes.key?(:'sub_ledger_id') self.sub_ledger_id = attributes[:'sub_ledger_id'] else self.sub_ledger_id = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'desired_value') self.desired_value = attributes[:'desired_value'] end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] else self.recipient_integration_id = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'transaction_uuid') self.transaction_uuid = attributes[:'transaction_uuid'] else self.transaction_uuid = nil end if attributes.key?(:'cart_item_position') self.cart_item_position = attributes[:'cart_item_position'] end if attributes.key?(:'cart_item_sub_position') self.cart_item_sub_position = attributes[:'cart_item_sub_position'] end if attributes.key?(:'card_identifier') self.card_identifier = attributes[:'card_identifier'] end if attributes.key?(:'bundle_index') self.bundle_index = attributes[:'bundle_index'] end if attributes.key?(:'bundle_name') self.bundle_name = attributes[:'bundle_name'] end if attributes.key?(:'awaits_activation') self.awaits_activation = attributes[:'awaits_activation'] end if attributes.key?(:'validity_duration') self.validity_duration = attributes[:'validity_duration'] end end |
Instance Attribute Details
#awaits_activation ⇒ Object
If ‘true`, the loyalty points remain pending until a specific action is complete. The `startDate` parameter automatically sets to `on_action`.
62 63 64 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 62 def awaits_activation @awaits_activation end |
#bundle_index ⇒ Object
The position of the bundle in a list of item bundles created from the same bundle definition.
56 57 58 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 56 def bundle_index @bundle_index end |
#bundle_name ⇒ Object
The name of the bundle definition.
59 60 61 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 59 def bundle_name @bundle_name end |
#card_identifier ⇒ Object
The card on which these points were added.
53 54 55 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 53 def card_identifier @card_identifier end |
#cart_item_position ⇒ Object
The index of the item in the cart items list on which the loyal points addition should be applied.
47 48 49 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 47 def cart_item_position @cart_item_position end |
#cart_item_sub_position ⇒ Object
For cart items with ‘quantity` > 1, the sub position indicates to which item the loyalty points addition is applied.
50 51 52 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 50 def cart_item_sub_position @cart_item_sub_position end |
#desired_value ⇒ Object
The original amount of loyalty points to be awarded.
32 33 34 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 32 def desired_value @desired_value end |
#expiry_date ⇒ Object
Date after which points will expire.
41 42 43 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 41 def expiry_date @expiry_date end |
#name ⇒ Object
The name / description of this loyalty point addition.
20 21 22 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 20 def name @name end |
#program_id ⇒ Object
The ID of the loyalty program where these points were added.
23 24 25 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 23 def program_id @program_id end |
#recipient_integration_id ⇒ Object
The user for whom these points were added.
35 36 37 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 35 def recipient_integration_id @recipient_integration_id end |
#start_date ⇒ Object
Date after which points will be valid.
38 39 40 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 38 def start_date @start_date end |
#sub_ledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
26 27 28 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 26 def sub_ledger_id @sub_ledger_id end |
#transaction_uuid ⇒ Object
The identifier of this addition in the loyalty ledger.
44 45 46 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 44 def transaction_uuid @transaction_uuid end |
#validity_duration ⇒ Object
The duration for which the points remain active, calculated relative to the activation date. Note: This value is returned only if ‘awaitsActivation` is `true` and `expiryDate` is not set.
65 66 67 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 65 def validity_duration @validity_duration end |
#value ⇒ Object
The amount of points that were added.
29 30 31 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 29 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 68 def self.attribute_map { :'name' => :'name', :'program_id' => :'programId', :'sub_ledger_id' => :'subLedgerId', :'value' => :'value', :'desired_value' => :'desiredValue', :'recipient_integration_id' => :'recipientIntegrationId', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'transaction_uuid' => :'transactionUUID', :'cart_item_position' => :'cartItemPosition', :'cart_item_sub_position' => :'cartItemSubPosition', :'card_identifier' => :'cardIdentifier', :'bundle_index' => :'bundleIndex', :'bundle_name' => :'bundleName', :'awaits_activation' => :'awaitsActivation', :'validity_duration' => :'validityDuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 411 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 100 def self.openapi_types { :'name' => :'String', :'program_id' => :'Integer', :'sub_ledger_id' => :'String', :'value' => :'Float', :'desired_value' => :'Float', :'recipient_integration_id' => :'String', :'start_date' => :'Time', :'expiry_date' => :'Time', :'transaction_uuid' => :'String', :'cart_item_position' => :'Float', :'cart_item_sub_position' => :'Float', :'card_identifier' => :'String', :'bundle_index' => :'Integer', :'bundle_name' => :'String', :'awaits_activation' => :'Boolean', :'validity_duration' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 375 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && program_id == o.program_id && sub_ledger_id == o.sub_ledger_id && value == o.value && desired_value == o.desired_value && recipient_integration_id == o.recipient_integration_id && start_date == o.start_date && expiry_date == o.expiry_date && transaction_uuid == o.transaction_uuid && cart_item_position == o.cart_item_position && cart_item_sub_position == o.cart_item_sub_position && card_identifier == o.card_identifier && bundle_index == o.bundle_index && bundle_name == o.bundle_name && awaits_activation == o.awaits_activation && validity_duration == o.validity_duration end |
#eql?(o) ⇒ Boolean
398 399 400 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 398 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 404 def hash [name, program_id, sub_ledger_id, value, desired_value, recipient_integration_id, start_date, expiry_date, transaction_uuid, cart_item_position, cart_item_sub_position, card_identifier, bundle_index, bundle_name, awaits_activation, validity_duration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 222 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @program_id.nil? invalid_properties.push('invalid value for "program_id", program_id cannot be nil.') end if @sub_ledger_id.nil? invalid_properties.push('invalid value for "sub_ledger_id", sub_ledger_id cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @recipient_integration_id.nil? invalid_properties.push('invalid value for "recipient_integration_id", recipient_integration_id cannot be nil.') end if @recipient_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.') end if @transaction_uuid.nil? invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.') end if !@card_identifier.nil? && @card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.') end if !@card_identifier.nil? && @card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "card_identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@card_identifier.nil? && @card_identifier !~ pattern invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/talon_one_sdk/models/add_loyalty_points_effect_props.rb', line 271 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @program_id.nil? return false if @sub_ledger_id.nil? return false if @value.nil? return false if @recipient_integration_id.nil? return false if @recipient_integration_id.to_s.length > 1000 return false if @transaction_uuid.nil? return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108 return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4 return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |