Class: TalonOne::ApplicationCIF
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ApplicationCIF
- Defined in:
- lib/talon_one_sdk/models/application_cif.rb
Instance Attribute Summary collapse
-
#active_expression_id ⇒ Object
The ID of the expression that the Application cart item filter uses.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#created ⇒ Object
The time this entity was created.
-
#created_by ⇒ Object
The ID of the user who created the Application cart item filter.
-
#description ⇒ Object
A short description of the Application cart item filter.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
Timestamp of the most recent update to the Application cart item filter.
-
#modified_by ⇒ Object
The ID of the user who last updated the Application cart item filter.
-
#name ⇒ Object
The name of the Application cart item filter used in API requests.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationCIF
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationCIF
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationCIF` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationCIF`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'active_expression_id') self.active_expression_id = attributes[:'active_expression_id'] end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'modified') self.modified = attributes[:'modified'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end end |
Instance Attribute Details
#active_expression_id ⇒ Object
The ID of the expression that the Application cart item filter uses.
31 32 33 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 31 def active_expression_id @active_expression_id end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
43 44 45 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 43 def application_id @application_id end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 22 def created @created end |
#created_by ⇒ Object
The ID of the user who created the Application cart item filter.
37 38 39 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 37 def created_by @created_by end |
#description ⇒ Object
A short description of the Application cart item filter.
28 29 30 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 28 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 19 def id @id end |
#modified ⇒ Object
Timestamp of the most recent update to the Application cart item filter.
40 41 42 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 40 def modified @modified end |
#modified_by ⇒ Object
The ID of the user who last updated the Application cart item filter.
34 35 36 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 34 def modified_by @modified_by end |
#name ⇒ Object
The name of the Application cart item filter used in API requests.
25 26 27 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 25 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 46 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'name' => :'name', :'description' => :'description', :'active_expression_id' => :'activeExpressionId', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'modified' => :'modified', :'application_id' => :'applicationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 97 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 92 def self.openapi_all_of [ :'Entity', :'NewApplicationCIF' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 71 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'name' => :'String', :'description' => :'String', :'active_expression_id' => :'Integer', :'modified_by' => :'Integer', :'created_by' => :'Integer', :'modified' => :'Time', :'application_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && name == o.name && description == o.description && active_expression_id == o.active_expression_id && modified_by == o.modified_by && created_by == o.created_by && modified == o.modified && application_id == o.application_id end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 259 def hash [id, created, name, description, active_expression_id, modified_by, created_by, modified, application_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 162 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 |
# File 'lib/talon_one_sdk/models/application_cif.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @name.nil? return false if @application_id.nil? true end |