Class: TalonOne::ApplicationCampaignAnalytics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ApplicationCampaignAnalytics
- Defined in:
- lib/talon_one_sdk/models/application_campaign_analytics.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#avg_items_per_session ⇒ Object
The number of items from sessions divided by the number of sessions.
-
#avg_session_value ⇒ Object
The average customer session value, calculated by dividing the revenue value by the number of sessions.
-
#campaign_id ⇒ Object
The ID of the campaign.
-
#campaign_name ⇒ Object
The name of the campaign.
-
#campaign_state ⇒ Object
The state of the campaign.
-
#campaign_tags ⇒ Object
A list of tags for the campaign.
-
#coupons_count ⇒ Object
The number of times a coupon was successfully redeemed in influenced sessions.
-
#end_time ⇒ Object
The end of the aggregation time frame in UTC.
-
#sessions_count ⇒ Object
The number of all closed sessions.
-
#start_time ⇒ Object
The start of the aggregation time frame in UTC.
-
#total_discounts ⇒ Object
The total value of discounts given for cart items in influenced sessions.
-
#total_revenue ⇒ Object
The total, pre-discount value of all items purchased in a customer session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationCampaignAnalytics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationCampaignAnalytics
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationCampaignAnalytics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationCampaignAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] else self.start_time = nil end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] else self.end_time = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'campaign_name') self.campaign_name = attributes[:'campaign_name'] else self.campaign_name = nil end if attributes.key?(:'campaign_tags') if (value = attributes[:'campaign_tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'campaign_state') self.campaign_state = attributes[:'campaign_state'] else self.campaign_state = nil end if attributes.key?(:'total_revenue') self.total_revenue = attributes[:'total_revenue'] end if attributes.key?(:'sessions_count') self.sessions_count = attributes[:'sessions_count'] end if attributes.key?(:'avg_items_per_session') self.avg_items_per_session = attributes[:'avg_items_per_session'] end if attributes.key?(:'avg_session_value') self.avg_session_value = attributes[:'avg_session_value'] end if attributes.key?(:'total_discounts') self.total_discounts = attributes[:'total_discounts'] end if attributes.key?(:'coupons_count') self.coupons_count = attributes[:'coupons_count'] end end |
Instance Attribute Details
#avg_items_per_session ⇒ Object
The number of items from sessions divided by the number of sessions. The ‘influenced` value includes only sessions with at least one applied effect.
43 44 45 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 43 def avg_items_per_session @avg_items_per_session end |
#avg_session_value ⇒ Object
The average customer session value, calculated by dividing the revenue value by the number of sessions. The ‘influenced` value includes only sessions with at least one applied effect.
46 47 48 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 46 def avg_session_value @avg_session_value end |
#campaign_id ⇒ Object
The ID of the campaign.
25 26 27 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 25 def campaign_id @campaign_id end |
#campaign_name ⇒ Object
The name of the campaign.
28 29 30 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 28 def campaign_name @campaign_name end |
#campaign_state ⇒ Object
The state of the campaign. Note: A disabled or archived campaign is not evaluated for rules or coupons.
34 35 36 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 34 def campaign_state @campaign_state end |
#campaign_tags ⇒ Object
A list of tags for the campaign.
31 32 33 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 31 def @campaign_tags end |
#coupons_count ⇒ Object
The number of times a coupon was successfully redeemed in influenced sessions.
52 53 54 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 52 def coupons_count @coupons_count end |
#end_time ⇒ Object
The end of the aggregation time frame in UTC.
22 23 24 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 22 def end_time @end_time end |
#sessions_count ⇒ Object
The number of all closed sessions. The ‘influenced` value includes only sessions with at least one applied effect.
40 41 42 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 40 def sessions_count @sessions_count end |
#start_time ⇒ Object
The start of the aggregation time frame in UTC.
19 20 21 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 19 def start_time @start_time end |
#total_discounts ⇒ Object
The total value of discounts given for cart items in influenced sessions.
49 50 51 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 49 def total_discounts @total_discounts end |
#total_revenue ⇒ Object
The total, pre-discount value of all items purchased in a customer session.
37 38 39 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 37 def total_revenue @total_revenue end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 77 def self.attribute_map { :'start_time' => :'startTime', :'end_time' => :'endTime', :'campaign_id' => :'campaignId', :'campaign_name' => :'campaignName', :'campaign_tags' => :'campaignTags', :'campaign_state' => :'campaignState', :'total_revenue' => :'totalRevenue', :'sessions_count' => :'sessionsCount', :'avg_items_per_session' => :'avgItemsPerSession', :'avg_session_value' => :'avgSessionValue', :'total_discounts' => :'totalDiscounts', :'coupons_count' => :'couponsCount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 357 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 105 def self.openapi_types { :'start_time' => :'Time', :'end_time' => :'Time', :'campaign_id' => :'Integer', :'campaign_name' => :'String', :'campaign_tags' => :'Array<String>', :'campaign_state' => :'String', :'total_revenue' => :'AnalyticsDataPointWithTrendAndInfluencedRate', :'sessions_count' => :'AnalyticsDataPointWithTrendAndInfluencedRate', :'avg_items_per_session' => :'AnalyticsDataPointWithTrendAndUplift', :'avg_session_value' => :'AnalyticsDataPointWithTrendAndUplift', :'total_discounts' => :'AnalyticsDataPointWithTrend', :'coupons_count' => :'AnalyticsDataPointWithTrend' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 325 def ==(o) return true if self.equal?(o) self.class == o.class && start_time == o.start_time && end_time == o.end_time && campaign_id == o.campaign_id && campaign_name == o.campaign_name && == o. && campaign_state == o.campaign_state && total_revenue == o.total_revenue && sessions_count == o.sessions_count && avg_items_per_session == o.avg_items_per_session && avg_session_value == o.avg_session_value && total_discounts == o.total_discounts && coupons_count == o.coupons_count end |
#eql?(o) ⇒ Boolean
344 345 346 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 344 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
350 351 352 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 350 def hash [start_time, end_time, campaign_id, campaign_name, , campaign_state, total_revenue, sessions_count, avg_items_per_session, avg_session_value, total_discounts, coupons_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @start_time.nil? invalid_properties.push('invalid value for "start_time", start_time cannot be nil.') end if @end_time.nil? invalid_properties.push('invalid value for "end_time", end_time cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @campaign_name.nil? invalid_properties.push('invalid value for "campaign_name", campaign_name cannot be nil.') end if @campaign_tags.nil? invalid_properties.push('invalid value for "campaign_tags", campaign_tags cannot be nil.') end if @campaign_tags.length > 50 invalid_properties.push('invalid value for "campaign_tags", number of items must be less than or equal to 50.') end if @campaign_state.nil? invalid_properties.push('invalid value for "campaign_state", campaign_state cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/application_campaign_analytics.rb', line 245 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @start_time.nil? return false if @end_time.nil? return false if @campaign_id.nil? return false if @campaign_name.nil? return false if @campaign_tags.nil? return false if @campaign_tags.length > 50 return false if @campaign_state.nil? campaign_state_validator = EnumAttributeValidator.new('String', ["expired", "scheduled", "running", "disabled", "archived", "staged"]) return false unless campaign_state_validator.valid?(@campaign_state) true end |