Class: TalonOne::ApplicationEvent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ApplicationEvent
- Defined in:
- lib/talon_one_sdk/models/application_event.rb
Instance Attribute Summary collapse
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
Additional JSON serialized data associated with the event.
-
#created ⇒ Object
The time this entity was created.
-
#effects ⇒ Object
An array containing the effects that were applied as a result of this event.
-
#id ⇒ Object
The internal ID of this entity.
-
#integration_id ⇒ Object
The unique ID of the event.
-
#profile_id ⇒ Object
The globally unique Talon.One ID of the customer that created this entity.
-
#rule_failure_reasons ⇒ Object
An array containing the rule failure reasons which happened during this event.
-
#session_id ⇒ Object
The globally unique Talon.One ID of the session that contains this event.
-
#store_id ⇒ Object
The ID of the store.
-
#store_integration_id ⇒ Object
The integration ID of the store.
-
#type ⇒ Object
The name of the event.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationEvent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationEvent
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationEvent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'store_id') self.store_id = attributes[:'store_id'] end if attributes.key?(:'store_integration_id') self.store_integration_id = attributes[:'store_integration_id'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'session_id') self.session_id = attributes[:'session_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] else self.attributes = nil end if attributes.key?(:'effects') if (value = attributes[:'effects']).is_a?(Array) self.effects = value end else self.effects = nil end if attributes.key?(:'rule_failure_reasons') if (value = attributes[:'rule_failure_reasons']).is_a?(Array) self.rule_failure_reasons = value end end end |
Instance Attribute Details
#application_id ⇒ Object
The ID of the Application that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 25 def application_id @application_id end |
#attributes ⇒ Object
Additional JSON serialized data associated with the event.
46 47 48 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 46 def attributes @attributes end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 22 def created @created end |
#effects ⇒ Object
An array containing the effects that were applied as a result of this event.
49 50 51 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 49 def effects @effects end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 19 def id @id end |
#integration_id ⇒ Object
The unique ID of the event. Only one event with this ID can be registered.
37 38 39 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 37 def integration_id @integration_id end |
#profile_id ⇒ Object
The globally unique Talon.One ID of the customer that created this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 28 def profile_id @profile_id end |
#rule_failure_reasons ⇒ Object
An array containing the rule failure reasons which happened during this event.
52 53 54 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 52 def rule_failure_reasons @rule_failure_reasons end |
#session_id ⇒ Object
The globally unique Talon.One ID of the session that contains this event.
40 41 42 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 40 def session_id @session_id end |
#store_id ⇒ Object
The ID of the store.
31 32 33 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 31 def store_id @store_id end |
#store_integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store.
34 35 36 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 34 def store_integration_id @store_integration_id end |
#type ⇒ Object
The name of the event. Must be a [custom event](docs.talon.one/docs/dev/concepts/entities/events#custom-events), not a built-in event.
43 44 45 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 43 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 55 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'application_id' => :'applicationId', :'profile_id' => :'profileId', :'store_id' => :'storeId', :'store_integration_id' => :'storeIntegrationId', :'integration_id' => :'integrationId', :'session_id' => :'sessionId', :'type' => :'type', :'attributes' => :'attributes', :'effects' => :'effects', :'rule_failure_reasons' => :'ruleFailureReasons' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 385 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 107 def self.openapi_all_of [ :'ApplicationCustomerEntity', :'ApplicationEntity', :'ApplicationStoreEntity', :'Entity', :'EventV3Entity', :'IntegrationStoreEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 83 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'application_id' => :'Integer', :'profile_id' => :'Integer', :'store_id' => :'Integer', :'store_integration_id' => :'String', :'integration_id' => :'String', :'session_id' => :'Integer', :'type' => :'String', :'attributes' => :'Object', :'effects' => :'Array<Effect>', :'rule_failure_reasons' => :'Array<RuleFailureReason>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && application_id == o.application_id && profile_id == o.profile_id && store_id == o.store_id && store_integration_id == o.store_integration_id && integration_id == o.integration_id && session_id == o.session_id && type == o.type && attributes == o.attributes && effects == o.effects && rule_failure_reasons == o.rule_failure_reasons end |
#eql?(o) ⇒ Boolean
372 373 374 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 372 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
378 379 380 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 378 def hash [id, created, application_id, profile_id, store_id, store_integration_id, integration_id, session_id, type, attributes, effects, rule_failure_reasons].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 201 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.') end if !@integration_id.nil? && @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @attributes.nil? invalid_properties.push('invalid value for "attributes", attributes cannot be nil.') end if @effects.nil? invalid_properties.push('invalid value for "effects", effects cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 407 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/application_event.rb', line 245 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @application_id.nil? return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 return false if !@integration_id.nil? && @integration_id.to_s.length < 1 return false if @type.nil? return false if @attributes.nil? return false if @effects.nil? true end |