Class: TalonOne::ApplicationReferee
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ApplicationReferee
- Defined in:
- lib/talon_one_sdk/models/application_referee.rb
Instance Attribute Summary collapse
-
#advocate_integration_id ⇒ Object
Integration ID of the Advocate’s Profile.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#code ⇒ Object
Advocate’s referral code.
-
#created ⇒ Object
Timestamp of the moment the customer redeemed the referral.
-
#friend_integration_id ⇒ Object
Integration ID of the Friend’s Profile.
-
#session_id ⇒ Object
Integration ID of the session in which the customer redeemed the referral.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationReferee
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationReferee
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ApplicationReferee` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ApplicationReferee`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'session_id') self.session_id = attributes[:'session_id'] else self.session_id = nil end if attributes.key?(:'advocate_integration_id') self.advocate_integration_id = attributes[:'advocate_integration_id'] else self.advocate_integration_id = nil end if attributes.key?(:'friend_integration_id') self.friend_integration_id = attributes[:'friend_integration_id'] else self.friend_integration_id = nil end if attributes.key?(:'code') self.code = attributes[:'code'] else self.code = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end end |
Instance Attribute Details
#advocate_integration_id ⇒ Object
Integration ID of the Advocate’s Profile.
25 26 27 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 25 def advocate_integration_id @advocate_integration_id end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 19 def application_id @application_id end |
#code ⇒ Object
Advocate’s referral code.
31 32 33 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 31 def code @code end |
#created ⇒ Object
Timestamp of the moment the customer redeemed the referral.
34 35 36 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 34 def created @created end |
#friend_integration_id ⇒ Object
Integration ID of the Friend’s Profile.
28 29 30 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 28 def friend_integration_id @friend_integration_id end |
#session_id ⇒ Object
Integration ID of the session in which the customer redeemed the referral.
22 23 24 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 22 def session_id @session_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 37 def self.attribute_map { :'application_id' => :'applicationId', :'session_id' => :'sessionId', :'advocate_integration_id' => :'advocateIntegrationId', :'friend_integration_id' => :'friendIntegrationId', :'code' => :'code', :'created' => :'created' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 287 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
77 78 79 80 81 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 77 def self.openapi_all_of [ :'ApplicationEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 59 def self.openapi_types { :'application_id' => :'Integer', :'session_id' => :'String', :'advocate_integration_id' => :'String', :'friend_integration_id' => :'String', :'code' => :'String', :'created' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 261 def ==(o) return true if self.equal?(o) self.class == o.class && application_id == o.application_id && session_id == o.session_id && advocate_integration_id == o.advocate_integration_id && friend_integration_id == o.friend_integration_id && code == o.code && created == o.created end |
#eql?(o) ⇒ Boolean
274 275 276 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 274 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
280 281 282 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 280 def hash [application_id, session_id, advocate_integration_id, friend_integration_id, code, created].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @session_id.nil? invalid_properties.push('invalid value for "session_id", session_id cannot be nil.') end if @advocate_integration_id.nil? invalid_properties.push('invalid value for "advocate_integration_id", advocate_integration_id cannot be nil.') end if @advocate_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "advocate_integration_id", the character length must be smaller than or equal to 1000.') end if @friend_integration_id.nil? invalid_properties.push('invalid value for "friend_integration_id", friend_integration_id cannot be nil.') end if @friend_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "friend_integration_id", the character length must be smaller than or equal to 1000.') end if @code.nil? invalid_properties.push('invalid value for "code", code cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/application_referee.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @application_id.nil? return false if @session_id.nil? return false if @advocate_integration_id.nil? return false if @advocate_integration_id.to_s.length > 1000 return false if @friend_integration_id.nil? return false if @friend_integration_id.to_s.length > 1000 return false if @code.nil? return false if @created.nil? true end |