Class: TalonOne::Audience

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/audience.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Audience

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/talon_one_sdk/models/audience.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Audience` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Audience`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'integration')
    self.integration = attributes[:'integration']
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'created_in3rd_party')
    self.created_in3rd_party = attributes[:'created_in3rd_party']
  end

  if attributes.key?(:'last_update')
    self.last_update = attributes[:'last_update']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



19
20
21
# File 'lib/talon_one_sdk/models/audience.rb', line 19

def 
  @account_id
end

#createdObject

The time this entity was created.



25
26
27
# File 'lib/talon_one_sdk/models/audience.rb', line 25

def created
  @created
end

#created_in3rd_partyObject

Determines if this audience is a 3rd party audience or not.



43
44
45
# File 'lib/talon_one_sdk/models/audience.rb', line 43

def created_in3rd_party
  @created_in3rd_party
end

#descriptionObject

A description of the audience.



34
35
36
# File 'lib/talon_one_sdk/models/audience.rb', line 34

def description
  @description
end

#idObject

The internal ID of this entity.



22
23
24
# File 'lib/talon_one_sdk/models/audience.rb', line 22

def id
  @id
end

#integrationObject

The Talon.One-supported [3rd-party platform](docs.talon.one/docs/dev/technology-partners/overview) that this audience was created in. For example, ‘mParticle`, `Segment`, `Shopify`, `Braze`, or `Iterable`. Note: If you do not integrate with any of these platforms, do not use this property.



37
38
39
# File 'lib/talon_one_sdk/models/audience.rb', line 37

def integration
  @integration
end

#integration_idObject

The ID of this audience in the third-party integration. Note: To create an audience that doesn’t come from a 3rd party platform, do not use this property.



40
41
42
# File 'lib/talon_one_sdk/models/audience.rb', line 40

def integration_id
  @integration_id
end

#last_updateObject

The last time that the audience memberships changed.



46
47
48
# File 'lib/talon_one_sdk/models/audience.rb', line 46

def last_update
  @last_update
end

#nameObject

The human-friendly display name for this audience.



28
29
30
# File 'lib/talon_one_sdk/models/audience.rb', line 28

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox Application.



31
32
33
# File 'lib/talon_one_sdk/models/audience.rb', line 31

def sandbox
  @sandbox
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/talon_one_sdk/models/audience.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/talon_one_sdk/models/audience.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/audience.rb', line 49

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'sandbox' => :'sandbox',
    :'description' => :'description',
    :'integration' => :'integration',
    :'integration_id' => :'integrationId',
    :'created_in3rd_party' => :'createdIn3rdParty',
    :'last_update' => :'lastUpdate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/talon_one_sdk/models/audience.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



97
98
99
100
101
102
103
# File 'lib/talon_one_sdk/models/audience.rb', line 97

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'NewAudience'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/talon_one_sdk/models/audience.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one_sdk/models/audience.rb', line 75

def self.openapi_types
  {
    :'account_id' => :'Integer',
    :'id' => :'Integer',
    :'created' => :'Time',
    :'name' => :'String',
    :'sandbox' => :'Boolean',
    :'description' => :'String',
    :'integration' => :'String',
    :'integration_id' => :'String',
    :'created_in3rd_party' => :'Boolean',
    :'last_update' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one_sdk/models/audience.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      sandbox == o.sandbox &&
      description == o.description &&
      integration == o.integration &&
      integration_id == o.integration_id &&
      created_in3rd_party == o.created_in3rd_party &&
      last_update == o.last_update
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/talon_one_sdk/models/audience.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/talon_one_sdk/models/audience.rb', line 307

def hash
  [, id, created, name, sandbox, description, integration, integration_id, created_in3rd_party, last_update].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/audience.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/talon_one_sdk/models/audience.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
# File 'lib/talon_one_sdk/models/audience.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@integration_id.nil? && @integration_id.to_s.length > 1000
  return false if !@integration_id.nil? && @integration_id.to_s.length < 1
  true
end