Class: TalonOne::BaseCampaign
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::BaseCampaign
- Defined in:
- lib/talon_one_sdk/models/base_campaign.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_ruleset_id ⇒ Object
[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/managing-campaign-groups) this campaign belongs to.
-
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#description ⇒ Object
A detailed description of the campaign.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#features ⇒ Object
The features enabled in this campaign.
-
#limits ⇒ Object
The set of [budget limits](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets) for this campaign.
-
#linked_store_ids ⇒ Object
A list of store IDs that you want to link to the campaign.
-
#name ⇒ Object
A user-facing name for this campaign.
-
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
-
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#state ⇒ Object
A disabled or archived campaign is not evaluated for rules or coupons.
-
#tags ⇒ Object
A list of tags for the campaign.
-
#type ⇒ Object
The campaign type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BaseCampaign
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BaseCampaign
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BaseCampaign` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BaseCampaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'enabled' end if attributes.key?(:'active_ruleset_id') self.active_ruleset_id = attributes[:'active_ruleset_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'reevaluate_on_return') self.reevaluate_on_return = attributes[:'reevaluate_on_return'] end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end else self.features = nil end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'referral_settings') self.referral_settings = attributes[:'referral_settings'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end else self.limits = nil end if attributes.key?(:'campaign_groups') if (value = attributes[:'campaign_groups']).is_a?(Array) self.campaign_groups = value end end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'advanced' end if attributes.key?(:'linked_store_ids') if (value = attributes[:'linked_store_ids']).is_a?(Array) self.linked_store_ids = value end end if attributes.key?(:'coupon_attributes') self.coupon_attributes = attributes[:'coupon_attributes'] end end |
Instance Attribute Details
#active_ruleset_id ⇒ Object
[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.
37 38 39 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 37 def active_ruleset_id @active_ruleset_id end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
31 32 33 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 31 def attributes @attributes end |
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/managing-campaign-groups) this campaign belongs to.
56 57 58 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 56 def campaign_groups @campaign_groups end |
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
65 66 67 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 65 def coupon_attributes @coupon_attributes end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
48 49 50 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 48 def coupon_settings @coupon_settings end |
#description ⇒ Object
A detailed description of the campaign.
22 23 24 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 22 def description @description end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
28 29 30 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 28 def end_time @end_time end |
#features ⇒ Object
The features enabled in this campaign.
46 47 48 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 46 def features @features end |
#limits ⇒ Object
The set of [budget limits](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets) for this campaign.
53 54 55 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 53 def limits @limits end |
#linked_store_ids ⇒ Object
A list of store IDs that you want to link to the campaign. Note: Campaigns with linked store IDs will only be evaluated when there is a [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) that references a linked store.
62 63 64 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 62 def linked_store_ids @linked_store_ids end |
#name ⇒ Object
A user-facing name for this campaign.
19 20 21 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 19 def name @name end |
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
43 44 45 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 43 def reevaluate_on_return @reevaluate_on_return end |
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
50 51 52 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 50 def referral_settings @referral_settings end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
25 26 27 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 25 def start_time @start_time end |
#state ⇒ Object
A disabled or archived campaign is not evaluated for rules or coupons.
34 35 36 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 34 def state @state end |
#tags ⇒ Object
A list of tags for the campaign.
40 41 42 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 40 def @tags end |
#type ⇒ Object
The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.
59 60 61 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 59 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
113 114 115 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 113 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
118 119 120 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 118 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 90 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'start_time' => :'startTime', :'end_time' => :'endTime', :'attributes' => :'attributes', :'state' => :'state', :'active_ruleset_id' => :'activeRulesetId', :'tags' => :'tags', :'reevaluate_on_return' => :'reevaluateOnReturn', :'features' => :'features', :'coupon_settings' => :'couponSettings', :'referral_settings' => :'referralSettings', :'limits' => :'limits', :'campaign_groups' => :'campaignGroups', :'type' => :'type', :'linked_store_ids' => :'linkedStoreIds', :'coupon_attributes' => :'couponAttributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 409 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
146 147 148 149 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 146 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 123 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'attributes' => :'Object', :'state' => :'String', :'active_ruleset_id' => :'Integer', :'tags' => :'Array<String>', :'reevaluate_on_return' => :'Boolean', :'features' => :'Array<String>', :'coupon_settings' => :'CodeGeneratorSettings', :'referral_settings' => :'CodeGeneratorSettings', :'limits' => :'Array<LimitConfig>', :'campaign_groups' => :'Array<Integer>', :'type' => :'String', :'linked_store_ids' => :'Array<Integer>', :'coupon_attributes' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 372 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && start_time == o.start_time && end_time == o.end_time && attributes == o.attributes && state == o.state && active_ruleset_id == o.active_ruleset_id && == o. && reevaluate_on_return == o.reevaluate_on_return && features == o.features && coupon_settings == o.coupon_settings && referral_settings == o.referral_settings && limits == o.limits && campaign_groups == o.campaign_groups && type == o.type && linked_store_ids == o.linked_store_ids && coupon_attributes == o.coupon_attributes end |
#eql?(o) ⇒ Boolean
396 397 398 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 396 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
402 403 404 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 402 def hash [name, description, start_time, end_time, attributes, state, active_ruleset_id, , reevaluate_on_return, features, coupon_settings, referral_settings, limits, campaign_groups, type, linked_store_ids, coupon_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 260 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end if @features.nil? invalid_properties.push('invalid value for "features", features cannot be nil.') end if @limits.nil? invalid_properties.push('invalid value for "limits", limits cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 431 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/talon_one_sdk/models/base_campaign.rb', line 296 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"]) return false unless state_validator.valid?(@state) return false if @tags.nil? return false if @tags.length > 50 return false if @features.nil? return false if @limits.nil? type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"]) return false unless type_validator.valid?(@type) true end |