Class: TalonOne::BaseSamlConnection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::BaseSamlConnection
- Defined in:
- lib/talon_one_sdk/models/base_saml_connection.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#audience_uri ⇒ Object
The application-defined unique identifier that is the intended audience of the SAML assertion.
-
#enabled ⇒ Object
Determines if this SAML connection active.
-
#issuer ⇒ Object
Identity Provider Entity ID.
-
#metadata_url ⇒ Object
Metadata URL.
-
#name ⇒ Object
ID of the SAML service.
-
#sign_on_url ⇒ Object
Single Sign-On URL.
-
#sign_out_url ⇒ Object
Single Sign-Out URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BaseSamlConnection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BaseSamlConnection
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BaseSamlConnection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BaseSamlConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] else self.issuer = nil end if attributes.key?(:'sign_on_url') self.sign_on_url = attributes[:'sign_on_url'] else self.sign_on_url = nil end if attributes.key?(:'sign_out_url') self.sign_out_url = attributes[:'sign_out_url'] end if attributes.key?(:'metadata_url') self. = attributes[:'metadata_url'] end if attributes.key?(:'audience_uri') self.audience_uri = attributes[:'audience_uri'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 19 def account_id @account_id end |
#audience_uri ⇒ Object
The application-defined unique identifier that is the intended audience of the SAML assertion. This is most often the SP Entity ID of your application. When not specified, the ACS URL will be used.
40 41 42 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 40 def audience_uri @audience_uri end |
#enabled ⇒ Object
Determines if this SAML connection active.
25 26 27 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 25 def enabled @enabled end |
#issuer ⇒ Object
Identity Provider Entity ID.
28 29 30 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 28 def issuer @issuer end |
#metadata_url ⇒ Object
Metadata URL.
37 38 39 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 37 def @metadata_url end |
#name ⇒ Object
ID of the SAML service.
22 23 24 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 22 def name @name end |
#sign_on_url ⇒ Object
Single Sign-On URL.
31 32 33 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 31 def sign_on_url @sign_on_url end |
#sign_out_url ⇒ Object
Single Sign-Out URL.
34 35 36 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 34 def sign_out_url @sign_out_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 43 def self.attribute_map { :'account_id' => :'accountId', :'name' => :'name', :'enabled' => :'enabled', :'issuer' => :'issuer', :'sign_on_url' => :'signOnURL', :'sign_out_url' => :'signOutURL', :'metadata_url' => :'metadataURL', :'audience_uri' => :'audienceURI' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 67 def self.openapi_types { :'account_id' => :'Integer', :'name' => :'String', :'enabled' => :'Boolean', :'issuer' => :'String', :'sign_on_url' => :'String', :'sign_out_url' => :'String', :'metadata_url' => :'String', :'audience_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 264 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && name == o.name && enabled == o.enabled && issuer == o.issuer && sign_on_url == o.sign_on_url && sign_out_url == o.sign_out_url && == o. && audience_uri == o.audience_uri end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 285 def hash [account_id, name, enabled, issuer, sign_on_url, sign_out_url, , audience_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @issuer.nil? invalid_properties.push('invalid value for "issuer", issuer cannot be nil.') end if @issuer.to_s.length < 1 invalid_properties.push('invalid value for "issuer", the character length must be greater than or equal to 1.') end if @sign_on_url.nil? invalid_properties.push('invalid value for "sign_on_url", sign_on_url cannot be nil.') end if @sign_on_url.to_s.length < 1 invalid_properties.push('invalid value for "sign_on_url", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/talon_one_sdk/models/base_saml_connection.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @enabled.nil? return false if @issuer.nil? return false if @issuer.to_s.length < 1 return false if @sign_on_url.nil? return false if @sign_on_url.to_s.length < 1 true end |