Class: TalonOne::BestPriorPrice

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/best_prior_price.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BestPriorPrice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BestPriorPrice` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BestPriorPrice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  else
    self.sku = nil
  end

  if attributes.key?(:'observed_at')
    self.observed_at = attributes[:'observed_at']
  else
    self.observed_at = nil
  end

  if attributes.key?(:'context_id')
    self.context_id = attributes[:'context_id']
  else
    self.context_id = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end
end

Instance Attribute Details

#context_idObject

The context ID of the context active at the time of observation.



28
29
30
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 28

def context_id
  @context_id
end

#idObject

The ID of the historical price.



19
20
21
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 19

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



33
34
35
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 33

def 
  @metadata
end

#observed_atObject

The date and time when the price was observed.



25
26
27
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 25

def observed_at
  @observed_at
end

#priceObject

Price of the item.



31
32
33
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 31

def price
  @price
end

#skuObject

sku



22
23
24
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 22

def sku
  @sku
end

#targetObject

Returns the value of attribute target.



35
36
37
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 35

def target
  @target
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'sku' => :'sku',
    :'observed_at' => :'observedAt',
    :'context_id' => :'contextId',
    :'price' => :'price',
    :'metadata' => :'metadata',
    :'target' => :'target'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 287

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 61

def self.openapi_types
  {
    :'id' => :'Integer',
    :'sku' => :'String',
    :'observed_at' => :'Time',
    :'context_id' => :'String',
    :'price' => :'Float',
    :'metadata' => :'BestPriorPriceMetadata',
    :'target' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



260
261
262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      sku == o.sku &&
      observed_at == o.observed_at &&
      context_id == o.context_id &&
      price == o.price &&
       == o. &&
      target == o.target
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 280

def hash
  [id, sku, observed_at, context_id, price, , target].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  if @observed_at.nil?
    invalid_properties.push('invalid value for "observed_at", observed_at cannot be nil.')
  end

  if @context_id.nil?
    invalid_properties.push('invalid value for "context_id", context_id cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
185
186
# File 'lib/talon_one_sdk/models/best_prior_price.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @sku.nil?
  return false if @observed_at.nil?
  return false if @context_id.nil?
  return false if @price.nil?
  return false if @metadata.nil?
  return false if @target.nil?
  true
end