Class: TalonOne::Campaign
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Campaign
- Defined in:
- lib/talon_one_sdk/models/campaign.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_revision_id ⇒ Object
ID of the revision that was last activated on this campaign.
-
#active_revision_version_id ⇒ Object
ID of the revision version that is active on the campaign.
-
#active_ruleset_id ⇒ Object
[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.
-
#add_free_item_effect_count ⇒ Object
This property is deprecated.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#awarded_giveaways_count ⇒ Object
This property is deprecated.
-
#budgets ⇒ Object
A list of all the budgets that are defined by this campaign and their usage.
-
#call_api_effect_count ⇒ Object
This property is deprecated.
-
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/managing-campaign-groups) this campaign belongs to.
-
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
-
#coupon_creation_count ⇒ Object
This property is deprecated.
-
#coupon_redemption_count ⇒ Object
This property is deprecated.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#created ⇒ Object
The exact moment this entity was created.
-
#created_by ⇒ Object
Name of the user who created this campaign if available.
-
#created_loyalty_points_count ⇒ Object
This property is deprecated.
-
#created_loyalty_points_effect_count ⇒ Object
This property is deprecated.
-
#current_revision_id ⇒ Object
ID of the revision currently being modified for the campaign.
-
#current_revision_version_id ⇒ Object
ID of the latest version applied on the current revision.
-
#custom_effect_count ⇒ Object
This property is deprecated.
-
#description ⇒ Object
A detailed description of the campaign.
-
#discount_count ⇒ Object
This property is deprecated.
-
#discount_effect_count ⇒ Object
This property is deprecated.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#experiment_id ⇒ Object
The ID of the Experiment this Campaign is part of.
-
#features ⇒ Object
The features enabled in this campaign.
-
#frontend_state ⇒ Object
The campaign state displayed in the Campaign Manager.
-
#id ⇒ Object
Unique ID for this entity.
-
#last_activity ⇒ Object
Timestamp of the most recent event received by this campaign.
-
#limits ⇒ Object
The set of [budget limits](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets) for this campaign.
-
#linked_store_ids ⇒ Object
A list of store IDs that you want to link to the campaign.
-
#name ⇒ Object
A user-facing name for this campaign.
-
#redeemed_loyalty_points_count ⇒ Object
This property is deprecated.
-
#redeemed_loyalty_points_effect_count ⇒ Object
This property is deprecated.
-
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
-
#referral_creation_count ⇒ Object
This property is deprecated.
-
#referral_redemption_count ⇒ Object
This property is deprecated.
-
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
-
#reservecoupon_effect_count ⇒ Object
This property is deprecated.
-
#revision_frontend_state ⇒ Object
The campaign revision state displayed in the Campaign Manager.
-
#stage_revision ⇒ Object
Flag for determining whether we use current revision when sending requests with staging API key.
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#state ⇒ Object
A disabled or archived campaign is not evaluated for rules or coupons.
-
#stores_imported ⇒ Object
Indicates whether the linked stores were imported via a CSV file.
-
#tags ⇒ Object
A list of tags for the campaign.
-
#template_id ⇒ Object
The ID of the Campaign Template this Campaign was created from.
-
#type ⇒ Object
The campaign type.
-
#updated ⇒ Object
Timestamp of the most recent update to the campaign’s property.
-
#updated_by ⇒ Object
Name of the user who last updated this campaign if available.
-
#user_id ⇒ Object
The ID of the user associated with this entity.
-
#value_maps_ids ⇒ Object
A list of value map IDs for the campaign.
-
#version ⇒ Object
Incrementing number representing how many revisions have been activated on this campaign, starts from 0 for a new campaign.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Campaign
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Campaign
Initializes the object
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 345 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Campaign` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Campaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'enabled' end if attributes.key?(:'active_ruleset_id') self.active_ruleset_id = attributes[:'active_ruleset_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'reevaluate_on_return') self.reevaluate_on_return = attributes[:'reevaluate_on_return'] else self.reevaluate_on_return = nil end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end else self.features = nil end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'referral_settings') self.referral_settings = attributes[:'referral_settings'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end else self.limits = nil end if attributes.key?(:'campaign_groups') if (value = attributes[:'campaign_groups']).is_a?(Array) self.campaign_groups = value end end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'advanced' end if attributes.key?(:'linked_store_ids') if (value = attributes[:'linked_store_ids']).is_a?(Array) self.linked_store_ids = value end end if attributes.key?(:'coupon_attributes') self.coupon_attributes = attributes[:'coupon_attributes'] end if attributes.key?(:'budgets') if (value = attributes[:'budgets']).is_a?(Array) self.budgets = value end end if attributes.key?(:'coupon_redemption_count') self.coupon_redemption_count = attributes[:'coupon_redemption_count'] end if attributes.key?(:'referral_redemption_count') self.referral_redemption_count = attributes[:'referral_redemption_count'] end if attributes.key?(:'discount_count') self.discount_count = attributes[:'discount_count'] end if attributes.key?(:'discount_effect_count') self.discount_effect_count = attributes[:'discount_effect_count'] end if attributes.key?(:'coupon_creation_count') self.coupon_creation_count = attributes[:'coupon_creation_count'] end if attributes.key?(:'custom_effect_count') self.custom_effect_count = attributes[:'custom_effect_count'] end if attributes.key?(:'referral_creation_count') self.referral_creation_count = attributes[:'referral_creation_count'] end if attributes.key?(:'add_free_item_effect_count') self.add_free_item_effect_count = attributes[:'add_free_item_effect_count'] end if attributes.key?(:'awarded_giveaways_count') self.awarded_giveaways_count = attributes[:'awarded_giveaways_count'] end if attributes.key?(:'created_loyalty_points_count') self.created_loyalty_points_count = attributes[:'created_loyalty_points_count'] end if attributes.key?(:'created_loyalty_points_effect_count') self.created_loyalty_points_effect_count = attributes[:'created_loyalty_points_effect_count'] end if attributes.key?(:'redeemed_loyalty_points_count') self.redeemed_loyalty_points_count = attributes[:'redeemed_loyalty_points_count'] end if attributes.key?(:'redeemed_loyalty_points_effect_count') self.redeemed_loyalty_points_effect_count = attributes[:'redeemed_loyalty_points_effect_count'] end if attributes.key?(:'call_api_effect_count') self.call_api_effect_count = attributes[:'call_api_effect_count'] end if attributes.key?(:'reservecoupon_effect_count') self.reservecoupon_effect_count = attributes[:'reservecoupon_effect_count'] end if attributes.key?(:'last_activity') self.last_activity = attributes[:'last_activity'] end if attributes.key?(:'updated') self.updated = attributes[:'updated'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'frontend_state') self.frontend_state = attributes[:'frontend_state'] else self.frontend_state = nil end if attributes.key?(:'stores_imported') self.stores_imported = attributes[:'stores_imported'] else self.stores_imported = nil end if attributes.key?(:'value_maps_ids') if (value = attributes[:'value_maps_ids']).is_a?(Array) self.value_maps_ids = value end end if attributes.key?(:'experiment_id') self.experiment_id = attributes[:'experiment_id'] end if attributes.key?(:'revision_frontend_state') self.revision_frontend_state = attributes[:'revision_frontend_state'] end if attributes.key?(:'active_revision_id') self.active_revision_id = attributes[:'active_revision_id'] end if attributes.key?(:'active_revision_version_id') self.active_revision_version_id = attributes[:'active_revision_version_id'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'current_revision_id') self.current_revision_id = attributes[:'current_revision_id'] end if attributes.key?(:'current_revision_version_id') self.current_revision_version_id = attributes[:'current_revision_version_id'] end if attributes.key?(:'stage_revision') self.stage_revision = attributes[:'stage_revision'] else self.stage_revision = false end end |
Instance Attribute Details
#active_revision_id ⇒ Object
ID of the revision that was last activated on this campaign.
158 159 160 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 158 def active_revision_id @active_revision_id end |
#active_revision_version_id ⇒ Object
ID of the revision version that is active on the campaign.
161 162 163 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 161 def active_revision_version_id @active_revision_version_id end |
#active_ruleset_id ⇒ Object
[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.
49 50 51 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 49 def active_ruleset_id @active_ruleset_id end |
#add_free_item_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of times the [add free item effect](docs.talon.one/docs/dev/integration-api/api-effects#addfreeitem) can be triggered in this campaign.
104 105 106 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 104 def add_free_item_effect_count @add_free_item_effect_count end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 25 def application_id @application_id end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
43 44 45 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 43 def attributes @attributes end |
#awarded_giveaways_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of giveaways awarded by rules in this campaign.
107 108 109 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 107 def awarded_giveaways_count @awarded_giveaways_count end |
#budgets ⇒ Object
A list of all the budgets that are defined by this campaign and their usage. Note: Budgets that are not defined do not appear in this list and their usage is not counted until they are defined.
80 81 82 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 80 def budgets @budgets end |
#call_api_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of webhooks triggered by rules in this campaign.
122 123 124 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 122 def call_api_effect_count @call_api_effect_count end |
#campaign_groups ⇒ Object
The IDs of the [campaign groups](docs.talon.one/docs/product/account/managing-campaign-groups) this campaign belongs to.
68 69 70 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 68 def campaign_groups @campaign_groups end |
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
77 78 79 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 77 def coupon_attributes @coupon_attributes end |
#coupon_creation_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of coupons created by rules in this campaign.
95 96 97 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 95 def coupon_creation_count @coupon_creation_count end |
#coupon_redemption_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Number of coupons redeemed in the campaign.
83 84 85 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 83 def coupon_redemption_count @coupon_redemption_count end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
60 61 62 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 60 def coupon_settings @coupon_settings end |
#created ⇒ Object
The exact moment this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 22 def created @created end |
#created_by ⇒ Object
Name of the user who created this campaign if available.
134 135 136 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 134 def created_by @created_by end |
#created_loyalty_points_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty points created by rules in this campaign.
110 111 112 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 110 def created_loyalty_points_count @created_loyalty_points_count end |
#created_loyalty_points_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty point creation effects triggered by rules in this campaign.
113 114 115 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 113 def created_loyalty_points_effect_count @created_loyalty_points_effect_count end |
#current_revision_id ⇒ Object
ID of the revision currently being modified for the campaign.
167 168 169 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 167 def current_revision_id @current_revision_id end |
#current_revision_version_id ⇒ Object
ID of the latest version applied on the current revision.
170 171 172 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 170 def current_revision_version_id @current_revision_version_id end |
#custom_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of custom effects triggered by rules in this campaign.
98 99 100 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 98 def custom_effect_count @custom_effect_count end |
#description ⇒ Object
A detailed description of the campaign.
34 35 36 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 34 def description @description end |
#discount_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total amount of discounts redeemed in the campaign.
89 90 91 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 89 def discount_count @discount_count end |
#discount_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of times discounts were redeemed in this campaign.
92 93 94 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 92 def discount_effect_count @discount_effect_count end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
40 41 42 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 40 def end_time @end_time end |
#experiment_id ⇒ Object
The ID of the Experiment this Campaign is part of.
152 153 154 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 152 def experiment_id @experiment_id end |
#features ⇒ Object
The features enabled in this campaign.
58 59 60 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 58 def features @features end |
#frontend_state ⇒ Object
The campaign state displayed in the Campaign Manager.
143 144 145 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 143 def frontend_state @frontend_state end |
#id ⇒ Object
Unique ID for this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 19 def id @id end |
#last_activity ⇒ Object
Timestamp of the most recent event received by this campaign.
128 129 130 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 128 def last_activity @last_activity end |
#limits ⇒ Object
The set of [budget limits](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets) for this campaign.
65 66 67 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 65 def limits @limits end |
#linked_store_ids ⇒ Object
A list of store IDs that you want to link to the campaign. Note: Campaigns with linked store IDs will only be evaluated when there is a [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) that references a linked store.
74 75 76 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 74 def linked_store_ids @linked_store_ids end |
#name ⇒ Object
A user-facing name for this campaign.
31 32 33 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 31 def name @name end |
#redeemed_loyalty_points_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty points redeemed by rules in this campaign.
116 117 118 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 116 def redeemed_loyalty_points_count @redeemed_loyalty_points_count end |
#redeemed_loyalty_points_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty point redemption effects triggered by rules in this campaign.
119 120 121 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 119 def redeemed_loyalty_points_effect_count @redeemed_loyalty_points_effect_count end |
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
55 56 57 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 55 def reevaluate_on_return @reevaluate_on_return end |
#referral_creation_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of referrals created by rules in this campaign.
101 102 103 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 101 def referral_creation_count @referral_creation_count end |
#referral_redemption_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Number of referral codes redeemed in the campaign.
86 87 88 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 86 def referral_redemption_count @referral_redemption_count end |
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
62 63 64 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 62 def referral_settings @referral_settings end |
#reservecoupon_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of reserve coupon effects triggered by rules in this campaign.
125 126 127 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 125 def reservecoupon_effect_count @reservecoupon_effect_count end |
#revision_frontend_state ⇒ Object
The campaign revision state displayed in the Campaign Manager.
155 156 157 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 155 def revision_frontend_state @revision_frontend_state end |
#stage_revision ⇒ Object
Flag for determining whether we use current revision when sending requests with staging API key.
173 174 175 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 173 def stage_revision @stage_revision end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
37 38 39 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 37 def start_time @start_time end |
#state ⇒ Object
A disabled or archived campaign is not evaluated for rules or coupons.
46 47 48 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 46 def state @state end |
#stores_imported ⇒ Object
Indicates whether the linked stores were imported via a CSV file.
146 147 148 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 146 def stores_imported @stores_imported end |
#tags ⇒ Object
A list of tags for the campaign.
52 53 54 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 52 def @tags end |
#template_id ⇒ Object
The ID of the Campaign Template this Campaign was created from.
140 141 142 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 140 def template_id @template_id end |
#type ⇒ Object
The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.
71 72 73 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 71 def type @type end |
#updated ⇒ Object
Timestamp of the most recent update to the campaign’s property. Updates to external entities used in this campaign are not registered by this property, such as collection or coupon updates.
131 132 133 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 131 def updated @updated end |
#updated_by ⇒ Object
Name of the user who last updated this campaign if available.
137 138 139 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 137 def updated_by @updated_by end |
#user_id ⇒ Object
The ID of the user associated with this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 28 def user_id @user_id end |
#value_maps_ids ⇒ Object
A list of value map IDs for the campaign.
149 150 151 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 149 def value_maps_ids @value_maps_ids end |
#version ⇒ Object
Incrementing number representing how many revisions have been activated on this campaign, starts from 0 for a new campaign.
164 165 166 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 164 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
257 258 259 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 257 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
262 263 264 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 262 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 198 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'application_id' => :'applicationId', :'user_id' => :'userId', :'name' => :'name', :'description' => :'description', :'start_time' => :'startTime', :'end_time' => :'endTime', :'attributes' => :'attributes', :'state' => :'state', :'active_ruleset_id' => :'activeRulesetId', :'tags' => :'tags', :'reevaluate_on_return' => :'reevaluateOnReturn', :'features' => :'features', :'coupon_settings' => :'couponSettings', :'referral_settings' => :'referralSettings', :'limits' => :'limits', :'campaign_groups' => :'campaignGroups', :'type' => :'type', :'linked_store_ids' => :'linkedStoreIds', :'coupon_attributes' => :'couponAttributes', :'budgets' => :'budgets', :'coupon_redemption_count' => :'couponRedemptionCount', :'referral_redemption_count' => :'referralRedemptionCount', :'discount_count' => :'discountCount', :'discount_effect_count' => :'discountEffectCount', :'coupon_creation_count' => :'couponCreationCount', :'custom_effect_count' => :'customEffectCount', :'referral_creation_count' => :'referralCreationCount', :'add_free_item_effect_count' => :'addFreeItemEffectCount', :'awarded_giveaways_count' => :'awardedGiveawaysCount', :'created_loyalty_points_count' => :'createdLoyaltyPointsCount', :'created_loyalty_points_effect_count' => :'createdLoyaltyPointsEffectCount', :'redeemed_loyalty_points_count' => :'redeemedLoyaltyPointsCount', :'redeemed_loyalty_points_effect_count' => :'redeemedLoyaltyPointsEffectCount', :'call_api_effect_count' => :'callApiEffectCount', :'reservecoupon_effect_count' => :'reservecouponEffectCount', :'last_activity' => :'lastActivity', :'updated' => :'updated', :'created_by' => :'createdBy', :'updated_by' => :'updatedBy', :'template_id' => :'templateId', :'frontend_state' => :'frontendState', :'stores_imported' => :'storesImported', :'value_maps_ids' => :'valueMapsIds', :'experiment_id' => :'experimentId', :'revision_frontend_state' => :'revisionFrontendState', :'active_revision_id' => :'activeRevisionId', :'active_revision_version_id' => :'activeRevisionVersionId', :'version' => :'version', :'current_revision_id' => :'currentRevisionId', :'current_revision_version_id' => :'currentRevisionVersionId', :'stage_revision' => :'stageRevision' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 920 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
332 333 334 335 336 337 338 339 340 341 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 332 def self.openapi_all_of [ :'AdditionalCampaignProperties', :'ApplicationEntity', :'BaseCampaign', :'CampaignVersions', :'EntityWithTalangVisibleID', :'UserEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
326 327 328 329 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 326 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 267 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'application_id' => :'Integer', :'user_id' => :'Integer', :'name' => :'String', :'description' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'attributes' => :'Object', :'state' => :'String', :'active_ruleset_id' => :'Integer', :'tags' => :'Array<String>', :'reevaluate_on_return' => :'Boolean', :'features' => :'Array<String>', :'coupon_settings' => :'CodeGeneratorSettings', :'referral_settings' => :'CodeGeneratorSettings', :'limits' => :'Array<LimitConfig>', :'campaign_groups' => :'Array<Integer>', :'type' => :'String', :'linked_store_ids' => :'Array<Integer>', :'coupon_attributes' => :'Object', :'budgets' => :'Array<CampaignBudget>', :'coupon_redemption_count' => :'Integer', :'referral_redemption_count' => :'Integer', :'discount_count' => :'Float', :'discount_effect_count' => :'Integer', :'coupon_creation_count' => :'Integer', :'custom_effect_count' => :'Integer', :'referral_creation_count' => :'Integer', :'add_free_item_effect_count' => :'Integer', :'awarded_giveaways_count' => :'Integer', :'created_loyalty_points_count' => :'Float', :'created_loyalty_points_effect_count' => :'Integer', :'redeemed_loyalty_points_count' => :'Float', :'redeemed_loyalty_points_effect_count' => :'Integer', :'call_api_effect_count' => :'Integer', :'reservecoupon_effect_count' => :'Integer', :'last_activity' => :'Time', :'updated' => :'Time', :'created_by' => :'String', :'updated_by' => :'String', :'template_id' => :'Integer', :'frontend_state' => :'String', :'stores_imported' => :'Boolean', :'value_maps_ids' => :'Array<Integer>', :'experiment_id' => :'Integer', :'revision_frontend_state' => :'String', :'active_revision_id' => :'Integer', :'active_revision_version_id' => :'Integer', :'version' => :'Integer', :'current_revision_id' => :'Integer', :'current_revision_version_id' => :'Integer', :'stage_revision' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 847 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && application_id == o.application_id && user_id == o.user_id && name == o.name && description == o.description && start_time == o.start_time && end_time == o.end_time && attributes == o.attributes && state == o.state && active_ruleset_id == o.active_ruleset_id && == o. && reevaluate_on_return == o.reevaluate_on_return && features == o.features && coupon_settings == o.coupon_settings && referral_settings == o.referral_settings && limits == o.limits && campaign_groups == o.campaign_groups && type == o.type && linked_store_ids == o.linked_store_ids && coupon_attributes == o.coupon_attributes && budgets == o.budgets && coupon_redemption_count == o.coupon_redemption_count && referral_redemption_count == o.referral_redemption_count && discount_count == o.discount_count && discount_effect_count == o.discount_effect_count && coupon_creation_count == o.coupon_creation_count && custom_effect_count == o.custom_effect_count && referral_creation_count == o.referral_creation_count && add_free_item_effect_count == o.add_free_item_effect_count && awarded_giveaways_count == o.awarded_giveaways_count && created_loyalty_points_count == o.created_loyalty_points_count && created_loyalty_points_effect_count == o.created_loyalty_points_effect_count && redeemed_loyalty_points_count == o.redeemed_loyalty_points_count && redeemed_loyalty_points_effect_count == o.redeemed_loyalty_points_effect_count && call_api_effect_count == o.call_api_effect_count && reservecoupon_effect_count == o.reservecoupon_effect_count && last_activity == o.last_activity && updated == o.updated && created_by == o.created_by && updated_by == o.updated_by && template_id == o.template_id && frontend_state == o.frontend_state && stores_imported == o.stores_imported && value_maps_ids == o.value_maps_ids && experiment_id == o.experiment_id && revision_frontend_state == o.revision_frontend_state && active_revision_id == o.active_revision_id && active_revision_version_id == o.active_revision_version_id && version == o.version && current_revision_id == o.current_revision_id && current_revision_version_id == o.current_revision_version_id && stage_revision == o.stage_revision end |
#eql?(o) ⇒ Boolean
907 908 909 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 907 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
913 914 915 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 913 def hash [id, created, application_id, user_id, name, description, start_time, end_time, attributes, state, active_ruleset_id, , reevaluate_on_return, features, coupon_settings, referral_settings, limits, campaign_groups, type, linked_store_ids, coupon_attributes, budgets, coupon_redemption_count, referral_redemption_count, discount_count, discount_effect_count, coupon_creation_count, custom_effect_count, referral_creation_count, add_free_item_effect_count, awarded_giveaways_count, created_loyalty_points_count, created_loyalty_points_effect_count, redeemed_loyalty_points_count, redeemed_loyalty_points_effect_count, call_api_effect_count, reservecoupon_effect_count, last_activity, updated, created_by, updated_by, template_id, frontend_state, stores_imported, value_maps_ids, experiment_id, revision_frontend_state, active_revision_id, active_revision_version_id, version, current_revision_id, current_revision_version_id, stage_revision].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 616 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end if @reevaluate_on_return.nil? invalid_properties.push('invalid value for "reevaluate_on_return", reevaluate_on_return cannot be nil.') end if @features.nil? invalid_properties.push('invalid value for "features", features cannot be nil.') end if @limits.nil? invalid_properties.push('invalid value for "limits", limits cannot be nil.') end if @frontend_state.nil? invalid_properties.push('invalid value for "frontend_state", frontend_state cannot be nil.') end if @stores_imported.nil? invalid_properties.push('invalid value for "stores_imported", stores_imported cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 942 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/talon_one_sdk/models/campaign.rb', line 680 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @application_id.nil? return false if @user_id.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"]) return false unless state_validator.valid?(@state) return false if @tags.nil? return false if @tags.length > 50 return false if @reevaluate_on_return.nil? return false if @features.nil? return false if @limits.nil? type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"]) return false unless type_validator.valid?(@type) return false if @frontend_state.nil? frontend_state_validator = EnumAttributeValidator.new('String', ["expired", "scheduled", "running", "disabled", "archived", "staged"]) return false unless frontend_state_validator.valid?(@frontend_state) return false if @stores_imported.nil? revision_frontend_state_validator = EnumAttributeValidator.new('String', ["revised", "pending"]) return false unless revision_frontend_state_validator.valid?(@revision_frontend_state) true end |