Class: TalonOne::CampaignEligibility

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/campaign_eligibility.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CampaignEligibility

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 137

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignEligibility` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignEligibility`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'enabled'
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  else
    self.features = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'eligibility')
    if (value = attributes[:'eligibility']).is_a?(Array)
      self.eligibility = value
    end
  else
    self.eligibility = nil
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application that owns this entity.



22
23
24
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 22

def application_id
  @application_id
end

#attributesObject

Arbitrary properties associated with this campaign.



37
38
39
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 37

def attributes
  @attributes
end

#descriptionObject

A detailed description of the campaign.



28
29
30
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 28

def description
  @description
end

#eligibilityObject

The customer’s eligibility for each campaign in the current customer session.



52
53
54
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 52

def eligibility
  @eligibility
end

#end_timeObject

Timestamp when the campaign will become inactive.



34
35
36
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 34

def end_time
  @end_time
end

#featuresObject

The features enabled in this campaign.



46
47
48
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 46

def features
  @features
end

#idObject

Unique ID of Campaign.



19
20
21
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 19

def id
  @id
end

#nameObject

The name of the campaign.



25
26
27
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 25

def name
  @name
end

#rulesObject

A list of rules containing customer-facing details of the rewards defined in the campaign.



49
50
51
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 49

def rules
  @rules
end

#start_timeObject

Timestamp when the campaign will become active.



31
32
33
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 31

def start_time
  @start_time
end

#stateObject

The state of the campaign.



40
41
42
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 40

def state
  @state
end

#tagsObject

A list of tags for the campaign.



43
44
45
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 43

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 77

def self.attribute_map
  {
    :'id' => :'id',
    :'application_id' => :'applicationId',
    :'name' => :'name',
    :'description' => :'description',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'attributes' => :'attributes',
    :'state' => :'state',
    :'tags' => :'tags',
    :'features' => :'features',
    :'rules' => :'rules',
    :'eligibility' => :'eligibility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 386

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



129
130
131
132
133
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 129

def self.openapi_all_of
  [
  :'IntegrationCampaign'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 105

def self.openapi_types
  {
    :'id' => :'Integer',
    :'application_id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'attributes' => :'Object',
    :'state' => :'String',
    :'tags' => :'Array<String>',
    :'features' => :'Array<String>',
    :'rules' => :'Array<RuleMetadata>',
    :'eligibility' => :'Array<CampaignEligibilityDetails>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 354

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      application_id == o.application_id &&
      name == o.name &&
      description == o.description &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      attributes == o.attributes &&
      state == o.state &&
      tags == o.tags &&
      features == o.features &&
      rules == o.rules &&
      eligibility == o.eligibility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


373
374
375
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 373

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



379
380
381
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 379

def hash
  [id, application_id, name, description, start_time, end_time, attributes, state, tags, features, rules, eligibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @tags.length > 50
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.')
  end

  if @features.nil?
    invalid_properties.push('invalid value for "features", features cannot be nil.')
  end

  if @eligibility.nil?
    invalid_properties.push('invalid value for "eligibility", eligibility cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/talon_one_sdk/models/campaign_eligibility.rb', line 268

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @application_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["enabled"])
  return false unless state_validator.valid?(@state)
  return false if @tags.nil?
  return false if @tags.length > 50
  return false if @features.nil?
  return false if @eligibility.nil?
  true
end