Class: TalonOne::CampaignGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CampaignGroup
- Defined in:
- lib/talon_one_sdk/models/campaign_group.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#campaign_ids ⇒ Object
A list of IDs of the campaigns that are part of the campaign access group.
-
#created ⇒ Object
The time this entity was created.
-
#description ⇒ Object
A longer description of the campaign access group.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
The time this entity was last modified.
-
#name ⇒ Object
The name of the campaign access group.
-
#subscribed_applications_ids ⇒ Object
A list of IDs of the Applications that this campaign access group is enabled for.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignGroup
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'modified') self.modified = attributes[:'modified'] else self.modified = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'subscribed_applications_ids') if (value = attributes[:'subscribed_applications_ids']).is_a?(Array) self.subscribed_applications_ids = value end end if attributes.key?(:'campaign_ids') if (value = attributes[:'campaign_ids']).is_a?(Array) self.campaign_ids = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 28 def account_id @account_id end |
#campaign_ids ⇒ Object
A list of IDs of the campaigns that are part of the campaign access group.
40 41 42 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 40 def campaign_ids @campaign_ids end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 22 def created @created end |
#description ⇒ Object
A longer description of the campaign access group.
34 35 36 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 34 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 19 def id @id end |
#modified ⇒ Object
The time this entity was last modified.
25 26 27 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 25 def modified @modified end |
#name ⇒ Object
The name of the campaign access group.
31 32 33 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 31 def name @name end |
#subscribed_applications_ids ⇒ Object
A list of IDs of the Applications that this campaign access group is enabled for.
37 38 39 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 37 def subscribed_applications_ids @subscribed_applications_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 43 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'modified' => :'modified', :'account_id' => :'accountId', :'name' => :'name', :'description' => :'description', :'subscribed_applications_ids' => :'subscribedApplicationsIds', :'campaign_ids' => :'campaignIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 288 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
87 88 89 90 91 92 93 94 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 87 def self.openapi_all_of [ :'AccountEntity', :'Entity', :'MutableEntity', :'NewCampaignGroup' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 67 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'modified' => :'Time', :'account_id' => :'Integer', :'name' => :'String', :'description' => :'String', :'subscribed_applications_ids' => :'Array<Integer>', :'campaign_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 260 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && modified == o.modified && account_id == o.account_id && name == o.name && description == o.description && subscribed_applications_ids == o.subscribed_applications_ids && campaign_ids == o.campaign_ids end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 281 def hash [id, created, modified, account_id, name, description, subscribed_applications_ids, campaign_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @modified.nil? invalid_properties.push('invalid value for "modified", modified cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/talon_one_sdk/models/campaign_group.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @modified.nil? return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length < 1 true end |