Class: TalonOne::CampaignSetBranchNode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CampaignSetBranchNode
- Defined in:
- lib/talon_one_sdk/models/campaign_set_branch_node.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
A description of the campaign set.
-
#elements ⇒ Object
Child elements of this set.
-
#evaluation_mode ⇒ Object
The mode by which campaigns in the campaign evaluation group are evaluated.
-
#evaluation_scope ⇒ Object
The evaluation scope of the campaign evaluation group.
-
#group_id ⇒ Object
The ID of the campaign set.
-
#locked ⇒ Object
An indicator of whether the campaign set is locked for modification.
-
#name ⇒ Object
Name of the set.
-
#operator ⇒ Object
An indicator of how the set operates on its elements.
-
#type ⇒ Object
Indicates the node type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignSetBranchNode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignSetBranchNode
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignSetBranchNode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignSetBranchNode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'elements') if (value = attributes[:'elements']).is_a?(Array) self.elements = value end else self.elements = nil end if attributes.key?(:'group_id') self.group_id = attributes[:'group_id'] else self.group_id = nil end if attributes.key?(:'locked') self.locked = attributes[:'locked'] else self.locked = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'evaluation_mode') self.evaluation_mode = attributes[:'evaluation_mode'] else self.evaluation_mode = nil end if attributes.key?(:'evaluation_scope') self.evaluation_scope = attributes[:'evaluation_scope'] else self.evaluation_scope = nil end end |
Instance Attribute Details
#description ⇒ Object
A description of the campaign set.
37 38 39 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 37 def description @description end |
#elements ⇒ Object
Child elements of this set.
28 29 30 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 28 def elements @elements end |
#evaluation_mode ⇒ Object
The mode by which campaigns in the campaign evaluation group are evaluated.
40 41 42 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 40 def evaluation_mode @evaluation_mode end |
#evaluation_scope ⇒ Object
The evaluation scope of the campaign evaluation group.
43 44 45 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 43 def evaluation_scope @evaluation_scope end |
#group_id ⇒ Object
The ID of the campaign set.
31 32 33 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 31 def group_id @group_id end |
#locked ⇒ Object
An indicator of whether the campaign set is locked for modification.
34 35 36 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 34 def locked @locked end |
#name ⇒ Object
Name of the set.
22 23 24 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 22 def name @name end |
#operator ⇒ Object
An indicator of how the set operates on its elements.
25 26 27 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 25 def operator @operator end |
#type ⇒ Object
Indicates the node type.
19 20 21 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 19 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 68 def self.attribute_map { :'type' => :'type', :'name' => :'name', :'operator' => :'operator', :'elements' => :'elements', :'group_id' => :'groupId', :'locked' => :'locked', :'description' => :'description', :'evaluation_mode' => :'evaluationMode', :'evaluation_scope' => :'evaluationScope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 358 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 93 def self.openapi_types { :'type' => :'String', :'name' => :'String', :'operator' => :'String', :'elements' => :'Array<CampaignSetNode>', :'group_id' => :'Integer', :'locked' => :'Boolean', :'description' => :'String', :'evaluation_mode' => :'String', :'evaluation_scope' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 329 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && name == o.name && operator == o.operator && elements == o.elements && group_id == o.group_id && locked == o.locked && description == o.description && evaluation_mode == o.evaluation_mode && evaluation_scope == o.evaluation_scope end |
#eql?(o) ⇒ Boolean
345 346 347 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 345 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 351 def hash [type, name, operator, elements, group_id, locked, description, evaluation_mode, evaluation_scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 186 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end if @elements.nil? invalid_properties.push('invalid value for "elements", elements cannot be nil.') end if @group_id.nil? invalid_properties.push('invalid value for "group_id", group_id cannot be nil.') end if @locked.nil? invalid_properties.push('invalid value for "locked", locked cannot be nil.') end if @evaluation_mode.nil? invalid_properties.push('invalid value for "evaluation_mode", evaluation_mode cannot be nil.') end if @evaluation_scope.nil? invalid_properties.push('invalid value for "evaluation_scope", evaluation_scope cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 380 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/talon_one_sdk/models/campaign_set_branch_node.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["SET"]) return false unless type_validator.valid?(@type) return false if @name.nil? return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["ALL", "FIRST"]) return false unless operator_validator.valid?(@operator) return false if @elements.nil? return false if @group_id.nil? return false if @locked.nil? return false if @evaluation_mode.nil? evaluation_mode_validator = EnumAttributeValidator.new('String', ["stackable", "listOrder", "lowestDiscount", "highestDiscount"]) return false unless evaluation_mode_validator.valid?(@evaluation_mode) return false if @evaluation_scope.nil? evaluation_scope_validator = EnumAttributeValidator.new('String', ["cartItem", "session"]) return false unless evaluation_scope_validator.valid?(@evaluation_scope) true end |