Class: TalonOne::CampaignStoreBudgetLimitConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CampaignStoreBudgetLimitConfig
- Defined in:
- lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
The limitable action to which this limit applies.
-
#entities ⇒ Object
The entity that this limit applies to.
-
#imported ⇒ Object
Indicates whether this limit configuration is managed via a CSV file.
-
#limit ⇒ Object
The value to set for the limit.
-
#period ⇒ Object
The period on which the budget limit recurs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignStoreBudgetLimitConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CampaignStoreBudgetLimitConfig
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CampaignStoreBudgetLimitConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CampaignStoreBudgetLimitConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'limit') self.limit = attributes[:'limit'] else self.limit = nil end if attributes.key?(:'period') self.period = attributes[:'period'] end if attributes.key?(:'entities') if (value = attributes[:'entities']).is_a?(Array) self.entities = value end else self.entities = nil end if attributes.key?(:'imported') self.imported = attributes[:'imported'] else self.imported = nil end end |
Instance Attribute Details
#action ⇒ Object
The limitable action to which this limit applies. For example: - ‘setDiscount` - `setDiscountEffect` - `redeemCoupon` - `createCoupon`
19 20 21 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 19 def action @action end |
#entities ⇒ Object
The entity that this limit applies to.
28 29 30 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 28 def entities @entities end |
#imported ⇒ Object
Indicates whether this limit configuration is managed via a CSV file.
31 32 33 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 31 def imported @imported end |
#limit ⇒ Object
The value to set for the limit.
22 23 24 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 22 def limit @limit end |
#period ⇒ Object
The period on which the budget limit recurs.
25 26 27 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 25 def period @period end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 56 def self.attribute_map { :'action' => :'action', :'limit' => :'limit', :'period' => :'period', :'entities' => :'entities', :'imported' => :'imported' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 260 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
94 95 96 97 98 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 94 def self.openapi_all_of [ :'LimitConfig' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 77 def self.openapi_types { :'action' => :'String', :'limit' => :'Float', :'period' => :'String', :'entities' => :'Array<String>', :'imported' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && limit == o.limit && period == o.period && entities == o.entities && imported == o.imported end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 253 def hash [action, limit, period, entities, imported].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @limit.nil? invalid_properties.push('invalid value for "limit", limit cannot be nil.') end if @limit < 0 invalid_properties.push('invalid value for "limit", must be greater than or equal to 0.') end if @entities.nil? invalid_properties.push('invalid value for "entities", entities cannot be nil.') end if @imported.nil? invalid_properties.push('invalid value for "imported", imported cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/talon_one_sdk/models/campaign_store_budget_limit_config.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? return false if @limit.nil? return false if @limit < 0 period_validator = EnumAttributeValidator.new('String', ["daily", "weekly", "monthly", "yearly"]) return false unless period_validator.valid?(@period) return false if @entities.nil? return false if @imported.nil? true end |