Class: TalonOne::CartItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CartItem
- Defined in:
- lib/talon_one_sdk/models/cart_item.rb
Instance Attribute Summary collapse
-
#additional_costs ⇒ Object
Use this property to set a value for the additional costs of this item, such as a shipping cost.
-
#adjustment_effective_from ⇒ Object
The date and time from which the price adjustment is effective.
-
#adjustment_effective_until ⇒ Object
The date and time until which the price adjustment is effective.
-
#adjustment_reference_id ⇒ Object
The reference ID of the selected price adjustment for this cart item.
-
#attributes ⇒ Object
Use this property to set a value for the attributes of your choice.
-
#catalog_item_id ⇒ Object
The catalog item ID.
-
#category ⇒ Object
Type, group or model of the item.
-
#height ⇒ Object
Height of item in mm.
-
#length ⇒ Object
Length of item in mm.
-
#name ⇒ Object
Name of item.
-
#position ⇒ Object
Position of the Cart Item in the Cart (calculated internally).
-
#price ⇒ Object
Price of the item in the currency defined by your Application.
-
#prices ⇒ Object
A map of keys and values representing the price types and related price adjustment details for this cart item.
-
#product ⇒ Object
Returns the value of attribute product.
-
#quantity ⇒ Object
Number of units of this item.
-
#remaining_quantity ⇒ Object
Remaining quantity of the item, calculated internally based on returns of this item.
-
#returned_quantity ⇒ Object
Number of returned items, calculated internally based on returns of this item.
-
#selected_price_type ⇒ Object
The selected price type for this cart item (e.g. the price for members only).
-
#sku ⇒ Object
Stock keeping unit of item.
-
#weight ⇒ Object
Weight of item in grams.
-
#width ⇒ Object
Width of item in mm.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CartItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CartItem
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 152 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CartItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CartItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'sku') self.sku = attributes[:'sku'] else self.sku = nil end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'returned_quantity') self.returned_quantity = attributes[:'returned_quantity'] end if attributes.key?(:'remaining_quantity') self.remaining_quantity = attributes[:'remaining_quantity'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'product') self.product = attributes[:'product'] end if attributes.key?(:'weight') self.weight = attributes[:'weight'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'length') self.length = attributes[:'length'] end if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'additional_costs') if (value = attributes[:'additional_costs']).is_a?(Hash) self.additional_costs = value end end if attributes.key?(:'catalog_item_id') self.catalog_item_id = attributes[:'catalog_item_id'] end if attributes.key?(:'selected_price_type') self.selected_price_type = attributes[:'selected_price_type'] end if attributes.key?(:'adjustment_reference_id') self.adjustment_reference_id = attributes[:'adjustment_reference_id'] end if attributes.key?(:'adjustment_effective_from') self.adjustment_effective_from = attributes[:'adjustment_effective_from'] end if attributes.key?(:'adjustment_effective_until') self.adjustment_effective_until = attributes[:'adjustment_effective_until'] end if attributes.key?(:'prices') if (value = attributes[:'prices']).is_a?(Hash) self.prices = value end end end |
Instance Attribute Details
#additional_costs ⇒ Object
Use this property to set a value for the additional costs of this item, such as a shipping cost. They must be created in the Campaign Manager before you set them with this property. See [Managing additional costs](docs.talon.one/docs/product/account/dev-tools/managing-additional-costs).
60 61 62 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 60 def additional_costs @additional_costs end |
#adjustment_effective_from ⇒ Object
The date and time from which the price adjustment is effective. Only returned if the selected price resulted from a price adjustment that contains this field.
72 73 74 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 72 def adjustment_effective_from @adjustment_effective_from end |
#adjustment_effective_until ⇒ Object
The date and time until which the price adjustment is effective. Only returned if the selected price resulted from a price adjustment that contains this field.
75 76 77 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 75 def adjustment_effective_until @adjustment_effective_until end |
#adjustment_reference_id ⇒ Object
The reference ID of the selected price adjustment for this cart item. Only returned if the selected price resulted from a price adjustment.
69 70 71 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 69 def adjustment_reference_id @adjustment_reference_id end |
#attributes ⇒ Object
Use this property to set a value for the attributes of your choice. [Attributes](docs.talon.one/docs/dev/concepts/attributes) represent any information to attach to this cart item. Custom _cart item_ attributes must be created in the Campaign Manager before you set them with this property. Note: Any previously defined attributes that you do not include in the array will be removed.
57 58 59 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 57 def attributes @attributes end |
#catalog_item_id ⇒ Object
The catalog item ID.
63 64 65 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 63 def catalog_item_id @catalog_item_id end |
#category ⇒ Object
Type, group or model of the item.
37 38 39 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 37 def category @category end |
#height ⇒ Object
Height of item in mm.
45 46 47 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 45 def height @height end |
#length ⇒ Object
Length of item in mm.
51 52 53 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 51 def length @length end |
#name ⇒ Object
Name of item.
19 20 21 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 19 def name @name end |
#position ⇒ Object
Position of the Cart Item in the Cart (calculated internally).
54 55 56 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 54 def position @position end |
#price ⇒ Object
Price of the item in the currency defined by your Application. This field is required if this item is not part of a [catalog](docs.talon.one/docs/product/account/dev-tools/managing-cart-item-catalogs). If it is part of a catalog, setting a price here overrides the price from the catalog.
34 35 36 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 34 def price @price end |
#prices ⇒ Object
A map of keys and values representing the price types and related price adjustment details for this cart item. The keys correspond to the ‘priceType` names.
78 79 80 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 78 def prices @prices end |
#product ⇒ Object
Returns the value of attribute product.
39 40 41 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 39 def product @product end |
#quantity ⇒ Object
Number of units of this item. Due to [cart item flattening](docs.talon.one/docs/product/rules/understanding-cart-item-flattening), if you provide a quantity greater than 1, the item will be split in as many items as the provided quantity. This will impact the number of per-item effects triggered from your campaigns.
25 26 27 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 25 def quantity @quantity end |
#remaining_quantity ⇒ Object
Remaining quantity of the item, calculated internally based on returns of this item.
31 32 33 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 31 def remaining_quantity @remaining_quantity end |
#returned_quantity ⇒ Object
Number of returned items, calculated internally based on returns of this item.
28 29 30 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 28 def returned_quantity @returned_quantity end |
#selected_price_type ⇒ Object
The selected price type for this cart item (e.g. the price for members only).
66 67 68 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 66 def selected_price_type @selected_price_type end |
#sku ⇒ Object
Stock keeping unit of item.
22 23 24 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 22 def sku @sku end |
#weight ⇒ Object
Weight of item in grams.
42 43 44 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 42 def weight @weight end |
#width ⇒ Object
Width of item in mm.
48 49 50 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 48 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
108 109 110 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 108 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 113 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 81 def self.attribute_map { :'name' => :'name', :'sku' => :'sku', :'quantity' => :'quantity', :'returned_quantity' => :'returnedQuantity', :'remaining_quantity' => :'remainingQuantity', :'price' => :'price', :'category' => :'category', :'product' => :'product', :'weight' => :'weight', :'height' => :'height', :'width' => :'width', :'length' => :'length', :'position' => :'position', :'attributes' => :'attributes', :'additional_costs' => :'additionalCosts', :'catalog_item_id' => :'catalogItemID', :'selected_price_type' => :'selectedPriceType', :'adjustment_reference_id' => :'adjustmentReferenceId', :'adjustment_effective_from' => :'adjustmentEffectiveFrom', :'adjustment_effective_until' => :'adjustmentEffectiveUntil', :'prices' => :'prices' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 365 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
145 146 147 148 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 145 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 118 def self.openapi_types { :'name' => :'String', :'sku' => :'String', :'quantity' => :'Integer', :'returned_quantity' => :'Integer', :'remaining_quantity' => :'Integer', :'price' => :'Float', :'category' => :'String', :'product' => :'Product', :'weight' => :'Float', :'height' => :'Float', :'width' => :'Float', :'length' => :'Float', :'position' => :'Float', :'attributes' => :'Object', :'additional_costs' => :'Hash<String, AdditionalCost>', :'catalog_item_id' => :'Integer', :'selected_price_type' => :'String', :'adjustment_reference_id' => :'String', :'adjustment_effective_from' => :'Time', :'adjustment_effective_until' => :'Time', :'prices' => :'Hash<String, PriceDetail>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 324 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && sku == o.sku && quantity == o.quantity && returned_quantity == o.returned_quantity && remaining_quantity == o.remaining_quantity && price == o.price && category == o.category && product == o.product && weight == o.weight && height == o.height && width == o.width && length == o.length && position == o.position && attributes == o.attributes && additional_costs == o.additional_costs && catalog_item_id == o.catalog_item_id && selected_price_type == o.selected_price_type && adjustment_reference_id == o.adjustment_reference_id && adjustment_effective_from == o.adjustment_effective_from && adjustment_effective_until == o.adjustment_effective_until && prices == o.prices end |
#eql?(o) ⇒ Boolean
352 353 354 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 352 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 358 def hash [name, sku, quantity, returned_quantity, remaining_quantity, price, category, product, weight, height, width, length, position, attributes, additional_costs, catalog_item_id, selected_price_type, adjustment_reference_id, adjustment_effective_from, adjustment_effective_until, prices].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 261 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @sku.nil? invalid_properties.push('invalid value for "sku", sku cannot be nil.') end if @sku.to_s.length < 1 invalid_properties.push('invalid value for "sku", the character length must be greater than or equal to 1.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end if @quantity < 1 invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
285 286 287 288 289 290 291 292 |
# File 'lib/talon_one_sdk/models/cart_item.rb', line 285 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @sku.nil? return false if @sku.to_s.length < 1 return false if @quantity.nil? return false if @quantity < 1 true end |