Class: TalonOne::CheckAttributeBlockBase
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CheckAttributeBlockBase
- Defined in:
- lib/talon_one_sdk/models/check_attribute_block_base.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_end ⇒ Object
Returns the value of attribute _end.
-
#attribute ⇒ Object
Returns the value of attribute attribute.
-
#count ⇒ Object
Returns the value of attribute count.
-
#end_inclusive ⇒ Object
When
true, theendvalue is included in the range for thewithinoperator. -
#id ⇒ Object
Unique identifier for this block.
-
#max ⇒ Object
Returns the value of attribute max.
-
#min ⇒ Object
Returns the value of attribute min.
-
#operator ⇒ Object
The comparison operator applied to the attribute.
-
#start ⇒ Object
Returns the value of attribute start.
-
#start_inclusive ⇒ Object
When
true, thestartvalue is included in the range for thewithinoperator. -
#tags ⇒ Object
Semantic labels attached to this block.
-
#timezone_insensitive ⇒ Object
Indicates whether the
withinoperator ignores time zones and compares the wall-clock time only. -
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
-
#value ⇒ Object
Returns the value of attribute value.
-
#values ⇒ Object
Returns the value of attribute values.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckAttributeBlockBase
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckAttributeBlockBase
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 152 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CheckAttributeBlockBase` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CheckAttributeBlockBase`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'attribute') self.attribute = attributes[:'attribute'] else self.attribute = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'min') self.min = attributes[:'min'] end if attributes.key?(:'max') self.max = attributes[:'max'] end if attributes.key?(:'start') self.start = attributes[:'start'] end if attributes.key?(:'_end') self._end = attributes[:'_end'] end if attributes.key?(:'start_inclusive') self.start_inclusive = attributes[:'start_inclusive'] end if attributes.key?(:'end_inclusive') self.end_inclusive = attributes[:'end_inclusive'] end if attributes.key?(:'timezone_insensitive') self.timezone_insensitive = attributes[:'timezone_insensitive'] end if attributes.key?(:'values') self.values = attributes[:'values'] end if attributes.key?(:'count') self.count = attributes[:'count'] end end |
Instance Attribute Details
#_end ⇒ Object
Returns the value of attribute _end.
40 41 42 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 40 def _end @_end end |
#attribute ⇒ Object
Returns the value of attribute attribute.
30 31 32 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 30 def attribute @attribute end |
#count ⇒ Object
Returns the value of attribute count.
53 54 55 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 53 def count @count end |
#end_inclusive ⇒ Object
When true, the end value is included in the range for the within operator.
46 47 48 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 46 def end_inclusive @end_inclusive end |
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 19 def id @id end |
#max ⇒ Object
Returns the value of attribute max.
36 37 38 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 36 def max @max end |
#min ⇒ Object
Returns the value of attribute min.
34 35 36 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 34 def min @min end |
#operator ⇒ Object
The comparison operator applied to the attribute.
28 29 30 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 28 def operator @operator end |
#start ⇒ Object
Returns the value of attribute start.
38 39 40 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 38 def start @start end |
#start_inclusive ⇒ Object
When true, the start value is included in the range for the within operator.
43 44 45 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 43 def start_inclusive @start_inclusive end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 25 def @tags end |
#timezone_insensitive ⇒ Object
Indicates whether the within operator ignores time zones and compares the wall-clock time only. When false, time zones are taken into account.
49 50 51 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 49 def timezone_insensitive @timezone_insensitive end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 22 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
32 33 34 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 32 def value @value end |
#values ⇒ Object
Returns the value of attribute values.
51 52 53 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 51 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 78 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'operator' => :'operator', :'attribute' => :'attribute', :'value' => :'value', :'min' => :'min', :'max' => :'max', :'start' => :'start', :'_end' => :'end', :'start_inclusive' => :'startInclusive', :'end_inclusive' => :'endInclusive', :'timezone_insensitive' => :'timezoneInsensitive', :'values' => :'values', :'count' => :'count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 336 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
144 145 146 147 148 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 144 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 130 def self.openapi_nullable Set.new([ :'attribute', :'value', :'min', :'max', :'start', :'_end', :'values', :'count' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 109 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'operator' => :'String', :'attribute' => :'Object', :'value' => :'Object', :'min' => :'Object', :'max' => :'Object', :'start' => :'Object', :'_end' => :'Object', :'start_inclusive' => :'Boolean', :'end_inclusive' => :'Boolean', :'timezone_insensitive' => :'Boolean', :'values' => :'Object', :'count' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 301 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && operator == o.operator && attribute == o.attribute && value == o.value && min == o.min && max == o.max && start == o.start && _end == o._end && start_inclusive == o.start_inclusive && end_inclusive == o.end_inclusive && timezone_insensitive == o.timezone_insensitive && values == o.values && count == o.count end |
#eql?(o) ⇒ Boolean
323 324 325 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 323 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
329 330 331 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 329 def hash [id, type, , operator, attribute, value, min, max, start, _end, start_inclusive, end_inclusive, timezone_insensitive, values, count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 239 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 |
# File 'lib/talon_one_sdk/models/check_attribute_block_base.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["equals", "not(equals)", "lessThan", "lessThanOrEqual", "greaterThan", "greaterThanOrEqual", "between", "contains", "not(contains)", "matchesRegexp", "startsWith", "endsWith", "oneOf", "not(oneOf)", "inCollection", "not(inCollection)", "empty", "not(empty)", "exists", "not(exists)", "isTrue", "isFalse", "containsAtLeast", "containsExactly", "containsOneOf", "containsNoneOf", "containsAllOf", "after", "before", "within", "not(within)"]) return false unless operator_validator.valid?(@operator) true end |