Class: TalonOne::Collection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Collection
- Defined in:
- lib/talon_one_sdk/models/collection.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
-
#created ⇒ Object
The time this entity was created.
-
#created_by ⇒ Object
ID of the user who created this effect.
-
#description ⇒ Object
A short description of the purpose of this collection.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
The time this entity was last modified.
-
#modified_by ⇒ Object
ID of the user who last updated this effect if available.
-
#name ⇒ Object
The name of this collection.
-
#payload ⇒ Object
The content of the collection.
-
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications where this collection is enabled.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Collection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Collection
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/talon_one_sdk/models/collection.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Collection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Collection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'modified') self.modified = attributes[:'modified'] else self.modified = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'subscribed_applications_ids') if (value = attributes[:'subscribed_applications_ids']).is_a?(Array) self.subscribed_applications_ids = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'payload') if (value = attributes[:'payload']).is_a?(Array) self.payload = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/collection.rb', line 25 def account_id @account_id end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
46 47 48 |
# File 'lib/talon_one_sdk/models/collection.rb', line 46 def application_id @application_id end |
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
49 50 51 |
# File 'lib/talon_one_sdk/models/collection.rb', line 49 def campaign_id @campaign_id end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/collection.rb', line 22 def created @created end |
#created_by ⇒ Object
ID of the user who created this effect.
43 44 45 |
# File 'lib/talon_one_sdk/models/collection.rb', line 43 def created_by @created_by end |
#description ⇒ Object
A short description of the purpose of this collection.
31 32 33 |
# File 'lib/talon_one_sdk/models/collection.rb', line 31 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/collection.rb', line 19 def id @id end |
#modified ⇒ Object
The time this entity was last modified.
28 29 30 |
# File 'lib/talon_one_sdk/models/collection.rb', line 28 def modified @modified end |
#modified_by ⇒ Object
ID of the user who last updated this effect if available.
40 41 42 |
# File 'lib/talon_one_sdk/models/collection.rb', line 40 def modified_by @modified_by end |
#name ⇒ Object
The name of this collection.
37 38 39 |
# File 'lib/talon_one_sdk/models/collection.rb', line 37 def name @name end |
#payload ⇒ Object
The content of the collection.
52 53 54 |
# File 'lib/talon_one_sdk/models/collection.rb', line 52 def payload @payload end |
#subscribed_applications_ids ⇒ Object
A list of the IDs of the Applications where this collection is enabled.
34 35 36 |
# File 'lib/talon_one_sdk/models/collection.rb', line 34 def subscribed_applications_ids @subscribed_applications_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/talon_one_sdk/models/collection.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/talon_one_sdk/models/collection.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/talon_one_sdk/models/collection.rb', line 55 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'account_id' => :'accountId', :'modified' => :'modified', :'description' => :'description', :'subscribed_applications_ids' => :'subscribedApplicationsIds', :'name' => :'name', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'application_id' => :'applicationId', :'campaign_id' => :'campaignId', :'payload' => :'payload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/talon_one_sdk/models/collection.rb', line 372 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/collection.rb', line 107 def self.openapi_all_of [ :'CollectionWithoutPayload' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/talon_one_sdk/models/collection.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/talon_one_sdk/models/collection.rb', line 83 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'account_id' => :'Integer', :'modified' => :'Time', :'description' => :'String', :'subscribed_applications_ids' => :'Array<Integer>', :'name' => :'String', :'modified_by' => :'Integer', :'created_by' => :'Integer', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'payload' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/talon_one_sdk/models/collection.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && account_id == o.account_id && modified == o.modified && description == o.description && subscribed_applications_ids == o.subscribed_applications_ids && name == o.name && modified_by == o.modified_by && created_by == o.created_by && application_id == o.application_id && campaign_id == o.campaign_id && payload == o.payload end |
#eql?(o) ⇒ Boolean
359 360 361 |
# File 'lib/talon_one_sdk/models/collection.rb', line 359 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/talon_one_sdk/models/collection.rb', line 365 def hash [id, created, account_id, modified, description, subscribed_applications_ids, name, modified_by, created_by, application_id, campaign_id, payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/talon_one_sdk/models/collection.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @modified.nil? invalid_properties.push('invalid value for "modified", modified cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if !@payload.nil? && @payload.length > 50 invalid_properties.push('invalid value for "payload", number of items must be less than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/talon_one_sdk/models/collection.rb', line 394 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/talon_one_sdk/models/collection.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @account_id.nil? return false if @modified.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^[^[:cntrl:]\s][^[:cntrl:]]*$/) return false if @created_by.nil? return false if !@payload.nil? && @payload.length > 50 true end |