Class: TalonOne::CouponCreationJob
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CouponCreationJob
- Defined in:
- lib/talon_one_sdk/models/coupon_creation_job.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
Arbitrary properties associated with coupons.
-
#batch_id ⇒ Object
The batch ID coupons created by this job will bear.
-
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
-
#chunk_execution_count ⇒ Object
The number of times an attempt to create a chunk of coupons was made during the processing of the job.
-
#chunk_size ⇒ Object
The number of coupons that will be created in a single transactions.
-
#communicated ⇒ Object
Whether or not the user that created this job was notified of its final state.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#created ⇒ Object
The time this entity was created.
-
#created_amount ⇒ Object
The number of coupon codes that were already created for this request.
-
#created_by ⇒ Object
ID of the user who created this effect.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#errors ⇒ Object
An array of individual problems encountered during the request.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#fail_count ⇒ Object
The number of times this job failed.
-
#id ⇒ Object
The internal ID of this entity.
-
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
-
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#status ⇒ Object
The current status of this request.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponCreationJob
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CouponCreationJob
Initializes the object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 173 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CouponCreationJob` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CouponCreationJob`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] else self.usage_limit = nil end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'number_of_coupons') self.number_of_coupons = attributes[:'number_of_coupons'] else self.number_of_coupons = nil end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] else self.attributes = nil end if attributes.key?(:'is_reservation_mandatory') self.is_reservation_mandatory = attributes[:'is_reservation_mandatory'] else self.is_reservation_mandatory = false end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] else self.batch_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_amount') self.created_amount = attributes[:'created_amount'] else self.created_amount = nil end if attributes.key?(:'fail_count') self.fail_count = attributes[:'fail_count'] else self.fail_count = nil end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end else self.errors = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'communicated') self.communicated = attributes[:'communicated'] else self.communicated = nil end if attributes.key?(:'chunk_execution_count') self.chunk_execution_count = attributes[:'chunk_execution_count'] else self.chunk_execution_count = nil end if attributes.key?(:'chunk_size') self.chunk_size = attributes[:'chunk_size'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
31 32 33 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 31 def account_id @account_id end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 28 def application_id @application_id end |
#attributes ⇒ Object
Arbitrary properties associated with coupons.
54 55 56 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 54 def attributes @attributes end |
#batch_id ⇒ Object
The batch ID coupons created by this job will bear.
60 61 62 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 60 def batch_id @batch_id end |
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 25 def campaign_id @campaign_id end |
#chunk_execution_count ⇒ Object
The number of times an attempt to create a chunk of coupons was made during the processing of the job.
81 82 83 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 81 def chunk_execution_count @chunk_execution_count end |
#chunk_size ⇒ Object
The number of coupons that will be created in a single transactions. Coupons will be created in chunks until arriving at the requested amount.
84 85 86 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 84 def chunk_size @chunk_size end |
#communicated ⇒ Object
Whether or not the user that created this job was notified of its final state.
78 79 80 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 78 def communicated @communicated end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
51 52 53 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 51 def coupon_settings @coupon_settings end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 22 def created @created end |
#created_amount ⇒ Object
The number of coupon codes that were already created for this request.
66 67 68 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 66 def created_amount @created_amount end |
#created_by ⇒ Object
ID of the user who created this effect.
75 76 77 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 75 def created_by @created_by end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
37 38 39 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 37 def discount_limit @discount_limit end |
#errors ⇒ Object
An array of individual problems encountered during the request.
72 73 74 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 72 def errors @errors end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
46 47 48 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 46 def expiry_date @expiry_date end |
#fail_count ⇒ Object
The number of times this job failed.
69 70 71 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 69 def fail_count @fail_count end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 19 def id @id end |
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
57 58 59 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 57 def is_reservation_mandatory @is_reservation_mandatory end |
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign.
49 50 51 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 49 def number_of_coupons @number_of_coupons end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
40 41 42 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 40 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
43 44 45 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 43 def start_date @start_date end |
#status ⇒ Object
The current status of this request. Possible values: - ‘pending verification` - `pending` - `completed` - `failed` - `coupon pattern full`
63 64 65 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 63 def status @status end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
34 35 36 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 34 def usage_limit @usage_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
116 117 118 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 116 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
121 122 123 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 121 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 87 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'campaign_id' => :'campaignId', :'application_id' => :'applicationId', :'account_id' => :'accountId', :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'number_of_coupons' => :'numberOfCoupons', :'coupon_settings' => :'couponSettings', :'attributes' => :'attributes', :'is_reservation_mandatory' => :'isReservationMandatory', :'batch_id' => :'batchId', :'status' => :'status', :'created_amount' => :'createdAmount', :'fail_count' => :'failCount', :'errors' => :'errors', :'created_by' => :'createdBy', :'communicated' => :'communicated', :'chunk_execution_count' => :'chunkExecutionCount', :'chunk_size' => :'chunkSize' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 708 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
161 162 163 164 165 166 167 168 169 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 161 def self.openapi_all_of [ :'AccountEntity', :'ApplicationEntity', :'CampaignEntity', :'Entity', :'NewCouponCreationJob' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
155 156 157 158 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 155 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 126 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'campaign_id' => :'Integer', :'application_id' => :'Integer', :'account_id' => :'Integer', :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'number_of_coupons' => :'Integer', :'coupon_settings' => :'CodeGeneratorSettings', :'attributes' => :'Object', :'is_reservation_mandatory' => :'Boolean', :'batch_id' => :'String', :'status' => :'String', :'created_amount' => :'Integer', :'fail_count' => :'Integer', :'errors' => :'Array<String>', :'created_by' => :'Integer', :'communicated' => :'Boolean', :'chunk_execution_count' => :'Integer', :'chunk_size' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 665 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && campaign_id == o.campaign_id && application_id == o.application_id && account_id == o.account_id && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && number_of_coupons == o.number_of_coupons && coupon_settings == o.coupon_settings && attributes == o.attributes && is_reservation_mandatory == o.is_reservation_mandatory && batch_id == o.batch_id && status == o.status && created_amount == o.created_amount && fail_count == o.fail_count && errors == o.errors && created_by == o.created_by && communicated == o.communicated && chunk_execution_count == o.chunk_execution_count && chunk_size == o.chunk_size end |
#eql?(o) ⇒ Boolean
695 696 697 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 695 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
701 702 703 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 701 def hash [id, created, campaign_id, application_id, account_id, usage_limit, discount_limit, reservation_limit, start_date, expiry_date, number_of_coupons, coupon_settings, attributes, is_reservation_mandatory, batch_id, status, created_amount, fail_count, errors, created_by, communicated, chunk_execution_count, chunk_size].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 318 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @usage_limit.nil? invalid_properties.push('invalid value for "usage_limit", usage_limit cannot be nil.') end if @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end if @number_of_coupons.nil? invalid_properties.push('invalid value for "number_of_coupons", number_of_coupons cannot be nil.') end if @number_of_coupons > 5000000 invalid_properties.push('invalid value for "number_of_coupons", must be smaller than or equal to 5000000.') end if @number_of_coupons < 1 invalid_properties.push('invalid value for "number_of_coupons", must be greater than or equal to 1.') end if @attributes.nil? invalid_properties.push('invalid value for "attributes", attributes cannot be nil.') end if @batch_id.nil? invalid_properties.push('invalid value for "batch_id", batch_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_amount.nil? invalid_properties.push('invalid value for "created_amount", created_amount cannot be nil.') end if @fail_count.nil? invalid_properties.push('invalid value for "fail_count", fail_count cannot be nil.') end if @errors.nil? invalid_properties.push('invalid value for "errors", errors cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @communicated.nil? invalid_properties.push('invalid value for "communicated", communicated cannot be nil.') end if @chunk_execution_count.nil? invalid_properties.push('invalid value for "chunk_execution_count", chunk_execution_count cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 730 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/talon_one_sdk/models/coupon_creation_job.rb', line 422 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @campaign_id.nil? return false if @application_id.nil? return false if @account_id.nil? return false if @usage_limit.nil? return false if @usage_limit > 999999 return false if @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 return false if @number_of_coupons.nil? return false if @number_of_coupons > 5000000 return false if @number_of_coupons < 1 return false if @attributes.nil? return false if @batch_id.nil? return false if @status.nil? return false if @created_amount.nil? return false if @fail_count.nil? return false if @errors.nil? return false if @created_by.nil? return false if @communicated.nil? return false if @chunk_execution_count.nil? true end |