Class: TalonOne::CouponDeletionJob
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CouponDeletionJob
- Defined in:
- lib/talon_one_sdk/models/coupon_deletion_job.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#campaign_ids ⇒ Object
Returns the value of attribute campaign_ids.
-
#communicated ⇒ Object
Indicates whether the user that created this job was notified of its final state.
-
#created ⇒ Object
The time this entity was created.
-
#created_by ⇒ Object
ID of the user who created this effect.
-
#deleted_amount ⇒ Object
The number of coupon codes that were already deleted for this request.
-
#errors ⇒ Object
An array of individual problems encountered during the request.
-
#fail_count ⇒ Object
The number of times this job failed.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#id ⇒ Object
The internal ID of this entity.
-
#status ⇒ Object
The current status of this request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponDeletionJob
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CouponDeletionJob
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CouponDeletionJob` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CouponDeletionJob`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'filters') self.filters = attributes[:'filters'] else self.filters = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'deleted_amount') self.deleted_amount = attributes[:'deleted_amount'] end if attributes.key?(:'fail_count') self.fail_count = attributes[:'fail_count'] else self.fail_count = nil end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end else self.errors = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'communicated') self.communicated = attributes[:'communicated'] else self.communicated = nil end if attributes.key?(:'campaign_ids') if (value = attributes[:'campaign_ids']).is_a?(Array) self.campaign_ids = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 28 def account_id @account_id end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 25 def application_id @application_id end |
#campaign_ids ⇒ Object
Returns the value of attribute campaign_ids.
50 51 52 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 50 def campaign_ids @campaign_ids end |
#communicated ⇒ Object
Indicates whether the user that created this job was notified of its final state.
48 49 50 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 48 def communicated @communicated end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 22 def created @created end |
#created_by ⇒ Object
ID of the user who created this effect.
45 46 47 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 45 def created_by @created_by end |
#deleted_amount ⇒ Object
The number of coupon codes that were already deleted for this request.
36 37 38 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 36 def deleted_amount @deleted_amount end |
#errors ⇒ Object
An array of individual problems encountered during the request.
42 43 44 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 42 def errors @errors end |
#fail_count ⇒ Object
The number of times this job failed.
39 40 41 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 39 def fail_count @fail_count end |
#filters ⇒ Object
Returns the value of attribute filters.
30 31 32 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 30 def filters @filters end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 19 def id @id end |
#status ⇒ Object
The current status of this request. Possible values: - ‘not_ready` - `pending` - `completed` - `failed`
33 34 35 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 33 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 53 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'application_id' => :'applicationId', :'account_id' => :'accountId', :'filters' => :'filters', :'status' => :'status', :'deleted_amount' => :'deletedAmount', :'fail_count' => :'failCount', :'errors' => :'errors', :'created_by' => :'createdBy', :'communicated' => :'communicated', :'campaign_ids' => :'campaignIDs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 402 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
105 106 107 108 109 110 111 112 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 105 def self.openapi_all_of [ :'AccountEntity', :'ApplicationEntity', :'Entity', :'NewCouponDeletionJob' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 81 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'application_id' => :'Integer', :'account_id' => :'Integer', :'filters' => :'CouponDeletionFilters', :'status' => :'String', :'deleted_amount' => :'Integer', :'fail_count' => :'Integer', :'errors' => :'Array<String>', :'created_by' => :'Integer', :'communicated' => :'Boolean', :'campaign_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 370 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && application_id == o.application_id && account_id == o.account_id && filters == o.filters && status == o.status && deleted_amount == o.deleted_amount && fail_count == o.fail_count && errors == o.errors && created_by == o.created_by && communicated == o.communicated && campaign_ids == o.campaign_ids end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 395 def hash [id, created, application_id, account_id, filters, status, deleted_amount, fail_count, errors, created_by, communicated, campaign_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @filters.nil? invalid_properties.push('invalid value for "filters", filters cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @fail_count.nil? invalid_properties.push('invalid value for "fail_count", fail_count cannot be nil.') end if @errors.nil? invalid_properties.push('invalid value for "errors", errors cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @communicated.nil? invalid_properties.push('invalid value for "communicated", communicated cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/talon_one_sdk/models/coupon_deletion_job.rb', line 253 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @application_id.nil? return false if @account_id.nil? return false if @filters.nil? return false if @status.nil? return false if @fail_count.nil? return false if @errors.nil? return false if @created_by.nil? return false if @communicated.nil? true end |