Class: TalonOne::CouponFailureSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CouponFailureSummary
- Defined in:
- lib/talon_one_sdk/models/coupon_failure_summary.rb
Overview
Summary of the reasons for coupon redemption failure.
Instance Attribute Summary collapse
-
#coupon_code ⇒ Object
Coupon code passed for evaluation.
-
#created_at ⇒ Object
Timestamp when the request was made.
-
#event_id ⇒ Object
ID of the event.
-
#id ⇒ Object
ID of the evaluation record.
-
#language ⇒ Object
Language of the summary.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#session_id ⇒ Object
ID of the customer session set by your integration layer.
-
#status ⇒ Object
Status defines if the coupon code was applied or rejected.
-
#summary ⇒ Object
A summary of the reasons for coupon redemption failure.
-
#updated_at ⇒ Object
Timestamp when the request was last updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponFailureSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CouponFailureSummary
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CouponFailureSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CouponFailureSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'session_id') self.session_id = attributes[:'session_id'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'coupon_code') self.coupon_code = attributes[:'coupon_code'] else self.coupon_code = nil end if attributes.key?(:'language') self.language = attributes[:'language'] else self.language = nil end if attributes.key?(:'summary') self.summary = attributes[:'summary'] else self.summary = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#coupon_code ⇒ Object
Coupon code passed for evaluation.
35 36 37 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 35 def coupon_code @coupon_code end |
#created_at ⇒ Object
Timestamp when the request was made.
44 45 46 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 44 def created_at @created_at end |
#event_id ⇒ Object
ID of the event.
23 24 25 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 23 def event_id @event_id end |
#id ⇒ Object
ID of the evaluation record.
20 21 22 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 20 def id @id end |
#language ⇒ Object
Language of the summary.
38 39 40 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 38 def language @language end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
29 30 31 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 29 def profile_id @profile_id end |
#session_id ⇒ Object
ID of the customer session set by your integration layer.
26 27 28 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 26 def session_id @session_id end |
#status ⇒ Object
Status defines if the coupon code was applied or rejected.
32 33 34 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 32 def status @status end |
#summary ⇒ Object
A summary of the reasons for coupon redemption failure.
41 42 43 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 41 def summary @summary end |
#updated_at ⇒ Object
Timestamp when the request was last updated.
47 48 49 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 47 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 50 def self.attribute_map { :'id' => :'id', :'event_id' => :'eventID', :'session_id' => :'sessionID', :'profile_id' => :'profileID', :'status' => :'status', :'coupon_code' => :'couponCode', :'language' => :'language', :'summary' => :'summary', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 337 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 76 def self.openapi_types { :'id' => :'Integer', :'event_id' => :'Integer', :'session_id' => :'String', :'profile_id' => :'String', :'status' => :'String', :'coupon_code' => :'String', :'language' => :'String', :'summary' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 307 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && event_id == o.event_id && session_id == o.session_id && profile_id == o.profile_id && status == o.status && coupon_code == o.coupon_code && language == o.language && summary == o.summary && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
324 325 326 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 324 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
330 331 332 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 330 def hash [id, event_id, session_id, profile_id, status, coupon_code, language, summary, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @coupon_code.nil? invalid_properties.push('invalid value for "coupon_code", coupon_code cannot be nil.') end if @language.nil? invalid_properties.push('invalid value for "language", language cannot be nil.') end if @summary.nil? invalid_properties.push('invalid value for "summary", summary cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/talon_one_sdk/models/coupon_failure_summary.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @event_id.nil? return false if @status.nil? return false if @coupon_code.nil? return false if @language.nil? return false if @summary.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |