Class: TalonOne::CouponsNotificationPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CouponsNotificationPolicy
- Defined in:
- lib/talon_one_sdk/models/coupons_notification_policy.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#batch_size ⇒ Object
The required size of each batch of data.
-
#batching_enabled ⇒ Object
Indicates whether batching is activated.
-
#include_data ⇒ Object
Indicates whether to include all generated coupons.
-
#name ⇒ Object
Notification name.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponsNotificationPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CouponsNotificationPolicy
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CouponsNotificationPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CouponsNotificationPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end else self.scopes = nil end if attributes.key?(:'batching_enabled') self.batching_enabled = attributes[:'batching_enabled'] else self.batching_enabled = true end if attributes.key?(:'include_data') self.include_data = attributes[:'include_data'] end if attributes.key?(:'batch_size') self.batch_size = attributes[:'batch_size'] else self.batch_size = 1000 end end |
Instance Attribute Details
#batch_size ⇒ Object
The required size of each batch of data. This value applies only when ‘batchingEnabled` is `true`.
30 31 32 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 30 def batch_size @batch_size end |
#batching_enabled ⇒ Object
Indicates whether batching is activated.
24 25 26 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 24 def batching_enabled @batching_enabled end |
#include_data ⇒ Object
Indicates whether to include all generated coupons. If ‘false`, only the `batchId` of the generated coupons is included.
27 28 29 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 27 def include_data @include_data end |
#name ⇒ Object
Notification name.
19 20 21 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 19 def name @name end |
#scopes ⇒ Object
Returns the value of attribute scopes.
21 22 23 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 21 def scopes @scopes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 55 def self.attribute_map { :'name' => :'name', :'scopes' => :'scopes', :'batching_enabled' => :'batchingEnabled', :'include_data' => :'includeData', :'batch_size' => :'batchSize' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 76 def self.openapi_types { :'name' => :'String', :'scopes' => :'Array<String>', :'batching_enabled' => :'Boolean', :'include_data' => :'Boolean', :'batch_size' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && scopes == o.scopes && batching_enabled == o.batching_enabled && include_data == o.include_data && batch_size == o.batch_size end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 213 def hash [name, scopes, batching_enabled, include_data, batch_size].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @scopes.nil? invalid_properties.push('invalid value for "scopes", scopes cannot be nil.') end if @scopes.length > 4 invalid_properties.push('invalid value for "scopes", number of items must be less than or equal to 4.') end if @scopes.length < 1 invalid_properties.push('invalid value for "scopes", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 175 176 177 |
# File 'lib/talon_one_sdk/models/coupons_notification_policy.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @scopes.nil? return false if @scopes.length > 4 return false if @scopes.length < 1 true end |