Class: TalonOne::CustomerProfileIntegrationResponseV2

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb

Overview

This is the response type returned by the updateCustomerProfileV2 endpoint.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerProfileIntegrationResponseV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerProfileIntegrationResponseV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerProfileIntegrationResponseV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_profile')
    self.customer_profile = attributes[:'customer_profile']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.key?(:'triggered_campaigns')
    if (value = attributes[:'triggered_campaigns']).is_a?(Array)
      self.triggered_campaigns = value
    end
  end

  if attributes.key?(:'rule_failure_reasons')
    if (value = attributes[:'rule_failure_reasons']).is_a?(Array)
      self.rule_failure_reasons = value
    end
  end

  if attributes.key?(:'awarded_giveaways')
    if (value = attributes[:'awarded_giveaways']).is_a?(Array)
      self.awarded_giveaways = value
    end
  end

  if attributes.key?(:'effects')
    if (value = attributes[:'effects']).is_a?(Array)
      self.effects = value
    end
  else
    self.effects = nil
  end

  if attributes.key?(:'created_coupons')
    if (value = attributes[:'created_coupons']).is_a?(Array)
      self.created_coupons = value
    end
  else
    self.created_coupons = nil
  end

  if attributes.key?(:'created_referrals')
    if (value = attributes[:'created_referrals']).is_a?(Array)
      self.created_referrals = value
    end
  else
    self.created_referrals = nil
  end
end

Instance Attribute Details

#awarded_giveawaysObject

Returns the value of attribute awarded_giveaways.



29
30
31
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 29

def awarded_giveaways
  @awarded_giveaways
end

#created_couponsObject

Returns the value of attribute created_coupons.



34
35
36
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 34

def created_coupons
  @created_coupons
end

#created_referralsObject

Returns the value of attribute created_referrals.



36
37
38
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 36

def created_referrals
  @created_referrals
end

#customer_profileObject

Returns the value of attribute customer_profile.



19
20
21
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 19

def customer_profile
  @customer_profile
end

#effectsObject

The effects generated by the rules in your running campaigns. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).



32
33
34
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 32

def effects
  @effects
end

#eventObject

Returns the value of attribute event.



21
22
23
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 21

def event
  @event
end

#loyaltyObject

Returns the value of attribute loyalty.



23
24
25
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 23

def loyalty
  @loyalty
end

#rule_failure_reasonsObject

Returns the value of attribute rule_failure_reasons.



27
28
29
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 27

def rule_failure_reasons
  @rule_failure_reasons
end

#triggered_campaignsObject

Returns the value of attribute triggered_campaigns.



25
26
27
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 25

def triggered_campaigns
  @triggered_campaigns
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 39

def self.attribute_map
  {
    :'customer_profile' => :'customerProfile',
    :'event' => :'event',
    :'loyalty' => :'loyalty',
    :'triggered_campaigns' => :'triggeredCampaigns',
    :'rule_failure_reasons' => :'ruleFailureReasons',
    :'awarded_giveaways' => :'awardedGiveaways',
    :'effects' => :'effects',
    :'created_coupons' => :'createdCoupons',
    :'created_referrals' => :'createdReferrals'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 64

def self.openapi_types
  {
    :'customer_profile' => :'CustomerProfile',
    :'event' => :'Event',
    :'loyalty' => :'Loyalty',
    :'triggered_campaigns' => :'Array<Campaign>',
    :'rule_failure_reasons' => :'Array<RuleFailureReason>',
    :'awarded_giveaways' => :'Array<Giveaway>',
    :'effects' => :'Array<Effect>',
    :'created_coupons' => :'Array<Coupon>',
    :'created_referrals' => :'Array<Referral>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_profile == o.customer_profile &&
      event == o.event &&
      loyalty == o.loyalty &&
      triggered_campaigns == o.triggered_campaigns &&
      rule_failure_reasons == o.rule_failure_reasons &&
      awarded_giveaways == o.awarded_giveaways &&
      effects == o.effects &&
      created_coupons == o.created_coupons &&
      created_referrals == o.created_referrals
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 239

def hash
  [customer_profile, event, loyalty, triggered_campaigns, rule_failure_reasons, awarded_giveaways, effects, created_coupons, created_referrals].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effects.nil?
    invalid_properties.push('invalid value for "effects", effects cannot be nil.')
  end

  if @created_coupons.nil?
    invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.')
  end

  if @created_referrals.nil?
    invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/customer_profile_integration_response_v2.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @effects.nil?
  return false if @created_coupons.nil?
  return false if @created_referrals.nil?
  true
end