Class: TalonOne::CustomerProfileReward
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CustomerProfileReward
- Defined in:
- lib/talon_one_sdk/models/customer_profile_reward.rb
Overview
A reward instance held by a customer profile.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the customer reward instance.
-
#loyalty_card_identifier ⇒ Object
The identifier of the loyalty card that the reward was unlocked with.
-
#loyalty_program_id ⇒ Object
The ID of the loyalty program that the loyalty card belongs to.
-
#reward_id ⇒ Object
The ID of the reward this instance belongs to.
-
#reward_name ⇒ Object
The name of the reward.
-
#status ⇒ Object
The status of the customer reward: -
unlocked: The reward is available for use. -
#unlocked_at ⇒ Object
The date and time when the reward was unlocked.
-
#unlocked_by_integration_id ⇒ Object
The integration ID of the customer profile that unlocked the reward.
-
#used_at ⇒ Object
The date and time when the reward was used.
-
#used_by_integration_id ⇒ Object
The integration ID of the customer profile that used the reward.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerProfileReward
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerProfileReward
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerProfileReward` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerProfileReward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'reward_id') self.reward_id = attributes[:'reward_id'] else self.reward_id = nil end if attributes.key?(:'reward_name') self.reward_name = attributes[:'reward_name'] else self.reward_name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'unlocked_at') self.unlocked_at = attributes[:'unlocked_at'] else self.unlocked_at = nil end if attributes.key?(:'unlocked_by_integration_id') self.unlocked_by_integration_id = attributes[:'unlocked_by_integration_id'] end if attributes.key?(:'used_at') self.used_at = attributes[:'used_at'] end if attributes.key?(:'used_by_integration_id') self.used_by_integration_id = attributes[:'used_by_integration_id'] end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] end if attributes.key?(:'loyalty_card_identifier') self.loyalty_card_identifier = attributes[:'loyalty_card_identifier'] end end |
Instance Attribute Details
#id ⇒ Object
The ID of the customer reward instance. A customer profile can have multiple instances of the same reward.
20 21 22 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 20 def id @id end |
#loyalty_card_identifier ⇒ Object
The identifier of the loyalty card that the reward was unlocked with. Only returned for rewards unlocked with a loyalty card.
47 48 49 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 47 def loyalty_card_identifier @loyalty_card_identifier end |
#loyalty_program_id ⇒ Object
The ID of the loyalty program that the loyalty card belongs to. Only returned for rewards unlocked with a loyalty card.
44 45 46 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 44 def loyalty_program_id @loyalty_program_id end |
#reward_id ⇒ Object
The ID of the reward this instance belongs to.
23 24 25 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 23 def reward_id @reward_id end |
#reward_name ⇒ Object
The name of the reward.
26 27 28 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 26 def reward_name @reward_name end |
#status ⇒ Object
The status of the customer reward: - unlocked: The reward is available for use. - used: The reward has been used.
29 30 31 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 29 def status @status end |
#unlocked_at ⇒ Object
The date and time when the reward was unlocked.
32 33 34 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 32 def unlocked_at @unlocked_at end |
#unlocked_by_integration_id ⇒ Object
The integration ID of the customer profile that unlocked the reward. For rewards unlocked with a loyalty card, this can be any customer profile linked to that loyalty card.
35 36 37 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 35 def unlocked_by_integration_id @unlocked_by_integration_id end |
#used_at ⇒ Object
The date and time when the reward was used.
38 39 40 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 38 def used_at @used_at end |
#used_by_integration_id ⇒ Object
The integration ID of the customer profile that used the reward. For rewards unlocked with a loyalty card, this can be any customer profile linked to that loyalty card. Only returned when the reward has been used.
41 42 43 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 41 def used_by_integration_id @used_by_integration_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 72 def self.attribute_map { :'id' => :'id', :'reward_id' => :'rewardId', :'reward_name' => :'rewardName', :'status' => :'status', :'unlocked_at' => :'unlockedAt', :'unlocked_by_integration_id' => :'unlockedByIntegrationId', :'used_at' => :'usedAt', :'used_by_integration_id' => :'usedByIntegrationId', :'loyalty_program_id' => :'loyaltyProgramId', :'loyalty_card_identifier' => :'loyaltyCardIdentifier' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 349 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 98 def self.openapi_types { :'id' => :'Integer', :'reward_id' => :'Integer', :'reward_name' => :'String', :'status' => :'String', :'unlocked_at' => :'Time', :'unlocked_by_integration_id' => :'String', :'used_at' => :'Time', :'used_by_integration_id' => :'String', :'loyalty_program_id' => :'Integer', :'loyalty_card_identifier' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 319 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && reward_id == o.reward_id && reward_name == o.reward_name && status == o.status && unlocked_at == o.unlocked_at && unlocked_by_integration_id == o.unlocked_by_integration_id && used_at == o.used_at && used_by_integration_id == o.used_by_integration_id && loyalty_program_id == o.loyalty_program_id && loyalty_card_identifier == o.loyalty_card_identifier end |
#eql?(o) ⇒ Boolean
336 337 338 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 336 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
342 343 344 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 342 def hash [id, reward_id, reward_name, status, unlocked_at, unlocked_by_integration_id, used_at, used_by_integration_id, loyalty_program_id, loyalty_card_identifier].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @reward_id.nil? invalid_properties.push('invalid value for "reward_id", reward_id cannot be nil.') end if @reward_name.nil? invalid_properties.push('invalid value for "reward_name", reward_name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @unlocked_at.nil? invalid_properties.push('invalid value for "unlocked_at", unlocked_at cannot be nil.') end if !@loyalty_card_identifier.nil? && @loyalty_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "loyalty_card_identifier", the character length must be smaller than or equal to 108.') end if !@loyalty_card_identifier.nil? && @loyalty_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "loyalty_card_identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@loyalty_card_identifier.nil? && @loyalty_card_identifier !~ pattern invalid_properties.push("invalid value for \"loyalty_card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 371 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/talon_one_sdk/models/customer_profile_reward.rb', line 229 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @reward_id.nil? return false if @reward_name.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["unlocked", "used"]) return false unless status_validator.valid?(@status) return false if @unlocked_at.nil? return false if !@loyalty_card_identifier.nil? && @loyalty_card_identifier.to_s.length > 108 return false if !@loyalty_card_identifier.nil? && @loyalty_card_identifier.to_s.length < 4 return false if !@loyalty_card_identifier.nil? && @loyalty_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |