Class: TalonOne::CustomerSession
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::CustomerSession
- Defined in:
- lib/talon_one_sdk/models/customer_session.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
A key-value map of the sessions attributes.
-
#cart_items ⇒ Object
Serialized JSON representation.
-
#coupon ⇒ Object
Any coupon code entered.
-
#created ⇒ Object
The time this entity was created.
-
#discounts ⇒ Object
A map of labelled discount values, values will be in the same currency as the application associated with the session.
-
#first_session ⇒ Object
Indicates whether this is the first session for the customer’s profile.
-
#identifiers ⇒ Object
Session custom identifiers that you can set limits on or use inside your rules.
-
#integration_id ⇒ Object
Returns the value of attribute integration_id.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#referral ⇒ Object
Any referral code entered.
-
#state ⇒ Object
Indicates the current state of the session.
-
#total ⇒ Object
The total sum of the cart in one session.
-
#update_count ⇒ Object
The number of times the session was updated.
-
#updated ⇒ Object
Timestamp of the most recent event received on this session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerSession
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerSession
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CustomerSession` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CustomerSession`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'coupon') self.coupon = attributes[:'coupon'] end if attributes.key?(:'referral') self.referral = attributes[:'referral'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'open' end if attributes.key?(:'cart_items') if (value = attributes[:'cart_items']).is_a?(Array) self.cart_items = value end end if attributes.key?(:'identifiers') if (value = attributes[:'identifiers']).is_a?(Array) self.identifiers = value end end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'first_session') self.first_session = attributes[:'first_session'] else self.first_session = nil end if attributes.key?(:'update_count') self.update_count = attributes[:'update_count'] else self.update_count = nil end if attributes.key?(:'discounts') if (value = attributes[:'discounts']).is_a?(Hash) self.discounts = value end else self.discounts = nil end if attributes.key?(:'updated') self.updated = attributes[:'updated'] else self.updated = nil end end |
Instance Attribute Details
#application_id ⇒ Object
The ID of the Application that owns this entity.
24 25 26 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 24 def application_id @application_id end |
#attributes ⇒ Object
A key-value map of the sessions attributes. The potentially valid attributes are configured in your accounts developer settings.
48 49 50 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 48 def attributes @attributes end |
#cart_items ⇒ Object
Serialized JSON representation.
39 40 41 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 39 def cart_items @cart_items end |
#coupon ⇒ Object
Any coupon code entered.
30 31 32 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 30 def coupon @coupon end |
#created ⇒ Object
The time this entity was created.
21 22 23 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 21 def created @created end |
#discounts ⇒ Object
A map of labelled discount values, values will be in the same currency as the application associated with the session.
57 58 59 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 57 def discounts @discounts end |
#first_session ⇒ Object
Indicates whether this is the first session for the customer’s profile. Will always be true for anonymous sessions.
51 52 53 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 51 def first_session @first_session end |
#identifiers ⇒ Object
Session custom identifiers that you can set limits on or use inside your rules. For example, you can use IP addresses as identifiers to potentially identify devices and limit discounts abuse in case of customers creating multiple accounts. See the [tutorial](docs.talon.one/docs/dev/tutorials/using-identifiers).
42 43 44 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 42 def identifiers @identifiers end |
#integration_id ⇒ Object
Returns the value of attribute integration_id.
18 19 20 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 18 def integration_id @integration_id end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
27 28 29 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 27 def profile_id @profile_id end |
#referral ⇒ Object
Any referral code entered.
33 34 35 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 33 def referral @referral end |
#state ⇒ Object
Indicates the current state of the session. Sessions can be created as ‘open` or `closed`. The state transitions are: 1. `open` → `closed` 2. `open` → `cancelled` 3. `closed` → `cancelled` or `partially_returned` 4. `partially_returned` → `cancelled` For more information, see [Customer session states](docs.talon.one/docs/dev/concepts/entities/customer-sessions).
36 37 38 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 36 def state @state end |
#total ⇒ Object
The total sum of the cart in one session.
45 46 47 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 45 def total @total end |
#update_count ⇒ Object
The number of times the session was updated. When the session is created, this value is initialized to ‘1`.
54 55 56 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 54 def update_count @update_count end |
#updated ⇒ Object
Timestamp of the most recent event received on this session.
60 61 62 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 60 def updated @updated end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
106 107 108 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 106 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
111 112 113 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 111 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 85 def self.attribute_map { :'integration_id' => :'integrationId', :'created' => :'created', :'application_id' => :'applicationId', :'profile_id' => :'profileId', :'coupon' => :'coupon', :'referral' => :'referral', :'state' => :'state', :'cart_items' => :'cartItems', :'identifiers' => :'identifiers', :'total' => :'total', :'attributes' => :'attributes', :'first_session' => :'firstSession', :'update_count' => :'updateCount', :'discounts' => :'discounts', :'updated' => :'updated' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 485 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
143 144 145 146 147 148 149 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 143 def self.openapi_all_of [ :'ApplicationEntity', :'IntegrationEntity', :'NewCustomerSession' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 137 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 116 def self.openapi_types { :'integration_id' => :'String', :'created' => :'Time', :'application_id' => :'Integer', :'profile_id' => :'String', :'coupon' => :'String', :'referral' => :'String', :'state' => :'String', :'cart_items' => :'Array<CartItem>', :'identifiers' => :'Array<String>', :'total' => :'Float', :'attributes' => :'Object', :'first_session' => :'Boolean', :'update_count' => :'Integer', :'discounts' => :'Hash<String, Float>', :'updated' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 450 def ==(o) return true if self.equal?(o) self.class == o.class && integration_id == o.integration_id && created == o.created && application_id == o.application_id && profile_id == o.profile_id && coupon == o.coupon && referral == o.referral && state == o.state && cart_items == o.cart_items && identifiers == o.identifiers && total == o.total && attributes == o.attributes && first_session == o.first_session && update_count == o.update_count && discounts == o.discounts && updated == o.updated end |
#eql?(o) ⇒ Boolean
472 473 474 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 472 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
478 479 480 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 478 def hash [integration_id, created, application_id, profile_id, coupon, referral, state, cart_items, identifiers, total, attributes, first_session, update_count, discounts, updated].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 252 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if !@coupon.nil? && @coupon.to_s.length > 100 invalid_properties.push('invalid value for "coupon", the character length must be smaller than or equal to 100.') end if !@referral.nil? && @referral.to_s.length > 100 invalid_properties.push('invalid value for "referral", the character length must be smaller than or equal to 100.') end if !@identifiers.nil? && @identifiers.length > 5 invalid_properties.push('invalid value for "identifiers", number of items must be less than or equal to 5.') end if @first_session.nil? invalid_properties.push('invalid value for "first_session", first_session cannot be nil.') end if @update_count.nil? invalid_properties.push('invalid value for "update_count", update_count cannot be nil.') end if @discounts.nil? invalid_properties.push('invalid value for "discounts", discounts cannot be nil.') end if @updated.nil? invalid_properties.push('invalid value for "updated", updated cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 507 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/talon_one_sdk/models/customer_session.rb', line 304 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @integration_id.nil? return false if @integration_id.to_s.length > 1000 return false if @created.nil? return false if @application_id.nil? return false if !@coupon.nil? && @coupon.to_s.length > 100 return false if !@referral.nil? && @referral.to_s.length > 100 state_validator = EnumAttributeValidator.new('String', ["open", "closed", "partially_returned", "cancelled"]) return false unless state_validator.valid?(@state) return false if !@identifiers.nil? && @identifiers.length > 5 return false if @first_session.nil? return false if @update_count.nil? return false if @discounts.nil? return false if @updated.nil? true end |