Class: TalonOne::DeleteCouponsData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::DeleteCouponsData
- Defined in:
- lib/talon_one_sdk/models/delete_coupons_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#batch_id ⇒ Object
Returns the value of attribute batch_id.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#employee_name ⇒ Object
Returns the value of attribute employee_name.
-
#notification_type ⇒ Object
The type of the notification.
-
#operation ⇒ Object
Returns the value of attribute operation.
-
#total_result_size ⇒ Object
Returns the value of attribute total_result_size.
-
#type_of_change ⇒ Object
Returns the value of attribute type_of_change.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeleteCouponsData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeleteCouponsData
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::DeleteCouponsData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::DeleteCouponsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type_of_change') self.type_of_change = attributes[:'type_of_change'] else self.type_of_change = nil end if attributes.key?(:'operation') self.operation = attributes[:'operation'] else self.operation = nil end if attributes.key?(:'employee_name') self.employee_name = attributes[:'employee_name'] else self.employee_name = nil end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] else self.batch_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'total_result_size') self.total_result_size = attributes[:'total_result_size'] else self.total_result_size = nil end if attributes.key?(:'notification_type') self.notification_type = attributes[:'notification_type'] else self.notification_type = nil end end |
Instance Attribute Details
#application_id ⇒ Object
Returns the value of attribute application_id.
26 27 28 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 26 def application_id @application_id end |
#batch_id ⇒ Object
Returns the value of attribute batch_id.
24 25 26 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 24 def batch_id @batch_id end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
28 29 30 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 28 def campaign_id @campaign_id end |
#employee_name ⇒ Object
Returns the value of attribute employee_name.
22 23 24 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 22 def employee_name @employee_name end |
#notification_type ⇒ Object
The type of the notification
33 34 35 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 33 def notification_type @notification_type end |
#operation ⇒ Object
Returns the value of attribute operation.
20 21 22 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 20 def operation @operation end |
#total_result_size ⇒ Object
Returns the value of attribute total_result_size.
30 31 32 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 30 def total_result_size @total_result_size end |
#type_of_change ⇒ Object
Returns the value of attribute type_of_change.
18 19 20 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 18 def type_of_change @type_of_change end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 58 def self.attribute_map { :'type_of_change' => :'TypeOfChange', :'operation' => :'Operation', :'employee_name' => :'EmployeeName', :'batch_id' => :'BatchID', :'application_id' => :'ApplicationID', :'campaign_id' => :'CampaignID', :'total_result_size' => :'TotalResultSize', :'notification_type' => :'NotificationType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 333 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 82 def self.openapi_types { :'type_of_change' => :'String', :'operation' => :'String', :'employee_name' => :'String', :'batch_id' => :'String', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'total_result_size' => :'Integer', :'notification_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && type_of_change == o.type_of_change && operation == o.operation && employee_name == o.employee_name && batch_id == o.batch_id && application_id == o.application_id && campaign_id == o.campaign_id && total_result_size == o.total_result_size && notification_type == o.notification_type end |
#eql?(o) ⇒ Boolean
320 321 322 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 320 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 326 def hash [type_of_change, operation, employee_name, batch_id, application_id, campaign_id, total_result_size, notification_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type_of_change.nil? invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.') end if @operation.nil? invalid_properties.push('invalid value for "operation", operation cannot be nil.') end if @employee_name.nil? invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.') end if @batch_id.nil? invalid_properties.push('invalid value for "batch_id", batch_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @total_result_size.nil? invalid_properties.push('invalid value for "total_result_size", total_result_size cannot be nil.') end if @notification_type.nil? invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/talon_one_sdk/models/delete_coupons_data.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type_of_change.nil? return false if @operation.nil? return false if @employee_name.nil? return false if @batch_id.nil? return false if @application_id.nil? return false if @campaign_id.nil? return false if @total_result_size.nil? return false if @notification_type.nil? notification_type_validator = EnumAttributeValidator.new('String', ["CouponsDeleted"]) return false unless notification_type_validator.valid?(@notification_type) true end |