Class: TalonOne::DeleteLoyaltyTransactionsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb

Overview

Request to delete transactions based on the specified scope.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeleteLoyaltyTransactionsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::DeleteLoyaltyTransactionsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::DeleteLoyaltyTransactionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  else
    self.scope = nil
  end

  if attributes.key?(:'subledger_ids')
    if (value = attributes[:'subledger_ids']).is_a?(Array)
      self.subledger_ids = value
    end
  end
end

Instance Attribute Details

#scopeObject

‘AllSubledgers` deletes all transactions for the specified customer profile from all ledgers in the loyalty program. `SelectedSubledgers` deletes all transactions for the specified customer profile only from the given ledgers in the loyalty program.



20
21
22
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 20

def scope
  @scope
end

#subledger_idsObject

The IDs of the ledgers from which to delete the customer’s transactions. This parameter is required if the ‘scope` is set to `SelectedSubledgers`. To specify the main ledger, provide an empty string ("").



23
24
25
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 23

def subledger_ids
  @subledger_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 48

def self.attribute_map
  {
    :'scope' => :'scope',
    :'subledger_ids' => :'subledgerIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 74

def self.openapi_nullable
  Set.new([
    :'subledger_ids'
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 66

def self.openapi_types
  {
    :'scope' => :'String',
    :'subledger_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scope == o.scope &&
      subledger_ids == o.subledger_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 158

def hash
  [scope, subledger_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
# File 'lib/talon_one_sdk/models/delete_loyalty_transactions_request.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @scope.nil?
  scope_validator = EnumAttributeValidator.new('String', ["AllSubledgers", "SelectedSubledgers"])
  return false unless scope_validator.valid?(@scope)
  true
end