Class: TalonOne::EffectEntity
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::EffectEntity
- Defined in:
- lib/talon_one_sdk/models/effect_entity.rb
Overview
Definition of all properties that are present on all effects, independent of their type.
Instance Attribute Summary collapse
-
#adjustment_reference_id ⇒ Object
The reference identifier of the selected price adjustment for this SKU.
-
#campaign_id ⇒ Object
The ID of the campaign that triggered this effect.
-
#campaign_revision_id ⇒ Object
The revision ID of the campaign that was used when triggering the effect.
-
#campaign_revision_version_id ⇒ Object
The revision version ID of the campaign that was used when triggering the effect.
-
#condition_index ⇒ Object
The index of the condition that was triggered.
-
#effect_type ⇒ Object
The type of effect that was triggered.
-
#evaluation_group_id ⇒ Object
The ID of the evaluation group.
-
#evaluation_group_mode ⇒ Object
The evaluation mode of the evaluation group.
-
#experiment_id ⇒ Object
The ID of the experiment that campaign belongs to.
-
#rule_index ⇒ Object
The position of the rule that triggered this effect within the ruleset.
-
#rule_name ⇒ Object
The name of the rule that triggered this effect.
-
#ruleset_id ⇒ Object
The ID of the ruleset that was active in the campaign when this effect was triggered.
-
#selected_price ⇒ Object
The value of the selected price type to apply to the SKU targeted by this effect, before any discounts are applied.
-
#selected_price_type ⇒ Object
The selected price type for the SKU targeted by this effect.
-
#triggered_by_coupon ⇒ Object
The ID of the coupon that was being evaluated when this effect was triggered.
-
#triggered_for_catalog_item ⇒ Object
The ID of the catalog item that was being evaluated when this effect was triggered.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EffectEntity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EffectEntity
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EffectEntity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EffectEntity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'experiment_id') self.experiment_id = attributes[:'experiment_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'ruleset_id') self.ruleset_id = attributes[:'ruleset_id'] else self.ruleset_id = nil end if attributes.key?(:'rule_index') self.rule_index = attributes[:'rule_index'] else self.rule_index = nil end if attributes.key?(:'rule_name') self.rule_name = attributes[:'rule_name'] else self.rule_name = nil end if attributes.key?(:'effect_type') self.effect_type = attributes[:'effect_type'] else self.effect_type = nil end if attributes.key?(:'triggered_by_coupon') self.triggered_by_coupon = attributes[:'triggered_by_coupon'] end if attributes.key?(:'triggered_for_catalog_item') self.triggered_for_catalog_item = attributes[:'triggered_for_catalog_item'] end if attributes.key?(:'condition_index') self.condition_index = attributes[:'condition_index'] end if attributes.key?(:'evaluation_group_id') self.evaluation_group_id = attributes[:'evaluation_group_id'] end if attributes.key?(:'evaluation_group_mode') self.evaluation_group_mode = attributes[:'evaluation_group_mode'] end if attributes.key?(:'campaign_revision_id') self.campaign_revision_id = attributes[:'campaign_revision_id'] end if attributes.key?(:'campaign_revision_version_id') self.campaign_revision_version_id = attributes[:'campaign_revision_version_id'] end if attributes.key?(:'selected_price_type') self.selected_price_type = attributes[:'selected_price_type'] end if attributes.key?(:'selected_price') self.selected_price = attributes[:'selected_price'] end if attributes.key?(:'adjustment_reference_id') self.adjustment_reference_id = attributes[:'adjustment_reference_id'] end end |
Instance Attribute Details
#adjustment_reference_id ⇒ Object
The reference identifier of the selected price adjustment for this SKU. This is only returned if the ‘selectedPrice` resulted from a price adjustment.
65 66 67 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 65 def adjustment_reference_id @adjustment_reference_id end |
#campaign_id ⇒ Object
The ID of the campaign that triggered this effect.
23 24 25 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 23 def campaign_id @campaign_id end |
#campaign_revision_id ⇒ Object
The revision ID of the campaign that was used when triggering the effect.
53 54 55 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 53 def campaign_revision_id @campaign_revision_id end |
#campaign_revision_version_id ⇒ Object
The revision version ID of the campaign that was used when triggering the effect.
56 57 58 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 56 def campaign_revision_version_id @campaign_revision_version_id end |
#condition_index ⇒ Object
The index of the condition that was triggered.
44 45 46 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 44 def condition_index @condition_index end |
#effect_type ⇒ Object
The type of effect that was triggered. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).
35 36 37 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 35 def effect_type @effect_type end |
#evaluation_group_id ⇒ Object
The ID of the evaluation group. For more information, see [Managing campaign evaluation](docs.talon.one/docs/product/applications/managing-campaign-evaluation).
47 48 49 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 47 def evaluation_group_id @evaluation_group_id end |
#evaluation_group_mode ⇒ Object
The evaluation mode of the evaluation group. For more information, see [Managing campaign evaluation](docs.talon.one/docs/product/applications/managing-campaign-evaluation).
50 51 52 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 50 def evaluation_group_mode @evaluation_group_mode end |
#experiment_id ⇒ Object
The ID of the experiment that campaign belongs to.
20 21 22 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 20 def experiment_id @experiment_id end |
#rule_index ⇒ Object
The position of the rule that triggered this effect within the ruleset.
29 30 31 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 29 def rule_index @rule_index end |
#rule_name ⇒ Object
The name of the rule that triggered this effect.
32 33 34 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 32 def rule_name @rule_name end |
#ruleset_id ⇒ Object
The ID of the ruleset that was active in the campaign when this effect was triggered.
26 27 28 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 26 def ruleset_id @ruleset_id end |
#selected_price ⇒ Object
The value of the selected price type to apply to the SKU targeted by this effect, before any discounts are applied.
62 63 64 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 62 def selected_price @selected_price end |
#selected_price_type ⇒ Object
The selected price type for the SKU targeted by this effect.
59 60 61 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 59 def selected_price_type @selected_price_type end |
#triggered_by_coupon ⇒ Object
The ID of the coupon that was being evaluated when this effect was triggered.
38 39 40 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 38 def triggered_by_coupon @triggered_by_coupon end |
#triggered_for_catalog_item ⇒ Object
The ID of the catalog item that was being evaluated when this effect was triggered.
41 42 43 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 41 def triggered_for_catalog_item @triggered_for_catalog_item end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 68 def self.attribute_map { :'experiment_id' => :'experimentId', :'campaign_id' => :'campaignId', :'ruleset_id' => :'rulesetId', :'rule_index' => :'ruleIndex', :'rule_name' => :'ruleName', :'effect_type' => :'effectType', :'triggered_by_coupon' => :'triggeredByCoupon', :'triggered_for_catalog_item' => :'triggeredForCatalogItem', :'condition_index' => :'conditionIndex', :'evaluation_group_id' => :'evaluationGroupID', :'evaluation_group_mode' => :'evaluationGroupMode', :'campaign_revision_id' => :'campaignRevisionId', :'campaign_revision_version_id' => :'campaignRevisionVersionId', :'selected_price_type' => :'selectedPriceType', :'selected_price' => :'selectedPrice', :'adjustment_reference_id' => :'adjustmentReferenceId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 346 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 100 def self.openapi_types { :'experiment_id' => :'Integer', :'campaign_id' => :'Integer', :'ruleset_id' => :'Integer', :'rule_index' => :'Integer', :'rule_name' => :'String', :'effect_type' => :'String', :'triggered_by_coupon' => :'Integer', :'triggered_for_catalog_item' => :'Integer', :'condition_index' => :'Integer', :'evaluation_group_id' => :'Integer', :'evaluation_group_mode' => :'String', :'campaign_revision_id' => :'Integer', :'campaign_revision_version_id' => :'Integer', :'selected_price_type' => :'String', :'selected_price' => :'Float', :'adjustment_reference_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && experiment_id == o.experiment_id && campaign_id == o.campaign_id && ruleset_id == o.ruleset_id && rule_index == o.rule_index && rule_name == o.rule_name && effect_type == o.effect_type && triggered_by_coupon == o.triggered_by_coupon && triggered_for_catalog_item == o.triggered_for_catalog_item && condition_index == o.condition_index && evaluation_group_id == o.evaluation_group_id && evaluation_group_mode == o.evaluation_group_mode && campaign_revision_id == o.campaign_revision_id && campaign_revision_version_id == o.campaign_revision_version_id && selected_price_type == o.selected_price_type && selected_price == o.selected_price && adjustment_reference_id == o.adjustment_reference_id end |
#eql?(o) ⇒ Boolean
333 334 335 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 333 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
339 340 341 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 339 def hash [experiment_id, campaign_id, ruleset_id, rule_index, rule_name, effect_type, triggered_by_coupon, triggered_for_catalog_item, condition_index, evaluation_group_id, evaluation_group_mode, campaign_revision_id, campaign_revision_version_id, selected_price_type, selected_price, adjustment_reference_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 220 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @ruleset_id.nil? invalid_properties.push('invalid value for "ruleset_id", ruleset_id cannot be nil.') end if @rule_index.nil? invalid_properties.push('invalid value for "rule_index", rule_index cannot be nil.') end if @rule_name.nil? invalid_properties.push('invalid value for "rule_name", rule_name cannot be nil.') end if @effect_type.nil? invalid_properties.push('invalid value for "effect_type", effect_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 368 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
248 249 250 251 252 253 254 255 256 |
# File 'lib/talon_one_sdk/models/effect_entity.rb', line 248 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @campaign_id.nil? return false if @ruleset_id.nil? return false if @rule_index.nil? return false if @rule_name.nil? return false if @effect_type.nil? true end |