Class: TalonOne::Environment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Environment
- Defined in:
- lib/talon_one_sdk/models/environment.rb
Instance Attribute Summary collapse
-
#achievements ⇒ Object
The achievements, linked to the campaigns, belonging to the application.
-
#additional_costs ⇒ Object
The additional costs that the application is subscribed to.
-
#application_cart_item_filters ⇒ Object
The cart item filters belonging to the Application.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
The attributes that the application is subscribed to.
-
#audiences ⇒ Object
The audiences contained in the account which the application belongs to.
-
#collections ⇒ Object
The account-level collections that the application is subscribed to.
-
#created ⇒ Object
The time this entity was created.
-
#functions ⇒ Object
The functions defined for this application.
-
#giveaways_pools ⇒ Object
The giveaways pools that the application is subscribed to.
-
#id ⇒ Object
The internal ID of this entity.
-
#loyalty_programs ⇒ Object
The loyalty programs that the application is subscribed to.
-
#price_types ⇒ Object
The price types that this Application can use.
-
#slots ⇒ Object
The slots defined for this application.
-
#templates ⇒ Object
The templates defined for this application.
-
#variables ⇒ Object
A stringified version of the environment’s Talang variables scope.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Environment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Environment
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/talon_one_sdk/models/environment.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Environment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Environment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'slots') if (value = attributes[:'slots']).is_a?(Array) self.slots = value end else self.slots = nil end if attributes.key?(:'functions') if (value = attributes[:'functions']).is_a?(Array) self.functions = value end else self.functions = nil end if attributes.key?(:'templates') if (value = attributes[:'templates']).is_a?(Array) self.templates = value end else self.templates = nil end if attributes.key?(:'variables') self.variables = attributes[:'variables'] else self.variables = nil end if attributes.key?(:'giveaways_pools') if (value = attributes[:'giveaways_pools']).is_a?(Array) self.giveaways_pools = value end end if attributes.key?(:'loyalty_programs') if (value = attributes[:'loyalty_programs']).is_a?(Array) self.loyalty_programs = value end end if attributes.key?(:'achievements') if (value = attributes[:'achievements']).is_a?(Array) self.achievements = value end end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Array) self.attributes = value end end if attributes.key?(:'additional_costs') if (value = attributes[:'additional_costs']).is_a?(Array) self.additional_costs = value end end if attributes.key?(:'audiences') if (value = attributes[:'audiences']).is_a?(Array) self.audiences = value end end if attributes.key?(:'collections') if (value = attributes[:'collections']).is_a?(Array) self.collections = value end end if attributes.key?(:'application_cart_item_filters') if (value = attributes[:'application_cart_item_filters']).is_a?(Array) self.application_cart_item_filters = value end end if attributes.key?(:'price_types') if (value = attributes[:'price_types']).is_a?(Array) self.price_types = value end end end |
Instance Attribute Details
#achievements ⇒ Object
The achievements, linked to the campaigns, belonging to the application.
46 47 48 |
# File 'lib/talon_one_sdk/models/environment.rb', line 46 def achievements @achievements end |
#additional_costs ⇒ Object
The additional costs that the application is subscribed to.
52 53 54 |
# File 'lib/talon_one_sdk/models/environment.rb', line 52 def additional_costs @additional_costs end |
#application_cart_item_filters ⇒ Object
The cart item filters belonging to the Application.
61 62 63 |
# File 'lib/talon_one_sdk/models/environment.rb', line 61 def application_cart_item_filters @application_cart_item_filters end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/environment.rb', line 25 def application_id @application_id end |
#attributes ⇒ Object
The attributes that the application is subscribed to.
49 50 51 |
# File 'lib/talon_one_sdk/models/environment.rb', line 49 def attributes @attributes end |
#audiences ⇒ Object
The audiences contained in the account which the application belongs to.
55 56 57 |
# File 'lib/talon_one_sdk/models/environment.rb', line 55 def audiences @audiences end |
#collections ⇒ Object
The account-level collections that the application is subscribed to.
58 59 60 |
# File 'lib/talon_one_sdk/models/environment.rb', line 58 def collections @collections end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/environment.rb', line 22 def created @created end |
#functions ⇒ Object
The functions defined for this application.
31 32 33 |
# File 'lib/talon_one_sdk/models/environment.rb', line 31 def functions @functions end |
#giveaways_pools ⇒ Object
The giveaways pools that the application is subscribed to.
40 41 42 |
# File 'lib/talon_one_sdk/models/environment.rb', line 40 def giveaways_pools @giveaways_pools end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/environment.rb', line 19 def id @id end |
#loyalty_programs ⇒ Object
The loyalty programs that the application is subscribed to.
43 44 45 |
# File 'lib/talon_one_sdk/models/environment.rb', line 43 def loyalty_programs @loyalty_programs end |
#price_types ⇒ Object
The price types that this Application can use.
64 65 66 |
# File 'lib/talon_one_sdk/models/environment.rb', line 64 def price_types @price_types end |
#slots ⇒ Object
The slots defined for this application.
28 29 30 |
# File 'lib/talon_one_sdk/models/environment.rb', line 28 def slots @slots end |
#templates ⇒ Object
The templates defined for this application.
34 35 36 |
# File 'lib/talon_one_sdk/models/environment.rb', line 34 def templates @templates end |
#variables ⇒ Object
A stringified version of the environment’s Talang variables scope.
37 38 39 |
# File 'lib/talon_one_sdk/models/environment.rb', line 37 def variables @variables end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/talon_one_sdk/models/environment.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/talon_one_sdk/models/environment.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/talon_one_sdk/models/environment.rb', line 67 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'application_id' => :'applicationId', :'slots' => :'slots', :'functions' => :'functions', :'templates' => :'templates', :'variables' => :'variables', :'giveaways_pools' => :'giveawaysPools', :'loyalty_programs' => :'loyaltyPrograms', :'achievements' => :'achievements', :'attributes' => :'attributes', :'additional_costs' => :'additionalCosts', :'audiences' => :'audiences', :'collections' => :'collections', :'application_cart_item_filters' => :'applicationCartItemFilters', :'price_types' => :'priceTypes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/talon_one_sdk/models/environment.rb', line 411 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/environment.rb', line 127 def self.openapi_all_of [ :'ApplicationEntity', :'Entity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/talon_one_sdk/models/environment.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/talon_one_sdk/models/environment.rb', line 99 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'application_id' => :'Integer', :'slots' => :'Array<SlotDef>', :'functions' => :'Array<FunctionDef>', :'templates' => :'Array<TemplateDef>', :'variables' => :'String', :'giveaways_pools' => :'Array<GiveawaysPool>', :'loyalty_programs' => :'Array<LoyaltyProgram>', :'achievements' => :'Array<Achievement>', :'attributes' => :'Array<Attribute>', :'additional_costs' => :'Array<AccountAdditionalCost>', :'audiences' => :'Array<Audience>', :'collections' => :'Array<Collection>', :'application_cart_item_filters' => :'Array<ApplicationCIF>', :'price_types' => :'Array<PriceType>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/talon_one_sdk/models/environment.rb', line 375 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && application_id == o.application_id && slots == o.slots && functions == o.functions && templates == o.templates && variables == o.variables && giveaways_pools == o.giveaways_pools && loyalty_programs == o.loyalty_programs && achievements == o.achievements && attributes == o.attributes && additional_costs == o.additional_costs && audiences == o.audiences && collections == o.collections && application_cart_item_filters == o.application_cart_item_filters && price_types == o.price_types end |
#eql?(o) ⇒ Boolean
398 399 400 |
# File 'lib/talon_one_sdk/models/environment.rb', line 398 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/talon_one_sdk/models/environment.rb', line 404 def hash [id, created, application_id, slots, functions, templates, variables, giveaways_pools, loyalty_programs, achievements, attributes, additional_costs, audiences, collections, application_cart_item_filters, price_types].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/talon_one_sdk/models/environment.rb', line 255 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @slots.nil? invalid_properties.push('invalid value for "slots", slots cannot be nil.') end if @functions.nil? invalid_properties.push('invalid value for "functions", functions cannot be nil.') end if @templates.nil? invalid_properties.push('invalid value for "templates", templates cannot be nil.') end if @variables.nil? invalid_properties.push('invalid value for "variables", variables cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/talon_one_sdk/models/environment.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/talon_one_sdk/models/environment.rb', line 291 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @application_id.nil? return false if @slots.nil? return false if @functions.nil? return false if @templates.nil? return false if @variables.nil? true end |