Class: TalonOne::EventV3

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/event_v3.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EventV3

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/talon_one_sdk/models/event_v3.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EventV3` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EventV3`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'evaluable_campaign_ids')
    if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array)
      self.evaluable_campaign_ids = value
    end
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  else
    self.integration_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'connected_session_id')
    self.connected_session_id = attributes[:'connected_session_id']
  end

  if attributes.key?(:'previous_event_id')
    self.previous_event_id = attributes[:'previous_event_id']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).



34
35
36
# File 'lib/talon_one_sdk/models/event_v3.rb', line 34

def attributes
  @attributes
end

#connected_session_idObject

The ID of the session that happened in the past.



37
38
39
# File 'lib/talon_one_sdk/models/event_v3.rb', line 37

def connected_session_id
  @connected_session_id
end

#evaluable_campaign_idsObject

When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.



25
26
27
# File 'lib/talon_one_sdk/models/event_v3.rb', line 25

def evaluable_campaign_ids
  @evaluable_campaign_ids
end

#integration_idObject

The unique ID of the current event. Only one event with this ID could be activated, duplicated events are forbidden.



28
29
30
# File 'lib/talon_one_sdk/models/event_v3.rb', line 28

def integration_id
  @integration_id
end

#previous_event_idObject

The unique identifier of the event that happened in the past.



40
41
42
# File 'lib/talon_one_sdk/models/event_v3.rb', line 40

def previous_event_id
  @previous_event_id
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.



19
20
21
# File 'lib/talon_one_sdk/models/event_v3.rb', line 19

def profile_id
  @profile_id
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



22
23
24
# File 'lib/talon_one_sdk/models/event_v3.rb', line 22

def store_integration_id
  @store_integration_id
end

#typeObject

A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.



31
32
33
# File 'lib/talon_one_sdk/models/event_v3.rb', line 31

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/event_v3.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/event_v3.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/talon_one_sdk/models/event_v3.rb', line 43

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'store_integration_id' => :'storeIntegrationId',
    :'evaluable_campaign_ids' => :'evaluableCampaignIds',
    :'integration_id' => :'integrationId',
    :'type' => :'type',
    :'attributes' => :'attributes',
    :'connected_session_id' => :'connectedSessionID',
    :'previous_event_id' => :'previousEventID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/talon_one_sdk/models/event_v3.rb', line 326

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



87
88
89
90
91
92
93
# File 'lib/talon_one_sdk/models/event_v3.rb', line 87

def self.openapi_all_of
  [
  :'EvaluableCampaignIds',
  :'IntegrationProfileEntityV3',
  :'IntegrationStoreEntity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/talon_one_sdk/models/event_v3.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/event_v3.rb', line 67

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'store_integration_id' => :'String',
    :'evaluable_campaign_ids' => :'Array<Integer>',
    :'integration_id' => :'String',
    :'type' => :'String',
    :'attributes' => :'Object',
    :'connected_session_id' => :'String',
    :'previous_event_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/talon_one_sdk/models/event_v3.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      store_integration_id == o.store_integration_id &&
      evaluable_campaign_ids == o.evaluable_campaign_ids &&
      integration_id == o.integration_id &&
      type == o.type &&
      attributes == o.attributes &&
      connected_session_id == o.connected_session_id &&
      previous_event_id == o.previous_event_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/talon_one_sdk/models/event_v3.rb', line 313

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



319
320
321
# File 'lib/talon_one_sdk/models/event_v3.rb', line 319

def hash
  [profile_id, store_integration_id, evaluable_campaign_ids, integration_id, type, attributes, connected_session_id, previous_event_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/talon_one_sdk/models/event_v3.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length < 1
    invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.')
  end

  if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
    invalid_properties.push('invalid value for "connected_session_id", the character length must be greater than or equal to 1.')
  end

  if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1
    invalid_properties.push('invalid value for "previous_event_id", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/talon_one_sdk/models/event_v3.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/talon_one_sdk/models/event_v3.rb', line 198

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length < 1
  return false if @type.nil?
  return false if @type.to_s.length < 1
  return false if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
  return false if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1
  true
end