Class: TalonOne::EventV3ReferralEntity
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::EventV3ReferralEntity
- Defined in:
- lib/talon_one_sdk/models/event_v3_referral_entity.rb
Instance Attribute Summary collapse
-
#referral_code ⇒ Object
The referral code submitted with the event.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventV3ReferralEntity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventV3ReferralEntity
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EventV3ReferralEntity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EventV3ReferralEntity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'referral_code') self.referral_code = attributes[:'referral_code'] end end |
Instance Attribute Details
#referral_code ⇒ Object
The referral code submitted with the event. The endpoint does not validate the code, and submitting a code does not redeem it. Use the "Referral code is valid" condition in the Rule Builder to validate and redeem the code, or "Referral code is valid (without redemption)" to validate without redeeming.
19 20 21 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 19 def referral_code @referral_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 22 def self.attribute_map { :'referral_code' => :'referralCode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 129 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
46 47 48 49 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 46 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 39 def self.openapi_types { :'referral_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && referral_code == o.referral_code end |
#eql?(o) ⇒ Boolean
116 117 118 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 116 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 122 def hash [referral_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 74 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@referral_code.nil? && @referral_code.to_s.length > 100 invalid_properties.push('invalid value for "referral_code", the character length must be smaller than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/event_v3_referral_entity.rb', line 86 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@referral_code.nil? && @referral_code.to_s.length > 100 true end |