Class: TalonOne::Experiment

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/experiment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Experiment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/experiment.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Experiment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Experiment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  else
    self.application_id = nil
  end

  if attributes.key?(:'is_variant_assignment_external')
    self.is_variant_assignment_external = attributes[:'is_variant_assignment_external']
  end

  if attributes.key?(:'campaign')
    self.campaign = attributes[:'campaign']
  end

  if attributes.key?(:'activated')
    self.activated = attributes[:'activated']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'disabled'
  end

  if attributes.key?(:'variants')
    if (value = attributes[:'variants']).is_a?(Array)
      self.variants = value
    end
  end

  if attributes.key?(:'deletedat')
    self.deletedat = attributes[:'deletedat']
  end
end

Instance Attribute Details

#activatedObject

The date and time the experiment was activated.



33
34
35
# File 'lib/talon_one_sdk/models/experiment.rb', line 33

def activated
  @activated
end

#application_idObject

The ID of the Application that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/experiment.rb', line 25

def application_id
  @application_id
end

#campaignObject

Returns the value of attribute campaign.



30
31
32
# File 'lib/talon_one_sdk/models/experiment.rb', line 30

def campaign
  @campaign
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/experiment.rb', line 22

def created
  @created
end

#deletedatObject

The date and time the experiment was deleted.



41
42
43
# File 'lib/talon_one_sdk/models/experiment.rb', line 41

def deletedat
  @deletedat
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/experiment.rb', line 19

def id
  @id
end

#is_variant_assignment_externalObject

The source of the assignment. - false - The variant assignment is handled internally by Talon.One. - true - The variant assignment is handled externally.



28
29
30
# File 'lib/talon_one_sdk/models/experiment.rb', line 28

def is_variant_assignment_external
  @is_variant_assignment_external
end

#stateObject

A disabled experiment is not evaluated for rules or coupons.



36
37
38
# File 'lib/talon_one_sdk/models/experiment.rb', line 36

def state
  @state
end

#variantsObject

Returns the value of attribute variants.



38
39
40
# File 'lib/talon_one_sdk/models/experiment.rb', line 38

def variants
  @variants
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/talon_one_sdk/models/experiment.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/talon_one_sdk/models/experiment.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one_sdk/models/experiment.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'application_id' => :'applicationId',
    :'is_variant_assignment_external' => :'isVariantAssignmentExternal',
    :'campaign' => :'campaign',
    :'activated' => :'activated',
    :'state' => :'state',
    :'variants' => :'variants',
    :'deletedat' => :'deletedat'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/talon_one_sdk/models/experiment.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



112
113
114
115
116
117
# File 'lib/talon_one_sdk/models/experiment.rb', line 112

def self.openapi_all_of
  [
  :'ApplicationEntity',
  :'Entity'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/talon_one_sdk/models/experiment.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/talon_one_sdk/models/experiment.rb', line 91

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'application_id' => :'Integer',
    :'is_variant_assignment_external' => :'Boolean',
    :'campaign' => :'Campaign',
    :'activated' => :'Time',
    :'state' => :'String',
    :'variants' => :'Array<ExperimentVariant>',
    :'deletedat' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/talon_one_sdk/models/experiment.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      application_id == o.application_id &&
      is_variant_assignment_external == o.is_variant_assignment_external &&
      campaign == o.campaign &&
      activated == o.activated &&
      state == o.state &&
      variants == o.variants &&
      deletedat == o.deletedat
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/talon_one_sdk/models/experiment.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/talon_one_sdk/models/experiment.rb', line 283

def hash
  [id, created, application_id, is_variant_assignment_external, campaign, activated, state, variants, deletedat].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/talon_one_sdk/models/experiment.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/talon_one_sdk/models/experiment.rb', line 312

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
# File 'lib/talon_one_sdk/models/experiment.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"])
  return false unless state_validator.valid?(@state)
  true
end