Class: TalonOne::ExperimentCampaignCopy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ExperimentCampaignCopy
- Defined in:
- lib/talon_one_sdk/models/experiment_campaign_copy.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A detailed description of the campaign.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#evaluation_group_id ⇒ Object
The ID of the campaign evaluation group the campaign belongs to.
-
#name ⇒ Object
Name of the copied campaign (Defaults to "Copy of original campaign name").
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#tags ⇒ Object
A list of tags for the campaign.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExperimentCampaignCopy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExperimentCampaignCopy
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentCampaignCopy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentCampaignCopy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'evaluation_group_id') self.evaluation_group_id = attributes[:'evaluation_group_id'] end end |
Instance Attribute Details
#description ⇒ Object
A detailed description of the campaign.
22 23 24 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 22 def description @description end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
28 29 30 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 28 def end_time @end_time end |
#evaluation_group_id ⇒ Object
The ID of the campaign evaluation group the campaign belongs to.
34 35 36 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 34 def evaluation_group_id @evaluation_group_id end |
#name ⇒ Object
Name of the copied campaign (Defaults to "Copy of original campaign name").
19 20 21 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 19 def name @name end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
25 26 27 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 25 def start_time @start_time end |
#tags ⇒ Object
A list of tags for the campaign.
31 32 33 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 31 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 37 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'start_time' => :'startTime', :'end_time' => :'endTime', :'tags' => :'tags', :'evaluation_group_id' => :'evaluationGroupId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 59 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'tags' => :'Array<String>', :'evaluation_group_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && start_time == o.start_time && end_time == o.end_time && == o. && evaluation_group_id == o.evaluation_group_id end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 174 def hash [name, description, start_time, end_time, , evaluation_group_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@tags.nil? && @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 |
# File 'lib/talon_one_sdk/models/experiment_campaign_copy.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tags.nil? && @tags.length > 50 true end |