Class: TalonOne::ExperimentSegmentInsight
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ExperimentSegmentInsight
- Defined in:
- lib/talon_one_sdk/models/experiment_segment_insight.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The specific group within the segmentation dimension.
-
#confidence ⇒ Object
The raw (unadjusted) confidence score expressed as a percentage.
-
#dimension ⇒ Object
The segmentation dimension used to group customers or purchases for analysis.
-
#variants ⇒ Object
Per-variant metric values for this segment.
-
#winner_variant_id ⇒ Object
The ID of the variant that performed better in this segment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExperimentSegmentInsight
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExperimentSegmentInsight
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentSegmentInsight` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentSegmentInsight`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'dimension') self.dimension = attributes[:'dimension'] else self.dimension = nil end if attributes.key?(:'bucket') self.bucket = attributes[:'bucket'] else self.bucket = nil end if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] else self.confidence = nil end if attributes.key?(:'winner_variant_id') self.winner_variant_id = attributes[:'winner_variant_id'] else self.winner_variant_id = nil end if attributes.key?(:'variants') if (value = attributes[:'variants']).is_a?(Array) self.variants = value end else self.variants = nil end end |
Instance Attribute Details
#bucket ⇒ Object
The specific group within the segmentation dimension.
22 23 24 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 22 def bucket @bucket end |
#confidence ⇒ Object
The raw (unadjusted) confidence score expressed as a percentage. Only segments with a confidence score greater than or equal to 95% are returned.
25 26 27 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 25 def confidence @confidence end |
#dimension ⇒ Object
The segmentation dimension used to group customers or purchases for analysis.
19 20 21 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 19 def dimension @dimension end |
#variants ⇒ Object
Per-variant metric values for this segment.
31 32 33 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 31 def variants @variants end |
#winner_variant_id ⇒ Object
The ID of the variant that performed better in this segment.
28 29 30 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 28 def winner_variant_id @winner_variant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 56 def self.attribute_map { :'dimension' => :'dimension', :'bucket' => :'bucket', :'confidence' => :'confidence', :'winner_variant_id' => :'winnerVariantId', :'variants' => :'variants' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 77 def self.openapi_types { :'dimension' => :'String', :'bucket' => :'String', :'confidence' => :'Float', :'winner_variant_id' => :'Integer', :'variants' => :'Array<ExperimentSegmentInsightVariant>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && dimension == o.dimension && bucket == o.bucket && confidence == o.confidence && winner_variant_id == o.winner_variant_id && variants == o.variants end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 274 def hash [dimension, bucket, confidence, winner_variant_id, variants].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 144 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @dimension.nil? invalid_properties.push('invalid value for "dimension", dimension cannot be nil.') end if @bucket.nil? invalid_properties.push('invalid value for "bucket", bucket cannot be nil.') end if @confidence.nil? invalid_properties.push('invalid value for "confidence", confidence cannot be nil.') end if @confidence > 100 invalid_properties.push('invalid value for "confidence", must be smaller than or equal to 100.') end if @confidence < 95 invalid_properties.push('invalid value for "confidence", must be greater than or equal to 95.') end if @winner_variant_id.nil? invalid_properties.push('invalid value for "winner_variant_id", winner_variant_id cannot be nil.') end if @variants.nil? invalid_properties.push('invalid value for "variants", variants cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/talon_one_sdk/models/experiment_segment_insight.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @dimension.nil? dimension_validator = EnumAttributeValidator.new('String', ["cart_value", "item_count", "customer_type"]) return false unless dimension_validator.valid?(@dimension) return false if @bucket.nil? bucket_validator = EnumAttributeValidator.new('String', ["low", "medium", "high", "new", "returning", "loyal"]) return false unless bucket_validator.valid?(@bucket) return false if @confidence.nil? return false if @confidence > 100 return false if @confidence < 95 return false if @winner_variant_id.nil? return false if @variants.nil? true end |