Class: TalonOne::ExtendLoyaltyPointsExpiryDateEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ExtendLoyaltyPointsExpiryDateEffectProps
- Defined in:
- lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb
Overview
The properties specific to the "extendLoyaltyPointsExpiryDate" effect. This gets triggered when a validated rule contains the "extend expiry date" effect. The current expiry date gets extended by the time frame given in the effect.
Instance Attribute Summary collapse
-
#affected_transactions ⇒ Object
List of transactions affected by the expiry date update.
-
#extension_duration ⇒ Object
Time frame by which the expiry date extends.
-
#program_id ⇒ Object
ID of the loyalty program that contains these points.
-
#sub_ledger_id ⇒ Object
API name of the loyalty program subledger that contains these points.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExtendLoyaltyPointsExpiryDateEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExtendLoyaltyPointsExpiryDateEffectProps
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExtendLoyaltyPointsExpiryDateEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExtendLoyaltyPointsExpiryDateEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] else self.program_id = nil end if attributes.key?(:'sub_ledger_id') self.sub_ledger_id = attributes[:'sub_ledger_id'] else self.sub_ledger_id = nil end if attributes.key?(:'extension_duration') self.extension_duration = attributes[:'extension_duration'] else self.extension_duration = nil end if attributes.key?(:'affected_transactions') if (value = attributes[:'affected_transactions']).is_a?(Array) self.affected_transactions = value end end end |
Instance Attribute Details
#affected_transactions ⇒ Object
List of transactions affected by the expiry date update.
29 30 31 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 29 def affected_transactions @affected_transactions end |
#extension_duration ⇒ Object
Time frame by which the expiry date extends. The time format is either: - immediate, or - an integer followed by a letter indicating the time unit. Examples: ‘immediate`, `30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can round certain units up or down: - `_D` for rounding down days only. Signifies the start of the day. - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year.
26 27 28 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 26 def extension_duration @extension_duration end |
#program_id ⇒ Object
ID of the loyalty program that contains these points.
20 21 22 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 20 def program_id @program_id end |
#sub_ledger_id ⇒ Object
API name of the loyalty program subledger that contains these points. added.
23 24 25 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 23 def sub_ledger_id @sub_ledger_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 32 def self.attribute_map { :'program_id' => :'programId', :'sub_ledger_id' => :'subLedgerId', :'extension_duration' => :'extensionDuration', :'affected_transactions' => :'affectedTransactions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 52 def self.openapi_types { :'program_id' => :'Integer', :'sub_ledger_id' => :'String', :'extension_duration' => :'String', :'affected_transactions' => :'Array<LoyaltyLedgerEntryExpiryDateChange>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && program_id == o.program_id && sub_ledger_id == o.sub_ledger_id && extension_duration == o.extension_duration && affected_transactions == o.affected_transactions end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 187 def hash [program_id, sub_ledger_id, extension_duration, affected_transactions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @program_id.nil? invalid_properties.push('invalid value for "program_id", program_id cannot be nil.') end if @sub_ledger_id.nil? invalid_properties.push('invalid value for "sub_ledger_id", sub_ledger_id cannot be nil.') end if @extension_duration.nil? invalid_properties.push('invalid value for "extension_duration", extension_duration cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 136 |
# File 'lib/talon_one_sdk/models/extend_loyalty_points_expiry_date_effect_props.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @program_id.nil? return false if @sub_ledger_id.nil? return false if @extension_duration.nil? true end |