Class: TalonOne::IntegrationCampaign
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationCampaign
- Defined in:
- lib/talon_one_sdk/models/integration_campaign.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#description ⇒ Object
A detailed description of the campaign.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#features ⇒ Object
The features enabled in this campaign.
-
#id ⇒ Object
Unique ID of Campaign.
-
#linked_audience_ids ⇒ Object
A list of audience IDs linked to this campaign.
-
#linked_store_ids ⇒ Object
A list of store IDs linked to this campaign.
-
#name ⇒ Object
The name of the campaign.
-
#rules ⇒ Object
A list of rules containing customer-facing details of the rewards defined in the campaign.
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#state ⇒ Object
The state of the campaign.
-
#tags ⇒ Object
A list of tags for the campaign.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationCampaign
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationCampaign
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationCampaign` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationCampaign`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'enabled' end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end else self.features = nil end if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end else self.rules = nil end if attributes.key?(:'linked_store_ids') if (value = attributes[:'linked_store_ids']).is_a?(Array) self.linked_store_ids = value end end if attributes.key?(:'linked_audience_ids') if (value = attributes[:'linked_audience_ids']).is_a?(Array) self.linked_audience_ids = value end end end |
Instance Attribute Details
#application_id ⇒ Object
The ID of the Application that owns this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 19 def application_id @application_id end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 37 def attributes @attributes end |
#description ⇒ Object
A detailed description of the campaign.
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 28 def description @description end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
34 35 36 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 34 def end_time @end_time end |
#features ⇒ Object
The features enabled in this campaign.
46 47 48 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 46 def features @features end |
#id ⇒ Object
Unique ID of Campaign.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 22 def id @id end |
#linked_audience_ids ⇒ Object
A list of audience IDs linked to this campaign.
55 56 57 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 55 def linked_audience_ids @linked_audience_ids end |
#linked_store_ids ⇒ Object
A list of store IDs linked to this campaign.
52 53 54 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 52 def linked_store_ids @linked_store_ids end |
#name ⇒ Object
The name of the campaign.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 25 def name @name end |
#rules ⇒ Object
A list of rules containing customer-facing details of the rewards defined in the campaign.
49 50 51 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 49 def rules @rules end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 31 def start_time @start_time end |
#state ⇒ Object
The state of the campaign.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 40 def state @state end |
#tags ⇒ Object
A list of tags for the campaign.
43 44 45 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 43 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 80 def self.attribute_map { :'application_id' => :'applicationId', :'id' => :'id', :'name' => :'name', :'description' => :'description', :'start_time' => :'startTime', :'end_time' => :'endTime', :'attributes' => :'attributes', :'state' => :'state', :'tags' => :'tags', :'features' => :'features', :'rules' => :'rules', :'linked_store_ids' => :'linkedStoreIds', :'linked_audience_ids' => :'linkedAudienceIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 398 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
134 135 136 137 138 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 134 def self.openapi_all_of [ :'IntegrationCampaignBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 128 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 109 def self.openapi_types { :'application_id' => :'Integer', :'id' => :'Integer', :'name' => :'String', :'description' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'attributes' => :'Object', :'state' => :'String', :'tags' => :'Array<String>', :'features' => :'Array<String>', :'rules' => :'Array<RuleMetadata>', :'linked_store_ids' => :'Array<Integer>', :'linked_audience_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 365 def ==(o) return true if self.equal?(o) self.class == o.class && application_id == o.application_id && id == o.id && name == o.name && description == o.description && start_time == o.start_time && end_time == o.end_time && attributes == o.attributes && state == o.state && == o. && features == o.features && rules == o.rules && linked_store_ids == o.linked_store_ids && linked_audience_ids == o.linked_audience_ids end |
#eql?(o) ⇒ Boolean
385 386 387 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 385 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
391 392 393 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 391 def hash [application_id, id, name, description, start_time, end_time, attributes, state, , features, rules, linked_store_ids, linked_audience_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 235 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end if @features.nil? invalid_properties.push('invalid value for "features", features cannot be nil.') end if @rules.nil? invalid_properties.push('invalid value for "rules", rules cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 420 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/talon_one_sdk/models/integration_campaign.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @application_id.nil? return false if @id.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["enabled"]) return false unless state_validator.valid?(@state) return false if @tags.nil? return false if @tags.length > 50 return false if @features.nil? return false if @rules.nil? true end |