Class: TalonOne::IntegrationEventV3Request
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationEventV3Request
- Defined in:
- lib/talon_one_sdk/models/integration_event_v3_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event.
-
#connected_session_id ⇒ Object
The ID of the session that happened in the past.
-
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine.
-
#integration_id ⇒ Object
The unique ID of the current event.
-
#loyalty_cards ⇒ Object
Identifiers of the loyalty cards used during this event.
-
#previous_event_id ⇒ Object
The unique identifier of the event that happened in the past.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#response_content ⇒ Object
Optional list of requested information to be present on the response related to the tracking custom event.
-
#store_integration_id ⇒ Object
The integration ID of the store.
-
#type ⇒ Object
A string representing the event name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationEventV3Request
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationEventV3Request
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationEventV3Request` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationEventV3Request`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] else self.profile_id = nil end if attributes.key?(:'store_integration_id') self.store_integration_id = attributes[:'store_integration_id'] end if attributes.key?(:'evaluable_campaign_ids') if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array) self.evaluable_campaign_ids = value end end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'connected_session_id') self.connected_session_id = attributes[:'connected_session_id'] end if attributes.key?(:'previous_event_id') self.previous_event_id = attributes[:'previous_event_id'] end if attributes.key?(:'loyalty_cards') if (value = attributes[:'loyalty_cards']).is_a?(Array) self.loyalty_cards = value end end if attributes.key?(:'response_content') if (value = attributes[:'response_content']).is_a?(Array) self.response_content = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).
34 35 36 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 34 def attributes @attributes end |
#connected_session_id ⇒ Object
The ID of the session that happened in the past.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 37 def connected_session_id @connected_session_id end |
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 25 def evaluable_campaign_ids @evaluable_campaign_ids end |
#integration_id ⇒ Object
The unique ID of the current event. Only one event with this ID could be activated, duplicated events are forbidden.
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 28 def integration_id @integration_id end |
#loyalty_cards ⇒ Object
Identifiers of the loyalty cards used during this event.
43 44 45 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 43 def loyalty_cards @loyalty_cards end |
#previous_event_id ⇒ Object
The unique identifier of the event that happened in the past.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 40 def previous_event_id @previous_event_id end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 19 def profile_id @profile_id end |
#response_content ⇒ Object
Optional list of requested information to be present on the response related to the tracking custom event.
46 47 48 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 46 def response_content @response_content end |
#store_integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 22 def store_integration_id @store_integration_id end |
#type ⇒ Object
A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 31 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 71 def self.attribute_map { :'profile_id' => :'profileId', :'store_integration_id' => :'storeIntegrationId', :'evaluable_campaign_ids' => :'evaluableCampaignIds', :'integration_id' => :'integrationId', :'type' => :'type', :'attributes' => :'attributes', :'connected_session_id' => :'connectedSessionID', :'previous_event_id' => :'previousEventID', :'loyalty_cards' => :'loyaltyCards', :'response_content' => :'responseContent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 389 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 119 def self.openapi_all_of [ :'EventV3' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 97 def self.openapi_types { :'profile_id' => :'String', :'store_integration_id' => :'String', :'evaluable_campaign_ids' => :'Array<Integer>', :'integration_id' => :'String', :'type' => :'String', :'attributes' => :'Object', :'connected_session_id' => :'String', :'previous_event_id' => :'String', :'loyalty_cards' => :'Array<String>', :'response_content' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 359 def ==(o) return true if self.equal?(o) self.class == o.class && profile_id == o.profile_id && store_integration_id == o.store_integration_id && evaluable_campaign_ids == o.evaluable_campaign_ids && integration_id == o.integration_id && type == o.type && attributes == o.attributes && connected_session_id == o.connected_session_id && previous_event_id == o.previous_event_id && loyalty_cards == o.loyalty_cards && response_content == o.response_content end |
#eql?(o) ⇒ Boolean
376 377 378 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 376 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
382 383 384 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 382 def hash [profile_id, store_integration_id, evaluable_campaign_ids, integration_id, type, attributes, connected_session_id, previous_event_id, loyalty_cards, response_content].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @profile_id.nil? invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.') end if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length < 1 invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.') end if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1 invalid_properties.push('invalid value for "connected_session_id", the character length must be greater than or equal to 1.') end if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1 invalid_properties.push('invalid value for "previous_event_id", the character length must be greater than or equal to 1.') end if !@loyalty_cards.nil? && @loyalty_cards.length > 1 invalid_properties.push('invalid value for "loyalty_cards", number of items must be less than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one_sdk/models/integration_event_v3_request.rb', line 244 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @profile_id.nil? return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 return false if @integration_id.nil? return false if @integration_id.to_s.length < 1 return false if @type.nil? return false if @type.to_s.length < 1 return false if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1 return false if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1 return false if !@loyalty_cards.nil? && @loyalty_cards.length > 1 true end |