Class: TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification
- Defined in:
- lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb
Instance Attribute Summary collapse
-
#actions ⇒ Object
Returns the value of attribute actions.
-
#current_points ⇒ Object
Returns the value of attribute current_points.
-
#current_tier ⇒ Object
The name of the customer's current tier.
-
#employee_name ⇒ Object
Returns the value of attribute employee_name.
-
#event_id ⇒ Object
The ID of the integration hub event.
-
#loyalty_program_id ⇒ Object
Returns the value of attribute loyalty_program_id.
-
#loyalty_program_name ⇒ Object
The name of the loyalty program.
-
#profile_integration_id ⇒ Object
Returns the value of attribute profile_integration_id.
-
#published_at ⇒ Object
Timestamp when the event was published.
-
#session_integration_id ⇒ Object
The integration ID of the session through which the points were earned or lost.
-
#source_of_event ⇒ Object
Returns the value of attribute source_of_event.
-
#subledger_id ⇒ Object
Returns the value of attribute subledger_id.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'profile_integration_id') self.profile_integration_id = attributes[:'profile_integration_id'] else self.profile_integration_id = nil end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] else self.loyalty_program_id = nil end if attributes.key?(:'loyalty_program_name') self.loyalty_program_name = attributes[:'loyalty_program_name'] else self.loyalty_program_name = nil end if attributes.key?(:'subledger_id') self.subledger_id = attributes[:'subledger_id'] else self.subledger_id = nil end if attributes.key?(:'source_of_event') self.source_of_event = attributes[:'source_of_event'] else self.source_of_event = nil end if attributes.key?(:'current_tier') self.current_tier = attributes[:'current_tier'] else self.current_tier = nil end if attributes.key?(:'session_integration_id') self.session_integration_id = attributes[:'session_integration_id'] end if attributes.key?(:'employee_name') self.employee_name = attributes[:'employee_name'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'current_points') self.current_points = attributes[:'current_points'] else self.current_points = nil end if attributes.key?(:'actions') if (value = attributes[:'actions']).is_a?(Array) self.actions = value end end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] else self.published_at = nil end end |
Instance Attribute Details
#actions ⇒ Object
Returns the value of attribute actions.
44 45 46 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 44 def actions @actions end |
#current_points ⇒ Object
Returns the value of attribute current_points.
42 43 44 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 42 def current_points @current_points end |
#current_tier ⇒ Object
The name of the customer's current tier.
33 34 35 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 33 def current_tier @current_tier end |
#employee_name ⇒ Object
Returns the value of attribute employee_name.
38 39 40 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 38 def employee_name @employee_name end |
#event_id ⇒ Object
The ID of the integration hub event. Return this value in the delivery-status callback to mark the event delivered or failed.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 19 def event_id @event_id end |
#loyalty_program_id ⇒ Object
Returns the value of attribute loyalty_program_id.
23 24 25 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 23 def loyalty_program_id @loyalty_program_id end |
#loyalty_program_name ⇒ Object
The name of the loyalty program.
26 27 28 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 26 def loyalty_program_name @loyalty_program_name end |
#profile_integration_id ⇒ Object
Returns the value of attribute profile_integration_id.
21 22 23 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 21 def profile_integration_id @profile_integration_id end |
#published_at ⇒ Object
Timestamp when the event was published.
47 48 49 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 47 def published_at @published_at end |
#session_integration_id ⇒ Object
The integration ID of the session through which the points were earned or lost. Only set when the change results from a rule engine execution; empty otherwise.
36 37 38 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 36 def session_integration_id @session_integration_id end |
#source_of_event ⇒ Object
Returns the value of attribute source_of_event.
30 31 32 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 30 def source_of_event @source_of_event end |
#subledger_id ⇒ Object
Returns the value of attribute subledger_id.
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 28 def subledger_id @subledger_id end |
#user_id ⇒ Object
Returns the value of attribute user_id.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 40 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 50 def self.attribute_map { :'event_id' => :'EventId', :'profile_integration_id' => :'ProfileIntegrationID', :'loyalty_program_id' => :'LoyaltyProgramID', :'loyalty_program_name' => :'LoyaltyProgramName', :'subledger_id' => :'SubledgerID', :'source_of_event' => :'SourceOfEvent', :'current_tier' => :'CurrentTier', :'session_integration_id' => :'SessionIntegrationID', :'employee_name' => :'EmployeeName', :'user_id' => :'UserID', :'current_points' => :'CurrentPoints', :'actions' => :'Actions', :'published_at' => :'PublishedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 377 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 79 def self.openapi_types { :'event_id' => :'Integer', :'profile_integration_id' => :'String', :'loyalty_program_id' => :'Integer', :'loyalty_program_name' => :'String', :'subledger_id' => :'String', :'source_of_event' => :'String', :'current_tier' => :'String', :'session_integration_id' => :'String', :'employee_name' => :'String', :'user_id' => :'Integer', :'current_points' => :'Float', :'actions' => :'Array<IntegrationHubEventPayloadLoyaltyProfileBasedPointsChangedNotificationAction>', :'published_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 344 def ==(o) return true if self.equal?(o) self.class == o.class && event_id == o.event_id && profile_integration_id == o.profile_integration_id && loyalty_program_id == o.loyalty_program_id && loyalty_program_name == o.loyalty_program_name && subledger_id == o.subledger_id && source_of_event == o.source_of_event && current_tier == o.current_tier && session_integration_id == o.session_integration_id && employee_name == o.employee_name && user_id == o.user_id && current_points == o.current_points && actions == o.actions && published_at == o.published_at end |
#eql?(o) ⇒ Boolean
364 365 366 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 364 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
370 371 372 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 370 def hash [event_id, profile_integration_id, loyalty_program_id, loyalty_program_name, subledger_id, source_of_event, current_tier, session_integration_id, employee_name, user_id, current_points, actions, published_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 194 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @profile_integration_id.nil? invalid_properties.push('invalid value for "profile_integration_id", profile_integration_id cannot be nil.') end if @loyalty_program_id.nil? invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.') end if @loyalty_program_name.nil? invalid_properties.push('invalid value for "loyalty_program_name", loyalty_program_name cannot be nil.') end if @subledger_id.nil? invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.') end if @source_of_event.nil? invalid_properties.push('invalid value for "source_of_event", source_of_event cannot be nil.') end if @current_tier.nil? invalid_properties.push('invalid value for "current_tier", current_tier cannot be nil.') end if @current_points.nil? invalid_properties.push('invalid value for "current_points", current_points cannot be nil.') end if @published_at.nil? invalid_properties.push('invalid value for "published_at", published_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 399 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_points_changed_notification.rb', line 238 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @event_id.nil? return false if @profile_integration_id.nil? return false if @loyalty_program_id.nil? return false if @loyalty_program_name.nil? return false if @subledger_id.nil? return false if @source_of_event.nil? return false if @current_tier.nil? return false if @current_points.nil? return false if @published_at.nil? true end |