Class: TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_integration_id')
    self.profile_integration_id = attributes[:'profile_integration_id']
  else
    self.profile_integration_id = nil
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  else
    self.loyalty_program_id = nil
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  else
    self.subledger_id = nil
  end

  if attributes.key?(:'source_of_event')
    self.source_of_event = attributes[:'source_of_event']
  else
    self.source_of_event = nil
  end

  if attributes.key?(:'current_tier')
    self.current_tier = attributes[:'current_tier']
  end

  if attributes.key?(:'current_points')
    self.current_points = attributes[:'current_points']
  else
    self.current_points = nil
  end

  if attributes.key?(:'old_tier')
    self.old_tier = attributes[:'old_tier']
  end

  if attributes.key?(:'points_required_to_the_next_tier')
    self.points_required_to_the_next_tier = attributes[:'points_required_to_the_next_tier']
  end

  if attributes.key?(:'next_tier')
    self.next_tier = attributes[:'next_tier']
  end

  if attributes.key?(:'tier_expiration_date')
    self.tier_expiration_date = attributes[:'tier_expiration_date']
  end

  if attributes.key?(:'timestamp_of_tier_change')
    self.timestamp_of_tier_change = attributes[:'timestamp_of_tier_change']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  else
    self.published_at = nil
  end
end

Instance Attribute Details

#current_pointsObject

Returns the value of attribute current_points.



28
29
30
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 28

def current_points
  @current_points
end

#current_tierObject

Returns the value of attribute current_tier.



26
27
28
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 26

def current_tier
  @current_tier
end

#loyalty_program_idObject

Returns the value of attribute loyalty_program_id.



20
21
22
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 20

def loyalty_program_id
  @loyalty_program_id
end

#next_tierObject

Returns the value of attribute next_tier.



34
35
36
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 34

def next_tier
  @next_tier
end

#old_tierObject

Returns the value of attribute old_tier.



30
31
32
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 30

def old_tier
  @old_tier
end

#points_required_to_the_next_tierObject

Returns the value of attribute points_required_to_the_next_tier.



32
33
34
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 32

def points_required_to_the_next_tier
  @points_required_to_the_next_tier
end

#profile_integration_idObject

Returns the value of attribute profile_integration_id.



18
19
20
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 18

def profile_integration_id
  @profile_integration_id
end

#published_atObject

Timestamp when the event was published.



41
42
43
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 41

def published_at
  @published_at
end

#source_of_eventObject

Returns the value of attribute source_of_event.



24
25
26
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 24

def source_of_event
  @source_of_event
end

#subledger_idObject

Returns the value of attribute subledger_id.



22
23
24
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 22

def subledger_id
  @subledger_id
end

#tier_expiration_dateObject

Returns the value of attribute tier_expiration_date.



36
37
38
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 36

def tier_expiration_date
  @tier_expiration_date
end

#timestamp_of_tier_changeObject

Returns the value of attribute timestamp_of_tier_change.



38
39
40
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 38

def timestamp_of_tier_change
  @timestamp_of_tier_change
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 44

def self.attribute_map
  {
    :'profile_integration_id' => :'ProfileIntegrationID',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'subledger_id' => :'SubledgerID',
    :'source_of_event' => :'SourceOfEvent',
    :'current_tier' => :'CurrentTier',
    :'current_points' => :'CurrentPoints',
    :'old_tier' => :'OldTier',
    :'points_required_to_the_next_tier' => :'PointsRequiredToTheNextTier',
    :'next_tier' => :'NextTier',
    :'tier_expiration_date' => :'TierExpirationDate',
    :'timestamp_of_tier_change' => :'TimestampOfTierChange',
    :'published_at' => :'PublishedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 72

def self.openapi_types
  {
    :'profile_integration_id' => :'String',
    :'loyalty_program_id' => :'Integer',
    :'subledger_id' => :'String',
    :'source_of_event' => :'String',
    :'current_tier' => :'String',
    :'current_points' => :'Float',
    :'old_tier' => :'String',
    :'points_required_to_the_next_tier' => :'Float',
    :'next_tier' => :'String',
    :'tier_expiration_date' => :'Time',
    :'timestamp_of_tier_change' => :'Time',
    :'published_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_integration_id == o.profile_integration_id &&
      loyalty_program_id == o.loyalty_program_id &&
      subledger_id == o.subledger_id &&
      source_of_event == o.source_of_event &&
      current_tier == o.current_tier &&
      current_points == o.current_points &&
      old_tier == o.old_tier &&
      points_required_to_the_next_tier == o.points_required_to_the_next_tier &&
      next_tier == o.next_tier &&
      tier_expiration_date == o.tier_expiration_date &&
      timestamp_of_tier_change == o.timestamp_of_tier_change &&
      published_at == o.published_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 304

def hash
  [profile_integration_id, loyalty_program_id, subledger_id, source_of_event, current_tier, current_points, old_tier, points_required_to_the_next_tier, next_tier, tier_expiration_date, timestamp_of_tier_change, published_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_integration_id.nil?
    invalid_properties.push('invalid value for "profile_integration_id", profile_integration_id cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @source_of_event.nil?
    invalid_properties.push('invalid value for "source_of_event", source_of_event cannot be nil.')
  end

  if @current_points.nil?
    invalid_properties.push('invalid value for "current_points", current_points cannot be nil.')
  end

  if @published_at.nil?
    invalid_properties.push('invalid value for "published_at", published_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one_sdk/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_integration_id.nil?
  return false if @loyalty_program_id.nil?
  return false if @subledger_id.nil?
  return false if @source_of_event.nil?
  return false if @current_points.nil?
  return false if @published_at.nil?
  true
end