Class: TalonOne::IntegrationHubEventRecord

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_hub_event_record.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubEventRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  else
    self.flow_id = nil
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  else
    self.event_type = nil
  end

  if attributes.key?(:'event_data')
    self.event_data = attributes[:'event_data']
  else
    self.event_data = nil
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  else
    self.published_at = nil
  end

  if attributes.key?(:'processed_at')
    self.processed_at = attributes[:'processed_at']
  end

  if attributes.key?(:'delivered_at')
    self.delivered_at = attributes[:'delivered_at']
  end

  if attributes.key?(:'process_after')
    self.process_after = attributes[:'process_after']
  else
    self.process_after = nil
  end

  if attributes.key?(:'_retry')
    self._retry = attributes[:'_retry']
  else
    self._retry = nil
  end
end

Instance Attribute Details

#_retryObject

Returns the value of attribute _retry.



34
35
36
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 34

def _retry
  @_retry
end

#delivered_atObject

Returns the value of attribute delivered_at.



30
31
32
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 30

def delivered_at
  @delivered_at
end

#event_dataObject

Returns the value of attribute event_data.



24
25
26
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 24

def event_data
  @event_data
end

#event_typeObject

Returns the value of attribute event_type.



22
23
24
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 22

def event_type
  @event_type
end

#flow_idObject

Returns the value of attribute flow_id.



20
21
22
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 20

def flow_id
  @flow_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 18

def id
  @id
end

#process_afterObject

Returns the value of attribute process_after.



32
33
34
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 32

def process_after
  @process_after
end

#processed_atObject

Returns the value of attribute processed_at.



28
29
30
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 28

def processed_at
  @processed_at
end

#published_atObject

Returns the value of attribute published_at.



26
27
28
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 26

def published_at
  @published_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 37

def self.attribute_map
  {
    :'id' => :'Id',
    :'flow_id' => :'FlowId',
    :'event_type' => :'EventType',
    :'event_data' => :'EventData',
    :'published_at' => :'PublishedAt',
    :'processed_at' => :'ProcessedAt',
    :'delivered_at' => :'DeliveredAt',
    :'process_after' => :'ProcessAfter',
    :'_retry' => :'Retry'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 77

def self.openapi_nullable
  Set.new([
    :'event_data',
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 62

def self.openapi_types
  {
    :'id' => :'Integer',
    :'flow_id' => :'Integer',
    :'event_type' => :'String',
    :'event_data' => :'Object',
    :'published_at' => :'Time',
    :'processed_at' => :'Time',
    :'delivered_at' => :'Time',
    :'process_after' => :'Time',
    :'_retry' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      flow_id == o.flow_id &&
      event_type == o.event_type &&
      event_data == o.event_data &&
      published_at == o.published_at &&
      processed_at == o.processed_at &&
      delivered_at == o.delivered_at &&
      process_after == o.process_after &&
      _retry == o._retry
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 279

def hash
  [id, flow_id, event_type, event_data, published_at, processed_at, delivered_at, process_after, _retry].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @flow_id.nil?
    invalid_properties.push('invalid value for "flow_id", flow_id cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @published_at.nil?
    invalid_properties.push('invalid value for "published_at", published_at cannot be nil.')
  end

  if @process_after.nil?
    invalid_properties.push('invalid value for "process_after", process_after cannot be nil.')
  end

  if @_retry.nil?
    invalid_properties.push('invalid value for "_retry", _retry cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
# File 'lib/talon_one_sdk/models/integration_hub_event_record.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @flow_id.nil?
  return false if @event_type.nil?
  return false if @published_at.nil?
  return false if @process_after.nil?
  return false if @_retry.nil?
  true
end