Class: TalonOne::IntegrationHubFlowConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationHubFlowConfig
- Defined in:
- lib/talon_one_sdk/models/integration_hub_flow_config.rb
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Returns the value of attribute api_key.
-
#max_events_per_message ⇒ Object
Maximum number of events to send in a single message to IntegrationHub.
-
#max_retries ⇒ Object
Maximum number of retries for a IntegrationHub event before it is ignored.
-
#worker_count ⇒ Object
Number of IntegrationHub workers to run in parallel for this flow (maximum 500).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationHubFlowConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationHubFlowConfig
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubFlowConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubFlowConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] else self.api_key = nil end if attributes.key?(:'worker_count') self.worker_count = attributes[:'worker_count'] else self.worker_count = 10 end if attributes.key?(:'max_events_per_message') self. = attributes[:'max_events_per_message'] else self. = 1000 end if attributes.key?(:'max_retries') self.max_retries = attributes[:'max_retries'] else self.max_retries = 10 end end |
Instance Attribute Details
#api_key ⇒ Object
Returns the value of attribute api_key.
18 19 20 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 18 def api_key @api_key end |
#max_events_per_message ⇒ Object
Maximum number of events to send in a single message to IntegrationHub.
24 25 26 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 24 def @max_events_per_message end |
#max_retries ⇒ Object
Maximum number of retries for a IntegrationHub event before it is ignored.
27 28 29 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 27 def max_retries @max_retries end |
#worker_count ⇒ Object
Number of IntegrationHub workers to run in parallel for this flow (maximum 500).
21 22 23 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 21 def worker_count @worker_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 30 def self.attribute_map { :'api_key' => :'ApiKey', :'worker_count' => :'WorkerCount', :'max_events_per_message' => :'MaxEventsPerMessage', :'max_retries' => :'MaxRetries' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 50 def self.openapi_types { :'api_key' => :'String', :'worker_count' => :'Integer', :'max_events_per_message' => :'Integer', :'max_retries' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
204 205 206 207 208 209 210 211 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 204 def ==(o) return true if self.equal?(o) self.class == o.class && api_key == o.api_key && worker_count == o.worker_count && == o. && max_retries == o.max_retries end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 221 def hash [api_key, worker_count, , max_retries].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @api_key.nil? invalid_properties.push('invalid value for "api_key", api_key cannot be nil.') end if !@worker_count.nil? && @worker_count > 500 invalid_properties.push('invalid value for "worker_count", must be smaller than or equal to 500.') end if !@worker_count.nil? && @worker_count < 1 invalid_properties.push('invalid value for "worker_count", must be greater than or equal to 1.') end if !@max_events_per_message.nil? && @max_events_per_message < 1 invalid_properties.push('invalid value for "max_events_per_message", must be greater than or equal to 1.') end if !@max_retries.nil? && @max_retries < 0 invalid_properties.push('invalid value for "max_retries", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/integration_hub_flow_config.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @api_key.nil? return false if !@worker_count.nil? && @worker_count > 500 return false if !@worker_count.nil? && @worker_count < 1 return false if !@max_events_per_message.nil? && @max_events_per_message < 1 return false if !@max_retries.nil? && @max_retries < 0 true end |