Class: TalonOne::IntegrationHubFlowResponse

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_hub_flow_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubFlowResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubFlowResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubFlowResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'integration_name')
    self.integration_name = attributes[:'integration_name']
  end

  if attributes.key?(:'instance_name')
    self.instance_name = attributes[:'instance_name']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'disabled_until')
    self.disabled_until = attributes[:'disabled_until']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  else
    self.event_type = nil
  end

  if attributes.key?(:'integration_hub_flow_url')
    self.integration_hub_flow_url = attributes[:'integration_hub_flow_url']
  else
    self.integration_hub_flow_url = nil
  end

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  else
    self.config = nil
  end
end

Instance Attribute Details

#application_idObject

ID of the application the flow is registered for.



34
35
36
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 34

def application_id
  @application_id
end

#configObject

Returns the value of attribute config.



45
46
47
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 45

def config
  @config
end

#created_atObject

Timestamp when the flow was created.



28
29
30
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 28

def created_at
  @created_at
end

#disabled_untilObject

Timestamp until which the flow is disabled. Null when the flow is active.



31
32
33
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 31

def disabled_until
  @disabled_until
end

#event_typeObject

The event type we want to register a flow for.



40
41
42
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 40

def event_type
  @event_type
end

#idObject

ID of the integration hub flow.



19
20
21
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 19

def id
  @id
end

#instance_nameObject

Name of the integration instance.



25
26
27
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 25

def instance_name
  @instance_name
end

#integration_hub_flow_urlObject

The URL of the integration hub flow that we want to trigger for the event.



43
44
45
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 43

def integration_hub_flow_url
  @integration_hub_flow_url
end

#integration_nameObject

Name of the integration.



22
23
24
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 22

def integration_name
  @integration_name
end

#loyalty_program_idObject

ID of the loyalty program the flow is registered for.



37
38
39
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 37

def loyalty_program_id
  @loyalty_program_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 48

def self.attribute_map
  {
    :'id' => :'id',
    :'integration_name' => :'integrationName',
    :'instance_name' => :'instanceName',
    :'created_at' => :'createdAt',
    :'disabled_until' => :'disabledUntil',
    :'application_id' => :'applicationId',
    :'loyalty_program_id' => :'loyaltyProgramId',
    :'event_type' => :'eventType',
    :'integration_hub_flow_url' => :'integrationHubFlowUrl',
    :'config' => :'config'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 90

def self.openapi_nullable
  Set.new([
    :'disabled_until',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 74

def self.openapi_types
  {
    :'id' => :'Integer',
    :'integration_name' => :'String',
    :'instance_name' => :'String',
    :'created_at' => :'Time',
    :'disabled_until' => :'Time',
    :'application_id' => :'Integer',
    :'loyalty_program_id' => :'Integer',
    :'event_type' => :'String',
    :'integration_hub_flow_url' => :'String',
    :'config' => :'IntegrationHubFlowConfigResponse'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      integration_name == o.integration_name &&
      instance_name == o.instance_name &&
      created_at == o.created_at &&
      disabled_until == o.disabled_until &&
      application_id == o.application_id &&
      loyalty_program_id == o.loyalty_program_id &&
      event_type == o.event_type &&
      integration_hub_flow_url == o.integration_hub_flow_url &&
      config == o.config
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 278

def hash
  [id, integration_name, instance_name, created_at, disabled_until, application_id, loyalty_program_id, event_type, integration_hub_flow_url, config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @integration_hub_flow_url.nil?
    invalid_properties.push('invalid value for "integration_hub_flow_url", integration_hub_flow_url cannot be nil.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
196
197
198
199
200
201
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 193

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created_at.nil?
  return false if @event_type.nil?
  return false if @integration_hub_flow_url.nil?
  return false if @config.nil?
  true
end