Class: TalonOne::IntegrationHubFlowResponse

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_hub_flow_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubFlowResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubFlowResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubFlowResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  else
    self.event_type = nil
  end

  if attributes.key?(:'integration_hub_flow_url')
    self.integration_hub_flow_url = attributes[:'integration_hub_flow_url']
  else
    self.integration_hub_flow_url = nil
  end

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  else
    self.config = nil
  end
end

Instance Attribute Details

#application_idObject

ID of application the flow is registered for.



22
23
24
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 22

def application_id
  @application_id
end

#configObject

Returns the value of attribute config.



30
31
32
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 30

def config
  @config
end

#event_typeObject

The event type we want to register a flow for.



25
26
27
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 25

def event_type
  @event_type
end

#idObject

ID of the integration hub flow.



19
20
21
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 19

def id
  @id
end

#integration_hub_flow_urlObject

The URL of the integration hub flow that we want to trigger for the event.



28
29
30
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 28

def integration_hub_flow_url
  @integration_hub_flow_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 33

def self.attribute_map
  {
    :'id' => :'Id',
    :'application_id' => :'ApplicationID',
    :'event_type' => :'EventType',
    :'integration_hub_flow_url' => :'IntegrationHubFlowUrl',
    :'config' => :'Config'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 54

def self.openapi_types
  {
    :'id' => :'Integer',
    :'application_id' => :'Integer',
    :'event_type' => :'String',
    :'integration_hub_flow_url' => :'String',
    :'config' => :'IntegrationHubFlowConfigResponse'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      application_id == o.application_id &&
      event_type == o.event_type &&
      integration_hub_flow_url == o.integration_hub_flow_url &&
      config == o.config
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 210

def hash
  [id, application_id, event_type, integration_hub_flow_url, config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @integration_hub_flow_url.nil?
    invalid_properties.push('invalid value for "integration_hub_flow_url", integration_hub_flow_url cannot be nil.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/integration_hub_flow_response.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @event_type.nil?
  return false if @integration_hub_flow_url.nil?
  return false if @config.nil?
  true
end