Class: TalonOne::IntegrationResponse

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_response.rb

Overview

Contains entities that might be valuable in Talon.One integrations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/integration_response.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_profile')
    self.customer_profile = attributes[:'customer_profile']
  end

  if attributes.key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.key?(:'triggered_campaigns')
    if (value = attributes[:'triggered_campaigns']).is_a?(Array)
      self.triggered_campaigns = value
    end
  end

  if attributes.key?(:'campaign_eligibility')
    if (value = attributes[:'campaign_eligibility']).is_a?(Array)
      self.campaign_eligibility = value
    end
  end

  if attributes.key?(:'effects')
    if (value = attributes[:'effects']).is_a?(Array)
      self.effects = value
    end
  else
    self.effects = nil
  end

  if attributes.key?(:'rule_failure_reasons')
    if (value = attributes[:'rule_failure_reasons']).is_a?(Array)
      self.rule_failure_reasons = value
    end
  end

  if attributes.key?(:'created_coupons')
    if (value = attributes[:'created_coupons']).is_a?(Array)
      self.created_coupons = value
    end
  else
    self.created_coupons = nil
  end

  if attributes.key?(:'created_referrals')
    if (value = attributes[:'created_referrals']).is_a?(Array)
      self.created_referrals = value
    end
  else
    self.created_referrals = nil
  end

  if attributes.key?(:'awarded_giveaways')
    if (value = attributes[:'awarded_giveaways']).is_a?(Array)
      self.awarded_giveaways = value
    end
  end
end

Instance Attribute Details

#awarded_giveawaysObject

The giveaways that were awarded during the event processing.



44
45
46
# File 'lib/talon_one_sdk/models/integration_response.rb', line 44

def awarded_giveaways
  @awarded_giveaways
end

#campaign_eligibilityObject

A list of campaigns and their evaluation status for the current customer session. Note: - This response can only be included if the ‘dry` parameter in the query is set to `true`. - Do not include `triggeredCampaigns` or `ruleFailureReasons` in `responseContent` to avoid duplicate results.



29
30
31
# File 'lib/talon_one_sdk/models/integration_response.rb', line 29

def campaign_eligibility
  @campaign_eligibility
end

#created_couponsObject

The coupons that were created during the event processing.



38
39
40
# File 'lib/talon_one_sdk/models/integration_response.rb', line 38

def created_coupons
  @created_coupons
end

#created_referralsObject

The referrals that were created during the event processing.



41
42
43
# File 'lib/talon_one_sdk/models/integration_response.rb', line 41

def created_referrals
  @created_referrals
end

#customer_profileObject

The customer profile associated with the event.



20
21
22
# File 'lib/talon_one_sdk/models/integration_response.rb', line 20

def customer_profile
  @customer_profile
end

#effectsObject

The effects generated by the rules in your running campaigns. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).



32
33
34
# File 'lib/talon_one_sdk/models/integration_response.rb', line 32

def effects
  @effects
end

#loyaltyObject

The loyalty program status of the customer.



23
24
25
# File 'lib/talon_one_sdk/models/integration_response.rb', line 23

def loyalty
  @loyalty
end

#rule_failure_reasonsObject

The reasons why certain rules were not triggered during the event processing.



35
36
37
# File 'lib/talon_one_sdk/models/integration_response.rb', line 35

def rule_failure_reasons
  @rule_failure_reasons
end

#triggered_campaignsObject

The campaigns that were triggered as a result of processing the event.



26
27
28
# File 'lib/talon_one_sdk/models/integration_response.rb', line 26

def triggered_campaigns
  @triggered_campaigns
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/talon_one_sdk/models/integration_response.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/talon_one_sdk/models/integration_response.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/talon_one_sdk/models/integration_response.rb', line 47

def self.attribute_map
  {
    :'customer_profile' => :'customerProfile',
    :'loyalty' => :'loyalty',
    :'triggered_campaigns' => :'triggeredCampaigns',
    :'campaign_eligibility' => :'campaignEligibility',
    :'effects' => :'effects',
    :'rule_failure_reasons' => :'ruleFailureReasons',
    :'created_coupons' => :'createdCoupons',
    :'created_referrals' => :'createdReferrals',
    :'awarded_giveaways' => :'awardedGiveaways'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/talon_one_sdk/models/integration_response.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/talon_one_sdk/models/integration_response.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/talon_one_sdk/models/integration_response.rb', line 72

def self.openapi_types
  {
    :'customer_profile' => :'CustomerProfile',
    :'loyalty' => :'Loyalty',
    :'triggered_campaigns' => :'Array<Campaign>',
    :'campaign_eligibility' => :'Array<CampaignEligibility>',
    :'effects' => :'Array<Effect>',
    :'rule_failure_reasons' => :'Array<RuleFailureReason>',
    :'created_coupons' => :'Array<Coupon>',
    :'created_referrals' => :'Array<Referral>',
    :'awarded_giveaways' => :'Array<Giveaway>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/integration_response.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_profile == o.customer_profile &&
      loyalty == o.loyalty &&
      triggered_campaigns == o.triggered_campaigns &&
      campaign_eligibility == o.campaign_eligibility &&
      effects == o.effects &&
      rule_failure_reasons == o.rule_failure_reasons &&
      created_coupons == o.created_coupons &&
      created_referrals == o.created_referrals &&
      awarded_giveaways == o.awarded_giveaways
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/talon_one_sdk/models/integration_response.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/talon_one_sdk/models/integration_response.rb', line 249

def hash
  [customer_profile, loyalty, triggered_campaigns, campaign_eligibility, effects, rule_failure_reasons, created_coupons, created_referrals, awarded_giveaways].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/talon_one_sdk/models/integration_response.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effects.nil?
    invalid_properties.push('invalid value for "effects", effects cannot be nil.')
  end

  if @created_coupons.nil?
    invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.')
  end

  if @created_referrals.nil?
    invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/integration_response.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
# File 'lib/talon_one_sdk/models/integration_response.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @effects.nil?
  return false if @created_coupons.nil?
  return false if @created_referrals.nil?
  true
end