Class: TalonOne::IntegrationStateV2

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/integration_state_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationStateV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationStateV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationStateV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_profile')
    self.customer_profile = attributes[:'customer_profile']
  end

  if attributes.key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.key?(:'triggered_campaigns')
    if (value = attributes[:'triggered_campaigns']).is_a?(Array)
      self.triggered_campaigns = value
    end
  end

  if attributes.key?(:'campaign_eligibility')
    if (value = attributes[:'campaign_eligibility']).is_a?(Array)
      self.campaign_eligibility = value
    end
  end

  if attributes.key?(:'effects')
    if (value = attributes[:'effects']).is_a?(Array)
      self.effects = value
    end
  else
    self.effects = nil
  end

  if attributes.key?(:'rule_failure_reasons')
    if (value = attributes[:'rule_failure_reasons']).is_a?(Array)
      self.rule_failure_reasons = value
    end
  end

  if attributes.key?(:'created_coupons')
    if (value = attributes[:'created_coupons']).is_a?(Array)
      self.created_coupons = value
    end
  else
    self.created_coupons = nil
  end

  if attributes.key?(:'created_referrals')
    if (value = attributes[:'created_referrals']).is_a?(Array)
      self.created_referrals = value
    end
  else
    self.created_referrals = nil
  end

  if attributes.key?(:'awarded_giveaways')
    if (value = attributes[:'awarded_giveaways']).is_a?(Array)
      self.awarded_giveaways = value
    end
  end

  if attributes.key?(:'referral')
    self.referral = attributes[:'referral']
  end

  if attributes.key?(:'coupons')
    if (value = attributes[:'coupons']).is_a?(Array)
      self.coupons = value
    end
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'advanced_event')
    self.advanced_event = attributes[:'advanced_event']
  end

  if attributes.key?(:'customer_session')
    self.customer_session = attributes[:'customer_session']
  end

  if attributes.key?(:'_return')
    self._return = attributes[:'_return']
  end

  if attributes.key?(:'previous_returns')
    if (value = attributes[:'previous_returns']).is_a?(Array)
      self.previous_returns = value
    end
  end
end

Instance Attribute Details

#_returnObject

The return that was processed.



61
62
63
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 61

def _return
  @_return
end

#advanced_eventObject

The advanced event that was processed.



55
56
57
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 55

def advanced_event
  @advanced_event
end

#awarded_giveawaysObject

The giveaways that were awarded during the event processing.



43
44
45
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 43

def awarded_giveaways
  @awarded_giveaways
end

#campaign_eligibilityObject

A list of campaigns and their evaluation status for the current customer session. Note: - This response can only be included if the ‘dry` parameter in the query is set to `true`. - Do not include `triggeredCampaigns` or `ruleFailureReasons` in `responseContent` to avoid duplicate results.



28
29
30
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 28

def campaign_eligibility
  @campaign_eligibility
end

#couponsObject

The coupons that were processed.



49
50
51
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 49

def coupons
  @coupons
end

#created_couponsObject

The coupons that were created during the event processing.



37
38
39
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 37

def created_coupons
  @created_coupons
end

#created_referralsObject

The referrals that were created during the event processing.



40
41
42
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 40

def created_referrals
  @created_referrals
end

#customer_profileObject

The customer profile associated with the event.



19
20
21
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 19

def customer_profile
  @customer_profile
end

#customer_sessionObject

The session that was processed.



58
59
60
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 58

def customer_session
  @customer_session
end

#effectsObject

The effects generated by the rules in your running campaigns. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).



31
32
33
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 31

def effects
  @effects
end

#eventObject

The event that was processed.



52
53
54
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 52

def event
  @event
end

#loyaltyObject

The loyalty program status of the customer.



22
23
24
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 22

def loyalty
  @loyalty
end

#previous_returnsObject

The previous returns associated with the event.



64
65
66
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 64

def previous_returns
  @previous_returns
end

#referralObject

The referral that was processed.



46
47
48
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 46

def referral
  @referral
end

#rule_failure_reasonsObject

The reasons why certain rules were not triggered during the event processing.



34
35
36
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 34

def rule_failure_reasons
  @rule_failure_reasons
end

#triggered_campaignsObject

The campaigns that were triggered as a result of processing the event.



25
26
27
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 25

def triggered_campaigns
  @triggered_campaigns
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 67

def self.attribute_map
  {
    :'customer_profile' => :'customerProfile',
    :'loyalty' => :'loyalty',
    :'triggered_campaigns' => :'triggeredCampaigns',
    :'campaign_eligibility' => :'campaignEligibility',
    :'effects' => :'effects',
    :'rule_failure_reasons' => :'ruleFailureReasons',
    :'created_coupons' => :'createdCoupons',
    :'created_referrals' => :'createdReferrals',
    :'awarded_giveaways' => :'awardedGiveaways',
    :'referral' => :'referral',
    :'coupons' => :'coupons',
    :'event' => :'event',
    :'advanced_event' => :'advancedEvent',
    :'customer_session' => :'customerSession',
    :'_return' => :'return',
    :'previous_returns' => :'previousReturns'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 336

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



127
128
129
130
131
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 127

def self.openapi_all_of
  [
  :'IntegrationResponse'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 121

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 99

def self.openapi_types
  {
    :'customer_profile' => :'CustomerProfile',
    :'loyalty' => :'Loyalty',
    :'triggered_campaigns' => :'Array<Campaign>',
    :'campaign_eligibility' => :'Array<CampaignEligibility>',
    :'effects' => :'Array<Effect>',
    :'rule_failure_reasons' => :'Array<RuleFailureReason>',
    :'created_coupons' => :'Array<Coupon>',
    :'created_referrals' => :'Array<Referral>',
    :'awarded_giveaways' => :'Array<Giveaway>',
    :'referral' => :'InventoryReferral',
    :'coupons' => :'Array<IntegrationCoupon>',
    :'event' => :'Event',
    :'advanced_event' => :'EventV3',
    :'customer_session' => :'CustomerSessionV2',
    :'_return' => :'ModelReturn',
    :'previous_returns' => :'Array<ModelReturn>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_profile == o.customer_profile &&
      loyalty == o.loyalty &&
      triggered_campaigns == o.triggered_campaigns &&
      campaign_eligibility == o.campaign_eligibility &&
      effects == o.effects &&
      rule_failure_reasons == o.rule_failure_reasons &&
      created_coupons == o.created_coupons &&
      created_referrals == o.created_referrals &&
      awarded_giveaways == o.awarded_giveaways &&
      referral == o.referral &&
      coupons == o.coupons &&
      event == o.event &&
      advanced_event == o.advanced_event &&
      customer_session == o.customer_session &&
      _return == o._return &&
      previous_returns == o.previous_returns
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 329

def hash
  [customer_profile, loyalty, triggered_campaigns, campaign_eligibility, effects, rule_failure_reasons, created_coupons, created_referrals, awarded_giveaways, referral, coupons, event, advanced_event, customer_session, _return, previous_returns].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 240

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effects.nil?
    invalid_properties.push('invalid value for "effects", effects cannot be nil.')
  end

  if @created_coupons.nil?
    invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.')
  end

  if @created_referrals.nil?
    invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



260
261
262
263
264
265
266
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 260

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @effects.nil?
  return false if @created_coupons.nil?
  return false if @created_referrals.nil?
  true
end