Class: TalonOne::IntegrationStateV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::IntegrationStateV2
- Defined in:
- lib/talon_one_sdk/models/integration_state_v2.rb
Instance Attribute Summary collapse
-
#_return ⇒ Object
The return that was processed.
-
#advanced_event ⇒ Object
The advanced event that was processed.
-
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
-
#coupons ⇒ Object
The coupons that were processed.
-
#created_coupons ⇒ Object
The coupons that were created during the event processing.
-
#created_referrals ⇒ Object
The referrals that were created during the event processing.
-
#customer_profile ⇒ Object
The customer profile associated with the event.
-
#customer_session ⇒ Object
The session that was processed.
-
#effects ⇒ Object
The effects generated by the rules in your running campaigns.
-
#event ⇒ Object
The event that was processed.
-
#loyalty ⇒ Object
The loyalty program status of the customer.
-
#previous_returns ⇒ Object
The previous returns associated with the event.
-
#referral ⇒ Object
The referral that was processed.
-
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
-
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationStateV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationStateV2
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationStateV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationStateV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_profile') self.customer_profile = attributes[:'customer_profile'] end if attributes.key?(:'loyalty') self.loyalty = attributes[:'loyalty'] end if attributes.key?(:'triggered_campaigns') if (value = attributes[:'triggered_campaigns']).is_a?(Array) self.triggered_campaigns = value end end if attributes.key?(:'effects') if (value = attributes[:'effects']).is_a?(Array) self.effects = value end else self.effects = nil end if attributes.key?(:'rule_failure_reasons') if (value = attributes[:'rule_failure_reasons']).is_a?(Array) self.rule_failure_reasons = value end end if attributes.key?(:'created_coupons') if (value = attributes[:'created_coupons']).is_a?(Array) self.created_coupons = value end else self.created_coupons = nil end if attributes.key?(:'created_referrals') if (value = attributes[:'created_referrals']).is_a?(Array) self.created_referrals = value end else self.created_referrals = nil end if attributes.key?(:'awarded_giveaways') if (value = attributes[:'awarded_giveaways']).is_a?(Array) self.awarded_giveaways = value end end if attributes.key?(:'referral') self.referral = attributes[:'referral'] end if attributes.key?(:'coupons') if (value = attributes[:'coupons']).is_a?(Array) self.coupons = value end end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'advanced_event') self.advanced_event = attributes[:'advanced_event'] end if attributes.key?(:'customer_session') self.customer_session = attributes[:'customer_session'] end if attributes.key?(:'_return') self._return = attributes[:'_return'] end if attributes.key?(:'previous_returns') if (value = attributes[:'previous_returns']).is_a?(Array) self.previous_returns = value end end end |
Instance Attribute Details
#_return ⇒ Object
The return that was processed.
58 59 60 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 58 def _return @_return end |
#advanced_event ⇒ Object
The advanced event that was processed.
52 53 54 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 52 def advanced_event @advanced_event end |
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
40 41 42 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 40 def awarded_giveaways @awarded_giveaways end |
#coupons ⇒ Object
The coupons that were processed.
46 47 48 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 46 def coupons @coupons end |
#created_coupons ⇒ Object
The coupons that were created during the event processing.
34 35 36 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 34 def created_coupons @created_coupons end |
#created_referrals ⇒ Object
The referrals that were created during the event processing.
37 38 39 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 37 def created_referrals @created_referrals end |
#customer_profile ⇒ Object
The customer profile associated with the event.
19 20 21 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 19 def customer_profile @customer_profile end |
#customer_session ⇒ Object
The session that was processed.
55 56 57 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 55 def customer_session @customer_session end |
#effects ⇒ Object
The effects generated by the rules in your running campaigns. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).
28 29 30 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 28 def effects @effects end |
#event ⇒ Object
The event that was processed.
49 50 51 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 49 def event @event end |
#loyalty ⇒ Object
The loyalty program status of the customer.
22 23 24 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 22 def loyalty @loyalty end |
#previous_returns ⇒ Object
The previous returns associated with the event.
61 62 63 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 61 def previous_returns @previous_returns end |
#referral ⇒ Object
The referral that was processed.
43 44 45 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 43 def referral @referral end |
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
31 32 33 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 31 def rule_failure_reasons @rule_failure_reasons end |
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
25 26 27 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 25 def triggered_campaigns @triggered_campaigns end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 64 def self.attribute_map { :'customer_profile' => :'customerProfile', :'loyalty' => :'loyalty', :'triggered_campaigns' => :'triggeredCampaigns', :'effects' => :'effects', :'rule_failure_reasons' => :'ruleFailureReasons', :'created_coupons' => :'createdCoupons', :'created_referrals' => :'createdReferrals', :'awarded_giveaways' => :'awardedGiveaways', :'referral' => :'referral', :'coupons' => :'coupons', :'event' => :'event', :'advanced_event' => :'advancedEvent', :'customer_session' => :'customerSession', :'_return' => :'return', :'previous_returns' => :'previousReturns' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 324 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
122 123 124 125 126 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 122 def self.openapi_all_of [ :'IntegrationResponse' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 95 def self.openapi_types { :'customer_profile' => :'CustomerProfile', :'loyalty' => :'Loyalty', :'triggered_campaigns' => :'Array<Campaign>', :'effects' => :'Array<Effect>', :'rule_failure_reasons' => :'Array<RuleFailureReason>', :'created_coupons' => :'Array<Coupon>', :'created_referrals' => :'Array<Referral>', :'awarded_giveaways' => :'Array<Giveaway>', :'referral' => :'InventoryReferral', :'coupons' => :'Array<IntegrationCoupon>', :'event' => :'Event', :'advanced_event' => :'EventV3', :'customer_session' => :'CustomerSessionV2', :'_return' => :'ModelReturn', :'previous_returns' => :'Array<ModelReturn>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 289 def ==(o) return true if self.equal?(o) self.class == o.class && customer_profile == o.customer_profile && loyalty == o.loyalty && triggered_campaigns == o.triggered_campaigns && effects == o.effects && rule_failure_reasons == o.rule_failure_reasons && created_coupons == o.created_coupons && created_referrals == o.created_referrals && awarded_giveaways == o.awarded_giveaways && referral == o.referral && coupons == o.coupons && event == o.event && advanced_event == o.advanced_event && customer_session == o.customer_session && _return == o._return && previous_returns == o.previous_returns end |
#eql?(o) ⇒ Boolean
311 312 313 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 311 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
317 318 319 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 317 def hash [customer_profile, loyalty, triggered_campaigns, effects, rule_failure_reasons, created_coupons, created_referrals, awarded_giveaways, referral, coupons, event, advanced_event, customer_session, _return, previous_returns].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 229 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @effects.nil? invalid_properties.push('invalid value for "effects", effects cannot be nil.') end if @created_coupons.nil? invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.') end if @created_referrals.nil? invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 346 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
249 250 251 252 253 254 255 |
# File 'lib/talon_one_sdk/models/integration_state_v2.rb', line 249 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @effects.nil? return false if @created_coupons.nil? return false if @created_referrals.nil? true end |