Class: TalonOne::InventoryCoupon
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::InventoryCoupon
- Defined in:
- lib/talon_one_sdk/models/inventory_coupon.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Custom attributes associated with this coupon.
-
#batch_id ⇒ Object
The id of the batch the coupon belongs to.
-
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
-
#created ⇒ Object
The time the coupon was created.
-
#discount_counter ⇒ Object
The amount of discounts given on rules redeeming this coupon.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#discount_remainder ⇒ Object
The remaining discount this coupon can give.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#id ⇒ Object
The internal ID of the coupon.
-
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
-
#import_id ⇒ Object
The ID of the Import which created this coupon.
-
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
-
#limits ⇒ Object
Limits configuration for a coupon.
-
#profile_redemption_count ⇒ Object
The number of times the coupon was redeemed by the profile.
-
#recipient_integration_id ⇒ Object
The Integration ID of the customer that is allowed to redeem this coupon.
-
#referral_id ⇒ Object
The integration ID of the referring customer (if any) for whom this coupon was created as an effect.
-
#reservation ⇒ Object
Defines the reservation type: - ‘true`: The coupon can be reserved for multiple customers.
-
#reservation_counter ⇒ Object
The number of times this coupon has been reserved.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#state ⇒ Object
Can be: - ‘active`: The coupon can be used.
-
#usage_counter ⇒ Object
The number of times the coupon has been successfully redeemed.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
-
#value ⇒ Object
The coupon code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InventoryCoupon
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InventoryCoupon
Initializes the object
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 175 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::InventoryCoupon` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::InventoryCoupon`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'usage_counter') self.usage_counter = attributes[:'usage_counter'] else self.usage_counter = nil end if attributes.key?(:'discount_counter') self.discount_counter = attributes[:'discount_counter'] end if attributes.key?(:'discount_remainder') self.discount_remainder = attributes[:'discount_remainder'] end if attributes.key?(:'reservation_counter') self.reservation_counter = attributes[:'reservation_counter'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'referral_id') self.referral_id = attributes[:'referral_id'] end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] end if attributes.key?(:'import_id') self.import_id = attributes[:'import_id'] end if attributes.key?(:'reservation') self.reservation = attributes[:'reservation'] else self.reservation = true end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end if attributes.key?(:'is_reservation_mandatory') self.is_reservation_mandatory = attributes[:'is_reservation_mandatory'] else self.is_reservation_mandatory = false end if attributes.key?(:'implicitly_reserved') self.implicitly_reserved = attributes[:'implicitly_reserved'] end if attributes.key?(:'profile_redemption_count') self.profile_redemption_count = attributes[:'profile_redemption_count'] else self.profile_redemption_count = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end end |
Instance Attribute Details
#attributes ⇒ Object
Custom attributes associated with this coupon.
61 62 63 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 61 def attributes @attributes end |
#batch_id ⇒ Object
The id of the batch the coupon belongs to.
76 77 78 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 76 def batch_id @batch_id end |
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 25 def campaign_id @campaign_id end |
#created ⇒ Object
The time the coupon was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 22 def created @created end |
#discount_counter ⇒ Object
The amount of discounts given on rules redeeming this coupon. Only usable if a coupon discount budget was set for this coupon.
52 53 54 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 52 def discount_counter @discount_counter end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
34 35 36 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 34 def discount_limit @discount_limit end |
#discount_remainder ⇒ Object
The remaining discount this coupon can give.
55 56 57 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 55 def discount_remainder @discount_remainder end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
43 44 45 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 43 def expiry_date @expiry_date end |
#id ⇒ Object
The internal ID of the coupon.
19 20 21 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 19 def id @id end |
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
82 83 84 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 82 def implicitly_reserved @implicitly_reserved end |
#import_id ⇒ Object
The ID of the Import which created this coupon.
70 71 72 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 70 def import_id @import_id end |
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
79 80 81 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 79 def is_reservation_mandatory @is_reservation_mandatory end |
#limits ⇒ Object
Limits configuration for a coupon. These limits will override the limits set from the campaign. Note: Only usable when creating a single coupon which is not tied to a specific recipient. Only per-profile limits are allowed to be configured.
46 47 48 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 46 def limits @limits end |
#profile_redemption_count ⇒ Object
The number of times the coupon was redeemed by the profile.
85 86 87 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 85 def profile_redemption_count @profile_redemption_count end |
#recipient_integration_id ⇒ Object
The Integration ID of the customer that is allowed to redeem this coupon.
67 68 69 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 67 def recipient_integration_id @recipient_integration_id end |
#referral_id ⇒ Object
The integration ID of the referring customer (if any) for whom this coupon was created as an effect.
64 65 66 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 64 def referral_id @referral_id end |
#reservation ⇒ Object
Defines the reservation type: - ‘true`: The coupon can be reserved for multiple customers. - `false`: The coupon can be reserved only for one customer. It is a personal code.
73 74 75 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 73 def reservation @reservation end |
#reservation_counter ⇒ Object
The number of times this coupon has been reserved.
58 59 60 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 58 def reservation_counter @reservation_counter end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
37 38 39 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 37 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
40 41 42 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 40 def start_date @start_date end |
#state ⇒ Object
Can be: - ‘active`: The coupon can be used. It is a reserved coupon that is not pending, used, or expired, and it has a non-exhausted limit counter. Note: This coupon state is returned for [scheduled campaigns](docs.talon.one/docs/product/campaigns/settings/managing-campaign-schedule), but the coupon cannot be used until the campaign is running. - `used`: The coupon has been redeemed and cannot be used again. It is not pending and has reached its redemption limit or was redeemed by the profile before expiration. - `expired`: The coupon was never redeemed, and it is now expired. It is non-pending, non-active, and non-used by the profile. - `pending`: The coupon will be usable in the future. - `disabled`: The coupon is part of a non-active campaign.
88 89 90 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 88 def state @state end |
#usage_counter ⇒ Object
The number of times the coupon has been successfully redeemed.
49 50 51 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 49 def usage_counter @usage_counter end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
31 32 33 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 31 def usage_limit @usage_limit end |
#value ⇒ Object
The coupon code.
28 29 30 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 28 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
121 122 123 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 121 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
126 127 128 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 126 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 91 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'campaign_id' => :'campaignId', :'value' => :'value', :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'limits' => :'limits', :'usage_counter' => :'usageCounter', :'discount_counter' => :'discountCounter', :'discount_remainder' => :'discountRemainder', :'reservation_counter' => :'reservationCounter', :'attributes' => :'attributes', :'referral_id' => :'referralId', :'recipient_integration_id' => :'recipientIntegrationId', :'import_id' => :'importId', :'reservation' => :'reservation', :'batch_id' => :'batchId', :'is_reservation_mandatory' => :'isReservationMandatory', :'implicitly_reserved' => :'implicitlyReserved', :'profile_redemption_count' => :'profileRedemptionCount', :'state' => :'state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 577 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
167 168 169 170 171 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 167 def self.openapi_all_of [ :'Coupon' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
161 162 163 164 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 161 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 131 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'campaign_id' => :'Integer', :'value' => :'String', :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'limits' => :'Array<LimitConfig>', :'usage_counter' => :'Integer', :'discount_counter' => :'Float', :'discount_remainder' => :'Float', :'reservation_counter' => :'Float', :'attributes' => :'Object', :'referral_id' => :'Integer', :'recipient_integration_id' => :'String', :'import_id' => :'Integer', :'reservation' => :'Boolean', :'batch_id' => :'String', :'is_reservation_mandatory' => :'Boolean', :'implicitly_reserved' => :'Boolean', :'profile_redemption_count' => :'Integer', :'state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 533 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && campaign_id == o.campaign_id && value == o.value && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && limits == o.limits && usage_counter == o.usage_counter && discount_counter == o.discount_counter && discount_remainder == o.discount_remainder && reservation_counter == o.reservation_counter && attributes == o.attributes && referral_id == o.referral_id && recipient_integration_id == o.recipient_integration_id && import_id == o.import_id && reservation == o.reservation && batch_id == o.batch_id && is_reservation_mandatory == o.is_reservation_mandatory && implicitly_reserved == o.implicitly_reserved && profile_redemption_count == o.profile_redemption_count && state == o.state end |
#eql?(o) ⇒ Boolean
564 565 566 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 564 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
570 571 572 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 570 def hash [id, created, campaign_id, value, usage_limit, discount_limit, reservation_limit, start_date, expiry_date, limits, usage_counter, discount_counter, discount_remainder, reservation_counter, attributes, referral_id, recipient_integration_id, import_id, reservation, batch_id, is_reservation_mandatory, implicitly_reserved, profile_redemption_count, state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 306 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if !@value.nil? && @value.to_s.length < 4 invalid_properties.push('invalid value for "value", the character length must be greater than or equal to 4.') end if !@usage_limit.nil? && @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if !@usage_limit.nil? && @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end if @usage_counter.nil? invalid_properties.push('invalid value for "usage_counter", usage_counter cannot be nil.') end if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.') end if @profile_redemption_count.nil? invalid_properties.push('invalid value for "profile_redemption_count", profile_redemption_count cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 599 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/talon_one_sdk/models/inventory_coupon.rb', line 370 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @campaign_id.nil? return false if !@value.nil? && @value.to_s.length < 4 return false if !@usage_limit.nil? && @usage_limit > 999999 return false if !@usage_limit.nil? && @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 return false if @usage_counter.nil? return false if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 return false if @profile_redemption_count.nil? return false if @state.nil? true end |