Class: TalonOne::LedgerEntry
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LedgerEntry
- Defined in:
- lib/talon_one_sdk/models/ledger_entry.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the Talon.One account that owns this profile.
-
#amount ⇒ Object
Amount of loyalty points.
-
#created ⇒ Object
The time this entity was created.
-
#event_id ⇒ Object
ID of the related event.
-
#expiry_date ⇒ Object
Expiration date of the points.
-
#id ⇒ Object
The internal ID of this entity.
-
#loyalty_program_id ⇒ Object
ID of the ledger.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#reason ⇒ Object
reason for awarding/deducting points.
-
#reference_id ⇒ Object
The ID of the balancing ledgerEntry.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LedgerEntry
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LedgerEntry
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LedgerEntry` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LedgerEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] else self.loyalty_program_id = nil end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] else self.reason = nil end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] else self.expiry_date = nil end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the Talon.One account that owns this profile.
28 29 30 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 28 def account_id @account_id end |
#amount ⇒ Object
Amount of loyalty points.
37 38 39 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 37 def amount @amount end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 22 def created @created end |
#event_id ⇒ Object
ID of the related event.
34 35 36 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 34 def event_id @event_id end |
#expiry_date ⇒ Object
Expiration date of the points.
43 44 45 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 43 def expiry_date @expiry_date end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 19 def id @id end |
#loyalty_program_id ⇒ Object
ID of the ledger.
31 32 33 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 31 def loyalty_program_id @loyalty_program_id end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
25 26 27 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 25 def profile_id @profile_id end |
#reason ⇒ Object
reason for awarding/deducting points.
40 41 42 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 40 def reason @reason end |
#reference_id ⇒ Object
The ID of the balancing ledgerEntry.
46 47 48 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 46 def reference_id @reference_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 49 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'profile_id' => :'profileId', :'account_id' => :'accountId', :'loyalty_program_id' => :'loyaltyProgramId', :'event_id' => :'eventId', :'amount' => :'amount', :'reason' => :'reason', :'expiry_date' => :'expiryDate', :'reference_id' => :'referenceId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 344 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
97 98 99 100 101 102 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 97 def self.openapi_all_of [ :'Entity', :'IntegrationProfileEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 75 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'profile_id' => :'String', :'account_id' => :'Integer', :'loyalty_program_id' => :'Integer', :'event_id' => :'Integer', :'amount' => :'Integer', :'reason' => :'String', :'expiry_date' => :'Time', :'reference_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 314 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && profile_id == o.profile_id && account_id == o.account_id && loyalty_program_id == o.loyalty_program_id && event_id == o.event_id && amount == o.amount && reason == o.reason && expiry_date == o.expiry_date && reference_id == o.reference_id end |
#eql?(o) ⇒ Boolean
331 332 333 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 331 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
337 338 339 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 337 def hash [id, created, profile_id, account_id, loyalty_program_id, event_id, amount, reason, expiry_date, reference_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @loyalty_program_id.nil? invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.') end if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end if @expiry_date.nil? invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 366 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/talon_one_sdk/models/ledger_entry.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @account_id.nil? return false if @loyalty_program_id.nil? return false if @event_id.nil? return false if @amount.nil? return false if @reason.nil? return false if @expiry_date.nil? true end |