Class: TalonOne::LimitCounter
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LimitCounter
- Defined in:
- lib/talon_one_sdk/models/limit_counter.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#action ⇒ Object
The limitable action of the limit counter.
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
-
#counter ⇒ Object
The current value for this limit counter.
-
#coupon_id ⇒ Object
The internal coupon ID for which this limit counter is used.
-
#coupon_value ⇒ Object
The coupon value for which this limit counter is used.
-
#id ⇒ Object
Unique ID for this entity.
-
#identifier ⇒ Object
The arbitrary identifier for which this limit counter is used.
-
#limit ⇒ Object
The highest possible value for this limit counter.
-
#period ⇒ Object
The time period for which this limit counter is used.
-
#profile_id ⇒ Object
The profile ID for which this limit counter is used.
-
#profile_integration_id ⇒ Object
The profile integration ID for which this limit counter is used.
-
#referral_id ⇒ Object
The referral ID for which this limit counter is used.
-
#referral_value ⇒ Object
The referral value for which this limit counter is used.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LimitCounter
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LimitCounter
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LimitCounter` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LimitCounter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'profile_integration_id') self.profile_integration_id = attributes[:'profile_integration_id'] end if attributes.key?(:'coupon_id') self.coupon_id = attributes[:'coupon_id'] end if attributes.key?(:'coupon_value') self.coupon_value = attributes[:'coupon_value'] end if attributes.key?(:'referral_id') self.referral_id = attributes[:'referral_id'] end if attributes.key?(:'referral_value') self.referral_value = attributes[:'referral_value'] end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'period') self.period = attributes[:'period'] end if attributes.key?(:'limit') self.limit = attributes[:'limit'] else self.limit = nil end if attributes.key?(:'counter') self.counter = attributes[:'counter'] else self.counter = nil end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 25 def account_id @account_id end |
#action ⇒ Object
The limitable action of the limit counter.
31 32 33 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 31 def action @action end |
#application_id ⇒ Object
The ID of the Application that owns this entity.
22 23 24 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 22 def application_id @application_id end |
#campaign_id ⇒ Object
The ID of the campaign that owns this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 19 def campaign_id @campaign_id end |
#counter ⇒ Object
The current value for this limit counter.
61 62 63 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 61 def counter @counter end |
#coupon_id ⇒ Object
The internal coupon ID for which this limit counter is used.
40 41 42 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 40 def coupon_id @coupon_id end |
#coupon_value ⇒ Object
The coupon value for which this limit counter is used.
43 44 45 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 43 def coupon_value @coupon_value end |
#id ⇒ Object
Unique ID for this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 28 def id @id end |
#identifier ⇒ Object
The arbitrary identifier for which this limit counter is used.
52 53 54 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 52 def identifier @identifier end |
#limit ⇒ Object
The highest possible value for this limit counter.
58 59 60 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 58 def limit @limit end |
#period ⇒ Object
The time period for which this limit counter is used.
55 56 57 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 55 def period @period end |
#profile_id ⇒ Object
The profile ID for which this limit counter is used.
34 35 36 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 34 def profile_id @profile_id end |
#profile_integration_id ⇒ Object
The profile integration ID for which this limit counter is used.
37 38 39 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 37 def profile_integration_id @profile_integration_id end |
#referral_id ⇒ Object
The referral ID for which this limit counter is used.
46 47 48 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 46 def referral_id @referral_id end |
#referral_value ⇒ Object
The referral value for which this limit counter is used.
49 50 51 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 49 def referral_value @referral_value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 64 def self.attribute_map { :'campaign_id' => :'campaignId', :'application_id' => :'applicationId', :'account_id' => :'accountId', :'id' => :'id', :'action' => :'action', :'profile_id' => :'profileId', :'profile_integration_id' => :'profileIntegrationId', :'coupon_id' => :'couponId', :'coupon_value' => :'couponValue', :'referral_id' => :'referralId', :'referral_value' => :'referralValue', :'identifier' => :'identifier', :'period' => :'period', :'limit' => :'limit', :'counter' => :'counter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 397 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
122 123 124 125 126 127 128 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 122 def self.openapi_all_of [ :'AccountEntity', :'ApplicationEntity', :'CampaignEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 95 def self.openapi_types { :'campaign_id' => :'Integer', :'application_id' => :'Integer', :'account_id' => :'Integer', :'id' => :'Integer', :'action' => :'String', :'profile_id' => :'Integer', :'profile_integration_id' => :'String', :'coupon_id' => :'Integer', :'coupon_value' => :'String', :'referral_id' => :'Integer', :'referral_value' => :'String', :'identifier' => :'String', :'period' => :'String', :'limit' => :'Float', :'counter' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 362 def ==(o) return true if self.equal?(o) self.class == o.class && campaign_id == o.campaign_id && application_id == o.application_id && account_id == o.account_id && id == o.id && action == o.action && profile_id == o.profile_id && profile_integration_id == o.profile_integration_id && coupon_id == o.coupon_id && coupon_value == o.coupon_value && referral_id == o.referral_id && referral_value == o.referral_value && identifier == o.identifier && period == o.period && limit == o.limit && counter == o.counter end |
#eql?(o) ⇒ Boolean
384 385 386 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 384 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
390 391 392 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 390 def hash [campaign_id, application_id, account_id, id, action, profile_id, profile_integration_id, coupon_id, coupon_value, referral_id, referral_value, identifier, period, limit, counter].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 223 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if !@profile_integration_id.nil? && @profile_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "profile_integration_id", the character length must be smaller than or equal to 1000.') end if @limit.nil? invalid_properties.push('invalid value for "limit", limit cannot be nil.') end if @counter.nil? invalid_properties.push('invalid value for "counter", counter cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 419 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/talon_one_sdk/models/limit_counter.rb', line 263 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @campaign_id.nil? return false if @application_id.nil? return false if @account_id.nil? return false if @id.nil? return false if @action.nil? return false if !@profile_integration_id.nil? && @profile_integration_id.to_s.length > 1000 return false if @limit.nil? return false if @counter.nil? true end |