Class: TalonOne::LoyaltyCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LoyaltyCard
- Defined in:
- lib/talon_one_sdk/models/loyalty_card.rb
Instance Attribute Summary collapse
-
#batch_id ⇒ Object
The ID of the batch in which the loyalty card was created.
-
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
-
#created ⇒ Object
The time this entity was created.
-
#id ⇒ Object
The internal ID of this entity.
-
#identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
-
#ledger ⇒ Object
Displays point balances of the card in the main ledger of the loyalty program.
-
#modified ⇒ Object
Timestamp of the most recent update of the loyalty card.
-
#new_card_identifier ⇒ Object
The identifier of the card to which the points were transferred.
-
#old_card_identifier ⇒ Object
The identifier of the card from which the points were transferred.
-
#profiles ⇒ Object
Integration IDs of the customers profiles linked to the card.
-
#program_id ⇒ Object
The ID of the loyalty program that owns this entity.
-
#program_name ⇒ Object
The integration name of the loyalty program that owns this entity.
-
#program_title ⇒ Object
The Campaign Manager-displayed name of the loyalty program that owns this entity.
-
#status ⇒ Object
Status of the loyalty card.
-
#subledgers ⇒ Object
Displays point balances of the card in the subledgers of the loyalty program.
-
#users_per_card_limit ⇒ Object
The max amount of customer profiles that can be linked to the card.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoyaltyCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LoyaltyCard
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] else self.program_id = nil end if attributes.key?(:'program_name') self.program_name = attributes[:'program_name'] end if attributes.key?(:'program_title') self.program_title = attributes[:'program_title'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'block_reason') self.block_reason = attributes[:'block_reason'] end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'users_per_card_limit') self.users_per_card_limit = attributes[:'users_per_card_limit'] else self.users_per_card_limit = nil end if attributes.key?(:'profiles') if (value = attributes[:'profiles']).is_a?(Array) self.profiles = value end end if attributes.key?(:'ledger') self.ledger = attributes[:'ledger'] end if attributes.key?(:'subledgers') if (value = attributes[:'subledgers']).is_a?(Hash) self.subledgers = value end end if attributes.key?(:'modified') self.modified = attributes[:'modified'] end if attributes.key?(:'old_card_identifier') self.old_card_identifier = attributes[:'old_card_identifier'] end if attributes.key?(:'new_card_identifier') self.new_card_identifier = attributes[:'new_card_identifier'] end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end end |
Instance Attribute Details
#batch_id ⇒ Object
The ID of the batch in which the loyalty card was created.
64 65 66 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 64 def batch_id @batch_id end |
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
37 38 39 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 37 def block_reason @block_reason end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 22 def created @created end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 19 def id @id end |
#identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
40 41 42 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 40 def identifier @identifier end |
#ledger ⇒ Object
Displays point balances of the card in the main ledger of the loyalty program.
49 50 51 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 49 def ledger @ledger end |
#modified ⇒ Object
Timestamp of the most recent update of the loyalty card.
55 56 57 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 55 def modified @modified end |
#new_card_identifier ⇒ Object
The identifier of the card to which the points were transferred.
61 62 63 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 61 def new_card_identifier @new_card_identifier end |
#old_card_identifier ⇒ Object
The identifier of the card from which the points were transferred.
58 59 60 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 58 def old_card_identifier @old_card_identifier end |
#profiles ⇒ Object
Integration IDs of the customers profiles linked to the card.
46 47 48 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 46 def profiles @profiles end |
#program_id ⇒ Object
The ID of the loyalty program that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 25 def program_id @program_id end |
#program_name ⇒ Object
The integration name of the loyalty program that owns this entity.
28 29 30 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 28 def program_name @program_name end |
#program_title ⇒ Object
The Campaign Manager-displayed name of the loyalty program that owns this entity.
31 32 33 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 31 def program_title @program_title end |
#status ⇒ Object
Status of the loyalty card. Can be ‘active` or `inactive`.
34 35 36 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 34 def status @status end |
#subledgers ⇒ Object
Displays point balances of the card in the subledgers of the loyalty program.
52 53 54 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 52 def subledgers @subledgers end |
#users_per_card_limit ⇒ Object
The max amount of customer profiles that can be linked to the card. 0 means unlimited.
43 44 45 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 43 def users_per_card_limit @users_per_card_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 67 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'program_id' => :'programID', :'program_name' => :'programName', :'program_title' => :'programTitle', :'status' => :'status', :'block_reason' => :'blockReason', :'identifier' => :'identifier', :'users_per_card_limit' => :'usersPerCardLimit', :'profiles' => :'profiles', :'ledger' => :'ledger', :'subledgers' => :'subledgers', :'modified' => :'modified', :'old_card_identifier' => :'oldCardIdentifier', :'new_card_identifier' => :'newCardIdentifier', :'batch_id' => :'batchId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 491 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
127 128 129 130 131 132 133 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 127 def self.openapi_all_of [ :'Entity', :'LoyaltyProgramEntity', :'UpdateLoyaltyCard' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 99 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'program_id' => :'Integer', :'program_name' => :'String', :'program_title' => :'String', :'status' => :'String', :'block_reason' => :'String', :'identifier' => :'String', :'users_per_card_limit' => :'Integer', :'profiles' => :'Array<LoyaltyCardProfileRegistration>', :'ledger' => :'LedgerInfo', :'subledgers' => :'Hash<String, LedgerInfo>', :'modified' => :'Time', :'old_card_identifier' => :'String', :'new_card_identifier' => :'String', :'batch_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 455 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && program_id == o.program_id && program_name == o.program_name && program_title == o.program_title && status == o.status && block_reason == o.block_reason && identifier == o.identifier && users_per_card_limit == o.users_per_card_limit && profiles == o.profiles && ledger == o.ledger && subledgers == o.subledgers && modified == o.modified && old_card_identifier == o.old_card_identifier && new_card_identifier == o.new_card_identifier && batch_id == o.batch_id end |
#eql?(o) ⇒ Boolean
478 479 480 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 478 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
484 485 486 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 484 def hash [id, created, program_id, program_name, program_title, status, block_reason, identifier, users_per_card_limit, profiles, ledger, subledgers, modified, old_card_identifier, new_card_identifier, batch_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 234 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @program_id.nil? invalid_properties.push('invalid value for "program_id", program_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @identifier.to_s.length > 108 invalid_properties.push('invalid value for "identifier", the character length must be smaller than or equal to 108.') end if @identifier.to_s.length < 4 invalid_properties.push('invalid value for "identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if @identifier !~ pattern invalid_properties.push("invalid value for \"identifier\", must conform to the pattern #{pattern}.") end if @users_per_card_limit.nil? invalid_properties.push('invalid value for "users_per_card_limit", users_per_card_limit cannot be nil.') end if @users_per_card_limit < 0 invalid_properties.push('invalid value for "users_per_card_limit", must be greater than or equal to 0.') end if !@old_card_identifier.nil? && @old_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "old_card_identifier", the character length must be smaller than or equal to 108.') end if !@old_card_identifier.nil? && @old_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "old_card_identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@old_card_identifier.nil? && @old_card_identifier !~ pattern invalid_properties.push("invalid value for \"old_card_identifier\", must conform to the pattern #{pattern}.") end if !@new_card_identifier.nil? && @new_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "new_card_identifier", the character length must be smaller than or equal to 108.') end if !@new_card_identifier.nil? && @new_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "new_card_identifier", the character length must be greater than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@new_card_identifier.nil? && @new_card_identifier !~ pattern invalid_properties.push("invalid value for \"new_card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 513 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/talon_one_sdk/models/loyalty_card.rb', line 309 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @program_id.nil? return false if @status.nil? return false if @identifier.nil? return false if @identifier.to_s.length > 108 return false if @identifier.to_s.length < 4 return false if @identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) return false if @users_per_card_limit.nil? return false if @users_per_card_limit < 0 return false if !@old_card_identifier.nil? && @old_card_identifier.to_s.length > 108 return false if !@old_card_identifier.nil? && @old_card_identifier.to_s.length < 4 return false if !@old_card_identifier.nil? && @old_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) return false if !@new_card_identifier.nil? && @new_card_identifier.to_s.length > 108 return false if !@new_card_identifier.nil? && @new_card_identifier.to_s.length < 4 return false if !@new_card_identifier.nil? && @new_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |