Class: TalonOne::LoyaltyProgramBalance
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::LoyaltyProgramBalance
- Defined in:
- lib/talon_one_sdk/models/loyalty_program_balance.rb
Overview
The balance in a Loyalty Program for some Customer.
Instance Attribute Summary collapse
-
#current_balance ⇒ Object
Sum of currently active points.
-
#expired_balance ⇒ Object
DEPRECATED Value is shown as 0.
-
#negative_balance ⇒ Object
Sum of negative points.
-
#pending_balance ⇒ Object
Sum of pending points.
-
#spent_balance ⇒ Object
DEPRECATED Value is shown as 0.
-
#tentative_current_balance ⇒ Object
The tentative points balance, reflecting the ‘currentBalance` and all point additions and deductions within the current open customer session.
-
#tentative_negative_balance ⇒ Object
The tentative negative balance after all additions and deductions from the current customer session are applied to ‘negativeBalance`.
-
#tentative_pending_balance ⇒ Object
The tentative points balance, reflecting the ‘pendingBalance` and all point additions with a future activation date within the current open customer session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoyaltyProgramBalance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LoyaltyProgramBalance
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyProgramBalance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyProgramBalance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'current_balance') self.current_balance = attributes[:'current_balance'] else self.current_balance = nil end if attributes.key?(:'pending_balance') self.pending_balance = attributes[:'pending_balance'] else self.pending_balance = nil end if attributes.key?(:'negative_balance') self.negative_balance = attributes[:'negative_balance'] end if attributes.key?(:'expired_balance') self.expired_balance = attributes[:'expired_balance'] else self.expired_balance = nil end if attributes.key?(:'spent_balance') self.spent_balance = attributes[:'spent_balance'] else self.spent_balance = nil end if attributes.key?(:'tentative_current_balance') self.tentative_current_balance = attributes[:'tentative_current_balance'] else self.tentative_current_balance = nil end if attributes.key?(:'tentative_pending_balance') self.tentative_pending_balance = attributes[:'tentative_pending_balance'] end if attributes.key?(:'tentative_negative_balance') self.tentative_negative_balance = attributes[:'tentative_negative_balance'] end end |
Instance Attribute Details
#current_balance ⇒ Object
Sum of currently active points.
20 21 22 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 20 def current_balance @current_balance end |
#expired_balance ⇒ Object
DEPRECATED Value is shown as 0.
29 30 31 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 29 def expired_balance @expired_balance end |
#negative_balance ⇒ Object
Sum of negative points. This implies that ‘currentBalance` is `0`.
26 27 28 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 26 def negative_balance @negative_balance end |
#pending_balance ⇒ Object
Sum of pending points.
23 24 25 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 23 def pending_balance @pending_balance end |
#spent_balance ⇒ Object
DEPRECATED Value is shown as 0.
32 33 34 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 32 def spent_balance @spent_balance end |
#tentative_current_balance ⇒ Object
The tentative points balance, reflecting the ‘currentBalance` and all point additions and deductions within the current open customer session. When the session is closed, the effects are applied and the `currentBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.
35 36 37 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 35 def tentative_current_balance @tentative_current_balance end |
#tentative_negative_balance ⇒ Object
The tentative negative balance after all additions and deductions from the current customer session are applied to ‘negativeBalance`. When the session is closed, the tentative effects are applied and `negativeBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.
41 42 43 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 41 def tentative_negative_balance @tentative_negative_balance end |
#tentative_pending_balance ⇒ Object
The tentative points balance, reflecting the ‘pendingBalance` and all point additions with a future activation date within the current open customer session. When the session is closed, the effects are applied and the `pendingBalance` is updated to this value. Note: Tentative balances are specific to the current session and do not take into account other open sessions for the given customer.
38 39 40 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 38 def tentative_pending_balance @tentative_pending_balance end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 44 def self.attribute_map { :'current_balance' => :'currentBalance', :'pending_balance' => :'pendingBalance', :'negative_balance' => :'negativeBalance', :'expired_balance' => :'expiredBalance', :'spent_balance' => :'spentBalance', :'tentative_current_balance' => :'tentativeCurrentBalance', :'tentative_pending_balance' => :'tentativePendingBalance', :'tentative_negative_balance' => :'tentativeNegativeBalance' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 68 def self.openapi_types { :'current_balance' => :'Float', :'pending_balance' => :'Float', :'negative_balance' => :'Float', :'expired_balance' => :'Float', :'spent_balance' => :'Float', :'tentative_current_balance' => :'Float', :'tentative_pending_balance' => :'Float', :'tentative_negative_balance' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && current_balance == o.current_balance && pending_balance == o.pending_balance && negative_balance == o.negative_balance && expired_balance == o.expired_balance && spent_balance == o.spent_balance && tentative_current_balance == o.tentative_current_balance && tentative_pending_balance == o.tentative_pending_balance && tentative_negative_balance == o.tentative_negative_balance end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 259 def hash [current_balance, pending_balance, negative_balance, expired_balance, spent_balance, tentative_current_balance, tentative_pending_balance, tentative_negative_balance].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @current_balance.nil? invalid_properties.push('invalid value for "current_balance", current_balance cannot be nil.') end if @pending_balance.nil? invalid_properties.push('invalid value for "pending_balance", pending_balance cannot be nil.') end if @expired_balance.nil? invalid_properties.push('invalid value for "expired_balance", expired_balance cannot be nil.') end if @spent_balance.nil? invalid_properties.push('invalid value for "spent_balance", spent_balance cannot be nil.') end if @tentative_current_balance.nil? invalid_properties.push('invalid value for "tentative_current_balance", tentative_current_balance cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 184 |
# File 'lib/talon_one_sdk/models/loyalty_program_balance.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @current_balance.nil? return false if @pending_balance.nil? return false if @expired_balance.nil? return false if @spent_balance.nil? return false if @tentative_current_balance.nil? true end |