Class: TalonOne::MessageLogEntry
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::MessageLogEntry
- Defined in:
- lib/talon_one_sdk/models/message_log_entry.rb
Overview
Message Log.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Identifier of the Application.
-
#campaign_id ⇒ Object
Identifier of the campaign.
-
#change_type ⇒ Object
Type of change that triggered the notification.
-
#created_at ⇒ Object
Timestamp when the log entry was created.
-
#entity_type ⇒ Object
The entity type the log is related to.
-
#id ⇒ Object
Unique identifier of the message.
-
#loyalty_program_id ⇒ Object
Identifier of the loyalty program.
-
#notification_id ⇒ Object
ID of the notification.
-
#notification_name ⇒ Object
The name of the notification.
-
#request ⇒ Object
Returns the value of attribute request.
-
#response ⇒ Object
Returns the value of attribute response.
-
#service ⇒ Object
Name of the service that generated the log entry.
-
#url ⇒ Object
The target URL of the request.
-
#webhook_id ⇒ Object
ID of the webhook.
-
#webhook_name ⇒ Object
The name of the webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MessageLogEntry
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MessageLogEntry
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MessageLogEntry` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MessageLogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'service') self.service = attributes[:'service'] else self.service = nil end if attributes.key?(:'change_type') self.change_type = attributes[:'change_type'] end if attributes.key?(:'notification_id') self.notification_id = attributes[:'notification_id'] end if attributes.key?(:'notification_name') self.notification_name = attributes[:'notification_name'] end if attributes.key?(:'webhook_id') self.webhook_id = attributes[:'webhook_id'] end if attributes.key?(:'webhook_name') self.webhook_name = attributes[:'webhook_name'] end if attributes.key?(:'request') self.request = attributes[:'request'] end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] else self.entity_type = nil end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end end |
Instance Attribute Details
#application_id ⇒ Object
Identifier of the Application.
54 55 56 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 54 def application_id @application_id end |
#campaign_id ⇒ Object
Identifier of the campaign.
60 61 62 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 60 def campaign_id @campaign_id end |
#change_type ⇒ Object
Type of change that triggered the notification.
26 27 28 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 26 def change_type @change_type end |
#created_at ⇒ Object
Timestamp when the log entry was created.
45 46 47 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 45 def created_at @created_at end |
#entity_type ⇒ Object
The entity type the log is related to.
48 49 50 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 48 def entity_type @entity_type end |
#id ⇒ Object
Unique identifier of the message.
20 21 22 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 20 def id @id end |
#loyalty_program_id ⇒ Object
Identifier of the loyalty program.
57 58 59 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 57 def loyalty_program_id @loyalty_program_id end |
#notification_id ⇒ Object
ID of the notification.
29 30 31 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 29 def notification_id @notification_id end |
#notification_name ⇒ Object
The name of the notification.
32 33 34 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 32 def notification_name @notification_name end |
#request ⇒ Object
Returns the value of attribute request.
40 41 42 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 40 def request @request end |
#response ⇒ Object
Returns the value of attribute response.
42 43 44 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 42 def response @response end |
#service ⇒ Object
Name of the service that generated the log entry.
23 24 25 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 23 def service @service end |
#url ⇒ Object
The target URL of the request.
51 52 53 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 51 def url @url end |
#webhook_id ⇒ Object
ID of the webhook.
35 36 37 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 35 def webhook_id @webhook_id end |
#webhook_name ⇒ Object
The name of the webhook.
38 39 40 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 38 def webhook_name @webhook_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
106 107 108 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 106 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
111 112 113 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 111 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 85 def self.attribute_map { :'id' => :'id', :'service' => :'service', :'change_type' => :'changeType', :'notification_id' => :'notificationId', :'notification_name' => :'notificationName', :'webhook_id' => :'webhookId', :'webhook_name' => :'webhookName', :'request' => :'request', :'response' => :'response', :'created_at' => :'createdAt', :'entity_type' => :'entityType', :'url' => :'url', :'application_id' => :'applicationId', :'loyalty_program_id' => :'loyaltyProgramId', :'campaign_id' => :'campaignId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 398 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 137 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 116 def self.openapi_types { :'id' => :'String', :'service' => :'String', :'change_type' => :'String', :'notification_id' => :'Integer', :'notification_name' => :'String', :'webhook_id' => :'Integer', :'webhook_name' => :'String', :'request' => :'MessageLogRequest', :'response' => :'MessageLogResponse', :'created_at' => :'Time', :'entity_type' => :'String', :'url' => :'String', :'application_id' => :'Integer', :'loyalty_program_id' => :'Integer', :'campaign_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 363 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && service == o.service && change_type == o.change_type && notification_id == o.notification_id && notification_name == o.notification_name && webhook_id == o.webhook_id && webhook_name == o.webhook_name && request == o.request && response == o.response && created_at == o.created_at && entity_type == o.entity_type && url == o.url && application_id == o.application_id && loyalty_program_id == o.loyalty_program_id && campaign_id == o.campaign_id end |
#eql?(o) ⇒ Boolean
385 386 387 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 385 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
391 392 393 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 391 def hash [id, service, change_type, notification_id, notification_name, webhook_id, webhook_name, request, response, created_at, entity_type, url, application_id, loyalty_program_id, campaign_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 229 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @service.nil? invalid_properties.push('invalid value for "service", service cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @entity_type.nil? invalid_properties.push('invalid value for "entity_type", entity_type cannot be nil.') end if !@application_id.nil? && @application_id < 1 invalid_properties.push('invalid value for "application_id", must be greater than or equal to 1.') end if !@loyalty_program_id.nil? && @loyalty_program_id < 1 invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.') end if !@campaign_id.nil? && @campaign_id < 1 invalid_properties.push('invalid value for "campaign_id", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 420 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/talon_one_sdk/models/message_log_entry.rb', line 265 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @service.nil? return false if @created_at.nil? return false if @entity_type.nil? entity_type_validator = EnumAttributeValidator.new('String', ["application", "loyalty_program", "webhook"]) return false unless entity_type_validator.valid?(@entity_type) return false if !@application_id.nil? && @application_id < 1 return false if !@loyalty_program_id.nil? && @loyalty_program_id < 1 return false if !@campaign_id.nil? && @campaign_id < 1 true end |