Class: TalonOne::MultipleAudiencesItem

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/multiple_audiences_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MultipleAudiencesItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::MultipleAudiencesItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::MultipleAudiencesItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 22

def created
  @created
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 19

def id
  @id
end

#integration_idObject

The ID of this audience in the third-party integration.



28
29
30
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 28

def integration_id
  @integration_id
end

#nameObject

The human-friendly display name for this audience.



25
26
27
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 25

def name
  @name
end

#statusObject

Indicates whether the audience is new, updated or unmodified by the request.



31
32
33
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 31

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 56

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'integration_id' => :'integrationId',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 287

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



94
95
96
97
98
99
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 94

def self.openapi_all_of
  [
  :'Entity',
  :'NewMultipleAudiencesItem'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 77

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'name' => :'String',
    :'integration_id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      integration_id == o.integration_id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 280

def hash
  [id, created, name, integration_id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@integration_id.nil? && @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/talon_one_sdk/models/multiple_audiences_item.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@integration_id.nil? && @integration_id.to_s.length > 1000
  return false if !@integration_id.nil? && @integration_id.to_s.length < 1
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["unmodified", "updated", "new"])
  return false unless status_validator.valid?(@status)
  true
end