Class: TalonOne::NewApplicationAPIKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewApplicationAPIKey
- Defined in:
- lib/talon_one_sdk/models/new_application_api_key.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
ID of account the key is used for.
-
#application_id ⇒ Object
ID of application the key is used for.
-
#created ⇒ Object
The date the API key was created.
-
#created_by ⇒ Object
ID of user who created.
-
#expires ⇒ Object
The date the API key expires.
-
#id ⇒ Object
ID of the API Key.
-
#key ⇒ Object
The API key.
-
#platform ⇒ Object
The third-party platform the API key is valid for.
-
#time_offset ⇒ Object
A time offset in nanoseconds associated with the API key.
-
#title ⇒ Object
Title of the API key.
-
#type ⇒ Object
The API key type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewApplicationAPIKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewApplicationAPIKey
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewApplicationAPIKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewApplicationAPIKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'expires') self.expires = attributes[:'expires'] else self.expires = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'time_offset') self.time_offset = attributes[:'time_offset'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end end |
Instance Attribute Details
#account_id ⇒ Object
ID of account the key is used for.
40 41 42 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 40 def account_id @account_id end |
#application_id ⇒ Object
ID of application the key is used for.
43 44 45 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 43 def application_id @application_id end |
#created ⇒ Object
The date the API key was created.
46 47 48 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 46 def created @created end |
#created_by ⇒ Object
ID of user who created.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 37 def created_by @created_by end |
#expires ⇒ Object
The date the API key expires.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 22 def expires @expires end |
#id ⇒ Object
ID of the API Key.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 34 def id @id end |
#key ⇒ Object
The API key.
49 50 51 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 49 def key @key end |
#platform ⇒ Object
The third-party platform the API key is valid for. Use ‘none` for a generic API key to be used from your own integration layer.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 25 def platform @platform end |
#time_offset ⇒ Object
A time offset in nanoseconds associated with the API key. When making a request using the API key, rule evaluation is based on a date that is calculated by adding the offset to the current date.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 31 def time_offset @time_offset end |
#title ⇒ Object
Title of the API key.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 19 def title @title end |
#type ⇒ Object
The API key type. Can be empty or ‘staging`. Staging API keys can only be used for dry requests with the [Update customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) endpoint, [Update customer profile](docs.talon.one/integration-api#tag/Customer-profiles/operation/updateCustomerProfileV2) endpoint, and [Track event](docs.talon.one/integration-api#tag/Events/operation/trackEventV2) endpoint. When using the _Update customer profile_ endpoint with a staging API key, the query parameter `runRuleEngine` must be `true`.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 28 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 74 def self.attribute_map { :'title' => :'title', :'expires' => :'expires', :'platform' => :'platform', :'type' => :'type', :'time_offset' => :'timeOffset', :'id' => :'id', :'created_by' => :'createdBy', :'account_id' => :'accountID', :'application_id' => :'applicationID', :'created' => :'created', :'key' => :'key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 399 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
124 125 126 127 128 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 124 def self.openapi_all_of [ :'ApplicationAPIKey' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 101 def self.openapi_types { :'title' => :'String', :'expires' => :'Time', :'platform' => :'String', :'type' => :'String', :'time_offset' => :'Integer', :'id' => :'Integer', :'created_by' => :'Integer', :'account_id' => :'Integer', :'application_id' => :'Integer', :'created' => :'Time', :'key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 368 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && expires == o.expires && platform == o.platform && type == o.type && time_offset == o.time_offset && id == o.id && created_by == o.created_by && account_id == o.account_id && application_id == o.application_id && created == o.created && key == o.key end |
#eql?(o) ⇒ Boolean
386 387 388 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 386 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
392 393 394 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 392 def hash [title, expires, platform, type, time_offset, id, created_by, account_id, application_id, created, key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @expires.nil? invalid_properties.push('invalid value for "expires", expires cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 421 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one_sdk/models/new_application_api_key.rb', line 249 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? return false if @expires.nil? platform_validator = EnumAttributeValidator.new('String', ["none", "segment", "braze", "mparticle", "shopify", "iterable", "customer_engagement", "customer_data", "salesforce", "emarsys"]) return false unless platform_validator.valid?(@platform) type_validator = EnumAttributeValidator.new('String', ["staging"]) return false unless type_validator.valid?(@type) return false if @id.nil? return false if @created_by.nil? return false if @account_id.nil? return false if @application_id.nil? return false if @created.nil? return false if @key.nil? true end |