Class: TalonOne::NewApplicationCIF
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewApplicationCIF
- Defined in:
- lib/talon_one_sdk/models/new_application_cif.rb
Instance Attribute Summary collapse
-
#active_expression_id ⇒ Object
The ID of the expression that the Application cart item filter uses.
-
#created_by ⇒ Object
The ID of the user who created the Application cart item filter.
-
#description ⇒ Object
A short description of the Application cart item filter.
-
#modified ⇒ Object
Timestamp of the most recent update to the Application cart item filter.
-
#modified_by ⇒ Object
The ID of the user who last updated the Application cart item filter.
-
#name ⇒ Object
The name of the Application cart item filter used in API requests.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewApplicationCIF
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewApplicationCIF
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewApplicationCIF` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewApplicationCIF`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'active_expression_id') self.active_expression_id = attributes[:'active_expression_id'] end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'modified') self.modified = attributes[:'modified'] end end |
Instance Attribute Details
#active_expression_id ⇒ Object
The ID of the expression that the Application cart item filter uses.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 25 def active_expression_id @active_expression_id end |
#created_by ⇒ Object
The ID of the user who created the Application cart item filter.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 31 def created_by @created_by end |
#description ⇒ Object
A short description of the Application cart item filter.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 22 def description @description end |
#modified ⇒ Object
Timestamp of the most recent update to the Application cart item filter.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 34 def modified @modified end |
#modified_by ⇒ Object
The ID of the user who last updated the Application cart item filter.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 28 def modified_by @modified_by end |
#name ⇒ Object
The name of the Application cart item filter used in API requests.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 19 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 37 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'active_expression_id' => :'activeExpressionId', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'modified' => :'modified' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 59 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'active_expression_id' => :'Integer', :'modified_by' => :'Integer', :'created_by' => :'Integer', :'modified' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 151 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && active_expression_id == o.active_expression_id && modified_by == o.modified_by && created_by == o.created_by && modified == o.modified end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 170 def hash [name, description, active_expression_id, modified_by, created_by, modified].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 |
# File 'lib/talon_one_sdk/models/new_application_cif.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |