Class: TalonOne::NewBlueprint
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewBlueprint
- Defined in:
- lib/talon_one_sdk/models/new_blueprint.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cart_item_filters ⇒ Object
Array of cart item filters to store in this blueprint.
-
#category ⇒ Object
Category used to group blueprints.
-
#description ⇒ Object
A longer, more detailed description of the blueprint.
-
#rules ⇒ Object
Array of rules to store in this blueprint.
-
#title ⇒ Object
The display name for the blueprint.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewBlueprint
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewBlueprint
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewBlueprint` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewBlueprint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'category') self.category = attributes[:'category'] else self.category = 'custom' end if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end end if attributes.key?(:'cart_item_filters') if (value = attributes[:'cart_item_filters']).is_a?(Array) self.cart_item_filters = value end end end |
Instance Attribute Details
#cart_item_filters ⇒ Object
Array of cart item filters to store in this blueprint. If not provided, will be extracted from the rules. Cart item filters should only contain name (no description, as description is at the blueprint level).
31 32 33 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 31 def cart_item_filters @cart_item_filters end |
#category ⇒ Object
Category used to group blueprints.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 25 def category @category end |
#description ⇒ Object
A longer, more detailed description of the blueprint.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 22 def description @description end |
#rules ⇒ Object
Array of rules to store in this blueprint. Rules should only contain title (no description, as description is at the blueprint level). At least one rule or cart item filter is required.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 28 def rules @rules end |
#title ⇒ Object
The display name for the blueprint.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 56 def self.attribute_map { :'title' => :'title', :'description' => :'description', :'category' => :'category', :'rules' => :'rules', :'cart_item_filters' => :'cartItemFilters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 77 def self.openapi_types { :'title' => :'String', :'description' => :'String', :'category' => :'String', :'rules' => :'Array<CatalogRule>', :'cart_item_filters' => :'Array<CartItemFilterTemplate>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && description == o.description && category == o.category && rules == o.rules && cart_item_filters == o.cart_item_filters end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 200 def hash [title, description, category, rules, cart_item_filters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/new_blueprint.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? category_validator = EnumAttributeValidator.new('String', ["promotions", "pricing", "loyalty", "custom"]) return false unless category_validator.valid?(@category) true end |