Class: TalonOne::NewCouponCreationJob
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewCouponCreationJob
- Defined in:
- lib/talon_one_sdk/models/new_coupon_creation_job.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with coupons.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
-
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewCouponCreationJob
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewCouponCreationJob
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCouponCreationJob` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCouponCreationJob`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'number_of_coupons') self.number_of_coupons = attributes[:'number_of_coupons'] else self.number_of_coupons = nil end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] else self.attributes = nil end if attributes.key?(:'is_reservation_mandatory') self.is_reservation_mandatory = attributes[:'is_reservation_mandatory'] else self.is_reservation_mandatory = false end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with coupons.
39 40 41 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 39 def attributes @attributes end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
36 37 38 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 36 def coupon_settings @coupon_settings end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 22 def discount_limit @discount_limit end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 31 def expiry_date @expiry_date end |
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
42 43 44 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 42 def is_reservation_mandatory @is_reservation_mandatory end |
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 34 def number_of_coupons @number_of_coupons end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 25 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 28 def start_date @start_date end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 19 def usage_limit @usage_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 45 def self.attribute_map { :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'number_of_coupons' => :'numberOfCoupons', :'coupon_settings' => :'couponSettings', :'attributes' => :'attributes', :'is_reservation_mandatory' => :'isReservationMandatory' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
91 92 93 94 95 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 91 def self.openapi_all_of [ :'CouponConstraints' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 70 def self.openapi_types { :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'number_of_coupons' => :'Integer', :'coupon_settings' => :'CodeGeneratorSettings', :'attributes' => :'Object', :'is_reservation_mandatory' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && number_of_coupons == o.number_of_coupons && coupon_settings == o.coupon_settings && attributes == o.attributes && is_reservation_mandatory == o.is_reservation_mandatory end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 327 def hash [usage_limit, discount_limit, reservation_limit, start_date, expiry_date, number_of_coupons, coupon_settings, attributes, is_reservation_mandatory].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@usage_limit.nil? && @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if !@usage_limit.nil? && @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end if @number_of_coupons.nil? invalid_properties.push('invalid value for "number_of_coupons", number_of_coupons cannot be nil.') end if @number_of_coupons > 5000000 invalid_properties.push('invalid value for "number_of_coupons", must be smaller than or equal to 5000000.') end if @number_of_coupons < 1 invalid_properties.push('invalid value for "number_of_coupons", must be greater than or equal to 1.') end if @attributes.nil? invalid_properties.push('invalid value for "attributes", attributes cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/talon_one_sdk/models/new_coupon_creation_job.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@usage_limit.nil? && @usage_limit > 999999 return false if !@usage_limit.nil? && @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 return false if @number_of_coupons.nil? return false if @number_of_coupons > 5000000 return false if @number_of_coupons < 1 return false if @attributes.nil? true end |