Class: TalonOne::NewCoupons
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewCoupons
- Defined in:
- lib/talon_one_sdk/models/new_coupons.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with this item.
-
#coupon_pattern ⇒ Object
The pattern used to generate coupon codes.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
-
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
-
#limits ⇒ Object
Limits configuration for a coupon.
-
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign.
-
#recipient_integration_id ⇒ Object
The integration ID for this coupon’s beneficiary’s profile.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#unique_prefix ⇒ Object
DEPRECATED To create more than 20,000 coupons in one request, use [Create coupons asynchronously](docs.talon.one/management-api#tag/Coupons/operation/createCouponsAsync) endpoint.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
-
#valid_characters ⇒ Object
List of characters used to generate the random parts of a code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewCoupons
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewCoupons
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCoupons` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCoupons`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'number_of_coupons') self.number_of_coupons = attributes[:'number_of_coupons'] else self.number_of_coupons = nil end if attributes.key?(:'unique_prefix') self.unique_prefix = attributes[:'unique_prefix'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] end if attributes.key?(:'valid_characters') if (value = attributes[:'valid_characters']).is_a?(Array) self.valid_characters = value end end if attributes.key?(:'coupon_pattern') self.coupon_pattern = attributes[:'coupon_pattern'] end if attributes.key?(:'is_reservation_mandatory') self.is_reservation_mandatory = attributes[:'is_reservation_mandatory'] else self.is_reservation_mandatory = false end if attributes.key?(:'implicitly_reserved') self.implicitly_reserved = attributes[:'implicitly_reserved'] end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with this item.
43 44 45 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 43 def attributes @attributes end |
#coupon_pattern ⇒ Object
The pattern used to generate coupon codes. The character ‘#` is a placeholder and is replaced by a random character from the `validCharacters` set.
52 53 54 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 52 def coupon_pattern @coupon_pattern end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 22 def discount_limit @discount_limit end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 31 def expiry_date @expiry_date end |
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
58 59 60 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 58 def implicitly_reserved @implicitly_reserved end |
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
55 56 57 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 55 def is_reservation_mandatory @is_reservation_mandatory end |
#limits ⇒ Object
Limits configuration for a coupon. These limits will override the limits set from the campaign. Note: Only usable when creating a single coupon which is not tied to a specific recipient. Only per-profile limits are allowed to be configured.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 34 def limits @limits end |
#number_of_coupons ⇒ Object
The number of new coupon codes to generate for the campaign. Must be at least 1.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 37 def number_of_coupons @number_of_coupons end |
#recipient_integration_id ⇒ Object
The integration ID for this coupon’s beneficiary’s profile.
46 47 48 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 46 def recipient_integration_id @recipient_integration_id end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 25 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 28 def start_date @start_date end |
#unique_prefix ⇒ Object
DEPRECATED To create more than 20,000 coupons in one request, use [Create coupons asynchronously](docs.talon.one/management-api#tag/Coupons/operation/createCouponsAsync) endpoint.
40 41 42 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 40 def unique_prefix @unique_prefix end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 19 def usage_limit @usage_limit end |
#valid_characters ⇒ Object
List of characters used to generate the random parts of a code. By default, the list of characters is equivalent to the ‘[A-Z, 0-9]` regular expression.
49 50 51 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 49 def valid_characters @valid_characters end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 61 def self.attribute_map { :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'limits' => :'limits', :'number_of_coupons' => :'numberOfCoupons', :'unique_prefix' => :'uniquePrefix', :'attributes' => :'attributes', :'recipient_integration_id' => :'recipientIntegrationId', :'valid_characters' => :'validCharacters', :'coupon_pattern' => :'couponPattern', :'is_reservation_mandatory' => :'isReservationMandatory', :'implicitly_reserved' => :'implicitlyReserved' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 402 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
117 118 119 120 121 122 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 117 def self.openapi_all_of [ :'CouponConstraints', :'CouponLimitConfigs' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 91 def self.openapi_types { :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'limits' => :'Array<LimitConfig>', :'number_of_coupons' => :'Integer', :'unique_prefix' => :'String', :'attributes' => :'Object', :'recipient_integration_id' => :'String', :'valid_characters' => :'Array<String>', :'coupon_pattern' => :'String', :'is_reservation_mandatory' => :'Boolean', :'implicitly_reserved' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 368 def ==(o) return true if self.equal?(o) self.class == o.class && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && limits == o.limits && number_of_coupons == o.number_of_coupons && unique_prefix == o.unique_prefix && attributes == o.attributes && recipient_integration_id == o.recipient_integration_id && valid_characters == o.valid_characters && coupon_pattern == o.coupon_pattern && is_reservation_mandatory == o.is_reservation_mandatory && implicitly_reserved == o.implicitly_reserved end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 395 def hash [usage_limit, discount_limit, reservation_limit, start_date, expiry_date, limits, number_of_coupons, unique_prefix, attributes, recipient_integration_id, valid_characters, coupon_pattern, is_reservation_mandatory, implicitly_reserved].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 207 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@usage_limit.nil? && @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if !@usage_limit.nil? && @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end if @number_of_coupons.nil? invalid_properties.push('invalid value for "number_of_coupons", number_of_coupons cannot be nil.') end if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.') end if !@coupon_pattern.nil? && @coupon_pattern.to_s.length > 100 invalid_properties.push('invalid value for "coupon_pattern", the character length must be smaller than or equal to 100.') end if !@coupon_pattern.nil? && @coupon_pattern.to_s.length < 3 invalid_properties.push('invalid value for "coupon_pattern", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/talon_one_sdk/models/new_coupons.rb', line 255 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@usage_limit.nil? && @usage_limit > 999999 return false if !@usage_limit.nil? && @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 return false if @number_of_coupons.nil? return false if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 return false if !@coupon_pattern.nil? && @coupon_pattern.to_s.length > 100 return false if !@coupon_pattern.nil? && @coupon_pattern.to_s.length < 3 true end |