Class: TalonOne::NewCustomerSessionV2
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewCustomerSessionV2
- Defined in:
- lib/talon_one_sdk/models/new_customer_session_v2.rb
Overview
The representation of the customer session.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_costs ⇒ Object
Use this property to set a value for the additional costs of this session, such as a shipping cost.
-
#attributes ⇒ Object
Use this property to set a value for the attributes of your choice.
-
#cart_items ⇒ Object
The items to add to this session.
-
#coupon_codes ⇒ Object
Any coupon codes entered.
-
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine.
-
#experiment_variant_allocations ⇒ Object
The experiment variant allocations to add to this session.
-
#identifiers ⇒ Object
Session custom identifiers that you can set limits on or use inside your rules.
-
#loyalty_cards ⇒ Object
Identifier of a loyalty card.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#referral_code ⇒ Object
Any referral code entered.
-
#state ⇒ Object
Indicates the current state of the session.
-
#store_integration_id ⇒ Object
The integration ID of the store.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewCustomerSessionV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewCustomerSessionV2
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewCustomerSessionV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewCustomerSessionV2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'store_integration_id') self.store_integration_id = attributes[:'store_integration_id'] end if attributes.key?(:'evaluable_campaign_ids') if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array) self.evaluable_campaign_ids = value end end if attributes.key?(:'coupon_codes') if (value = attributes[:'coupon_codes']).is_a?(Array) self.coupon_codes = value end end if attributes.key?(:'referral_code') self.referral_code = attributes[:'referral_code'] end if attributes.key?(:'loyalty_cards') if (value = attributes[:'loyalty_cards']).is_a?(Array) self.loyalty_cards = value end end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'open' end if attributes.key?(:'cart_items') if (value = attributes[:'cart_items']).is_a?(Array) self.cart_items = value end end if attributes.key?(:'experiment_variant_allocations') if (value = attributes[:'experiment_variant_allocations']).is_a?(Array) self.experiment_variant_allocations = value end end if attributes.key?(:'additional_costs') if (value = attributes[:'additional_costs']).is_a?(Hash) self.additional_costs = value end end if attributes.key?(:'identifiers') if (value = attributes[:'identifiers']).is_a?(Array) self.identifiers = value end end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end end |
Instance Attribute Details
#additional_costs ⇒ Object
Use this property to set a value for the additional costs of this session, such as a shipping cost. They must be created in the Campaign Manager before you set them with this property. See [Managing additional costs](docs.talon.one/docs/product/account/dev-tools/managing-additional-costs).
47 48 49 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 47 def additional_costs @additional_costs end |
#attributes ⇒ Object
Use this property to set a value for the attributes of your choice. Attributes represent any information to attach to your session, like the shipping city. You can use [built-in attributes](docs.talon.one/docs/dev/concepts/attributes#built-in-attributes) or [custom ones](docs.talon.one/docs/dev/concepts/attributes#custom-attributes). Custom attributes must be created in the Campaign Manager before you set them with this property.
53 54 55 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 53 def attributes @attributes end |
#cart_items ⇒ Object
The items to add to this session. **Do not exceed 1000 items** and ensure the sum of all cart item’s ‘quantity` **does not exceed 10.000** per request.
41 42 43 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 41 def cart_items @cart_items end |
#coupon_codes ⇒ Object
Any coupon codes entered. **Important - for requests only**: - If you [create a coupon budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign, ensure the session contains a coupon code by the time you close it. - In requests where ‘dry=false`, providing an empty array discards any previous coupons. To avoid this, omit the parameter entirely.
29 30 31 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 29 def coupon_codes @coupon_codes end |
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.
26 27 28 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 26 def evaluable_campaign_ids @evaluable_campaign_ids end |
#experiment_variant_allocations ⇒ Object
The experiment variant allocations to add to this session.
44 45 46 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 44 def experiment_variant_allocations @experiment_variant_allocations end |
#identifiers ⇒ Object
Session custom identifiers that you can set limits on or use inside your rules. For example, you can use IP addresses as identifiers to potentially identify devices and limit discounts abuse in case of customers creating multiple accounts. See the [tutorial](docs.talon.one/docs/dev/tutorials/using-identifiers). Important: Ensure the session contains an identifier by the time you close it if: - You [create a unique identifier budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign. - Your campaign has [coupons](docs.talon.one/docs/product/campaigns/coupons/coupon-page-overview). - We recommend passing an anonymized (hashed) version of the identifier value.
50 51 52 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 50 def identifiers @identifiers end |
#loyalty_cards ⇒ Object
Identifier of a loyalty card.
35 36 37 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 35 def loyalty_cards @loyalty_cards end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
20 21 22 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 20 def profile_id @profile_id end |
#referral_code ⇒ Object
Any referral code entered. **Important - for requests only**: - If you [create a referral budget](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets/#budget-types) for your campaign, ensure the session contains a referral code by the time you close it. - In requests where ‘dry=false`, providing an empty value discards the previous referral code. To avoid this, omit the parameter entirely.
32 33 34 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 32 def referral_code @referral_code end |
#state ⇒ Object
Indicates the current state of the session. Sessions can be created as ‘open` or `closed`. The state transitions are: 1. `open` → `closed` 2. `open` → `cancelled` 3. Either: - `closed` → `cancelled` (only via [Update customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2)) or - `closed` → `partially_returned` (only via [Return cart items](docs.talon.one/integration-api#tag/Customer-sessions/operation/returnCartItems)) - `closed` → `open` (only via [Reopen customer session](docs.talon.one/integration-api#tag/Customer-sessions/operation/reopenCustomerSession)) 4. `partially_returned` → `cancelled` For more information, see [Customer session states](docs.talon.one/docs/dev/concepts/entities/customer-sessions).
38 39 40 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 38 def state @state end |
#store_integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store.
23 24 25 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 23 def store_integration_id @store_integration_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
96 97 98 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 96 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 101 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 78 def self.attribute_map { :'profile_id' => :'profileId', :'store_integration_id' => :'storeIntegrationId', :'evaluable_campaign_ids' => :'evaluableCampaignIds', :'coupon_codes' => :'couponCodes', :'referral_code' => :'referralCode', :'loyalty_cards' => :'loyaltyCards', :'state' => :'state', :'cart_items' => :'cartItems', :'experiment_variant_allocations' => :'experimentVariantAllocations', :'additional_costs' => :'additionalCosts', :'identifiers' => :'identifiers', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 367 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
130 131 132 133 134 135 136 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 130 def self.openapi_all_of [ :'EvaluableCampaignIds', :'IntegrationProfileEntity', :'IntegrationStoreEntity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
124 125 126 127 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 124 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 106 def self.openapi_types { :'profile_id' => :'String', :'store_integration_id' => :'String', :'evaluable_campaign_ids' => :'Array<Integer>', :'coupon_codes' => :'Array<String>', :'referral_code' => :'String', :'loyalty_cards' => :'Array<String>', :'state' => :'String', :'cart_items' => :'Array<CartItem>', :'experiment_variant_allocations' => :'Array<ExperimentVariantAllocation>', :'additional_costs' => :'Hash<String, AdditionalCost>', :'identifiers' => :'Array<String>', :'attributes' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 335 def ==(o) return true if self.equal?(o) self.class == o.class && profile_id == o.profile_id && store_integration_id == o.store_integration_id && evaluable_campaign_ids == o.evaluable_campaign_ids && coupon_codes == o.coupon_codes && referral_code == o.referral_code && loyalty_cards == o.loyalty_cards && state == o.state && cart_items == o.cart_items && experiment_variant_allocations == o.experiment_variant_allocations && additional_costs == o.additional_costs && identifiers == o.identifiers && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
354 355 356 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 354 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
360 361 362 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 360 def hash [profile_id, store_integration_id, evaluable_campaign_ids, coupon_codes, referral_code, loyalty_cards, state, cart_items, experiment_variant_allocations, additional_costs, identifiers, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 223 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 invalid_properties.push('invalid value for "store_integration_id", the character length must be greater than or equal to 1.') end if !@referral_code.nil? && @referral_code.to_s.length > 100 invalid_properties.push('invalid value for "referral_code", the character length must be smaller than or equal to 100.') end if !@loyalty_cards.nil? && @loyalty_cards.length > 1 invalid_properties.push('invalid value for "loyalty_cards", number of items must be less than or equal to 1.') end if !@identifiers.nil? && @identifiers.length > 5 invalid_properties.push('invalid value for "identifiers", number of items must be less than or equal to 5.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 389 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/talon_one_sdk/models/new_customer_session_v2.rb', line 251 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 return false if !@referral_code.nil? && @referral_code.to_s.length > 100 return false if !@loyalty_cards.nil? && @loyalty_cards.length > 1 state_validator = EnumAttributeValidator.new('String', ["open", "closed", "partially_returned", "cancelled"]) return false unless state_validator.valid?(@state) return false if !@identifiers.nil? && @identifiers.length > 5 true end |