Class: TalonOne::NewRevisionVersion
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewRevisionVersion
- Defined in:
- lib/talon_one_sdk/models/new_revision_version.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_ruleset_id ⇒ Object
The ID of the ruleset this campaign will use.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#description ⇒ Object
A detailed description of the campaign.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#features ⇒ Object
A list of features for the campaign.
-
#limits ⇒ Object
The set of limits that will operate for this campaign version.
-
#name ⇒ Object
A user-facing name for this campaign.
-
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
-
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#tags ⇒ Object
A list of tags for the campaign.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewRevisionVersion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewRevisionVersion
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewRevisionVersion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewRevisionVersion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'active_ruleset_id') self.active_ruleset_id = attributes[:'active_ruleset_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'referral_settings') self.referral_settings = attributes[:'referral_settings'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'reevaluate_on_return') self.reevaluate_on_return = attributes[:'reevaluate_on_return'] end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end end if attributes.key?(:'coupon_attributes') self.coupon_attributes = attributes[:'coupon_attributes'] end end |
Instance Attribute Details
#active_ruleset_id ⇒ Object
The ID of the ruleset this campaign will use.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 34 def active_ruleset_id @active_ruleset_id end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 28 def attributes @attributes end |
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
53 54 55 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 53 def coupon_attributes @coupon_attributes end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
39 40 41 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 39 def coupon_settings @coupon_settings end |
#description ⇒ Object
A detailed description of the campaign.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 31 def description @description end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 25 def end_time @end_time end |
#features ⇒ Object
A list of features for the campaign.
50 51 52 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 50 def features @features end |
#limits ⇒ Object
The set of limits that will operate for this campaign version.
44 45 46 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 44 def limits @limits end |
#name ⇒ Object
A user-facing name for this campaign.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 19 def name @name end |
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
47 48 49 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 47 def reevaluate_on_return @reevaluate_on_return end |
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
41 42 43 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 41 def referral_settings @referral_settings end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 22 def start_time @start_time end |
#tags ⇒ Object
A list of tags for the campaign.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 37 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
97 98 99 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 97 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
102 103 104 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 102 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 78 def self.attribute_map { :'name' => :'name', :'start_time' => :'startTime', :'end_time' => :'endTime', :'attributes' => :'attributes', :'description' => :'description', :'active_ruleset_id' => :'activeRulesetId', :'tags' => :'tags', :'coupon_settings' => :'couponSettings', :'referral_settings' => :'referralSettings', :'limits' => :'limits', :'reevaluate_on_return' => :'reevaluateOnReturn', :'features' => :'features', :'coupon_attributes' => :'couponAttributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 298 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
126 127 128 129 130 131 132 133 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 126 def self.openapi_nullable Set.new([ :'start_time', :'end_time', :'description', :'active_ruleset_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 107 def self.openapi_types { :'name' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'attributes' => :'Object', :'description' => :'String', :'active_ruleset_id' => :'Integer', :'tags' => :'Array<String>', :'coupon_settings' => :'CodeGeneratorSettings', :'referral_settings' => :'CodeGeneratorSettings', :'limits' => :'Array<LimitConfig>', :'reevaluate_on_return' => :'Boolean', :'features' => :'Array<String>', :'coupon_attributes' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && start_time == o.start_time && end_time == o.end_time && attributes == o.attributes && description == o.description && active_ruleset_id == o.active_ruleset_id && == o. && coupon_settings == o.coupon_settings && referral_settings == o.referral_settings && limits == o.limits && reevaluate_on_return == o.reevaluate_on_return && features == o.features && coupon_attributes == o.coupon_attributes end |
#eql?(o) ⇒ Boolean
285 286 287 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 285 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 291 def hash [name, start_time, end_time, attributes, description, active_ruleset_id, , coupon_settings, referral_settings, limits, reevaluate_on_return, features, coupon_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 212 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@tags.nil? && @tags.length > 50 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 232 233 |
# File 'lib/talon_one_sdk/models/new_revision_version.rb', line 228 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@tags.nil? && @tags.length > 50 true end |