Class: TalonOne::NewReward

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/new_reward.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewReward

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/talon_one_sdk/models/new_reward.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewReward` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewReward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'api_name')
    self.api_name = attributes[:'api_name']
  else
    self.api_name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  else
    self.application_ids = nil
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  else
    self.sandbox = nil
  end
end

Instance Attribute Details

#api_nameObject

A unique identifier used to reference the reward in API integrations.



22
23
24
# File 'lib/talon_one_sdk/models/new_reward.rb', line 22

def api_name
  @api_name
end

#application_idsObject

The IDs of the Applications this reward is connected to. Note: Currently, a reward can only be connected to one Application.



28
29
30
# File 'lib/talon_one_sdk/models/new_reward.rb', line 28

def application_ids
  @application_ids
end

#descriptionObject

A description of the reward.



25
26
27
# File 'lib/talon_one_sdk/models/new_reward.rb', line 25

def description
  @description
end

#nameObject

The name of the reward.



19
20
21
# File 'lib/talon_one_sdk/models/new_reward.rb', line 19

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox reward. Rewards of a given type can only be connected to Applications of the same type.



31
32
33
# File 'lib/talon_one_sdk/models/new_reward.rb', line 31

def sandbox
  @sandbox
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/talon_one_sdk/models/new_reward.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/talon_one_sdk/models/new_reward.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/talon_one_sdk/models/new_reward.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'api_name' => :'apiName',
    :'description' => :'description',
    :'application_ids' => :'applicationIds',
    :'sandbox' => :'sandbox'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/talon_one_sdk/models/new_reward.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/talon_one_sdk/models/new_reward.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/talon_one_sdk/models/new_reward.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'api_name' => :'String',
    :'description' => :'String',
    :'application_ids' => :'Array<Integer>',
    :'sandbox' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
# File 'lib/talon_one_sdk/models/new_reward.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      api_name == o.api_name &&
      description == o.description &&
      application_ids == o.application_ids &&
      sandbox == o.sandbox
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/talon_one_sdk/models/new_reward.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/talon_one_sdk/models/new_reward.rb', line 231

def hash
  [name, api_name, description, application_ids, sandbox].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/talon_one_sdk/models/new_reward.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @api_name.nil?
    invalid_properties.push('invalid value for "api_name", api_name cannot be nil.')
  end

  if @api_name.to_s.length < 1
    invalid_properties.push('invalid value for "api_name", the character length must be greater than or equal to 1.')
  end

  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/talon_one_sdk/models/new_reward.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
161
# File 'lib/talon_one_sdk/models/new_reward.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @api_name.nil?
  return false if @api_name.to_s.length < 1
  return false if @application_ids.nil?
  return false if @sandbox.nil?
  true
end