Class: TalonOne::NewStore
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewStore
- Defined in:
- lib/talon_one_sdk/models/new_store.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
The attributes of the store.
-
#description ⇒ Object
The description of the store.
-
#integration_id ⇒ Object
The integration ID of the store.
-
#name ⇒ Object
The name of the store.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewStore
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewStore
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewStore` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewStore`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end end |
Instance Attribute Details
#attributes ⇒ Object
The attributes of the store.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 25 def attributes @attributes end |
#description ⇒ Object
The description of the store.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 22 def description @description end |
#integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store. Note: You cannot edit the ‘integrationId` after the store has been created.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 28 def integration_id @integration_id end |
#name ⇒ Object
The name of the store.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 19 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 31 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'attributes' => :'attributes', :'integration_id' => :'integrationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 234 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
67 68 69 70 71 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 67 def self.openapi_all_of [ :'UpdateStore' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 51 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'attributes' => :'Object', :'integration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && attributes == o.attributes && integration_id == o.integration_id end |
#eql?(o) ⇒ Boolean
221 222 223 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 221 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 227 def hash [name, description, attributes, integration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 200 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/talon_one_sdk/models/new_store.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 200 return false if @name.to_s.length < 1 return false if @description.nil? return false if @integration_id.nil? return false if @integration_id.to_s.length > 1000 return false if @integration_id.to_s.length < 1 true end |