Class: TalonOne::NewWebhook
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::NewWebhook
- Defined in:
- lib/talon_one_sdk/models/new_webhook.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_ids ⇒ Object
The IDs of the Applications in which this webhook is available.
-
#authentication_id ⇒ Object
The ID of the credential that this webhook is using.
-
#description ⇒ Object
A description of the webhook.
-
#draft ⇒ Object
Indicates if the webhook is a draft.
-
#enabled ⇒ Object
Enables or disables webhook from showing in the Rule Builder.
-
#headers ⇒ Object
List of API HTTP headers for this webhook.
-
#params ⇒ Object
Array of template argument definitions.
-
#payload ⇒ Object
API payload (supports templating using parameters) for this webhook.
-
#title ⇒ Object
Name or title for this webhook.
-
#url ⇒ Object
API URL (supports templating using parameters) for this webhook.
-
#verb ⇒ Object
API method for this webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NewWebhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NewWebhook
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::NewWebhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::NewWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'application_ids') if (value = attributes[:'application_ids']).is_a?(Array) self.application_ids = value end else self.application_ids = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'draft') self.draft = attributes[:'draft'] else self.draft = nil end if attributes.key?(:'verb') self.verb = attributes[:'verb'] else self.verb = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Array) self.headers = value end else self.headers = nil end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'params') if (value = attributes[:'params']).is_a?(Array) self.params = value end else self.params = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'authentication_id') self.authentication_id = attributes[:'authentication_id'] end end |
Instance Attribute Details
#application_ids ⇒ Object
The IDs of the Applications in which this webhook is available. An empty array means the webhook is available in ‘All Applications`.
19 20 21 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 19 def application_ids @application_ids end |
#authentication_id ⇒ Object
The ID of the credential that this webhook is using.
49 50 51 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 49 def authentication_id @authentication_id end |
#description ⇒ Object
A description of the webhook.
25 26 27 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 25 def description @description end |
#draft ⇒ Object
Indicates if the webhook is a draft.
28 29 30 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 28 def draft @draft end |
#enabled ⇒ Object
Enables or disables webhook from showing in the Rule Builder.
46 47 48 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 46 def enabled @enabled end |
#headers ⇒ Object
List of API HTTP headers for this webhook.
37 38 39 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 37 def headers @headers end |
#params ⇒ Object
Array of template argument definitions.
43 44 45 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 43 def params @params end |
#payload ⇒ Object
API payload (supports templating using parameters) for this webhook.
40 41 42 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 40 def payload @payload end |
#title ⇒ Object
Name or title for this webhook.
22 23 24 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 22 def title @title end |
#url ⇒ Object
API URL (supports templating using parameters) for this webhook.
34 35 36 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 34 def url @url end |
#verb ⇒ Object
API method for this webhook.
31 32 33 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 31 def verb @verb end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 74 def self.attribute_map { :'application_ids' => :'applicationIds', :'title' => :'title', :'description' => :'description', :'draft' => :'draft', :'verb' => :'verb', :'url' => :'url', :'headers' => :'headers', :'payload' => :'payload', :'params' => :'params', :'enabled' => :'enabled', :'authentication_id' => :'authenticationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 387 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 101 def self.openapi_types { :'application_ids' => :'Array<Integer>', :'title' => :'String', :'description' => :'String', :'draft' => :'Boolean', :'verb' => :'String', :'url' => :'String', :'headers' => :'Array<String>', :'payload' => :'String', :'params' => :'Array<TemplateArgDef>', :'enabled' => :'Boolean', :'authentication_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 356 def ==(o) return true if self.equal?(o) self.class == o.class && application_ids == o.application_ids && title == o.title && description == o.description && draft == o.draft && verb == o.verb && url == o.url && headers == o.headers && payload == o.payload && params == o.params && enabled == o.enabled && authentication_id == o.authentication_id end |
#eql?(o) ⇒ Boolean
374 375 376 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 374 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
380 381 382 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 380 def hash [application_ids, title, description, draft, verb, url, headers, payload, params, enabled, authentication_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 208 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @application_ids.nil? invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end pattern = Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/) if @title !~ pattern invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.") end if @draft.nil? invalid_properties.push('invalid value for "draft", draft cannot be nil.') end if @verb.nil? invalid_properties.push('invalid value for "verb", verb cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @headers.nil? invalid_properties.push('invalid value for "headers", headers cannot be nil.') end if @params.nil? invalid_properties.push('invalid value for "params", params cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 409 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/talon_one_sdk/models/new_webhook.rb', line 253 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @application_ids.nil? return false if @title.nil? return false if @title !~ Regexp.new(/^[A-Za-z][A-Za-z0-9_.!~*'() -]*$/) return false if @draft.nil? return false if @verb.nil? verb_validator = EnumAttributeValidator.new('String', ["POST", "PUT", "GET", "DELETE", "PATCH"]) return false unless verb_validator.valid?(@verb) return false if @url.nil? return false if @headers.nil? return false if @params.nil? return false if @enabled.nil? true end |