Class: TalonOne::PriceType
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::PriceType
- Defined in:
- lib/talon_one_sdk/models/price_type.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this price type.
-
#created ⇒ Object
The time this entity was created.
-
#description ⇒ Object
A description of the price type.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
The date and time when the price type was last modified.
-
#name ⇒ Object
The API name of the price type.
-
#subscribed_catalogs_ids ⇒ Object
A list of the IDs of the catalogs that are subscribed to this price type.
-
#targeted_audiences_ids ⇒ Object
A list of the IDs of the audiences targeted by this price type.
-
#title ⇒ Object
The name displayed in the Campaign Manager for the price type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PriceType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PriceType
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::PriceType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::PriceType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'modified') self.modified = attributes[:'modified'] else self.modified = nil end if attributes.key?(:'subscribed_catalogs_ids') if (value = attributes[:'subscribed_catalogs_ids']).is_a?(Array) self.subscribed_catalogs_ids = value end else self.subscribed_catalogs_ids = nil end if attributes.key?(:'targeted_audiences_ids') if (value = attributes[:'targeted_audiences_ids']).is_a?(Array) self.targeted_audiences_ids = value end else self.targeted_audiences_ids = nil end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this price type.
25 26 27 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 25 def account_id @account_id end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 22 def created @created end |
#description ⇒ Object
A description of the price type.
34 35 36 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 34 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 19 def id @id end |
#modified ⇒ Object
The date and time when the price type was last modified.
37 38 39 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 37 def modified @modified end |
#name ⇒ Object
The API name of the price type. This is an immutable value.
28 29 30 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 28 def name @name end |
#subscribed_catalogs_ids ⇒ Object
A list of the IDs of the catalogs that are subscribed to this price type.
40 41 42 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 40 def subscribed_catalogs_ids @subscribed_catalogs_ids end |
#targeted_audiences_ids ⇒ Object
A list of the IDs of the audiences targeted by this price type.
43 44 45 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 43 def targeted_audiences_ids @targeted_audiences_ids end |
#title ⇒ Object
The name displayed in the Campaign Manager for the price type.
31 32 33 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 31 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 46 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'account_id' => :'accountId', :'name' => :'name', :'title' => :'title', :'description' => :'description', :'modified' => :'modified', :'subscribed_catalogs_ids' => :'subscribedCatalogsIds', :'targeted_audiences_ids' => :'targetedAudiencesIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 331 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 92 def self.openapi_all_of [ :'Entity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 71 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'account_id' => :'Integer', :'name' => :'String', :'title' => :'String', :'description' => :'String', :'modified' => :'Time', :'subscribed_catalogs_ids' => :'Array<Integer>', :'targeted_audiences_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 302 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && account_id == o.account_id && name == o.name && title == o.title && description == o.description && modified == o.modified && subscribed_catalogs_ids == o.subscribed_catalogs_ids && targeted_audiences_ids == o.targeted_audiences_ids end |
#eql?(o) ⇒ Boolean
318 319 320 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 318 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
324 325 326 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 324 def hash [id, created, account_id, name, title, description, modified, subscribed_catalogs_ids, targeted_audiences_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end pattern = Regexp.new(/^[A-Za-z]\w*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @modified.nil? invalid_properties.push('invalid value for "modified", modified cannot be nil.') end if @subscribed_catalogs_ids.nil? invalid_properties.push('invalid value for "subscribed_catalogs_ids", subscribed_catalogs_ids cannot be nil.') end if @targeted_audiences_ids.nil? invalid_properties.push('invalid value for "targeted_audiences_ids", targeted_audiences_ids cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/talon_one_sdk/models/price_type.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @name.nil? return false if @name !~ Regexp.new(/^[A-Za-z]\w*$/) return false if @title.nil? return false if @modified.nil? return false if @subscribed_catalogs_ids.nil? return false if @targeted_audiences_ids.nil? true end |