Class: TalonOne::PromotionGroupBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::PromotionGroupBlock
- Defined in:
- lib/talon_one_sdk/models/promotion_group_block.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#blocks ⇒ Object
Child blocks evaluated according to the operator.
-
#id ⇒ Object
Unique identifier for this block.
-
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
-
#on_failure ⇒ Object
Promotion blocks evaluated when this block fails or returns false.
-
#operator ⇒ Object
Logical operator applied across child blocks.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PromotionGroupBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PromotionGroupBlock
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::PromotionGroupBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::PromotionGroupBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'blocks') if (value = attributes[:'blocks']).is_a?(Array) self.blocks = value end else self.blocks = nil end if attributes.key?(:'on_failure') if (value = attributes[:'on_failure']).is_a?(Array) self.on_failure = value end end if attributes.key?(:'on_error') if (value = attributes[:'on_error']).is_a?(Hash) self.on_error = value end end end |
Instance Attribute Details
#blocks ⇒ Object
Child blocks evaluated according to the operator.
31 32 33 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 31 def blocks @blocks end |
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 19 def id @id end |
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
37 38 39 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 37 def on_error @on_error end |
#on_failure ⇒ Object
Promotion blocks evaluated when this block fails or returns false.
34 35 36 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 34 def on_failure @on_failure end |
#operator ⇒ Object
Logical operator applied across child blocks. ‘all` requires every child to pass, `atLeastOne` requires at least one, `none` requires all to fail.
28 29 30 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 28 def operator @operator end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 25 def @tags end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 62 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'operator' => :'operator', :'blocks' => :'blocks', :'on_failure' => :'onFailure', :'on_error' => :'onError' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
104 105 106 107 108 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 104 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 85 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'operator' => :'String', :'blocks' => :'Array<Object>', :'on_failure' => :'Array<Object>', :'on_error' => :'Hash<String, Array<Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && operator == o.operator && blocks == o.blocks && on_failure == o.on_failure && on_error == o.on_error end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 270 def hash [id, type, , operator, blocks, on_failure, on_error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end if @blocks.nil? invalid_properties.push('invalid value for "blocks", blocks cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 |
# File 'lib/talon_one_sdk/models/promotion_group_block.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["all", "atLeastOne", "none"]) return false unless operator_validator.valid?(@operator) return false if @blocks.nil? true end |