Class: TalonOne::RejectCouponEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RejectCouponEffectProps
- Defined in:
- lib/talon_one_sdk/models/reject_coupon_effect_props.rb
Overview
The properties specific to the "rejectCoupon" effect. This gets triggered whenever the coupon was rejected. See rejectionReason for more info on why.
Instance Attribute Summary collapse
-
#campaign_exclusion_reason ⇒ Object
The reason why the campaign was not applied.
-
#condition_index ⇒ Object
The index of the condition that caused the rejection of the coupon.
-
#details ⇒ Object
More details about the failure.
-
#effect_index ⇒ Object
The index of the effect that caused the rejection of the coupon.
-
#rejection_reason ⇒ Object
The reason why this coupon was rejected.
-
#value ⇒ Object
The coupon code that was rejected.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RejectCouponEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RejectCouponEffectProps
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RejectCouponEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RejectCouponEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'rejection_reason') self.rejection_reason = attributes[:'rejection_reason'] else self.rejection_reason = nil end if attributes.key?(:'condition_index') self.condition_index = attributes[:'condition_index'] end if attributes.key?(:'effect_index') self.effect_index = attributes[:'effect_index'] end if attributes.key?(:'details') self.details = attributes[:'details'] end if attributes.key?(:'campaign_exclusion_reason') self.campaign_exclusion_reason = attributes[:'campaign_exclusion_reason'] end end |
Instance Attribute Details
#campaign_exclusion_reason ⇒ Object
The reason why the campaign was not applied.
35 36 37 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 35 def campaign_exclusion_reason @campaign_exclusion_reason end |
#condition_index ⇒ Object
The index of the condition that caused the rejection of the coupon.
26 27 28 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 26 def condition_index @condition_index end |
#details ⇒ Object
More details about the failure.
32 33 34 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 32 def details @details end |
#effect_index ⇒ Object
The index of the effect that caused the rejection of the coupon.
29 30 31 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 29 def effect_index @effect_index end |
#rejection_reason ⇒ Object
The reason why this coupon was rejected.
23 24 25 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 23 def rejection_reason @rejection_reason end |
#value ⇒ Object
The coupon code that was rejected.
20 21 22 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 20 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 38 def self.attribute_map { :'value' => :'value', :'rejection_reason' => :'rejectionReason', :'condition_index' => :'conditionIndex', :'effect_index' => :'effectIndex', :'details' => :'details', :'campaign_exclusion_reason' => :'campaignExclusionReason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 60 def self.openapi_types { :'value' => :'String', :'rejection_reason' => :'String', :'condition_index' => :'Integer', :'effect_index' => :'Integer', :'details' => :'String', :'campaign_exclusion_reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && value == o.value && rejection_reason == o.rejection_reason && condition_index == o.condition_index && effect_index == o.effect_index && details == o.details && campaign_exclusion_reason == o.campaign_exclusion_reason end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 188 def hash [value, rejection_reason, condition_index, effect_index, details, campaign_exclusion_reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @rejection_reason.nil? invalid_properties.push('invalid value for "rejection_reason", rejection_reason cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 |
# File 'lib/talon_one_sdk/models/reject_coupon_effect_props.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @value.nil? return false if @rejection_reason.nil? true end |