Class: TalonOne::Revision
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Revision
- Defined in:
- lib/talon_one_sdk/models/revision.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#activate_at ⇒ Object
Returns the value of attribute activate_at.
-
#activated_at ⇒ Object
Returns the value of attribute activated_at.
-
#activated_by ⇒ Object
Returns the value of attribute activated_by.
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#created ⇒ Object
Returns the value of attribute created.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#current_version ⇒ Object
Returns the value of attribute current_version.
-
#id ⇒ Object
Unique ID for this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Revision
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Revision
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/talon_one_sdk/models/revision.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Revision` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Revision`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'activate_at') self.activate_at = attributes[:'activate_at'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'activated_at') self.activated_at = attributes[:'activated_at'] end if attributes.key?(:'activated_by') self.activated_by = attributes[:'activated_by'] end if attributes.key?(:'current_version') self.current_version = attributes[:'current_version'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
23 24 25 |
# File 'lib/talon_one_sdk/models/revision.rb', line 23 def account_id @account_id end |
#activate_at ⇒ Object
Returns the value of attribute activate_at.
21 22 23 |
# File 'lib/talon_one_sdk/models/revision.rb', line 21 def activate_at @activate_at end |
#activated_at ⇒ Object
Returns the value of attribute activated_at.
33 34 35 |
# File 'lib/talon_one_sdk/models/revision.rb', line 33 def activated_at @activated_at end |
#activated_by ⇒ Object
Returns the value of attribute activated_by.
35 36 37 |
# File 'lib/talon_one_sdk/models/revision.rb', line 35 def activated_by @activated_by end |
#application_id ⇒ Object
Returns the value of attribute application_id.
25 26 27 |
# File 'lib/talon_one_sdk/models/revision.rb', line 25 def application_id @application_id end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
27 28 29 |
# File 'lib/talon_one_sdk/models/revision.rb', line 27 def campaign_id @campaign_id end |
#created ⇒ Object
Returns the value of attribute created.
29 30 31 |
# File 'lib/talon_one_sdk/models/revision.rb', line 29 def created @created end |
#created_by ⇒ Object
Returns the value of attribute created_by.
31 32 33 |
# File 'lib/talon_one_sdk/models/revision.rb', line 31 def created_by @created_by end |
#current_version ⇒ Object
Returns the value of attribute current_version.
37 38 39 |
# File 'lib/talon_one_sdk/models/revision.rb', line 37 def current_version @current_version end |
#id ⇒ Object
Unique ID for this entity. Not to be confused with the Integration ID, which is set by your integration layer and used in most endpoints.
19 20 21 |
# File 'lib/talon_one_sdk/models/revision.rb', line 19 def id @id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/talon_one_sdk/models/revision.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/revision.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/talon_one_sdk/models/revision.rb', line 40 def self.attribute_map { :'id' => :'id', :'activate_at' => :'activateAt', :'account_id' => :'accountId', :'application_id' => :'applicationId', :'campaign_id' => :'campaignId', :'created' => :'created', :'created_by' => :'createdBy', :'activated_at' => :'activatedAt', :'activated_by' => :'activatedBy', :'current_version' => :'currentVersion' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/talon_one_sdk/models/revision.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
88 89 90 91 92 93 |
# File 'lib/talon_one_sdk/models/revision.rb', line 88 def self.openapi_all_of [ :'IdentifiableEntity', :'RevisionActivation' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/talon_one_sdk/models/revision.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/talon_one_sdk/models/revision.rb', line 66 def self.openapi_types { :'id' => :'Integer', :'activate_at' => :'Time', :'account_id' => :'Integer', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'created' => :'Time', :'created_by' => :'Integer', :'activated_at' => :'Time', :'activated_by' => :'Integer', :'current_version' => :'RevisionVersion' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/talon_one_sdk/models/revision.rb', line 271 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && activate_at == o.activate_at && account_id == o.account_id && application_id == o.application_id && campaign_id == o.campaign_id && created == o.created && created_by == o.created_by && activated_at == o.activated_at && activated_by == o.activated_by && current_version == o.current_version end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/talon_one_sdk/models/revision.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/talon_one_sdk/models/revision.rb', line 294 def hash [id, activate_at, account_id, application_id, campaign_id, created, created_by, activated_at, activated_by, current_version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/talon_one_sdk/models/revision.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/talon_one_sdk/models/revision.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/talon_one_sdk/models/revision.rb', line 198 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @account_id.nil? return false if @application_id.nil? return false if @campaign_id.nil? return false if @created.nil? return false if @created_by.nil? true end |