Class: TalonOne::Reward
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Reward
- Defined in:
- lib/talon_one_sdk/models/reward.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns this entity.
-
#api_name ⇒ Object
A unique identifier used to reference the reward in API integrations.
-
#application_ids ⇒ Object
The IDs of the Applications this reward is connected to.
-
#bindings ⇒ Object
A list of named variables created before the reward’s rules are evaluated.
-
#created ⇒ Object
The time this entity was created.
-
#description ⇒ Object
A description of the reward.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
The timestamp when the reward was last updated in RFC3339 format.
-
#name ⇒ Object
The name of the reward.
-
#rule ⇒ Object
Rule to apply.
-
#sandbox ⇒ Object
Indicates if this is a live or sandbox reward.
-
#status ⇒ Object
The status of the reward.
-
#visibility_conditions ⇒ Object
An optional rule that manages who can see this reward.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Reward
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Reward
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/talon_one_sdk/models/reward.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Reward` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Reward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'api_name') self.api_name = attributes[:'api_name'] else self.api_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'application_ids') if (value = attributes[:'application_ids']).is_a?(Array) self.application_ids = value end else self.application_ids = nil end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] else self.sandbox = nil end if attributes.key?(:'visibility_conditions') self.visibility_conditions = attributes[:'visibility_conditions'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'bindings') if (value = attributes[:'bindings']).is_a?(Array) self.bindings = value end end if attributes.key?(:'modified') self.modified = attributes[:'modified'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns this entity.
25 26 27 |
# File 'lib/talon_one_sdk/models/reward.rb', line 25 def account_id @account_id end |
#api_name ⇒ Object
A unique identifier used to reference the reward in API integrations.
31 32 33 |
# File 'lib/talon_one_sdk/models/reward.rb', line 31 def api_name @api_name end |
#application_ids ⇒ Object
The IDs of the Applications this reward is connected to. Note: Currently, a reward can only be connected to one Application.
37 38 39 |
# File 'lib/talon_one_sdk/models/reward.rb', line 37 def application_ids @application_ids end |
#bindings ⇒ Object
A list of named variables created before the reward’s rules are evaluated. Each binding pairs a name with a talang expression. The expression is evaluated once and its result is available by name in any rule condition or effect. Bindings must be defined outside of individual rules.
49 50 51 |
# File 'lib/talon_one_sdk/models/reward.rb', line 49 def bindings @bindings end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/reward.rb', line 22 def created @created end |
#description ⇒ Object
A description of the reward.
34 35 36 |
# File 'lib/talon_one_sdk/models/reward.rb', line 34 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/reward.rb', line 19 def id @id end |
#modified ⇒ Object
The timestamp when the reward was last updated in RFC3339 format.
52 53 54 |
# File 'lib/talon_one_sdk/models/reward.rb', line 52 def modified @modified end |
#name ⇒ Object
The name of the reward.
28 29 30 |
# File 'lib/talon_one_sdk/models/reward.rb', line 28 def name @name end |
#rule ⇒ Object
Rule to apply. Note: The ‘bindings` field inside the rule must not be used in this endpoint. All bindings should be defined at the reward level via the top-level `bindings` field.
46 47 48 |
# File 'lib/talon_one_sdk/models/reward.rb', line 46 def rule @rule end |
#sandbox ⇒ Object
Indicates if this is a live or sandbox reward. Rewards of a given type can only be connected to Applications of the same type.
40 41 42 |
# File 'lib/talon_one_sdk/models/reward.rb', line 40 def sandbox @sandbox end |
#status ⇒ Object
The status of the reward.
55 56 57 |
# File 'lib/talon_one_sdk/models/reward.rb', line 55 def status @status end |
#visibility_conditions ⇒ Object
An optional rule that manages who can see this reward. If not specified, the reward is visible to all customers. Note: Only the ‘condition` field is evaluated within this rule. The `effects` field must be an empty array, and `bindings` are not supported.
43 44 45 |
# File 'lib/talon_one_sdk/models/reward.rb', line 43 def visibility_conditions @visibility_conditions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/talon_one_sdk/models/reward.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/talon_one_sdk/models/reward.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/reward.rb', line 80 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'account_id' => :'accountId', :'name' => :'name', :'api_name' => :'apiName', :'description' => :'description', :'application_ids' => :'applicationIds', :'sandbox' => :'sandbox', :'visibility_conditions' => :'visibilityConditions', :'rule' => :'rule', :'bindings' => :'bindings', :'modified' => :'modified', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/talon_one_sdk/models/reward.rb', line 421 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/reward.rb', line 134 def self.openapi_all_of [ :'AccountEntity', :'Entity', :'NewReward' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 |
# File 'lib/talon_one_sdk/models/reward.rb', line 128 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/talon_one_sdk/models/reward.rb', line 109 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'account_id' => :'Integer', :'name' => :'String', :'api_name' => :'String', :'description' => :'String', :'application_ids' => :'Array<Integer>', :'sandbox' => :'Boolean', :'visibility_conditions' => :'Rule', :'rule' => :'Rule', :'bindings' => :'Array<Binding>', :'modified' => :'Time', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/talon_one_sdk/models/reward.rb', line 388 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && account_id == o.account_id && name == o.name && api_name == o.api_name && description == o.description && application_ids == o.application_ids && sandbox == o.sandbox && visibility_conditions == o.visibility_conditions && rule == o.rule && bindings == o.bindings && modified == o.modified && status == o.status end |
#eql?(o) ⇒ Boolean
408 409 410 |
# File 'lib/talon_one_sdk/models/reward.rb', line 408 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
414 415 416 |
# File 'lib/talon_one_sdk/models/reward.rb', line 414 def hash [id, created, account_id, name, api_name, description, application_ids, sandbox, visibility_conditions, rule, bindings, modified, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/talon_one_sdk/models/reward.rb', line 233 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @api_name.nil? invalid_properties.push('invalid value for "api_name", api_name cannot be nil.') end if @api_name.to_s.length < 1 invalid_properties.push('invalid value for "api_name", the character length must be greater than or equal to 1.') end if @application_ids.nil? invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.') end if @sandbox.nil? invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/talon_one_sdk/models/reward.rb', line 443 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/talon_one_sdk/models/reward.rb', line 281 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length < 1 return false if @api_name.nil? return false if @api_name.to_s.length < 1 return false if @application_ids.nil? return false if @sandbox.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "inactive"]) return false unless status_validator.valid?(@status) true end |