Class: TalonOne::Reward

Inherits:
ApiModelBase show all
Defined in:
lib/talon_one_sdk/models/reward.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Reward

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/talon_one_sdk/models/reward.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Reward` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Reward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'api_name')
    self.api_name = attributes[:'api_name']
  else
    self.api_name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  else
    self.application_ids = nil
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  else
    self.sandbox = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



25
26
27
# File 'lib/talon_one_sdk/models/reward.rb', line 25

def 
  @account_id
end

#api_nameObject

A unique identifier used to reference the reward in API integrations.



31
32
33
# File 'lib/talon_one_sdk/models/reward.rb', line 31

def api_name
  @api_name
end

#application_idsObject

The IDs of the Applications this reward is connected to. Note: Currently, a reward can only be connected to one Application.



37
38
39
# File 'lib/talon_one_sdk/models/reward.rb', line 37

def application_ids
  @application_ids
end

#createdObject

The time this entity was created.



22
23
24
# File 'lib/talon_one_sdk/models/reward.rb', line 22

def created
  @created
end

#descriptionObject

A description of the reward.



34
35
36
# File 'lib/talon_one_sdk/models/reward.rb', line 34

def description
  @description
end

#idObject

The internal ID of this entity.



19
20
21
# File 'lib/talon_one_sdk/models/reward.rb', line 19

def id
  @id
end

#nameObject

The name of the reward.



28
29
30
# File 'lib/talon_one_sdk/models/reward.rb', line 28

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox reward. Rewards of a given type can only be connected to Applications of the same type.



40
41
42
# File 'lib/talon_one_sdk/models/reward.rb', line 40

def sandbox
  @sandbox
end

#statusObject

The status of the reward.



43
44
45
# File 'lib/talon_one_sdk/models/reward.rb', line 43

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/talon_one_sdk/models/reward.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/talon_one_sdk/models/reward.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/talon_one_sdk/models/reward.rb', line 68

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'api_name' => :'apiName',
    :'description' => :'description',
    :'application_ids' => :'applicationIds',
    :'sandbox' => :'sandbox',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/talon_one_sdk/models/reward.rb', line 379

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



114
115
116
117
118
119
120
# File 'lib/talon_one_sdk/models/reward.rb', line 114

def self.openapi_all_of
  [
  :'AccountEntity',
  :'Entity',
  :'NewReward'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/talon_one_sdk/models/reward.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/talon_one_sdk/models/reward.rb', line 93

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'api_name' => :'String',
    :'description' => :'String',
    :'application_ids' => :'Array<Integer>',
    :'sandbox' => :'Boolean',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/talon_one_sdk/models/reward.rb', line 350

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      name == o.name &&
      api_name == o.api_name &&
      description == o.description &&
      application_ids == o.application_ids &&
      sandbox == o.sandbox &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/talon_one_sdk/models/reward.rb', line 366

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



372
373
374
# File 'lib/talon_one_sdk/models/reward.rb', line 372

def hash
  [id, created, , name, api_name, description, application_ids, sandbox, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/reward.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @api_name.nil?
    invalid_properties.push('invalid value for "api_name", api_name cannot be nil.')
  end

  if @api_name.to_s.length < 1
    invalid_properties.push('invalid value for "api_name", the character length must be greater than or equal to 1.')
  end

  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/talon_one_sdk/models/reward.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/talon_one_sdk/models/reward.rb', line 243

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @api_name.nil?
  return false if @api_name.to_s.length < 1
  return false if @application_ids.nil?
  return false if @sandbox.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "inactive"])
  return false unless status_validator.valid?(@status)
  true
end