Class: TalonOne::RiskNotification
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RiskNotification
- Defined in:
- lib/talon_one_sdk/models/risk_notification.rb
Overview
A risk notification configuration rule.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
Indicates whether this risk notification is active.
-
#activity ⇒ Object
The activity metric to analyze within the given entity.
-
#created ⇒ Object
The time this entity was created.
-
#entity ⇒ Object
The entity type to analyze within the given time frame.
-
#id ⇒ Object
The internal ID of this entity.
-
#modified ⇒ Object
Timestamp of the most recent update.
-
#time_frame ⇒ Object
The rolling time window for risk evaluation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RiskNotification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RiskNotification
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RiskNotification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RiskNotification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'entity') self.entity = attributes[:'entity'] else self.entity = nil end if attributes.key?(:'activity') self.activity = attributes[:'activity'] else self.activity = nil end if attributes.key?(:'time_frame') self.time_frame = attributes[:'time_frame'] else self.time_frame = nil end if attributes.key?(:'active') self.active = attributes[:'active'] else self.active = nil end if attributes.key?(:'modified') self.modified = attributes[:'modified'] else self.modified = nil end end |
Instance Attribute Details
#active ⇒ Object
Indicates whether this risk notification is active.
35 36 37 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 35 def active @active end |
#activity ⇒ Object
The activity metric to analyze within the given entity.
29 30 31 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 29 def activity @activity end |
#created ⇒ Object
The time this entity was created.
23 24 25 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 23 def created @created end |
#entity ⇒ Object
The entity type to analyze within the given time frame.
26 27 28 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 26 def entity @entity end |
#id ⇒ Object
The internal ID of this entity.
20 21 22 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 20 def id @id end |
#modified ⇒ Object
Timestamp of the most recent update.
38 39 40 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 38 def modified @modified end |
#time_frame ⇒ Object
The rolling time window for risk evaluation.
32 33 34 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 32 def time_frame @time_frame end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 63 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'entity' => :'entity', :'activity' => :'activity', :'time_frame' => :'timeFrame', :'active' => :'active', :'modified' => :'modified' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 326 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
105 106 107 108 109 110 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 105 def self.openapi_all_of [ :'Entity', :'NewRiskNotification' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 86 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'entity' => :'String', :'activity' => :'String', :'time_frame' => :'String', :'active' => :'Boolean', :'modified' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 299 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && entity == o.entity && activity == o.activity && time_frame == o.time_frame && active == o.active && modified == o.modified end |
#eql?(o) ⇒ Boolean
313 314 315 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 313 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
319 320 321 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 319 def hash [id, created, entity, activity, time_frame, active, modified].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @entity.nil? invalid_properties.push('invalid value for "entity", entity cannot be nil.') end if @activity.nil? invalid_properties.push('invalid value for "activity", activity cannot be nil.') end if @time_frame.nil? invalid_properties.push('invalid value for "time_frame", time_frame cannot be nil.') end if @active.nil? invalid_properties.push('invalid value for "active", active cannot be nil.') end if @modified.nil? invalid_properties.push('invalid value for "modified", modified cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/risk_notification.rb', line 209 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @entity.nil? entity_validator = EnumAttributeValidator.new('String', ["customer_profile", "customer_session"]) return false unless entity_validator.valid?(@entity) return false if @activity.nil? activity_validator = EnumAttributeValidator.new('String', ["loyalty_points_earned", "discounted_amount", "completed_orders", "coupon_attempts"]) return false unless activity_validator.valid?(@activity) return false if @time_frame.nil? time_frame_validator = EnumAttributeValidator.new('String', ["1_day", "1_week", "1_month"]) return false unless time_frame_validator.valid?(@time_frame) return false if @active.nil? return false if @modified.nil? true end |