Class: TalonOne::RuleMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::RuleMetadata
- Defined in:
- lib/talon_one_sdk/models/rule_metadata.rb
Instance Attribute Summary collapse
-
#display_description ⇒ Object
A customer-facing description that explains the details of the rule.
-
#display_name ⇒ Object
A customer-facing name for the rule.
-
#related_data ⇒ Object
Any additional data associated with the rule, such as an image URL, vendor name, or a content management system (CMS) ID.
-
#title ⇒ Object
A short description of the rule.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RuleMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RuleMetadata
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RuleMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RuleMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'display_description') self.display_description = attributes[:'display_description'] end if attributes.key?(:'related_data') self. = attributes[:'related_data'] end end |
Instance Attribute Details
#display_description ⇒ Object
A customer-facing description that explains the details of the rule. For example, this property can contain details about eligibility requirements, reward timelines, or terms and conditions.
25 26 27 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 25 def display_description @display_description end |
#display_name ⇒ Object
A customer-facing name for the rule.
22 23 24 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 22 def display_name @display_name end |
#related_data ⇒ Object
Any additional data associated with the rule, such as an image URL, vendor name, or a content management system (CMS) ID.
28 29 30 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 28 def @related_data end |
#title ⇒ Object
A short description of the rule.
19 20 21 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 31 def self.attribute_map { :'title' => :'title', :'display_name' => :'displayName', :'display_description' => :'displayDescription', :'related_data' => :'relatedData' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 157 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 51 def self.openapi_types { :'title' => :'String', :'display_name' => :'String', :'display_description' => :'String', :'related_data' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && display_name == o.display_name && display_description == o.display_description && == o. end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 150 def hash [title, display_name, display_description, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 |
# File 'lib/talon_one_sdk/models/rule_metadata.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? true end |