Class: TalonOne::ScimUser
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ScimUser
- Defined in:
- lib/talon_one_sdk/models/scim_user.rb
Overview
Schema definition for users that have been provisioned using the SCIM protocol with an identity provider, for example, Microsoft Entra ID.
Instance Attribute Summary collapse
-
#active ⇒ Object
Status of the user.
-
#display_name ⇒ Object
Display name of the user.
-
#id ⇒ Object
ID of the user.
-
#name ⇒ Object
Returns the value of attribute name.
-
#user_name ⇒ Object
Unique identifier of the user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScimUser
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScimUser
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ScimUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ScimUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] else self.user_name = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end end |
Instance Attribute Details
#active ⇒ Object
Status of the user.
20 21 22 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 20 def active @active end |
#display_name ⇒ Object
Display name of the user.
23 24 25 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 23 def display_name @display_name end |
#id ⇒ Object
ID of the user.
31 32 33 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 31 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
28 29 30 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 28 def name @name end |
#user_name ⇒ Object
Unique identifier of the user. This is usually an email address.
26 27 28 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 26 def user_name @user_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 34 def self.attribute_map { :'active' => :'active', :'display_name' => :'displayName', :'user_name' => :'userName', :'name' => :'name', :'id' => :'id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
72 73 74 75 76 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 72 def self.openapi_all_of [ :'ScimNewUser' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 55 def self.openapi_types { :'active' => :'Boolean', :'display_name' => :'String', :'user_name' => :'String', :'name' => :'ScimBaseUserName', :'id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && display_name == o.display_name && user_name == o.user_name && name == o.name && id == o.id end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 184 def hash [active, display_name, user_name, name, id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user_name.nil? invalid_properties.push('invalid value for "user_name", user_name cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 |
# File 'lib/talon_one_sdk/models/scim_user.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user_name.nil? return false if @id.nil? true end |