Class: TalonOne::SetDiscountPerAdditionalCostPerItemEffectProps

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb

Overview

The properties specific to the "setDiscountPerAdditionalCostPerItem" effect. This gets triggered whenever a validated rule contained a "set discount per additional cost per item" effect. This is a discount that should be applied on a specific additional cost in a specific item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SetDiscountPerAdditionalCostPerItemEffectProps

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SetDiscountPerAdditionalCostPerItemEffectProps` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SetDiscountPerAdditionalCostPerItemEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'additional_cost_id')
    self.additional_cost_id = attributes[:'additional_cost_id']
  else
    self.additional_cost_id = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  else
    self.position = nil
  end

  if attributes.key?(:'sub_position')
    self.sub_position = attributes[:'sub_position']
  end

  if attributes.key?(:'additional_cost')
    self.additional_cost = attributes[:'additional_cost']
  else
    self.additional_cost = nil
  end

  if attributes.key?(:'desired_value')
    self.desired_value = attributes[:'desired_value']
  end
end

Instance Attribute Details

#additional_costObject

The name of the additional cost.



35
36
37
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 35

def additional_cost
  @additional_cost
end

#additional_cost_idObject

The ID of the additional cost.



23
24
25
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 23

def additional_cost_id
  @additional_cost_id
end

#desired_valueObject

Only with [partial discounts enabled](docs.talon.one/docs/product/campaigns/campaign-evaluation/#partial-discounts). Represents the monetary value of the discount to be applied to additional discount without considering budget limitations.



38
39
40
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 38

def desired_value
  @desired_value
end

#nameObject

The name / description of this discount



20
21
22
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 20

def name
  @name
end

#positionObject

The index of the item in the cart item list containing the additional cost to be discounted.



29
30
31
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 29

def position
  @position
end

#sub_positionObject

For cart items with ‘quantity` > 1, the sub position indicates which item the discount applies to.



32
33
34
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 32

def sub_position
  @sub_position
end

#valueObject

The total monetary value of the discount.



26
27
28
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 26

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 41

def self.attribute_map
  {
    :'name' => :'name',
    :'additional_cost_id' => :'additionalCostId',
    :'value' => :'value',
    :'position' => :'position',
    :'sub_position' => :'subPosition',
    :'additional_cost' => :'additionalCost',
    :'desired_value' => :'desiredValue'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 64

def self.openapi_types
  {
    :'name' => :'String',
    :'additional_cost_id' => :'Integer',
    :'value' => :'Float',
    :'position' => :'Float',
    :'sub_position' => :'Float',
    :'additional_cost' => :'String',
    :'desired_value' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      additional_cost_id == o.additional_cost_id &&
      value == o.value &&
      position == o.position &&
      sub_position == o.sub_position &&
      additional_cost == o.additional_cost &&
      desired_value == o.desired_value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 249

def hash
  [name, additional_cost_id, value, position, sub_position, additional_cost, desired_value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @additional_cost_id.nil?
    invalid_properties.push('invalid value for "additional_cost_id", additional_cost_id cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @position.nil?
    invalid_properties.push('invalid value for "position", position cannot be nil.')
  end

  if @additional_cost.nil?
    invalid_properties.push('invalid value for "additional_cost", additional_cost cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
# File 'lib/talon_one_sdk/models/set_discount_per_additional_cost_per_item_effect_props.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @additional_cost_id.nil?
  return false if @value.nil?
  return false if @position.nil?
  return false if @additional_cost.nil?
  true
end