Class: TalonOne::ShowNotificationBlock
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::ShowNotificationBlock
- Defined in:
- lib/talon_one_sdk/models/show_notification_block.rb
Instance Attribute Summary collapse
-
#body ⇒ Object
The notification body text.
-
#id ⇒ Object
Unique identifier for this block.
-
#notification_type ⇒ Object
The type of notification to display.
-
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
-
#on_failure ⇒ Object
Blocks evaluated when this block fails or returns false.
-
#tags ⇒ Object
Semantic labels attached to this block.
-
#title ⇒ Object
The notification heading shown to the customer.
-
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ShowNotificationBlock
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ShowNotificationBlock
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ShowNotificationBlock` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ShowNotificationBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'notification_type') self.notification_type = attributes[:'notification_type'] else self.notification_type = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'on_failure') if (value = attributes[:'on_failure']).is_a?(Array) self.on_failure = value end end if attributes.key?(:'on_error') if (value = attributes[:'on_error']).is_a?(Hash) self.on_error = value end end end |
Instance Attribute Details
#body ⇒ Object
The notification body text. Supports template placeholders (e.g. "TalonOne::ShowNotificationBlock.{$Session{$Session.Total}") evaluated at rule execution time.
34 35 36 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 34 def body @body end |
#id ⇒ Object
Unique identifier for this block.
19 20 21 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 19 def id @id end |
#notification_type ⇒ Object
The type of notification to display.
28 29 30 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 28 def notification_type @notification_type end |
#on_error ⇒ Object
Named error handlers evaluated when a specific error occurs.
40 41 42 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 40 def on_error @on_error end |
#on_failure ⇒ Object
Blocks evaluated when this block fails or returns false.
37 38 39 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 37 def on_failure @on_failure end |
#tags ⇒ Object
Semantic labels attached to this block.
25 26 27 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 25 def @tags end |
#title ⇒ Object
The notification heading shown to the customer.
31 32 33 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 31 def title @title end |
#type ⇒ Object
Identifies the block variant and determines which additional properties are present in it.
22 23 24 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 43 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'tags' => :'tags', :'notification_type' => :'notificationType', :'title' => :'title', :'body' => :'body', :'on_failure' => :'onFailure', :'on_error' => :'onError' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
87 88 89 90 91 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 87 def self.openapi_all_of [ :'BaseBlock' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 67 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'tags' => :'Array<String>', :'notification_type' => :'String', :'title' => :'String', :'body' => :'String', :'on_failure' => :'Array<Object>', :'on_error' => :'Hash<String, Array<Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && == o. && notification_type == o.notification_type && title == o.title && body == o.body && on_failure == o.on_failure && on_error == o.on_error end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 254 def hash [id, type, , notification_type, title, body, on_failure, on_error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @notification_type.nil? invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 185 186 187 188 189 |
# File 'lib/talon_one_sdk/models/show_notification_block.rb', line 182 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @notification_type.nil? return false if @title.nil? true end |