Class: TalonOne::SlotDef
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::SlotDef
- Defined in:
- lib/talon_one_sdk/models/slot_def.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A short description of the slot.
-
#help ⇒ Object
Extended help text for the slot.
-
#name ⇒ Object
The dot-separated path to this slot for use in Talang.
-
#title ⇒ Object
Campaigner-friendly name for the slot.
-
#type ⇒ Object
The type of this slot, one of string, number, boolean, or list.
-
#writable ⇒ Object
Whether or not this slot can be updated by rule effects.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SlotDef
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SlotDef
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SlotDef` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SlotDef`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'help') self.help = attributes[:'help'] end if attributes.key?(:'writable') self.writable = attributes[:'writable'] else self.writable = nil end end |
Instance Attribute Details
#description ⇒ Object
A short description of the slot.
28 29 30 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 28 def description @description end |
#help ⇒ Object
Extended help text for the slot.
31 32 33 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 31 def help @help end |
#name ⇒ Object
The dot-separated path to this slot for use in Talang.
19 20 21 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 19 def name @name end |
#title ⇒ Object
Campaigner-friendly name for the slot.
25 26 27 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 25 def title @title end |
#type ⇒ Object
The type of this slot, one of string, number, boolean, or list.
22 23 24 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 22 def type @type end |
#writable ⇒ Object
Whether or not this slot can be updated by rule effects.
34 35 36 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 34 def writable @writable end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 37 def self.attribute_map { :'name' => :'name', :'type' => :'type', :'title' => :'title', :'description' => :'description', :'help' => :'help', :'writable' => :'writable' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 59 def self.openapi_types { :'name' => :'String', :'type' => :'String', :'title' => :'String', :'description' => :'String', :'help' => :'String', :'writable' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && type == o.type && title == o.title && description == o.description && help == o.help && writable == o.writable end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 221 def hash [name, type, title, description, help, writable].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @writable.nil? invalid_properties.push('invalid value for "writable", writable cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 157 158 |
# File 'lib/talon_one_sdk/models/slot_def.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @type.nil? return false if @title.nil? return false if @writable.nil? true end |