Class: TalonOne::StartAchievementProgressEffectProps
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::StartAchievementProgressEffectProps
- Defined in:
- lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb
Overview
This effect indicates that the customer's progress in an achievement was started during the current session. The progress value is set to 0. It is triggered when a rule using the Start achievement progress effect is successfully validated. This effect only marks the start of progress tracking. It can fire together with increaseAchievementProgress when progress starts and increases at the same time. In that case, both effects share the same progressTrackerId, startDate, and endDate. For on-completion achievements, each iteration also gets its own startDate and endDate.
Instance Attribute Summary collapse
-
#achievement_id ⇒ Object
The ID of the achievement.
-
#achievement_name ⇒ Object
The name of the achievement.
-
#end_date ⇒ Object
Timestamp at which this progress period ends.
-
#progress_tracker_id ⇒ Object
The ID of the customer's progress tracker for this achievement.
-
#start_date ⇒ Object
Timestamp at which the customer's progress started.
-
#target ⇒ Object
The target value to complete the achievement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StartAchievementProgressEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StartAchievementProgressEffectProps
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StartAchievementProgressEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StartAchievementProgressEffectProps`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'achievement_id') self.achievement_id = attributes[:'achievement_id'] else self.achievement_id = nil end if attributes.key?(:'achievement_name') self.achievement_name = attributes[:'achievement_name'] else self.achievement_name = nil end if attributes.key?(:'progress_tracker_id') self.progress_tracker_id = attributes[:'progress_tracker_id'] else self.progress_tracker_id = nil end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] else self.start_date = nil end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end end |
Instance Attribute Details
#achievement_id ⇒ Object
The ID of the achievement.
20 21 22 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 20 def achievement_id @achievement_id end |
#achievement_name ⇒ Object
The name of the achievement.
23 24 25 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 23 def achievement_name @achievement_name end |
#end_date ⇒ Object
Timestamp at which this progress period ends. Only returned for achievements that have a fixed end date. On-completion achievements have no end date.
35 36 37 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 35 def end_date @end_date end |
#progress_tracker_id ⇒ Object
The ID of the customer's progress tracker for this achievement. For on-completion achievements, this effect generates a unique ID for each iteration.
26 27 28 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 26 def progress_tracker_id @progress_tracker_id end |
#start_date ⇒ Object
Timestamp at which the customer's progress started.
32 33 34 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 32 def start_date @start_date end |
#target ⇒ Object
The target value to complete the achievement.
29 30 31 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 29 def target @target end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 38 def self.attribute_map { :'achievement_id' => :'achievementId', :'achievement_name' => :'achievementName', :'progress_tracker_id' => :'progressTrackerId', :'target' => :'target', :'start_date' => :'startDate', :'end_date' => :'endDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 60 def self.openapi_types { :'achievement_id' => :'Integer', :'achievement_name' => :'String', :'progress_tracker_id' => :'Integer', :'target' => :'Float', :'start_date' => :'Time', :'end_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && achievement_id == o.achievement_id && achievement_name == o.achievement_name && progress_tracker_id == o.progress_tracker_id && target == o.target && start_date == o.start_date && end_date == o.end_date end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 239 def hash [achievement_id, achievement_name, progress_tracker_id, target, start_date, end_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @achievement_id.nil? invalid_properties.push('invalid value for "achievement_id", achievement_id cannot be nil.') end if @achievement_name.nil? invalid_properties.push('invalid value for "achievement_name", achievement_name cannot be nil.') end if @progress_tracker_id.nil? invalid_properties.push('invalid value for "progress_tracker_id", progress_tracker_id cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end if @start_date.nil? invalid_properties.push('invalid value for "start_date", start_date cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 165 166 |
# File 'lib/talon_one_sdk/models/start_achievement_progress_effect_props.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @achievement_id.nil? return false if @achievement_name.nil? return false if @progress_tracker_id.nil? return false if @target.nil? return false if @start_date.nil? true end |