Class: TalonOne::Store
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Store
- Defined in:
- lib/talon_one_sdk/models/store.rb
Instance Attribute Summary collapse
-
#application_id ⇒ Object
The ID of the Application that owns this entity.
-
#attributes ⇒ Object
The attributes of the store.
-
#created ⇒ Object
The time this entity was created.
-
#description ⇒ Object
The description of the store.
-
#id ⇒ Object
The internal ID of this entity.
-
#integration_id ⇒ Object
The integration ID of the store.
-
#linked_campaign_ids ⇒ Object
A list of IDs of the campaigns that are linked with current store.
-
#name ⇒ Object
The name of the store.
-
#updated ⇒ Object
Timestamp of the most recent update on this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Store
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Store
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/talon_one_sdk/models/store.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Store` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Store`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] else self.integration_id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'updated') self.updated = attributes[:'updated'] else self.updated = nil end if attributes.key?(:'linked_campaign_ids') if (value = attributes[:'linked_campaign_ids']).is_a?(Array) self.linked_campaign_ids = value end end end |
Instance Attribute Details
#application_id ⇒ Object
The ID of the Application that owns this entity.
37 38 39 |
# File 'lib/talon_one_sdk/models/store.rb', line 37 def application_id @application_id end |
#attributes ⇒ Object
The attributes of the store.
31 32 33 |
# File 'lib/talon_one_sdk/models/store.rb', line 31 def attributes @attributes end |
#created ⇒ Object
The time this entity was created.
22 23 24 |
# File 'lib/talon_one_sdk/models/store.rb', line 22 def created @created end |
#description ⇒ Object
The description of the store.
28 29 30 |
# File 'lib/talon_one_sdk/models/store.rb', line 28 def description @description end |
#id ⇒ Object
The internal ID of this entity.
19 20 21 |
# File 'lib/talon_one_sdk/models/store.rb', line 19 def id @id end |
#integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store. Note: You cannot edit the ‘integrationId` after the store has been created.
34 35 36 |
# File 'lib/talon_one_sdk/models/store.rb', line 34 def integration_id @integration_id end |
#linked_campaign_ids ⇒ Object
A list of IDs of the campaigns that are linked with current store.
43 44 45 |
# File 'lib/talon_one_sdk/models/store.rb', line 43 def linked_campaign_ids @linked_campaign_ids end |
#name ⇒ Object
The name of the store.
25 26 27 |
# File 'lib/talon_one_sdk/models/store.rb', line 25 def name @name end |
#updated ⇒ Object
Timestamp of the most recent update on this entity.
40 41 42 |
# File 'lib/talon_one_sdk/models/store.rb', line 40 def updated @updated end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/talon_one_sdk/models/store.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/talon_one_sdk/models/store.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/talon_one_sdk/models/store.rb', line 46 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'name' => :'name', :'description' => :'description', :'attributes' => :'attributes', :'integration_id' => :'integrationId', :'application_id' => :'applicationId', :'updated' => :'updated', :'linked_campaign_ids' => :'linkedCampaignIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/talon_one_sdk/models/store.rb', line 355 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 97 |
# File 'lib/talon_one_sdk/models/store.rb', line 92 def self.openapi_all_of [ :'Entity', :'NewStore' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/talon_one_sdk/models/store.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one_sdk/models/store.rb', line 71 def self.openapi_types { :'id' => :'Integer', :'created' => :'Time', :'name' => :'String', :'description' => :'String', :'attributes' => :'Object', :'integration_id' => :'String', :'application_id' => :'Integer', :'updated' => :'Time', :'linked_campaign_ids' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/talon_one_sdk/models/store.rb', line 326 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && name == o.name && description == o.description && attributes == o.attributes && integration_id == o.integration_id && application_id == o.application_id && updated == o.updated && linked_campaign_ids == o.linked_campaign_ids end |
#eql?(o) ⇒ Boolean
342 343 344 |
# File 'lib/talon_one_sdk/models/store.rb', line 342 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/talon_one_sdk/models/store.rb', line 348 def hash [id, created, name, description, attributes, integration_id, application_id, updated, linked_campaign_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/talon_one_sdk/models/store.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 200 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "integration_id", the character length must be smaller than or equal to 1000.') end if @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be greater than or equal to 1.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @updated.nil? invalid_properties.push('invalid value for "updated", updated cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/talon_one_sdk/models/store.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/talon_one_sdk/models/store.rb', line 222 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @created.nil? return false if @name.nil? return false if @name.to_s.length > 200 return false if @name.to_s.length < 1 return false if @description.nil? return false if @integration_id.nil? return false if @integration_id.to_s.length > 1000 return false if @integration_id.to_s.length < 1 return false if @application_id.nil? return false if @updated.nil? true end |