Class: TalonOne::SupportRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::SupportRequest
- Defined in:
- lib/talon_one_sdk/models/support_request.rb
Overview
Summary of a support request created by a customer support agent.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Identifier of the Application connected to the loyalty program or the campaign.
-
#campaign_id ⇒ Object
Identifier of the campaign where the coupon or gift card is created.
-
#created_at ⇒ Object
Timestamp when the request was made.
-
#created_by_user ⇒ Object
Email address of the customer support agent who created the support request.
-
#customer_profile_id ⇒ Object
Integration ID of the customer profile linked to the support request.
-
#id ⇒ Object
Identifier of the support request.
-
#loyalty_program_id ⇒ Object
Identifier of the loyalty program where the points are added or deducted.
-
#processed_at ⇒ Object
Timestamp when the request was approved or rejected.
-
#processed_by_user ⇒ Object
Email address of the admin who approved or rejected the support request.
-
#processing_note ⇒ Object
Notes attached by the admin when rejecting or approving a request.
-
#request_note ⇒ Object
Notes attached to the support request.
-
#request_status ⇒ Object
Current status of the support request.
-
#request_type ⇒ Object
Type of reward requested, including gift cards, personal coupons, and loyalty point additions or deductions.
-
#request_value ⇒ Object
Requested monetary balance of the gift card or the number of loyalty points to be added or deducted.
-
#subledger_id ⇒ Object
Identifier of the subledger the points are added to or deducted from.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SupportRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SupportRequest
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 146 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::SupportRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::SupportRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] else self.application_id = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] end if attributes.key?(:'subledger_id') self.subledger_id = attributes[:'subledger_id'] end if attributes.key?(:'created_by_user') self.created_by_user = attributes[:'created_by_user'] else self.created_by_user = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'customer_profile_id') self.customer_profile_id = attributes[:'customer_profile_id'] else self.customer_profile_id = nil end if attributes.key?(:'request_type') self.request_type = attributes[:'request_type'] else self.request_type = nil end if attributes.key?(:'request_value') self.request_value = attributes[:'request_value'] end if attributes.key?(:'request_note') self.request_note = attributes[:'request_note'] else self.request_note = nil end if attributes.key?(:'request_status') self.request_status = attributes[:'request_status'] else self.request_status = nil end if attributes.key?(:'processed_at') self.processed_at = attributes[:'processed_at'] end if attributes.key?(:'processing_note') self.processing_note = attributes[:'processing_note'] end if attributes.key?(:'processed_by_user') self.processed_by_user = attributes[:'processed_by_user'] end end |
Instance Attribute Details
#application_id ⇒ Object
Identifier of the Application connected to the loyalty program or the campaign. It is displayed in your Talon.One deployment URL.
23 24 25 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 23 def application_id @application_id end |
#campaign_id ⇒ Object
Identifier of the campaign where the coupon or gift card is created.
26 27 28 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 26 def campaign_id @campaign_id end |
#created_at ⇒ Object
Timestamp when the request was made.
38 39 40 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 38 def created_at @created_at end |
#created_by_user ⇒ Object
Email address of the customer support agent who created the support request.
35 36 37 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 35 def created_by_user @created_by_user end |
#customer_profile_id ⇒ Object
Integration ID of the customer profile linked to the support request.
41 42 43 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 41 def customer_profile_id @customer_profile_id end |
#id ⇒ Object
Identifier of the support request.
20 21 22 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 20 def id @id end |
#loyalty_program_id ⇒ Object
Identifier of the loyalty program where the points are added or deducted.
29 30 31 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 29 def loyalty_program_id @loyalty_program_id end |
#processed_at ⇒ Object
Timestamp when the request was approved or rejected.
56 57 58 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 56 def processed_at @processed_at end |
#processed_by_user ⇒ Object
Email address of the admin who approved or rejected the support request.
62 63 64 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 62 def processed_by_user @processed_by_user end |
#processing_note ⇒ Object
Notes attached by the admin when rejecting or approving a request.
59 60 61 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 59 def processing_note @processing_note end |
#request_note ⇒ Object
Notes attached to the support request.
50 51 52 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 50 def request_note @request_note end |
#request_status ⇒ Object
Current status of the support request.
53 54 55 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 53 def request_status @request_status end |
#request_type ⇒ Object
Type of reward requested, including gift cards, personal coupons, and loyalty point additions or deductions.
44 45 46 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 44 def request_type @request_type end |
#request_value ⇒ Object
Requested monetary balance of the gift card or the number of loyalty points to be added or deducted.
47 48 49 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 47 def request_value @request_value end |
#subledger_id ⇒ Object
Identifier of the subledger the points are added to or deducted from. If there is no existing subledger with this ID, the subledger is created automatically.
32 33 34 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 32 def subledger_id @subledger_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
108 109 110 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 108 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 113 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 87 def self.attribute_map { :'id' => :'id', :'application_id' => :'applicationId', :'campaign_id' => :'campaignId', :'loyalty_program_id' => :'loyaltyProgramId', :'subledger_id' => :'subledgerId', :'created_by_user' => :'createdByUser', :'created_at' => :'createdAt', :'customer_profile_id' => :'customerProfileId', :'request_type' => :'requestType', :'request_value' => :'requestValue', :'request_note' => :'requestNote', :'request_status' => :'requestStatus', :'processed_at' => :'processedAt', :'processing_note' => :'processingNote', :'processed_by_user' => :'processedByUser' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 432 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
139 140 141 142 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 139 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 118 def self.openapi_types { :'id' => :'Integer', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'loyalty_program_id' => :'Integer', :'subledger_id' => :'Integer', :'created_by_user' => :'String', :'created_at' => :'Time', :'customer_profile_id' => :'String', :'request_type' => :'String', :'request_value' => :'Float', :'request_note' => :'String', :'request_status' => :'String', :'processed_at' => :'Time', :'processing_note' => :'String', :'processed_by_user' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 397 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && application_id == o.application_id && campaign_id == o.campaign_id && loyalty_program_id == o.loyalty_program_id && subledger_id == o.subledger_id && created_by_user == o.created_by_user && created_at == o.created_at && customer_profile_id == o.customer_profile_id && request_type == o.request_type && request_value == o.request_value && request_note == o.request_note && request_status == o.request_status && processed_at == o.processed_at && processing_note == o.processing_note && processed_by_user == o.processed_by_user end |
#eql?(o) ⇒ Boolean
419 420 421 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 419 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
425 426 427 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 425 def hash [id, application_id, campaign_id, loyalty_program_id, subledger_id, created_by_user, created_at, customer_profile_id, request_type, request_value, request_note, request_status, processed_at, processing_note, processed_by_user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 239 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @created_by_user.nil? invalid_properties.push('invalid value for "created_by_user", created_by_user cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @customer_profile_id.nil? invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.') end if @request_type.nil? invalid_properties.push('invalid value for "request_type", request_type cannot be nil.') end if !@request_value.nil? && @request_value <= 0 invalid_properties.push('invalid value for "request_value", must be greater than 0.') end if @request_note.nil? invalid_properties.push('invalid value for "request_note", request_note cannot be nil.') end if @request_status.nil? invalid_properties.push('invalid value for "request_status", request_status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/talon_one_sdk/models/support_request.rb', line 283 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @application_id.nil? return false if @created_by_user.nil? return false if @created_at.nil? return false if @customer_profile_id.nil? return false if @request_type.nil? request_type_validator = EnumAttributeValidator.new('String', ["gift_card", "personal_coupon", "loyalty_points_added", "loyalty_points_deducted"]) return false unless request_type_validator.valid?(@request_type) return false if !@request_value.nil? && @request_value <= 0 return false if @request_note.nil? return false if @request_status.nil? request_status_validator = EnumAttributeValidator.new('String', ["pending_approval", "approved", "rejected"]) return false unless request_status_validator.valid?(@request_status) true end |