Class: TalonOne::Tier
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::Tier
- Defined in:
- lib/talon_one_sdk/models/tier.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#downgrade_policy ⇒ Object
The policy that defines how customer tiers are downgraded in the loyalty program after tier reevaluation.
-
#expiry_date ⇒ Object
Date when tier level expires in the RFC3339 format (in the Loyalty Program’s timezone).
-
#id ⇒ Object
The internal ID of the tier.
-
#name ⇒ Object
The name of the tier.
-
#start_date ⇒ Object
Date and time when the customer moved to this tier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Tier
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Tier
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/talon_one_sdk/models/tier.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Tier` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Tier`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'downgrade_policy') self.downgrade_policy = attributes[:'downgrade_policy'] end end |
Instance Attribute Details
#downgrade_policy ⇒ Object
The policy that defines how customer tiers are downgraded in the loyalty program after tier reevaluation. - ‘one_down`: If the customer doesn’t have enough points to stay in the current tier, they are downgraded by one tier. - ‘balance_based`: The customer’s tier is reevaluated based on the amount of active points they have at the moment.
31 32 33 |
# File 'lib/talon_one_sdk/models/tier.rb', line 31 def downgrade_policy @downgrade_policy end |
#expiry_date ⇒ Object
Date when tier level expires in the RFC3339 format (in the Loyalty Program’s timezone).
28 29 30 |
# File 'lib/talon_one_sdk/models/tier.rb', line 28 def expiry_date @expiry_date end |
#id ⇒ Object
The internal ID of the tier.
19 20 21 |
# File 'lib/talon_one_sdk/models/tier.rb', line 19 def id @id end |
#name ⇒ Object
The name of the tier.
22 23 24 |
# File 'lib/talon_one_sdk/models/tier.rb', line 22 def name @name end |
#start_date ⇒ Object
Date and time when the customer moved to this tier. This value uses the loyalty program’s time zone setting.
25 26 27 |
# File 'lib/talon_one_sdk/models/tier.rb', line 25 def start_date @start_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/talon_one_sdk/models/tier.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/talon_one_sdk/models/tier.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/talon_one_sdk/models/tier.rb', line 56 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'downgrade_policy' => :'downgradePolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/talon_one_sdk/models/tier.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/talon_one_sdk/models/tier.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/talon_one_sdk/models/tier.rb', line 77 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'start_date' => :'Time', :'expiry_date' => :'Time', :'downgrade_policy' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 |
# File 'lib/talon_one_sdk/models/tier.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && start_date == o.start_date && expiry_date == o.expiry_date && downgrade_policy == o.downgrade_policy end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/talon_one_sdk/models/tier.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/talon_one_sdk/models/tier.rb', line 211 def hash [id, name, start_date, expiry_date, downgrade_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/talon_one_sdk/models/tier.rb', line 136 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/talon_one_sdk/models/tier.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 |
# File 'lib/talon_one_sdk/models/tier.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? downgrade_policy_validator = EnumAttributeValidator.new('String', ["one_down", "balance_based"]) return false unless downgrade_policy_validator.valid?(@downgrade_policy) true end |