Class: TalonOne::TierWillDowngradeData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::TierWillDowngradeData
- Defined in:
- lib/talon_one_sdk/models/tier_will_downgrade_data.rb
Instance Attribute Summary collapse
-
#current_points ⇒ Object
The number of points the customer will have after the tier downgrade.
-
#current_tier ⇒ Object
The name of the customer’s current tier.
-
#customer_profile_id ⇒ Object
The integration ID of the customer profile whose tier was downgraded.
-
#loyalty_program_id ⇒ Object
The ID of the loyalty program.
-
#next_tier ⇒ Object
The name of the customer’s next tier.
-
#points_required_to_remain ⇒ Object
The number of points needed for a customer to remain on the same tier.
-
#subledger_id ⇒ Object
The ID of the subledger, when applicable.
-
#tier_expiration_date ⇒ Object
The date and time the tier expires.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TierWillDowngradeData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TierWillDowngradeData
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::TierWillDowngradeData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::TierWillDowngradeData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_profile_id') self.customer_profile_id = attributes[:'customer_profile_id'] else self.customer_profile_id = nil end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] else self.loyalty_program_id = nil end if attributes.key?(:'subledger_id') self.subledger_id = attributes[:'subledger_id'] else self.subledger_id = '' end if attributes.key?(:'current_tier') self.current_tier = attributes[:'current_tier'] else self.current_tier = nil end if attributes.key?(:'current_points') self.current_points = attributes[:'current_points'] else self.current_points = nil end if attributes.key?(:'points_required_to_remain') self.points_required_to_remain = attributes[:'points_required_to_remain'] else self.points_required_to_remain = nil end if attributes.key?(:'next_tier') self.next_tier = attributes[:'next_tier'] end if attributes.key?(:'tier_expiration_date') self.tier_expiration_date = attributes[:'tier_expiration_date'] end end |
Instance Attribute Details
#current_points ⇒ Object
The number of points the customer will have after the tier downgrade.
31 32 33 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 31 def current_points @current_points end |
#current_tier ⇒ Object
The name of the customer’s current tier.
28 29 30 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 28 def current_tier @current_tier end |
#customer_profile_id ⇒ Object
The integration ID of the customer profile whose tier was downgraded.
19 20 21 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 19 def customer_profile_id @customer_profile_id end |
#loyalty_program_id ⇒ Object
The ID of the loyalty program.
22 23 24 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 22 def loyalty_program_id @loyalty_program_id end |
#next_tier ⇒ Object
The name of the customer’s next tier.
37 38 39 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 37 def next_tier @next_tier end |
#points_required_to_remain ⇒ Object
The number of points needed for a customer to remain on the same tier.
34 35 36 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 34 def points_required_to_remain @points_required_to_remain end |
#subledger_id ⇒ Object
The ID of the subledger, when applicable. If this field is empty, the main ledger is used.
25 26 27 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 25 def subledger_id @subledger_id end |
#tier_expiration_date ⇒ Object
The date and time the tier expires.
40 41 42 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 40 def tier_expiration_date @tier_expiration_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 43 def self.attribute_map { :'customer_profile_id' => :'CustomerProfileID', :'loyalty_program_id' => :'LoyaltyProgramID', :'subledger_id' => :'SubledgerID', :'current_tier' => :'CurrentTier', :'current_points' => :'CurrentPoints', :'points_required_to_remain' => :'PointsRequiredToRemain', :'next_tier' => :'NextTier', :'tier_expiration_date' => :'TierExpirationDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 291 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 67 def self.openapi_types { :'customer_profile_id' => :'String', :'loyalty_program_id' => :'Integer', :'subledger_id' => :'String', :'current_tier' => :'String', :'current_points' => :'Float', :'points_required_to_remain' => :'Float', :'next_tier' => :'String', :'tier_expiration_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && customer_profile_id == o.customer_profile_id && loyalty_program_id == o.loyalty_program_id && subledger_id == o.subledger_id && current_tier == o.current_tier && current_points == o.current_points && points_required_to_remain == o.points_required_to_remain && next_tier == o.next_tier && tier_expiration_date == o.tier_expiration_date end |
#eql?(o) ⇒ Boolean
278 279 280 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 278 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 284 def hash [customer_profile_id, loyalty_program_id, subledger_id, current_tier, current_points, points_required_to_remain, next_tier, tier_expiration_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @customer_profile_id.nil? invalid_properties.push('invalid value for "customer_profile_id", customer_profile_id cannot be nil.') end if @loyalty_program_id.nil? invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.') end if @loyalty_program_id < 1 invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.') end if @subledger_id.nil? invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.') end if @current_tier.nil? invalid_properties.push('invalid value for "current_tier", current_tier cannot be nil.') end if @current_points.nil? invalid_properties.push('invalid value for "current_points", current_points cannot be nil.') end if @points_required_to_remain.nil? invalid_properties.push('invalid value for "points_required_to_remain", points_required_to_remain cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/talon_one_sdk/models/tier_will_downgrade_data.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @customer_profile_id.nil? return false if @loyalty_program_id.nil? return false if @loyalty_program_id < 1 return false if @subledger_id.nil? return false if @current_tier.nil? return false if @current_points.nil? return false if @points_required_to_remain.nil? true end |