Class: TalonOne::UpdateApplication
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateApplication
- Defined in:
- lib/talon_one_sdk/models/update_application.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#attributes_settings ⇒ Object
Returns the value of attribute attributes_settings.
-
#case_sensitivity ⇒ Object
The case sensitivity behavior to check coupon codes in the campaigns of this Application.
-
#currency ⇒ Object
The default currency for new customer sessions.
-
#default_cart_item_filter_id ⇒ Object
The ID of the default Cart-Item-Filter for this application.
-
#default_discount_additional_cost_per_item_scope ⇒ Object
The default scope to apply ‘setDiscountPerItem` effects on if no scope was provided with the effect.
-
#default_discount_scope ⇒ Object
The default scope to apply ‘setDiscount` effects on if no scope was provided with the effect.
-
#default_evaluation_group_id ⇒ Object
The ID of the default campaign evaluation group to which new campaigns will be added unless a different group is selected when creating the campaign.
-
#description ⇒ Object
A longer description of the application.
-
#enable_campaign_state_management ⇒ Object
Indicates whether the campaign staging and revisions feature is enabled for the Application.
-
#enable_cascading_discounts ⇒ Object
Indicates if discounts should cascade for this Application.
-
#enable_flattened_cart_items ⇒ Object
Indicates if cart items of quantity larger than one should be separated into different items of quantity one.
-
#enable_partial_discounts ⇒ Object
Indicates if this Application supports partial discounts.
-
#limits ⇒ Object
Default limits for campaigns created in this application.
-
#name ⇒ Object
The name of this application.
-
#sandbox ⇒ Object
Indicates if this is a live or sandbox Application.
-
#timezone ⇒ Object
A string containing an IANA timezone descriptor.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateApplication
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateApplication
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateApplication` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateApplication`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'case_sensitivity') self.case_sensitivity = attributes[:'case_sensitivity'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'default_discount_scope') self.default_discount_scope = attributes[:'default_discount_scope'] end if attributes.key?(:'enable_cascading_discounts') self.enable_cascading_discounts = attributes[:'enable_cascading_discounts'] end if attributes.key?(:'enable_flattened_cart_items') self.enable_flattened_cart_items = attributes[:'enable_flattened_cart_items'] end if attributes.key?(:'attributes_settings') self.attributes_settings = attributes[:'attributes_settings'] end if attributes.key?(:'sandbox') self.sandbox = attributes[:'sandbox'] end if attributes.key?(:'enable_partial_discounts') self.enable_partial_discounts = attributes[:'enable_partial_discounts'] end if attributes.key?(:'default_discount_additional_cost_per_item_scope') self.default_discount_additional_cost_per_item_scope = attributes[:'default_discount_additional_cost_per_item_scope'] end if attributes.key?(:'default_evaluation_group_id') self.default_evaluation_group_id = attributes[:'default_evaluation_group_id'] end if attributes.key?(:'default_cart_item_filter_id') self.default_cart_item_filter_id = attributes[:'default_cart_item_filter_id'] end if attributes.key?(:'enable_campaign_state_management') self.enable_campaign_state_management = attributes[:'enable_campaign_state_management'] end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
34 35 36 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 34 def attributes @attributes end |
#attributes_settings ⇒ Object
Returns the value of attribute attributes_settings.
48 49 50 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 48 def attributes_settings @attributes_settings end |
#case_sensitivity ⇒ Object
The case sensitivity behavior to check coupon codes in the campaigns of this Application.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 31 def case_sensitivity @case_sensitivity end |
#currency ⇒ Object
The default currency for new customer sessions.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 28 def currency @currency end |
#default_cart_item_filter_id ⇒ Object
The ID of the default Cart-Item-Filter for this application.
63 64 65 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 63 def default_cart_item_filter_id @default_cart_item_filter_id end |
#default_discount_additional_cost_per_item_scope ⇒ Object
The default scope to apply ‘setDiscountPerItem` effects on if no scope was provided with the effect.
57 58 59 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 57 def default_discount_additional_cost_per_item_scope @default_discount_additional_cost_per_item_scope end |
#default_discount_scope ⇒ Object
The default scope to apply ‘setDiscount` effects on if no scope was provided with the effect.
40 41 42 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 40 def default_discount_scope @default_discount_scope end |
#default_evaluation_group_id ⇒ Object
The ID of the default campaign evaluation group to which new campaigns will be added unless a different group is selected when creating the campaign.
60 61 62 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 60 def default_evaluation_group_id @default_evaluation_group_id end |
#description ⇒ Object
A longer description of the application.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 22 def description @description end |
#enable_campaign_state_management ⇒ Object
Indicates whether the campaign staging and revisions feature is enabled for the Application. Important: After this feature is enabled, it cannot be disabled.
66 67 68 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 66 def enable_campaign_state_management @enable_campaign_state_management end |
#enable_cascading_discounts ⇒ Object
Indicates if discounts should cascade for this Application.
43 44 45 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 43 def enable_cascading_discounts @enable_cascading_discounts end |
#enable_flattened_cart_items ⇒ Object
Indicates if cart items of quantity larger than one should be separated into different items of quantity one.
46 47 48 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 46 def enable_flattened_cart_items @enable_flattened_cart_items end |
#enable_partial_discounts ⇒ Object
Indicates if this Application supports partial discounts.
54 55 56 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 54 def enable_partial_discounts @enable_partial_discounts end |
#limits ⇒ Object
Default limits for campaigns created in this application.
37 38 39 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 37 def limits @limits end |
#name ⇒ Object
The name of this application.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 19 def name @name end |
#sandbox ⇒ Object
Indicates if this is a live or sandbox Application.
51 52 53 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 51 def sandbox @sandbox end |
#timezone ⇒ Object
A string containing an IANA timezone descriptor.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 25 def timezone @timezone end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
114 115 116 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 114 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
119 120 121 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 119 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 91 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'timezone' => :'timezone', :'currency' => :'currency', :'case_sensitivity' => :'caseSensitivity', :'attributes' => :'attributes', :'limits' => :'limits', :'default_discount_scope' => :'defaultDiscountScope', :'enable_cascading_discounts' => :'enableCascadingDiscounts', :'enable_flattened_cart_items' => :'enableFlattenedCartItems', :'attributes_settings' => :'attributesSettings', :'sandbox' => :'sandbox', :'enable_partial_discounts' => :'enablePartialDiscounts', :'default_discount_additional_cost_per_item_scope' => :'defaultDiscountAdditionalCostPerItemScope', :'default_evaluation_group_id' => :'defaultEvaluationGroupId', :'default_cart_item_filter_id' => :'defaultCartItemFilterId', :'enable_campaign_state_management' => :'enableCampaignStateManagement' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 407 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
147 148 149 150 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 147 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 124 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'timezone' => :'String', :'currency' => :'String', :'case_sensitivity' => :'String', :'attributes' => :'Object', :'limits' => :'Array<LimitConfig>', :'default_discount_scope' => :'String', :'enable_cascading_discounts' => :'Boolean', :'enable_flattened_cart_items' => :'Boolean', :'attributes_settings' => :'AttributesSettings', :'sandbox' => :'Boolean', :'enable_partial_discounts' => :'Boolean', :'default_discount_additional_cost_per_item_scope' => :'String', :'default_evaluation_group_id' => :'Integer', :'default_cart_item_filter_id' => :'Integer', :'enable_campaign_state_management' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 370 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && timezone == o.timezone && currency == o.currency && case_sensitivity == o.case_sensitivity && attributes == o.attributes && limits == o.limits && default_discount_scope == o.default_discount_scope && enable_cascading_discounts == o.enable_cascading_discounts && enable_flattened_cart_items == o.enable_flattened_cart_items && attributes_settings == o.attributes_settings && sandbox == o.sandbox && enable_partial_discounts == o.enable_partial_discounts && default_discount_additional_cost_per_item_scope == o.default_discount_additional_cost_per_item_scope && default_evaluation_group_id == o.default_evaluation_group_id && default_cart_item_filter_id == o.default_cart_item_filter_id && enable_campaign_state_management == o.enable_campaign_state_management end |
#eql?(o) ⇒ Boolean
394 395 396 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 394 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
400 401 402 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 400 def hash [name, description, timezone, currency, case_sensitivity, attributes, limits, default_discount_scope, enable_cascading_discounts, enable_flattened_cart_items, attributes_settings, sandbox, enable_partial_discounts, default_discount_additional_cost_per_item_scope, default_evaluation_group_id, default_cart_item_filter_id, enable_campaign_state_management].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 247 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @timezone.nil? invalid_properties.push('invalid value for "timezone", timezone cannot be nil.') end if @timezone.to_s.length < 1 invalid_properties.push('invalid value for "timezone", the character length must be greater than or equal to 1.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @currency.to_s.length < 1 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 429 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/talon_one_sdk/models/update_application.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @timezone.nil? return false if @timezone.to_s.length < 1 return false if @currency.nil? return false if @currency.to_s.length < 1 case_sensitivity_validator = EnumAttributeValidator.new('String', ["sensitive", "insensitive-uppercase", "insensitive-lowercase"]) return false unless case_sensitivity_validator.valid?(@case_sensitivity) default_discount_scope_validator = EnumAttributeValidator.new('String', ["sessionTotal", "cartItems", "additionalCosts"]) return false unless default_discount_scope_validator.valid?(@default_discount_scope) default_discount_additional_cost_per_item_scope_validator = EnumAttributeValidator.new('String', ["price", "itemTotal", "additionalCosts"]) return false unless default_discount_additional_cost_per_item_scope_validator.valid?(@default_discount_additional_cost_per_item_scope) true end |