Class: TalonOne::UpdateCoupon
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateCoupon
- Defined in:
- lib/talon_one_sdk/models/update_coupon.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary properties associated with this item.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
-
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
-
#limits ⇒ Object
Limits configuration for a coupon.
-
#recipient_integration_id ⇒ Object
The integration ID for this coupon’s beneficiary’s profile.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCoupon
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCoupon
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCoupon` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCoupon`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'is_reservation_mandatory') self.is_reservation_mandatory = attributes[:'is_reservation_mandatory'] else self.is_reservation_mandatory = false end if attributes.key?(:'implicitly_reserved') self.implicitly_reserved = attributes[:'implicitly_reserved'] end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary properties associated with this item.
40 41 42 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 40 def attributes @attributes end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 22 def discount_limit @discount_limit end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 31 def expiry_date @expiry_date end |
#implicitly_reserved ⇒ Object
An indication of whether the coupon is implicitly reserved for all customers.
46 47 48 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 46 def implicitly_reserved @implicitly_reserved end |
#is_reservation_mandatory ⇒ Object
An indication of whether the code can be redeemed only if it has been reserved first.
43 44 45 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 43 def is_reservation_mandatory @is_reservation_mandatory end |
#limits ⇒ Object
Limits configuration for a coupon. These limits will override the limits set from the campaign. Note: Only usable when creating a single coupon which is not tied to a specific recipient. Only per-profile limits are allowed to be configured.
34 35 36 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 34 def limits @limits end |
#recipient_integration_id ⇒ Object
The integration ID for this coupon’s beneficiary’s profile.
37 38 39 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 37 def recipient_integration_id @recipient_integration_id end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 25 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 28 def start_date @start_date end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 19 def usage_limit @usage_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 49 def self.attribute_map { :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'limits' => :'limits', :'recipient_integration_id' => :'recipientIntegrationId', :'attributes' => :'attributes', :'is_reservation_mandatory' => :'isReservationMandatory', :'implicitly_reserved' => :'implicitlyReserved' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 315 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
97 98 99 100 101 102 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 97 def self.openapi_all_of [ :'CouponConstraints', :'CouponLimitConfigs' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 75 def self.openapi_types { :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'limits' => :'Array<LimitConfig>', :'recipient_integration_id' => :'String', :'attributes' => :'Object', :'is_reservation_mandatory' => :'Boolean', :'implicitly_reserved' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && limits == o.limits && recipient_integration_id == o.recipient_integration_id && attributes == o.attributes && is_reservation_mandatory == o.is_reservation_mandatory && implicitly_reserved == o.implicitly_reserved end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 308 def hash [usage_limit, discount_limit, reservation_limit, start_date, expiry_date, limits, recipient_integration_id, attributes, is_reservation_mandatory, implicitly_reserved].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@usage_limit.nil? && @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if !@usage_limit.nil? && @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/talon_one_sdk/models/update_coupon.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@usage_limit.nil? && @usage_limit > 999999 return false if !@usage_limit.nil? && @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 return false if !@recipient_integration_id.nil? && @recipient_integration_id.to_s.length > 1000 true end |