Class: TalonOne::UpdateCouponBatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateCouponBatch
- Defined in:
- lib/talon_one_sdk/models/update_coupon_batch.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Optional property to set the value of custom coupon attributes.
-
#batch_id ⇒ Object
The ID of the batch the coupon(s) belong to.
-
#discount_limit ⇒ Object
The total discount value that the code can give.
-
#expiry_date ⇒ Object
Expiration date of the coupon.
-
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
-
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
-
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCouponBatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCouponBatch
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCouponBatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCouponBatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'usage_limit') self.usage_limit = attributes[:'usage_limit'] end if attributes.key?(:'discount_limit') self.discount_limit = attributes[:'discount_limit'] end if attributes.key?(:'reservation_limit') self.reservation_limit = attributes[:'reservation_limit'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end end |
Instance Attribute Details
#attributes ⇒ Object
Optional property to set the value of custom coupon attributes. They are defined in the Campaign Manager, see [Managing attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes). Coupon attributes can also be set to mandatory in your Application [settings](docs.talon.one/docs/product/applications/using-attributes#making-attributes-mandatory). If your Application uses mandatory attributes, you must use this property to set their value.
34 35 36 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 34 def attributes @attributes end |
#batch_id ⇒ Object
The ID of the batch the coupon(s) belong to.
37 38 39 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 37 def batch_id @batch_id end |
#discount_limit ⇒ Object
The total discount value that the code can give. Typically used to represent a gift card value.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 22 def discount_limit @discount_limit end |
#expiry_date ⇒ Object
Expiration date of the coupon. Coupon never expires if this is omitted.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 31 def expiry_date @expiry_date end |
#reservation_limit ⇒ Object
The number of reservations that can be made with this coupon code.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 25 def reservation_limit @reservation_limit end |
#start_date ⇒ Object
Timestamp at which point the coupon becomes valid.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 28 def start_date @start_date end |
#usage_limit ⇒ Object
The number of times the coupon code can be redeemed. ‘0` means unlimited redemptions but any campaign usage limits will still apply.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 19 def usage_limit @usage_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 40 def self.attribute_map { :'usage_limit' => :'usageLimit', :'discount_limit' => :'discountLimit', :'reservation_limit' => :'reservationLimit', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'attributes' => :'attributes', :'batch_id' => :'batchID' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
82 83 84 85 86 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 82 def self.openapi_all_of [ :'CouponConstraints' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 63 def self.openapi_types { :'usage_limit' => :'Integer', :'discount_limit' => :'Float', :'reservation_limit' => :'Integer', :'start_date' => :'Time', :'expiry_date' => :'Time', :'attributes' => :'Object', :'batch_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && usage_limit == o.usage_limit && discount_limit == o.discount_limit && reservation_limit == o.reservation_limit && start_date == o.start_date && expiry_date == o.expiry_date && attributes == o.attributes && batch_id == o.batch_id end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 254 def hash [usage_limit, discount_limit, reservation_limit, start_date, expiry_date, attributes, batch_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@usage_limit.nil? && @usage_limit > 999999 invalid_properties.push('invalid value for "usage_limit", must be smaller than or equal to 999999.') end if !@usage_limit.nil? && @usage_limit < 0 invalid_properties.push('invalid value for "usage_limit", must be greater than or equal to 0.') end if !@discount_limit.nil? && @discount_limit > 1000000000000000 invalid_properties.push('invalid value for "discount_limit", must be smaller than or equal to 1000000000000000.') end if !@discount_limit.nil? && @discount_limit < 0 invalid_properties.push('invalid value for "discount_limit", must be greater than or equal to 0.') end if !@reservation_limit.nil? && @reservation_limit > 999999 invalid_properties.push('invalid value for "reservation_limit", must be smaller than or equal to 999999.') end if !@reservation_limit.nil? && @reservation_limit < 0 invalid_properties.push('invalid value for "reservation_limit", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/talon_one_sdk/models/update_coupon_batch.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@usage_limit.nil? && @usage_limit > 999999 return false if !@usage_limit.nil? && @usage_limit < 0 return false if !@discount_limit.nil? && @discount_limit > 1000000000000000 return false if !@discount_limit.nil? && @discount_limit < 0 return false if !@reservation_limit.nil? && @reservation_limit > 999999 return false if !@reservation_limit.nil? && @reservation_limit < 0 true end |