Class: TalonOne::UpdateReward
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TalonOne::UpdateReward
- Defined in:
- lib/talon_one_sdk/models/update_reward.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bindings ⇒ Object
A list of named variables created before the reward’s rules are evaluated.
-
#description ⇒ Object
A description of the reward.
-
#name ⇒ Object
The name of the reward.
-
#rule ⇒ Object
Rule to apply.
-
#status ⇒ Object
The status of the reward.
-
#visibility_conditions ⇒ Object
An optional rule that manages who can see this reward.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateReward
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateReward
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateReward` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateReward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'visibility_conditions') self.visibility_conditions = attributes[:'visibility_conditions'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'bindings') if (value = attributes[:'bindings']).is_a?(Array) self.bindings = value end end end |
Instance Attribute Details
#bindings ⇒ Object
A list of named variables created before the reward’s rules are evaluated. Each binding pairs a name with a talang expression. The expression is evaluated once and its result is available by name in any rule condition or effect. Bindings must be defined outside of individual rules.
34 35 36 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 34 def bindings @bindings end |
#description ⇒ Object
A description of the reward.
22 23 24 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 22 def description @description end |
#name ⇒ Object
The name of the reward.
19 20 21 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 19 def name @name end |
#rule ⇒ Object
Rule to apply. Note: The ‘bindings` field inside the rule must not be used in this endpoint. All bindings should be defined at the reward level via the top-level `bindings` field.
31 32 33 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 31 def rule @rule end |
#status ⇒ Object
The status of the reward.
25 26 27 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 25 def status @status end |
#visibility_conditions ⇒ Object
An optional rule that manages who can see this reward. If not specified, the reward is visible to all customers. Note: Only the ‘condition` field is evaluated within this rule. The `effects` field must be an empty array, and `bindings` are not supported.
28 29 30 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 28 def visibility_conditions @visibility_conditions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 59 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'status' => :'status', :'visibility_conditions' => :'visibilityConditions', :'rule' => :'rule', :'bindings' => :'bindings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 81 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'status' => :'String', :'visibility_conditions' => :'Rule', :'rule' => :'Rule', :'bindings' => :'Array<Binding>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && status == o.status && visibility_conditions == o.visibility_conditions && rule == o.rule && bindings == o.bindings end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 222 def hash [name, description, status, visibility_conditions, rule, bindings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one_sdk/models/update_reward.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "inactive"]) return false unless status_validator.valid?(@status) true end |